% File src/library/base/man/DateTimeClasses.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{DateTimeClasses}
% implementation mostly in ../R/datetime.R
\alias{DateTimeClasses}
\alias{POSIXct}
\alias{POSIXlt}
\alias{POSIXt}
\alias{print.POSIXct}
\alias{print.POSIXlt}
\alias{summary.POSIXct}
\alias{summary.POSIXlt}
\alias{+.POSIXt}
\alias{-.POSIXt}
\alias{Ops.POSIXt}
\alias{Math.POSIXt}
\alias{Summary.POSIXct}
\alias{Math.POSIXlt}
\alias{Summary.POSIXlt}
\alias{[.POSIXct}
\alias{[<-.POSIXct}
\alias{[[.POSIXct}
\alias{[.POSIXlt}
\alias{[<-.POSIXlt}
\alias{as.data.frame.POSIXct}
\alias{as.data.frame.POSIXlt}
\alias{as.list.POSIXct}
\alias{.leap.seconds}
\alias{anyNA.POSIXlt}
\alias{is.na.POSIXlt}
\alias{c.POSIXct}
\alias{c.POSIXlt}
\alias{as.matrix.POSIXlt}
\alias{length.POSIXlt}
\alias{mean.POSIXct}
\alias{mean.POSIXlt}
\alias{str.POSIXt}
\alias{check_tzones}
\alias{duplicated.POSIXlt}
\alias{unique.POSIXlt}
\alias{split.POSIXct}
\alias{names.POSIXlt}
\alias{names<-.POSIXlt}

\alias{date-time} % linked to in difftime.Rd

\title{Date-Time Classes}
\description{
  暦日と時刻を表すクラス \code{"POSIXlt"} と \code{"POSIXct"} の説明．
}
\usage{
\method{print}{POSIXct}(x, \dots)

\method{summary}{POSIXct}(object, digits = 15, \dots)

\special{time + z}
\special{z + time}
\special{time - z}
\special{time1 lop time2}
}
\arguments{
  \item{x, object}{プリントもしくは要約されるべき日付-時刻クラスの一つからのオブジェクト．}
  \item{digits}{計算に対する有効桁数：
    最小の重要な時刻を正確に表現するのに必要なだけ大きい必要がある．}
  \item{\dots}{他のメソッドへ・から引き渡される追加引数．}
  \item{time}{日付-時刻オブジェクト}
  \item{time1, time2}{日付-時刻オブジェクトもしくは文字列ベクトル． (文字列ベクトルは
    \code{\link{as.POSIXct}} により強制変換される．)}
  \item{z}{(秒単位の)数値ベクトル}
  \item{lop}{次の一つ \code{==}, \code{!=}, \code{<}, \code{<=}, \code{>}
    または \code{>=}．}
}
\details{
基本になる日付/時刻クラスが二つある．クラス Class \code{"POSIXct"} 
は1970年(UTC タイムゾーンの)初めからの(符号付き)秒数を数値ベクトルとして表現する．
クラス \code{"POSIXlt"} は以下のベクトルの名前付きリスト
  \describe{
    \item{\code{sec}}{0--61: 秒．}
    \item{\code{min}}{0--59: 分．}
    \item{\code{hour}}{0--23: 時．}
    \item{\code{mday}}{1--31: 月始めからの日数．}
    \item{\code{mon}}{0--11: 新年以来の月数．}
    \item{\code{year}}{１９００年以来の年数．}
    \item{\code{wday}}{日曜日から始まる週の日数 0--6．}
    \item{\code{yday}}{0--365: 一年の日数．}
    \item{\code{isdst}}{DST(Day-Saving Time，サマータイム)のフラグ．
      サマータイム中なら正，そうでなければゼロ，未知なら負．}
    \item{\code{zone}}{(オプション．) その時に実効的なタイムゾーンの略称：
      未知なら \code{""} (しかし \code{""} はまた UTC に対しても使われる可能性がある).}
    \item{\code{gmtoff}}{(オプション．) GMT からの秒数のオフセット：
      正値は子午線の東．未知ならば普通 \code{NA} であるが，
      \code{0} が未知を表すこともある．}
  }
(最後の二つの成分は UTC 時刻では不在で，プラットフォーム依存である：
BSD や \code{glibc} がサポートする(Linux と OS X を含む)プラットフォームや，
\R と共に出荷される \code{tzcode} の移植を使う(Windows を含む)ものを
含む．しかしそれらは必ずしも設定されていない．)
多くのメソッド (\code{\link{length}(x)}, \code{\link{print}()} そして \code{\link{str}})
が \code{"POSIXct"} のような抽象的な日付-時刻ベクトルに適用されるため，
内部的なリスト構造はいくらか隠蔽されている．これらのクラスは 
  \sQuote{calendar  time} (\code{time_t} データ型) と \sQuote{local time} (または 
破損した時刻，\code{struct tm} データ型) の POSIX/C99 構成に対応し，そこから
名称を受け継いでいる．\code{"POSIXlt"} の成分は，\code{sec} と \code{zone} を
除いて整数ベクトルである．

\code{"POSIXct"} はデータフレームに含むのにより便利である．そして
\code{"POSIXlt"} はより可読性が高い．仮想的なクラス 
\code{"POSIXt"} が存在し，二つのクラスはそれを継承する：
これは二つのクラスを混ぜあわせるために減算等の操作を許すのに使われる．

%  \code{"POSIXct"} is more convenient for including in data frames, and
%  \code{"POSIXlt"} is closer to human-readable forms.  A virtual class
%  \code{"POSIXt"} exists from which both of the classes inherit: it is
%  used to allow operations such as subtraction to mix the two classes.

\code{"POSIXlt"} の成分 \code{wday} と \code{yday} は情報用で，
暦日への変換では使われない．しかしながら \code{isdst} はサマータイムの
最後における時間を区別するために必要とされる： 典型的には午前１時から
２時が2回，最初にサマータイム中，次に標準的な時間中，に起きる．

%  Components \code{wday} and \code{yday} of \code{"POSIXlt"} are for
%  information, and are not used in the conversion to calendar time.
%  However, \code{isdst} is needed to distinguish times at the end of
%  DST: typically 1am to 2am occurs twice, first in DST and then in
%  standard time.  At all other times \code{isdst} can be deduced from
%  the first six values, but the behaviour if it is set incorrectly is
%  platform-dependent.
%  % POSIX says used 'initially', so it should probably be ignored.
%  % glibc has a complicated fixup.

双方のクラスに対して論理比較と幾つかの算術演算が利用できる．
日付-時間オブジェクトから秒数を加算，減産できるが，二つの日付-時間クラス
を加えることはできない．二つの日付-時間クラスの差は \code{\link{difftime}}
の利用と同値である． 特にタイムゾーンが指定されない限り，\code{"POSIXlt"} は
こうした演算では現在のタイムゾーン中にあると解釈されることを注意しよう．

%  Logical comparisons and some arithmetic operations are available for
%  both classes.  One can add or subtract a number of seconds from a
%  date-time object, but not add two date-time objects.  Subtraction of
%  two date-time objects is equivalent to using \code{\link{difftime}}.
%  Be aware that \code{"POSIXlt"} objects will be interpreted as being in
%  the current time zone for these operations unless a time zone has been
%  specified.

\code{"POSIXlt"} オブジェクトはしばしば属性 \code{"tzone"} を持つ．
これは長さ3の文字列ベクトルで，\env{TZ} 環境変数からのタイムゾーン名，
基本タイムゾーン名，そしてもうひとつの(サマータイム)タイムゾーン名を与える．
時折これは唯の長さ1であることがあり，\link{time zone} 名を与える．

%  \code{"POSIXct"} objects may also have an attribute \code{"tzone"}, a
%  character vector of length one.  If set to a non-empty value, it will
%  determine how the object is converted to class \code{"POSIXlt"} and in
%  particular how it is printed.  This is usually desirable, but if you
%  want to specify an object in a particular time zone but to be printed
%  in the current time zone you may want to remove the \code{"tzone"}
%  attribute (e.g., by \code{c(x)}).

不幸なことに変換はタイムゾーンと閏秒の操作で複雑である
(26日間がこれまで86401秒の長さであった．執筆時の最後は2015年に
付け加えられた．余分の秒の時間はオブジェクト  \code{.leap.seconds} にある．)
これの詳細は可能ならばOSのサービスに委託されている．
幾つかの稀なシステムは閏秒を使っていたようだが，すべての現在の既知の
プラットフォームはそれらを無視する(POSIXが要請するように)．
これは構築時に検出・訂正されるので， \R が使う \code{"POSIXct"}  時間は
いかなるプラットフォームでも閏秒を含まない．

%  Unfortunately, the conversion is complicated by the operation of time
%  zones and leap seconds (26 days have been 86401 seconds long so far,
%  the last at the time of writing being added in 2015: the times of the
%  extra seconds are in the object \code{.leap.seconds}).  The details of
%  this are entrusted to the OS services where possible.  It seems that
%  some rare systems used to use leap seconds, but all known current
%  platforms ignore them (as required by POSIX).  This is detected and
%  corrected for at build time, so \code{"POSIXct"} times used by \R do
%  not include leap seconds on any platform.

\code{"POSIXlt"} オブジェクト上で \code{\link{c}} を使うとそれらは
現在のタイムゾーンに変換され，\code{"POSIXｃｔ"} オブジェクト上ではすべての
 \code{"tzone"} 属性を捨てさる(たとえそれらがすべて同じタイムゾーンを
使っていても)．

%  Using \code{\link{c}} on \code{"POSIXlt"} objects converts them to the
%  current time zone, and on \code{"POSIXct"} objects drops any
%  \code{"tzone"} attributes (even if they are all marked with the same
%  time zone).

幾つかの時刻は特別な問題を持つ．まず，閏秒が無視され，
\code{"2005-12-31 23:59:60"} のような実時間は
(おそらく)次の秒として扱われる．しかしながら，これらは \R では決して
起こらないであろうし，入力としてもありそうもない．
次に，幾つかの OS では \code{"1969-12-31 23:59:59 UTC"} に関して
 POSIX/C99標準が問題を持つ．これは暦日としては \code{-1} であり，
 これはそうした OS ではエラーコードの一つとして使われている．
従って \code{as.POSIXct("1969-12-31 23:59:59", format = "\%Y-\%m-\%d \%H:\%M:\%S", tz = "UTC")}
は \code{NA} を与えるかもしれず，故に \code{as.POSIXct("1969-12-31 23:59:59",
 tz = "UTC")} は \code{"1969-12-31 23:59:00"} を与える．他の OS 
(Windows で使われている \R のコードを含む)は別個にエラーを報告し，
従ってこの時刻を適正として処理できる．

%  A few times have specific issues.  First, the leap seconds are ignored,
%  and real times such as \code{"2005-12-31 23:59:60"} are (probably)
%  treated as the next second.  However, they will never be generated by
%  \R, and are unlikely to arise as input.  Second, on some OSes there is
%  a problem in the POSIX/C99 standard with \code{"1969-12-31 23:59:59 UTC"},
%  which is \code{-1} in calendar time and that value is on those OSes
%  also used as an error code.  Thus \code{as.POSIXct("1969-12-31
%  23:59:59", format = "\%Y-\%m-\%d \%H:\%M:\%S", tz = "UTC")} may give
%  \code{NA}, and hence \code{as.POSIXct("1969-12-31 23:59:59",
%  tz = "UTC")} will give \code{"1969-12-31 23:59:00"}.  Other OSes
%  (including the code used by \R on Windows) report errors separately
%  and so are able to handle that time as valid.
%  The print methods respect \code{\link{options}("max.print")}.
%}

  プリントメソッドは \code{\link{options}("max.print")} を尊重する．
}

\section{1秒以下の正確さ}{
クラス \code{"POSIXct"} と \code{"POSIXlt"} は分数秒を表現できる．
(二つの形式間での分数の変換は正確ではないかもしれないが，
マイクロ秒以上の正確さを持つであろう．)

分数秒は \code{\link{options}("digits.secs")} が設定されている時だけ
プリントされる： \code{\link{strftime}} を見よ．
}

%\section{Sub-second Accuracy}{
%  Classes \code{"POSIXct"} and  \code{"POSIXlt"} are able to express
%  fractions of a second.  (Conversion of fractions between the two forms
%  may not be exact, but will have better than microsecond accuracy.)
%  Fractional seconds are printed only if
%  \code{\link{options}("digits.secs")} is set: see \code{\link{strftime}}.
%}

\section{適正な時間範囲}{
\code{"POSIXlt"} クラスは非常に広い時刻範囲を表現できる(数百万年)が，
そうした時刻はあるタイムゾーンを参照してのみ解釈できる．
  
%\section{Valid ranges for times}{
%  The \code{"POSIXlt"} class can represent a very wide range of times (up
%  to billions of years), but such times can only be interpreted with
%  reference to a time zone.

  % https://www.timeanddate.com/calendar/julian-gregorian-switch.html
タイムゾーンの概念は17世紀に導入され，グレゴリオ暦は1582年に導入されたが
1927年までは広く受け入れられなかった．
OSサービスはほとんど変わらずにグレゴリオ暦を仮定しており，地域で規定された
タイムゾーンがその日付に有効と仮定しているかもしれない．
(最も初期の法制化されたタイムゾーンは1847-12-01のロンドンである．)
ある種のOSはタイムゾーン内の位置の経度に基づいた \sQuote{ローカルタイム} の
以前の使用を仮定している．

%  % https://www.timeanddate.com/calendar/julian-gregorian-switch.html
%  The concept of time zones was first adopted in the nineteenth century,
%  and the Gregorian calendar was introduced in 1582 but not universally
%  adopted until 1927.  OS services almost invariably assume the
%  Gregorian calendar and may assume that the time zone that was first
%  enacted for the location was in force before that date.  (The earliest
%  legislated time zone seems to have been London on 1847-12-01.)  Some
%  OSes assume the previous use of \sQuote{local time} based on the
%  longitude of a location within the time zone.
%  % from the Olson files.
  
殆どのOSは \code{POSIXct} 時刻を C 型の  \code{long} として
表現している． これは32ビット OS では期間1902年から2037年をカバーする
ことを意味する．  すべての既知の64ビット プラットフォームと我々が３２ビットWindowsで
使っているコードに対しては，表示可能な時刻範囲は数百万年である．
しかしながら全てが1902年以前と2037年以降を正確にカバーするわけではない．
符号なし型を使い従って1970年以前の時刻を表現できなかった無知蒙昧なOSが
幾つかある．
  
%  Most operating systems represent \code{POSIXct} times as C type
%  \code{long}. This means that on 32-bit OSes this covers the period
%  1902 to 2037.  On all known 64-bit platforms and for the code we use
%  on 32-bit Windows, the range of representable times is billions of
%  years: however, not all can convert correctly times before 1902 or
%  after 2037.  A few benighted OSes used a unsigned type and so cannot
%  represent times before 1970.
%  % glibc in 2003/4, AIX?

可能な場合はプラットフォームの限界が検出される．
そして限界外では我々は独自の自前の C コードを使う．
これは，1902年(当時はサマータイムが存在しなかった)や予測された
2030年から2037年に対して(DSTへの移行が同様に日曜日だとして
選ばれた)使用されているGMTからのオフセットを使う．
そして  \code{isdst} が正であるか，(もし \code{-1} ならば)またはもし
DSTが2030年以降のその日に使用されているならば，
別の(サマータイム)タイムゾーンを使う．

%  Where possible the platform limits are detected, and outside
%  the limits we use our own C code.  This uses the offset from
%  GMT in use either for 1902 (when there was no DST) or that predicted
%  for one of 2030 to 2037 (chosen so that the likely DST transition days
%  are Sundays), and uses the alternate (daylight-saving) time zone only
%  if \code{isdst} is positive or (if \code{-1}) if DST was predicted to
%  be in operation in the 2030s on that day.

UTCからのオフセットが1902年以前では変わる土地(例えばローマ)があることを
注意しよう．これらはOSのサポートがある場合だけ正確に処理される．

%  Note that there are places (e.g., Rome) whose offset from UTC varied
%  in the years prior to 1902, and these will be handled correctly only
%  where there is OS support.

DST 規則が将来も残ると仮定する理由はない．実際USは2005年に将来復帰する
可能性と共に，それを2007年から変更することを決定した．従って一年，二年間を超える
変換は不確かである．
}

%  There is no reason to suppose that the DST rules will remain the same
%  in the future, and indeed the US legislated in 2005 to change its
%  rules as from 2007, with a possible future reversion.  So conversions
%  for times more than a year or two ahead are speculative.  
%}

\seealso{
時刻なしの日付に対しては \link{Dates}．
クラス間の変換については \code{\link{as.POSIXct}} と \code{\link{as.POSIXlt}}．

文字列表現への・からの変換については \code{\link{strptime}}．

\code{"POSIXct"} オブジェクトとしての時刻については \code{\link{Sys.time}}．

時間差については \code{\link{difftime}}．

これらのクラスに対するメソッドについては \code{\link{cut.POSIXt}}, \code{\link{seq.POSIXt}},
\code{\link{round.POSIXt}} そして \code{\link{trunc.POSIXt}}．

  便利な抽出関数については \code{\link{weekdays}}．}

%\seealso{
%  \link{Dates} for dates without times.
%  \code{\link{as.POSIXct}} and \code{\link{as.POSIXlt}} for conversion
%  between the classes.
%
%  \code{\link{strptime}} for conversion to and from character
%  representations.
%
%  \code{\link{Sys.time}} for clock time as a \code{"POSIXct"} object.
%
%  \code{\link{difftime}} for time intervals.
%
%  \code{\link{cut.POSIXt}}, \code{\link{seq.POSIXt}},
%  \code{\link{round.POSIXt}} and \code{\link{trunc.POSIXt}} for methods
%  for these classes.
%
%  \code{\link{weekdays}} for convenience extraction functions.
%}

\references{
  Ripley, B. D. and Hornik, K. (2001) Date-time classes. \emph{R News},
  \bold{1/2}, 8--11.
  \url{https://www.r-project.org/doc/Rnews/Rnews_2001-2.pdf}
}

\section{警告}{
ある種の Unix 風システム(特に Linux) では環境変数 \env{TZ} が設定
されていないが，一方でそれを必要とする内部コード(POSIX がそうであるように)を持つ．
我々はこれを解決すべく努力してきたが，もし予期せぬ事態が起きたら \env{TZ} を
設定してみること．適正な設定については \code{\link{Sys.timezone}} を見よ．

クラス \code{"POSIXlt"} のオブジェクトを比較する際には細心の注意が要る．
成分と属性がオプションであるだけでなく，幾つかの成分は \sQuote{まだ未定} 
を意味する値を持ちながら，同時に異なったタイムゾーンでは全く異なった
体裁で表示されることがある．
}

%Some Unix-like systems (especially Linux ones) do not have environment
%  variable \env{TZ} set, yet have internal code that expects it (as does
%  POSIX).  We have tried to work around this, but if you get unexpected
%  results try setting \env{TZ}.  See \code{\link{Sys.timezone}} for
%  valid settings.
%
%  Great care is needed when comparing objects of class \code{"POSIXlt"}.
%  Not only are components and attributes optional; several components
%  may have values meaning \sQuote{not yet determined} and the same time
%  represented in different time zones will look quite different.
%}

\examples{\donttest{% <-->  不良に設定されたプラットフォームでは失敗の可能性
(z <- Sys.time())             # クラス "POSIXct" としての現在の日付，

Sys.time() - 3600             # 一時間前

as.POSIXlt(Sys.time(), "GMT") # GMTでの現在時刻
format(.leap.seconds)         # 使用タイムゾーンでの閏秒
print(.leap.seconds, tz = "PST8PDT")  # Seattle では

##  "POSIXlt" の*内部*表現を眺める：
leapS <- as.POSIXlt(.leap.seconds)
names(leapS) ; is.list(leapS)
## str() "スマートすぎる" -->  unclass(.) が必要:
utils::str(unclass(leapS), vec.len = 7)
}}
\keyword{utilities}
\keyword{chron}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/DateTimeClasses.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{DateTimeClasses}
%% implementation mostly in ../R/datetime.R
%\alias{DateTimeClasses}
%\alias{POSIXct}
%\alias{POSIXlt}
%\alias{POSIXt}
%\alias{print.POSIXct}
%\alias{print.POSIXlt}
%\alias{summary.POSIXct}
%\alias{summary.POSIXlt}
%\alias{+.POSIXt}
%\alias{-.POSIXt}
%\alias{Ops.POSIXt}
%\alias{Math.POSIXt}
%\alias{Summary.POSIXct}
%\alias{Math.POSIXlt}
%\alias{Summary.POSIXlt}
%\alias{[.POSIXct}
%\alias{[<-.POSIXct}
%\alias{[[.POSIXct}
%\alias{[.POSIXlt}
%\alias{[<-.POSIXlt}
%\alias{as.data.frame.POSIXct}
%\alias{as.data.frame.POSIXlt}
%\alias{as.list.POSIXct}
%\alias{.leap.seconds}
%\alias{anyNA.POSIXlt}
%\alias{is.na.POSIXlt}
%\alias{c.POSIXct}
%\alias{c.POSIXlt}
%\alias{as.matrix.POSIXlt}
%\alias{length.POSIXlt}
%\alias{mean.POSIXct}
%\alias{mean.POSIXlt}
%\alias{str.POSIXt}
%\alias{check_tzones}
%\alias{duplicated.POSIXlt}
%\alias{unique.POSIXlt}
%\alias{split.POSIXct}
%\alias{names.POSIXlt}
%\alias{names<-.POSIXlt}
%
%\alias{date-time} % linked to in difftime.Rd
%
%\title{Date-Time Classes}
%\description{
%  Description of the classes \code{"POSIXlt"} and \code{"POSIXct"}
%  representing calendar dates and times.
%}
%\usage{
%\method{print}{POSIXct}(x, \dots)
%
%\method{summary}{POSIXct}(object, digits = 15, \dots)
%
%\special{time + z}
%\special{z + time}
%\special{time - z}
%\special{time1 lop time2}
%}
%\arguments{
%  \item{x, object}{An object to be printed or summarized from one of the
%    date-time classes.}
%  \item{digits}{Number of significant digits for the computations:
%    should be high enough to represent the least important time unit
%    exactly.}
%  \item{\dots}{Further arguments to be passed from or to other methods.}
%  \item{time}{date-time objects}
%  \item{time1, time2}{date-time objects or character vectors.  (Character
%    vectors are converted by \code{\link{as.POSIXct}}.)}
%  \item{z}{a numeric vector (in seconds)}
%  \item{lop}{One of \code{==}, \code{!=}, \code{<}, \code{<=}, \code{>}
%    or \code{>=}.}
%}
%\details{
%  There are two basic classes of date/times.  Class \code{"POSIXct"}
%  represents the (signed) number of seconds since the beginning of 1970
%  (in the UTC time zone) as a numeric vector.  Class \code{"POSIXlt"} is
%  a named list of vectors representing
%  \describe{
%    \item{\code{sec}}{0--61: seconds.}
%    \item{\code{min}}{0--59: minutes.}
%    \item{\code{hour}}{0--23: hours.}
%    \item{\code{mday}}{1--31: day of the month}
%    \item{\code{mon}}{0--11: months after the first of the year.}
%    \item{\code{year}}{years since 1900.}
%    \item{\code{wday}}{0--6 day of the week, starting on Sunday.}
%    \item{\code{yday}}{0--365: day of the year.}
%    \item{\code{isdst}}{Daylight Saving Time flag.  Positive if in
%      force, zero if not, negative if unknown.}
%    \item{\code{zone}}{(Optional.) The abbreviation for the time zone in
%      force at that time: \code{""} if unknown (but \code{""} might also
%      be used for UTC).}
%    \item{\code{gmtoff}}{(Optional.) The offset in seconds from GMT:
%      positive values are East of the meridian.  Usually \code{NA} if
%      unknown, but \code{0} could mean unknown.}
%  }
%  (The last two components are not present for times in UTC and are
%  platform-dependent: they are supported on platforms based on BSD or
%  \code{glibc} (including Linux and OS X) and those using the
%  \code{tzcode} implementation shipped with \R (including Windows). But
%  they are not necessarily set.).  Note that the internal list structure
%  is somewhat hidden, as many methods (including
%  \code{\link{length}(x)}, \code{\link{print}()} and \code{\link{str}})
%  apply to the abstract date-time vector, as for \code{"POSIXct"}.  The
%  classes correspond to the POSIX/C99 constructs of \sQuote{calendar
%  time} (the \code{time_t} data type) and \sQuote{local time} (or
%  broken-down time, the \code{struct tm} data type), from which they
%  also inherit their names.  The components of \code{"POSIXlt"} are
%  integer vectors, except \code{sec} and \code{zone}.
%
%  \code{"POSIXct"} is more convenient for including in data frames, and
%  \code{"POSIXlt"} is closer to human-readable forms.  A virtual class
%  \code{"POSIXt"} exists from which both of the classes inherit: it is
%  used to allow operations such as subtraction to mix the two classes.
%
%  Components \code{wday} and \code{yday} of \code{"POSIXlt"} are for
%  information, and are not used in the conversion to calendar time.
%  However, \code{isdst} is needed to distinguish times at the end of
%  DST: typically 1am to 2am occurs twice, first in DST and then in
%  standard time.  At all other times \code{isdst} can be deduced from
%  the first six values, but the behaviour if it is set incorrectly is
%  platform-dependent.
%  % POSIX says used 'initially', so it should probably be ignored.
%  % glibc has a complicated fixup.
%
%  Logical comparisons and some arithmetic operations are available for
%  both classes.  One can add or subtract a number of seconds from a
%  date-time object, but not add two date-time objects.  Subtraction of
%  two date-time objects is equivalent to using \code{\link{difftime}}.
%  Be aware that \code{"POSIXlt"} objects will be interpreted as being in
%  the current time zone for these operations unless a time zone has been
%  specified.
%
%  \code{"POSIXlt"} objects will often have an attribute \code{"tzone"},
%  a character vector of length 3 giving the time zone name from the
%  \env{TZ} environment variable and the names of the base time zone
%  and the alternate (daylight-saving) time zone.  Sometimes this may
%  just be of length one, giving the \link{time zone} name.
%
%  \code{"POSIXct"} objects may also have an attribute \code{"tzone"}, a
%  character vector of length one.  If set to a non-empty value, it will
%  determine how the object is converted to class \code{"POSIXlt"} and in
%  particular how it is printed.  This is usually desirable, but if you
%  want to specify an object in a particular time zone but to be printed
%  in the current time zone you may want to remove the \code{"tzone"}
%  attribute (e.g., by \code{c(x)}).
%
%  Unfortunately, the conversion is complicated by the operation of time
%  zones and leap seconds (26 days have been 86401 seconds long so far,
%  the last at the time of writing being added in 2015: the times of the
%  extra seconds are in the object \code{.leap.seconds}).  The details of
%  this are entrusted to the OS services where possible.  It seems that
%  some rare systems used to use leap seconds, but all known current
%  platforms ignore them (as required by POSIX).  This is detected and
%  corrected for at build time, so \code{"POSIXct"} times used by \R do
%  not include leap seconds on any platform.
%
%  Using \code{\link{c}} on \code{"POSIXlt"} objects converts them to the
%  current time zone, and on \code{"POSIXct"} objects drops any
%  \code{"tzone"} attributes (even if they are all marked with the same
%  time zone).
%
%  A few times have specific issues.  First, the leap seconds are ignored,
%  and real times such as \code{"2005-12-31 23:59:60"} are (probably)
%  treated as the next second.  However, they will never be generated by
%  \R, and are unlikely to arise as input.  Second, on some OSes there is
%  a problem in the POSIX/C99 standard with \code{"1969-12-31 23:59:59 UTC"},
%  which is \code{-1} in calendar time and that value is on those OSes
%  also used as an error code.  Thus \code{as.POSIXct("1969-12-31
%  23:59:59", format = "\%Y-\%m-\%d \%H:\%M:\%S", tz = "UTC")} may give
%  \code{NA}, and hence \code{as.POSIXct("1969-12-31 23:59:59",
%  tz = "UTC")} will give \code{"1969-12-31 23:59:00"}.  Other OSes
%  (including the code used by \R on Windows) report errors separately
%  and so are able to handle that time as valid.
%
%  The print methods respect \code{\link{options}("max.print")}.
%}
%\section{Sub-second Accuracy}{
%  Classes \code{"POSIXct"} and  \code{"POSIXlt"} are able to express
%  fractions of a second.  (Conversion of fractions between the two forms
%  may not be exact, but will have better than microsecond accuracy.)
%
%  Fractional seconds are printed only if
%  \code{\link{options}("digits.secs")} is set: see \code{\link{strftime}}.
%}
%\section{Valid ranges for times}{
%  The \code{"POSIXlt"} class can represent a very wide range of times (up
%  to billions of years), but such times can only be interpreted with
%  reference to a time zone.
%
%  % https://www.timeanddate.com/calendar/julian-gregorian-switch.html
%  The concept of time zones was first adopted in the nineteenth century,
%  and the Gregorian calendar was introduced in 1582 but not universally
%  adopted until 1927.  OS services almost invariably assume the
%  Gregorian calendar and may assume that the time zone that was first
%  enacted for the location was in force before that date.  (The earliest
%  legislated time zone seems to have been London on 1847-12-01.)  Some
%  OSes assume the previous use of \sQuote{local time} based on the
%  longitude of a location within the time zone.
%  % from the Olson files.
%  
%  Most operating systems represent \code{POSIXct} times as C type
%  \code{long}. This means that on 32-bit OSes this covers the period
%  1902 to 2037.  On all known 64-bit platforms and for the code we use
%  on 32-bit Windows, the range of representable times is billions of
%  years: however, not all can convert correctly times before 1902 or
%  after 2037.  A few benighted OSes used a unsigned type and so cannot
%  represent times before 1970.
%  % glibc in 2003/4, AIX?
%
%  Where possible the platform limits are detected, and outside
%  the limits we use our own C code.  This uses the offset from
%  GMT in use either for 1902 (when there was no DST) or that predicted
%  for one of 2030 to 2037 (chosen so that the likely DST transition days
%  are Sundays), and uses the alternate (daylight-saving) time zone only
%  if \code{isdst} is positive or (if \code{-1}) if DST was predicted to
%  be in operation in the 2030s on that day.
%
%  Note that there are places (e.g., Rome) whose offset from UTC varied
%  in the years prior to 1902, and these will be handled correctly only
%  where there is OS support.
%
%  There is no reason to suppose that the DST rules will remain the same
%  in the future, and indeed the US legislated in 2005 to change its
%  rules as from 2007, with a possible future reversion.  So conversions
%  for times more than a year or two ahead are speculative.  
%}
%\seealso{
%  \link{Dates} for dates without times.
%
%  \code{\link{as.POSIXct}} and \code{\link{as.POSIXlt}} for conversion
%  between the classes.
%
%  \code{\link{strptime}} for conversion to and from character
%  representations.
%
%  \code{\link{Sys.time}} for clock time as a \code{"POSIXct"} object.
%
%  \code{\link{difftime}} for time intervals.
%
%  \code{\link{cut.POSIXt}}, \code{\link{seq.POSIXt}},
%  \code{\link{round.POSIXt}} and \code{\link{trunc.POSIXt}} for methods
%  for these classes.
%
%  \code{\link{weekdays}} for convenience extraction functions.
%}
%\references{
%  Ripley, B. D. and Hornik, K. (2001) Date-time classes. \emph{R News},
%  \bold{1/2}, 8--11.
%  \url{https://www.r-project.org/doc/Rnews/Rnews_2001-2.pdf}
%}
%
%\section{Warnings}{
%  Some Unix-like systems (especially Linux ones) do not have environment
%  variable \env{TZ} set, yet have internal code that expects it (as does
%  POSIX).  We have tried to work around this, but if you get unexpected
%  results try setting \env{TZ}.  See \code{\link{Sys.timezone}} for
%  valid settings.
%
%  Great care is needed when comparing objects of class \code{"POSIXlt"}.
%  Not only are components and attributes optional; several components
%  may have values meaning \sQuote{not yet determined} and the same time
%  represented in different time zones will look quite different.
%}
%\examples{\donttest{% <-->  may fail on platforms wrongly set up
%(z <- Sys.time())             # the current date, as class "POSIXct"
%
%Sys.time() - 3600             # an hour ago
%
%as.POSIXlt(Sys.time(), "GMT") # the current time in GMT
%format(.leap.seconds)         # the leap seconds in your time zone
%print(.leap.seconds, tz = "PST8PDT")  # and in Seattle's
%
%## look at *internal* representation of "POSIXlt" :
%leapS <- as.POSIXlt(.leap.seconds)
%names(leapS) ; is.list(leapS)
%## str() "too smart" -->  need unclass(.):
%utils::str(unclass(leapS), vec.len = 7)
%}}
%\keyword{utilities}
%\keyword{chron}
%
\encoding{UTF8}
