% File src/library/base/man/NA.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{NA}
\alias{NA}
\alias{NA_integer_}
\alias{NA_real_}
\alias{NA_complex_}
\alias{NA_character_}
\alias{is.na}
\alias{is.na.data.frame}
\alias{is.na<-}
\alias{is.na<-.default}
\alias{anyNA}
\alias{anyMissing}% an alternative name (in Biobase and S+ as of ~2006)
\title{Not Available / Missing Values}
\description{
\code{NA} は欠損値を指示する長さ1の論理定数である．
 \code{NA} はバイト型を除くすべての他の型に強制変換可能である．
他にも欠損値を意味する他の原子的ベクトル型の定数 \code{NA_integer_},
  \code{NA_real_}, \code{NA_complex_} そして \code{NA_character_}
がある：これら全ては \R の予約語である．

総称的関数 \code{is.na} はどの要素が欠損しているかを指示する．

総称的関数 \code{is.na<-} は要素を \code{NA} に設定する．

総称的関数 \code{anyNA} は \code{any(is.na(x))} を
可能性としてより速い仕方で実装する(特に原子的ベクトルに対して)．
}
\usage{
NA
is.na(x)
anyNA(x, recursive = FALSE)

\method{is.na}{data.frame}(x)

is.na(x) <- value
}
\arguments{
  \item{x}{テストされる \R オブジェクト；
 \code{is.na} に対する既定のメソッドは原子的ベクトル，リスト，そして対リストを
処理する：\code{anyNA} に対するそれはまた \code{NULL} を処理する．}
  \item{recursive}{論理値： \code{anyNA} をリストと対リストに再帰的に
適用するか？}
  \item{value}{\code{x} と一緒に使うための適当な添字ベクトル．}
}

\details{
文字型の \code{NA} は文字列 \code{"NA"} とは異なる．
欠損文字列を正確に指定したいプログラマーは \code{NA_character_}
(\code{"NA"} ではなく)を使うべきである．または
 \code{is.na<-} を使い要素に \code{NA} を設定する．

\code{is.na} と \code{anyNA} は総称的である：オブジェクトの特定の
クラスを処理するメソッドを書くことが出来る，
 \link{InternalMethods} を見よ．
  
関数 \code{is.na<-} は欠損性を設定する安全な方法を提供出来る．
例えば，それは因子に対しては異なった挙動をする．

\code{NA} を使った数値計算の結果は普通 \code{NA} になる．
可能な例外は \code{\link{NaN}} が含まれる時で，
結果はどちらにもなりうる．論理計算は \code{NA} を 
欠損した \code{TRUE/FALSE} 値として扱い，もし表現式が \code{NA} 被演算項に
依存しなければ \code{TRUE} や \code{FALSE} を返す可能性がある．
  
\code{anyNA} に対する既定メソッドはクラスや \code{NULL} 無しの原子的ベクトルを
処理する．クラスを持つオブジェクト，そして \code{recursive = FALSE} ならば，
リストや対リストに対しては \code{any(is.na(x)} を呼び出す．
}
\value{
原子的なベクトルに適用された \code{is.na} の既定メソッドは，
その引数 \code{x} と同じ長さの論理値ベクトルを返す，
\code{NA} とマークされた要素に対しては \code{TRUE} を含む．
もしくは数値または複素数値ベクトルに対しては \code{\link{NaN}}，
さもなければ \code{FALSE} を返す．
(複素数値は，その実部か虚部のどちらかが \code{NA} または \code{\link{NaN}}
の時 \code{NA} と見做される．)
属性 \code{dim}, \code{dimnames} そして \code{names} は結果にコピーされる．

既定メソッドはまたリストや対リストに対しても動作する：
\code{is.na} に対しては，要素が長さ1の原子的ベクトルでベクトルの単一の要素が
 \code{NA} か \code{NaN} と見做されない限り，結果は要素毎に偽となる．
(要素のクラスに対する任意の \code{is.na} メソッドは無視されることを注意する)．
 \code{anyNA(recursive = FALSE)} は \code{is.na} と同じ動作をする；
 \code{anyNA(recursive = TRUE)} は \code{anyNA} を各要素に(選択適用された
メソッドとともに)適用する．

\code{is.na} に対するデータフレームのメソッドはデータフレームと同じ
次元を持つ論理値行列を返す．そして次元名はデータフレームの
行と列名から取られる．
  
\code{anyNA(NULL)} は間違いである：\code{is.na(NULL)} は警告付きで
 \code{logical(0)} になる．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Chambers, J. M. (1998)
  \emph{Programming with Data.  A Guide to the S Language}.
  Springer.
}
\seealso{
  \code{\link{NaN}}, \code{\link{is.nan}} 等，
そして補助関数 \code{\link{complete.cases}}．

メソッド関数が欠損値を処理するように調整する仕方については
\code{\link{na.action}}, \code{\link{na.omit}}, \code{\link{na.fail}}．
}
\examples{
is.na(c(1, NA))        #> FALSE  TRUE
is.na(paste(c(1, NA))) #> FALSE FALSE

(xx <- c(0:4))
is.na(xx) <- c(2, 4)
xx                     #> 0 NA  2 NA  4
anyNA(xx) # TRUE

# 論理演算子には NA を返さないものがある
c(TRUE, FALSE) & NA
c(TRUE, FALSE) | NA

\donttest{
## わかりやすいケースで速度の差を計る：
## 差はプラットフォームに依存する，殆どの場合3倍
x <- 1:10000; x[5000] <- NaN  # x を倍精度実数に強制変換
if(require("microbenchmark")) { # すべてのプラットフォームで確実に動作するわけではない
  print(microbenchmark(any(is.na(x)), anyNA(x)))
} else {
  nSim <- 2^13
  print(rbind(is.na = system.time(replicate(nSim, any(is.na(x)))),
              anyNA = system.time(replicate(nSim, anyNA(x)))))
}
}

## anyNA() は list() とともに動作する：
LL <- list(1:5, c(NA, 5:8), c("A","NA"), c("a", NA_character_))
L2 <- LL[c(1,3)]
sapply(LL, anyNA); c(anyNA(LL), anyNA(LL, TRUE))
sapply(L2, anyNA); c(anyNA(L2), anyNA(L2, TRUE))

## ... リスト，そして従ってデータフレームでも：
dN <- dd <- USJudgeRatings; dN[3,6] <- NA
anyNA(dd) # FALSE
anyNA(dN) # TRUE
}
\keyword{NA}
\keyword{logic}
\keyword{manip}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/NA.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{NA}
%\alias{NA}
%\alias{NA_integer_}
%\alias{NA_real_}
%\alias{NA_complex_}
%\alias{NA_character_}
%\alias{is.na}
%\alias{is.na.data.frame}
%\alias{is.na<-}
%\alias{is.na<-.default}
%\alias{anyNA}
%\alias{anyMissing}% an alternative name (in Biobase and S+ as of ~2006)
%\title{\sQuote{Not Available} / Missing Values}
%\description{
%  \code{NA} is a logical constant of length 1 which contains a missing
%  value indicator.  \code{NA} can be coerced to any other vector
%  type except raw.  There are also constants \code{NA_integer_},
%  \code{NA_real_}, \code{NA_complex_} and \code{NA_character_} of the
%  other atomic vector types which support missing values: all of these
%  are \link{reserved} words in the \R language.
%
%  The generic function \code{is.na} indicates which elements are missing.
%
%  The generic function \code{is.na<-} sets elements to \code{NA}.
%
%  The generic function \code{anyNA} implements \code{any(is.na(x))} in a
%  possibly faster way (especially for atomic vectors).
%}
%\usage{
%NA
%is.na(x)
%anyNA(x, recursive = FALSE)
%
%\method{is.na}{data.frame}(x)
%
%is.na(x) <- value
%}
%\arguments{
%  \item{x}{an \R object to be tested: the default method for
%    \code{is.na} handles atomic vectors, lists and pairlists: that for
%    \code{anyNA} also handles \code{NULL}.}
%  \item{recursive}{logical: should \code{anyNA} be applied recursively
%    to lists and pairlists?}
%  \item{value}{a suitable index vector for use with \code{x}.}
%}
%
%\details{
%  The \code{NA} of character type is distinct from the string
%  \code{"NA"}.  Programmers who need to specify an explicit missing
%  string should use \code{NA_character_} (rather than \code{"NA"}) or set
%  elements to \code{NA} using \code{is.na<-}.
%
%  \code{is.na} and \code{anyNA} are generic: you can write
%  methods to handle specific classes of objects, see
%  \link{InternalMethods}.
%  
%  Function \code{is.na<-} may provide a safer way to set missingness.
%  It behaves differently for factors, for example.
%
%  Numerical computations using \code{NA} will normally result in \code{NA}: a
%  possible exception is where \code{\link{NaN}} is also involved, in
%  which case either might result.  Logical computations treat \code{NA}
%  as a missing \code{TRUE/FALSE} value, and so may return \code{TRUE} or 
%  \code{FALSE} if the expression does not depend on the \code{NA} operand.
%  
%  The default method for \code{anyNA} handles atomic vectors without a
%  class and \code{NULL}.  It calls \code{any(is.na(x)} on objects with
%  classes and for \code{recursive = FALSE}, on lists and pairlists.
%}
%\value{
%  The default method for \code{is.na} applied to an atomic vector
%  returns a logical vector of the same length as its argument \code{x},
%  containing \code{TRUE} for those elements marked \code{NA} or, for
%  numeric or complex vectors, \code{\link{NaN}}, and \code{FALSE}
%  otherwise. (A complex value is regarded as \code{NA} if either its
%  real or imaginary part is \code{NA} or \code{\link{NaN}}.)
%  \code{dim}, \code{dimnames} and \code{names} attributes are copied to
%  the result.
%
%  The default methods also work for lists and pairlists:\cr
%  For \code{is.na}, elementwise the result is false unless that element
%  is a length-one atomic vector and the single element of that vector is
%  regarded as \code{NA} or \code{NaN} (note that any \code{is.na}
%  method for the class of the element is ignored).\cr
%  \code{anyNA(recursive = FALSE)} works the same way as \code{is.na};
%  \code{anyNA(recursive = TRUE)} applies \code{anyNA} (with method
%  dispatch) to each element.
%
%  The data frame method for \code{is.na} returns a logical matrix
%  with the same dimensions as the data frame, and with dimnames taken
%  from the row and column names of the data frame.
%  
%  \code{anyNA(NULL)} is false: \code{is.na(NULL)} is \code{logical(0)}
%  with a warning.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Chambers, J. M. (1998)
%  \emph{Programming with Data.  A Guide to the S Language}.
%  Springer.
%}
%\seealso{
%  \code{\link{NaN}}, \code{\link{is.nan}}, etc.,
%  and the utility function \code{\link{complete.cases}}.
%
%  \code{\link{na.action}}, \code{\link{na.omit}}, \code{\link{na.fail}}
%  on how methods can be tuned to deal with missing values.
%}
%\examples{
%is.na(c(1, NA))        #> FALSE  TRUE
%is.na(paste(c(1, NA))) #> FALSE FALSE
%
%(xx <- c(0:4))
%is.na(xx) <- c(2, 4)
%xx                     #> 0 NA  2 NA  4
%anyNA(xx) # TRUE
%
%# Some logical operations do not return NA
%c(TRUE, FALSE) & NA
%c(TRUE, FALSE) | NA
%
%\donttest{
%## Measure speed difference in a favourable case:
%## the difference depends on the platform, on most ca 3x.
%x <- 1:10000; x[5000] <- NaN  # coerces x to be double
%if(require("microbenchmark")) { # does not work reliably on all platforms
%  print(microbenchmark(any(is.na(x)), anyNA(x)))
%} else {
%  nSim <- 2^13
%  print(rbind(is.na = system.time(replicate(nSim, any(is.na(x)))),
%              anyNA = system.time(replicate(nSim, anyNA(x)))))
%}
%}
%
%## anyNA() can work recursively with list()s:
%LL <- list(1:5, c(NA, 5:8), c("A","NA"), c("a", NA_character_))
%L2 <- LL[c(1,3)]
%sapply(LL, anyNA); c(anyNA(LL), anyNA(LL, TRUE))
%sapply(L2, anyNA); c(anyNA(L2), anyNA(L2, TRUE))
%
%## ... lists, and hence data frames, too:
%dN <- dd <- USJudgeRatings; dN[3,6] <- NA
%anyNA(dd) # FALSE
%anyNA(dN) # TRUE
%}
%\keyword{NA}
%\keyword{logic}
%\keyword{manip}
%
\encoding{UTF8}
