% File src/library/base/man/any.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{any}
\title{Are Some Values True?}
\usage{
any(\dots, na.rm = FALSE)
}
\alias{any}
\description{
 論理値ベクトルのセットをあたえた時，値の少なくとも一つが真か?
}
\arguments{
  \item{\dots}{ゼロ個以上の論理値ベクトル．長さゼロの他のオブジェクトは無視され，
残りは任意のクラスを無視して論理値に強制変換される．}
  \item{na.rm}{論理値．もし真なら \code{NA} 値は結果を計算する前に取り除かれる．}
}
\details{
  これは総称的関数である：メソッドを直接または
  \code{\link[=S3groupGeneric]{Summary}} グループ総称として書くことが出来る．
これが適正に働くためには，引数 \code{\dots} は名前無しで，選択適用は最初の
引数に関する必要がある．

整数以外の型(バイト，倍精度実数，複素数，文字，リスト)への強制変換は
想定外であり警告が出る．

これはプリミティブな関数である．
}
\value{
  値は長さ1の論理値ベクトル．

  \code{x} を(強制変換後の) \code{...} 中のすべての論理値ベクトルを連結した
ものとする． \code{na.rm = TRUE} ならば \code{NA} は取り除く．

返される値はもし \code{x} 中の値が少なくとも一つ \code{TRUE} ならば \code{TRUE} で，
すべてが \code{FALSE} ならば \code{FALSE} になる(値が一つもない場合を含む)．
さもなければ値は \code{NA} である(これはもし \code{na.rm = FALSE} で 
 \code{\dots} が値 \code{TRUE} を一つも含まず，そして少なくとも一つの 
 \code{NA} 値を含む場合に起こる)．
}
\section{S4 メソッド}{
  これは S4 \code{\link[=S4groupGeneric]{Summary}} グループ総称の一部である．
それに対するメソッドはシグネチャ \code{x, \dots, na.rm} を利用しなければならない．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
 \code{any} と相補的な \code{\link{all}}．
}
\examples{
range(x <- sort(round(stats::rnorm(10) - 1.2, 1)))
if(any(x < 0)) cat("x contains negative values\n")
}
\keyword{logic}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/any.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{any}
%\title{Are Some Values True?}
%\usage{
%any(\dots, na.rm = FALSE)
%}
%\alias{any}
%\description{
%  Given a set of logical vectors, is at least one of the values true?
%}
%\arguments{
%  \item{\dots}{zero or more logical vectors.  Other objects of zero
%    length are ignored, and the rest are coerced to logical ignoring
%    any class.}
%  \item{na.rm}{logical.  If true \code{NA} values are removed before
%    the result is computed.}
%}
%\details{
%  This is a generic function: methods can be defined for it
%  directly or via the \code{\link[=S3groupGeneric]{Summary}} group generic.
%  For this to work properly, the arguments \code{\dots} should be
%  unnamed, and dispatch is on the first argument.
%
%  Coercion of types other than integer (raw, double, complex, character,
%  list) gives a warning as this is often unintentional.
%
%  This is a \link{primitive} function.
%}
%\value{
%  The value is a logical vector of length one.
%
%  Let \code{x} denote the concatenation of all the logical vectors in
%  \code{...} (after coercion), after removing \code{NA}s if requested by
%  \code{na.rm = TRUE}.
%
%  The value returned is \code{TRUE} if at least one of the values in
%  \code{x} is \code{TRUE}, and \code{FALSE} if all of the values in
%  \code{x} are \code{FALSE} (including if there are no values).  Otherwise
%  the value is \code{NA} (which can only occur if \code{na.rm = FALSE}
%  and \code{\dots} contains no \code{TRUE} values and at least one
%  \code{NA} value).
%}
%\section{S4 methods}{
%  This is part of the S4 \code{\link[=S4groupGeneric]{Summary}}
%  group generic.  Methods for it must use the signature
%  \code{x, \dots, na.rm}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{all}}, the \sQuote{complement} of \code{any}.
%}
%\examples{
%range(x <- sort(round(stats::rnorm(10) - 1.2, 1)))
%if(any(x < 0)) cat("x contains negative values\n")
%}
%\keyword{logic}
%
\encoding{UTF8}
