% File src/library/base/man/array.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{array}
\alias{array}
\alias{as.array}
\alias{as.array.default}
\alias{is.array}
\title{Multi-way Arrays}
\description{配列を作る，テストする．
}
\usage{
array(data = NA, dim = length(data), dimnames = NULL)
as.array(x, ...)
is.array(x)
}
\arguments{
  \item{data}{配列を埋めるデータを与えるベクトル(リストや \code{\link{expression}} を含む)．
原子的でないクラス付きオブジェクトは \code{\link{as.vector}} で変換される．}
  \item{dim}{作成される配列に帯する次元属性，つまり長さ1以上の整数ベクトルで
各次元の最大添字を与える．}
  \item{dimnames}{\code{NULL} か次元に対する名前．
これはリストでなければならず(さもなければ無視される)，各次元毎に1成分を持ち，
それぞれ \code{NULL} かその次元に対する \code{m} を長さに持つ文字列ベクトルである．
リストは名前を持つことができ，リスト名は次元に対する名前として使える．
もしリストが次元数より短ければ，\code{NULL} で必要な長さまで延長される．}
  \item{x}{\R オブジェクト．}
  \item{\dots}{メソッドへ，から引き渡される追加引数．}
}
\details{
\R の配列は1,2もしくはそれ以上の次元を持つことが出来る．
これは単に次元を与える追加属性をもつベクトルで，
オプションでこれらの次元に名前を持つことが出来る(属性 \code{"dimnames"})．

二次元配列は \code{\link{matrix}} と同じものである．

1次元配列はしばしばベクトルと同じに見えるが，ある種の関数では異なった扱いを受ける：
 \code{\link{str}} は最近の \R のバージョンでは区別される．

属性 \code{"dim"} は非負の値を持つ長さ1もしくはそれ以上の整数ベクトルである：
値の積は配列の長さに一致する必要がある．

属性 \code{"dimnames"} はオプションである：もしあればそれは
各次元毎に一つの成分を持つリストで，\code{NULL} かその次元に与えられた
 \code{"dim"} 属性の要素で与えられる長さの文字列ベクトルである．

  \code{is.array} はプリミティブ関数である．

リスト配列に対しては，メソッド \code{print} は長さが1でない項目を 
型と長さを示す形式 \samp{integer,7} で表す．
}
\value{
  \code{array} は \code{dim} で指定される広がりと \code{dimnames} 中の命名情報を
持つ配列を返す．\code{data} 中の値は配列中に左側の添字が最も早く変化するように
収められる．もし \code{data} 中の要素が配列を埋めるのに少なすぎれば
 \code{data} 中の要素がリサイクルされる．もし \code{data} が長さ0をもてば，
適当な型の \code{NA} (バイト型には \code{0})が原子的なベクトルに，
リストには \code{NULL} が使われる．

\code{\link{matrix}} とはことなり，\code{array} は現在 \code{as.vector} が残す
クラス付きリスト \code{data} からの属性を取り除かない．

  \code{as.array} は配列への強制変換のための総称的関数である．
既定メソッドはこれを属性 \code{\link{dim}} を付け加えることで行う．
もし \code{x} が \code{\link{names}} を持てば，\code{\link{dimnames}} も付加される．
これの唯一の目的は後で \code{dim[names]} 属性にアクセス出来るようにすることである．

  \code{is.array} は \code{TRUE} か \code{FALSE} をその引数が配列であるか
(つまり正の長さの \code{dim} 属性をもつか)どうかに従って返す．
これは総称的である：特定のクラスのオブジェクトを処理するメソッドを書くことが出来る，
 \link{InternalMethods} を見よ．
}
\note{
  \code{is.array} はプリミティブな関数．

  \R 2.x.y は(ドキュメント化されていなかったが)長さゼロの \code{dim} 引数を
認めており，そして長さ1のベクトルを返した．  
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{aperm}}, \code{\link{matrix}},
  \code{\link{dim}}, \code{\link{dimnames}}.
}
\examples{
dim(as.array(letters))
array(1:3, c(2,4)) # 1:3  を "2 2/3 回" リサイクル
#     [,1] [,2] [,3] [,4]
#[1,]    1    3    2    1
#[2,]    2    1    3    2
}
\keyword{array}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/array.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{array}
%\alias{array}
%\alias{as.array}
%\alias{as.array.default}
%\alias{is.array}
%\title{Multi-way Arrays}
%\description{
%  Creates or tests for arrays.
%}
%\usage{
%array(data = NA, dim = length(data), dimnames = NULL)
%as.array(x, ...)
%is.array(x)
%}
%\arguments{
%  \item{data}{a vector (including a list or \code{\link{expression}}
%    vector) giving data to fill the array.  Non-atomic classed objects
%    are coerced by \code{\link{as.vector}}.}
%  \item{dim}{the dim attribute for the array to be created, that is an
%    integer vector of length one or more giving the maximal indices in
%    each dimension.}
%  \item{dimnames}{either \code{NULL} or the names for the dimensions.
%    This must a list (or it will be ignored) with one component for each
%    dimension, either \code{NULL} or a character vector of the length
%    given by \code{dim} for that dimension.  The list can be named, and
%    the list names will be used as names for the dimensions.  If the
%    list is shorter than the number of dimensions, it is extended by
%    \code{NULL}s to the length required.}
%  \item{x}{an \R object.}
%  \item{\dots}{additional arguments to be passed to or from methods.}
%}
%\details{
%  An array in \R can have one, two or more dimensions.  It is simply a
%  vector which is stored with additional \link{attributes} giving the
%  dimensions (attribute \code{"dim"}) and optionally names for those
%  dimensions (attribute \code{"dimnames"}).
%
%  A two-dimensional array is the same thing as a \code{\link{matrix}}.
%
%  One-dimensional arrays often look like vectors, but may be handled
%  differently by some functions: \code{\link{str}} does distinguish
%  them in recent versions of \R.
%
%  The \code{"dim"} attribute is an integer vector of length one or more
%  containing non-negative values: the product of the values must match
%  the length of the array.
%
%  The \code{"dimnames"} attribute is optional: if present it is a list
%  with one component for each dimension, either \code{NULL} or a
%  character vector of the length given by the element of the
%  \code{"dim"} attribute for that dimension.
%
%  \code{is.array} is a \link{primitive} function.
%
%  For a list array, the \code{print} methods prints entries of length
%  not one in the form \samp{integer,7} indicating the type and length.
%}
%\value{
%  \code{array} returns an array with the extents specified in \code{dim}
%  and naming information in \code{dimnames}.  The values in \code{data} are
%  taken to be those in the array with the leftmost subscript moving
%  fastest.  If there are too few elements in \code{data} to fill the array,
%  then the elements in \code{data} are recycled.  If \code{data} has
%  length zero, \code{NA} of an appropriate type is used for atomic
%  vectors (\code{0} for raw vectors) and \code{NULL} for lists.
%
%  Unlike \code{\link{matrix}}, \code{array} does not currently remove
%  any attributes left by \code{as.vector} from a classed list
%  \code{data}, so can return a list array with a class attribute.
%
%  \code{as.array} is a generic function for coercing to arrays.  The
%  default method does so by attaching a \code{\link{dim}} attribute to
%  it.  It also attaches \code{\link{dimnames}} if \code{x} has
%  \code{\link{names}}.  The sole purpose of this is to make it possible
%  to access the \code{dim[names]} attribute at a later time.
%
%  \code{is.array} returns \code{TRUE} or \code{FALSE} depending on
%  whether its argument is an array (i.e., has a \code{dim} attribute of
%  positive length) or not.  It is generic: you can write methods to handle
%  specific classes of objects, see \link{InternalMethods}.
%}
%\note{
%  \code{is.array} is a \link{primitive} function.
%
%  \R 2.x.y allowed (although documented not to) a zero-length \code{dim}
%  argument, and returned a vector of length one.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{aperm}}, \code{\link{matrix}},
%  \code{\link{dim}}, \code{\link{dimnames}}.
%}
%\examples{
%dim(as.array(letters))
%array(1:3, c(2,4)) # recycle 1:3 "2 2/3 times"
%#     [,1] [,2] [,3] [,4]
%#[1,]    1    3    2    1
%#[2,]    2    1    3    2
%}
%\keyword{array}
%
\encoding{UTF8}
