% File src/library/base/man/browserText.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{browserText}
\alias{browserText}
\alias{browserCondition}
\alias{browserSetDebug}
\title{
Functions to Retrieve Values Supplied by Calls to the Browser
}
\description{
ブラウザの呼び出しはテキスト引数や条件引数を与えることで
文脈を提供できる．
これらの関数はこの引数のいずれかを探すのに使うことができる．
}
\usage{
browserText(n = 1)
browserCondition(n = 1)
browserSetDebug(n = 1)
}
\arguments{
  \item{n}{スキップする文脈の数，負であってはならない．}
}
\details{
\code{browser} への各呼び出しはテキスト文字列化条件を与える．
関数 \code{browserText} と \code{browserCondition} はこれらの値を見つける方法を
提供する．ある時点でアクティブな複数のブラウザの文脈が
あり得るので，異なった文脈からの値の探索がサポートされている．
最奥(最も最近に開始された)のブラウザの文脈は番号1を持つ：
他の文脈は順番に番号付けられる．

\code{browserSetDebug} は呼び出し関数の一つからブラウザを
起動する機構を提供する．呼び出しスタックに対するより完全な詳細については 
 \code{\link{sys.frame}} を見よ．
\code{browserSetDebug} を使うには，ある呼び出し関数を選択し，
それが呼び出しスタック中の位置を決定し，そしてその値を \code{n} に
設定して \code{browserSetDebug} を呼び出す．
そうすると，ブラウザのプロンプトに \code{c} とタイプすれば評価が継続し，
ブラウザに入り込む他の呼び出しが無いか他の中断がなければ，
評価が指定のクロージャに復帰するやいなや制御は再び停止する．
これは gdb の up 機能や，他のデバッガの "step out" 機能に類似している．
}
\value{
\code{browserText} はテキストを返す．一方 \code{browserCondition} は
指定されたブラウザのコンテキストからの条件を返す．

\code{browserSetDebug} は \code{NULL} を不可視で返す．
}
\author{
R. Gentleman
}
\note{
ブラウザのコンテキストの集合を更に問い合わせできたら興味深いかもしれない．
この機能は将来付け加えられるかもしれない．
}

\seealso{
\code{\link{browser}}
}
\keyword{debugging}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/browserText.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{browserText}
%\alias{browserText}
%\alias{browserCondition}
%\alias{browserSetDebug}
%\title{
%Functions to Retrieve Values Supplied by Calls to the Browser
%}
%\description{
%A call to browser can provide context by supplying either a text
%argument or a condition argument.  These functions can be used to
%retrieve either of these arguments.
%}
%\usage{
%browserText(n = 1)
%browserCondition(n = 1)
%browserSetDebug(n = 1)
%}
%\arguments{
%  \item{n}{The number of contexts to skip over, it must be non-negative.}
%}
%\details{
%Each call to \code{browser} can supply either a text string or a condition.
%The functions \code{browserText} and \code{browserCondition} provide ways
%to retrieve those values.  Since there can be multiple browser contexts
%active at any time we also support retrieving values from the different
%contexts.  The innermost (most recently initiated) browser context is
%numbered 1: other contexts are numbered sequentially.
%
%\code{browserSetDebug} provides a mechanism for initiating the browser in
%one of the calling functions.  See \code{\link{sys.frame}} for a more
%complete discussion of the calling stack. To use \code{browserSetDebug}
%you select some calling function, determine how far back it is in the call
%stack and call \code{browserSetDebug} with \code{n} set to that value.
%Then, by typing \code{c} at the browser prompt you will cause evaluation
%to continue, and provided there are no intervening calls to browser or
%other interrupts, control will halt again once evaluation has returned to
%the closure specified.  This is similar to the up functionality in gdb
%or the "step out" functionality in other debuggers.
%}
%\value{
%\code{browserText} returns the text, while \code{browserCondition}
%returns the condition from the specified browser context.
%
%\code{browserSetDebug} returns NULL, invisibly.
%}
%\author{
%R. Gentleman
%}
%\note{
%It may be of interest to allow for querying further up the set of browser
%contexts and this functionality may be added at a later date.
%}
%
%\seealso{
%\code{\link{browser}}
%}
%\keyword{debugging}
%
\encoding{UTF8}
