% File src/library/base/man/cat.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{cat}
\title{Concatenate and Print}
\usage{
cat(\dots , file = "", sep = " ", fill = FALSE, labels = NULL,
    append = FALSE)
}
\alias{cat}
\description{
  表現を連結しオブジェクトを出力する．\code{cat} は 
  \code{\link{print}} よりもかなり変換が少ない．
}
\arguments{
  \item{\dots}{\R オブジェクト(許されるオブジェクトの型については
  \sQuote{詳細}を見よ)．}
  \item{file}{コネクション，またはそこへプリントすべきファイルの名前である文字列．
    もし \code{""} (既定)なら \code{cat} は標準出力コネクション，
    \code{\link{sink}} でリダイレクトされ無い限りコンソール，にプリントする．
%#ifdef unix
    (Unix なら)もしこれが \code{"|cmd"} なら出力はパイプコネクションを
    オープンし，\code{cmd} で与えられた命令にパイプされる．
%#endif
  }
  \item{sep}{各要素の後に付加される文字列のベクトル．}
  \item{fill}{出力を連続する行に分割する仕方を制御する論理値または(正の)
    数値．もし \code{FALSE} (既定)ならば，新行は \code{"\\n"} が明確に
    プリントされた時だけ作られる．さもなければ出力は，\code{fill} が
    \code{TRUE} ならばオプション \code{width} に等しい幅で，\code{fill} が
    数値ならばその数値で，行に分割される．正でない \code{fill} 値は無視され
    警告が出る．}
  \item{labels}{プリントされる行に対するラベルの文字列．
    もし \code{fill} が \code{FALSE} ならば無視される．}
  \item{append}{論理値．引数 \code{file} がファイルの名前の時だけ
    (そしてコネクションや \code{"|cmd"} でない時だけ)使われる．
    もし \code{TRUE} なら出力は \code{file} に付加される；さもなければ
    \code{file} の中身を上書きする．}
}
\details{
  \code{cat} はユーザ定義の関数中で出力を行うのに便利である．
  引数は文字列に変換され，それらを一つの文字列に連結し，
  与えられた \code{sep = } 文字を各要素に付加し，そしてそれらを出力する．

  \samp{"\\n"} によって明示的に要求されるか，
  引数 \code{fill} が \code{TRUE} か数値でない限り改行はされない．

  もし \code{file} がコネクションで書き込みのためにオープンされていれば，
  それはその現在の位置から書き込まれる．もしオープンされていなければ
  呼び出しの間中モード \code{"wt"} でオープンされ，それから閉じられる．

  現在原子的ベクトルと名前，そして \code{NULL} や他の長さゼロのオブジェクト
  (これらは何も出力しない)が処理される．
  文字列は\sQuote{そのまま}で出力される．
  (一方 \code{\link{print.default}} はプリント不可な文字とバックスラッシュを
  エスケープする．エンコードされた文字列 \code{cat} で出力したければ
  \code{\link{encodeString}} を使う．)  他の型の \R のオブジェクトは
  \code{cat} に引き渡す前に変換(例えば \code{\link{as.character}} や
  \code{\link{format}} を使い)されなければならない．
  これは因子を含み，整数ベクトルとして出力される．

  \code{cat} は数値/複素数値の要素を
  \code{print} と同様に(S の仲間のような \code{\link{as.character}} 風ではなく)
  出力するので，\code{\link{options}}, \code{"digits"} そして \code{"scipen"}
  が関係する．しかしながら，これはすべての要素に対して同じ欄を使うのではなく，
  各要素に対して必要な最小の欄幅を使う．
}
\note{
  もし \code{sep} の要素が新行文字を含んでいたら，それは
  分離記号ではなく終端子のベクトルとして扱われ，一つの要素は
  すべてのベクトル要素の後と最後の新行の後に出力される．
  項目は必要に応じてリサイクルされる．
}
\value{
  無い(不可視の \code{NULL})．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  文字列に連結する \code{\link{print}}, \code{\link{format}} と \code{\link{paste}}．
}
\examples{
iter <- stats::rpois(1, lambda = 10)
## 情報メッセージをプリントする
cat("iteration = ", iter <- iter + 1, "\n")

## 'fill' とラベル行：
cat(paste(letters, 100* 1:26), fill = TRUE, labels = paste0("{", 1:10, "}:"))
}
\keyword{print}
\keyword{file}
\keyword{connection}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/cat.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{cat}
%\title{Concatenate and Print}
%\usage{
%cat(\dots , file = "", sep = " ", fill = FALSE, labels = NULL,
%    append = FALSE)
%}
%\alias{cat}
%\description{
%  Outputs the objects, concatenating the representations.  \code{cat}
%  performs much less conversion than \code{\link{print}}.
%}
%\arguments{
%  \item{\dots}{\R objects (see \sQuote{Details} for the types of objects
%    allowed).}
%  \item{file}{A \link{connection}, or a character string naming the file
%    to print to.  If \code{""} (the default), \code{cat} prints to the
%    standard output connection, the console unless redirected by
%    \code{\link{sink}}.
%#ifdef unix
%    If it is \code{"|cmd"}, the output is piped to the command given
%    by \file{cmd}, by opening a pipe connection.
%#endif
%  }
%  \item{sep}{a character vector of strings to append after each element.}
%  \item{fill}{a logical or (positive) numeric controlling how the output is
%    broken into successive lines.  If \code{FALSE} (default), only newlines
%    created explicitly by \samp{"\\n"} are printed.  Otherwise, the
%    output is broken into lines with print width equal to the option
%    \code{width} if \code{fill} is \code{TRUE}, or the value of
%    \code{fill} if this is numeric.  Non-positive \code{fill} values are
%    ignored, with a warning.}
%  \item{labels}{character vector of labels for the lines printed.
%    Ignored if \code{fill} is \code{FALSE}.}
%  \item{append}{logical. Only used if the argument \code{file} is the
%    name of file (and not a connection or \code{"|cmd"}).
%    If \code{TRUE} output will be appended to
%    \code{file}; otherwise, it will overwrite the contents of
%    \code{file}.}
%}
%\details{
%  \code{cat} is useful for producing output in user-defined functions.
%  It converts its arguments to character vectors, concatenates
%  them to a single character vector, appends the given \code{sep = }
%  string(s) to each element and then outputs them.
%
%  No linefeeds are output unless explicitly requested by \samp{"\\n"}
%  or if generated by filling (if argument \code{fill} is \code{TRUE} or
%  numeric).
%
%  If \code{file} is a connection and open for writing it is written from
%  its current position.  If it is not open, it is opened for the
%  duration of the call in \code{"wt"} mode and then closed again.
%
%  Currently only \link{atomic} vectors and \link{name}s are handled,
%  together with \code{NULL} and other zero-length objects (which produce
%  no output).  Character strings are output \sQuote{as is} (unlike
%  \code{\link{print.default}} which escapes non-printable characters and
%  backslash --- use \code{\link{encodeString}} if you want to output
%  encoded strings using \code{cat}).  Other types of \R object should be
%  converted (e.g., by \code{\link{as.character}} or \code{\link{format}})
%  before being passed to \code{cat}.  That includes factors, which are
%  output as integer vectors.
%
%  \code{cat} converts numeric/complex elements in the same way as
%  \code{print} (and not in the same way as \code{\link{as.character}}
%  which is used by the S equivalent), so \code{\link{options}}
%  \code{"digits"} and \code{"scipen"} are relevant.  However, it uses
%  the minimum field width necessary for each element, rather than the
%  same field width for all elements.
%}
%\note{
%  If any element of \code{sep} contains a newline character, it is
%  treated as a vector of terminators rather than separators, an element
%  being output after every vector element \emph{and} a newline after the
%  last.  Entries are recycled as needed.
%}
%\value{
%  None (invisible \code{NULL}).
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{print}}, \code{\link{format}}, and \code{\link{paste}}
%  which concatenates into a string.
%}
%\examples{
%iter <- stats::rpois(1, lambda = 10)
%## print an informative message
%cat("iteration = ", iter <- iter + 1, "\n")
%
%## 'fill' and label lines:
%cat(paste(letters, 100* 1:26), fill = TRUE, labels = paste0("{", 1:10, "}:"))
%}
%\keyword{print}
%\keyword{file}
%\keyword{connection}
%

\encoding{UTF8}
