% File src/library/base/man/det.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{det}
\title{Calculate the Determinant of a Matrix}
\alias{det}
\alias{determinant}
\alias{determinant.matrix}
\usage{
det(x, \dots)
determinant(x, logarithm = TRUE, \dots)
}
\description{
  \code{det} は行列の行列式を計算する．\code{determinant} は行列式の
  絶対値(オプションでその対数値)と行列式の符号を個別に返す総称的関数である．
  }
\arguments{
  \item{x}{数値行列：論理値は数値に強制変換される．}
  \item{logarithm}{論理値；もし \code{TRUE} (既定値)ならば行列式の絶対値の
    対数を返す．}
  \item{\dots}{オプション引数．現在未使用．
    \code{det} の以前のバージョンはオプションの \code{method} 引数を認めていた．
    この引数は無視されるがエラーにはならない．}
}
\details{
  関数 \code{determinant} は LU 分解を使い
  関数 \code{det} は単に \code{determinant} への呼び出しのラッパである．

  しばしば，行列式を計算することはある問題を解くためにあなたがすべきことでは無い．
}
\value{
  \code{det} に対しては \code{x} の行列式．\code{determinant} に対しては
  次の成分を持つリスト
  \item{modulus}{数値．もし \code{logarithm} が \code{FALSE} ならば行列式の絶対値；
    さもなければ絶対値の対数．}
  \item{sign}{整数；行列式の正負に応じて \eqn{+1} か \eqn{-1}．}
}
\examples{
(x <- matrix(1:4, ncol = 2))
unlist(determinant(x))
det(x)

det(print(cbind(1, 1:3, c(2,0,1))))
}

\keyword{array}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/det.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{det}
%\title{Calculate the Determinant of a Matrix}
%\alias{det}
%\alias{determinant}
%\alias{determinant.matrix}
%\usage{
%det(x, \dots)
%determinant(x, logarithm = TRUE, \dots)
%}
%\description{
%  \code{det} calculates the determinant of a matrix.  \code{determinant}
%  is a generic function that returns separately the modulus of the determinant,
%  optionally on the logarithm scale, and the sign of the determinant.
%  }
%\arguments{
%  \item{x}{numeric matrix: logical matrices are coerced to numeric.}
%  \item{logarithm}{logical; if \code{TRUE} (default) return the
%    logarithm of the modulus of the determinant.}
%  \item{\dots}{Optional arguments.  At present none are used.  Previous
%    versions of \code{det} allowed an optional \code{method} argument.
%    This argument will be ignored but will not produce an error.}
%}
%\details{
%  The \code{determinant} function uses an LU decomposition and the
%  \code{det} function is simply a wrapper around a call to
%  \code{determinant}.
%
%  Often, computing the determinant is \emph{not} what you should be doing
%  to solve a given problem.
%}
%\value{
%  For \code{det}, the determinant of \code{x}.  For \code{determinant}, a
%  list with components
%  \item{modulus}{a numeric value.  The modulus (absolute value) of the
%    determinant if \code{logarithm} is \code{FALSE}; otherwise the
%    logarithm of the modulus.}
%  \item{sign}{integer; either \eqn{+1} or \eqn{-1} according to whether
%    the determinant is positive or negative.}
%}
%\examples{
%(x <- matrix(1:4, ncol = 2))
%unlist(determinant(x))
%det(x)
%
%det(print(cbind(1, 1:3, c(2,0,1))))
%}
%
%\keyword{array}
%
\encoding{UTF8}
