% File src/library/base/man/dput.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{dput}
\alias{dput}
\alias{dget}
\title{Write an Object to a File or Recreate it}
\description{
  \R オブジェクトもアスキーテキスト表現をファイルやコネクションに書き込む，
  もしくはそれからオブジェクトを再現する．
}
\usage{
dput(x, file = "",
     control = c("keepNA", "keepInteger", "showAttributes"))

dget(file, keep.source = FALSE)
}
\arguments{
  \item{x}{オブジェクト．}
  \item{file}{ファイルかコネクションの名前である文字列．
    \code{""} はコンソールへの出力を意味する．}
  \item{control}{逆構文解析オプションを指示する文字列ベクトル．
    それらの解説は \code{\link{.deparseOpts}} を見よ．}
  \item{keep.source}{論理値：もし可能なら，関数の構文解析時に
    ソースの書式を保持するか?}
}
\details{
  \code{dput} は \code{file} を開きオブジェクト \code{x} の逆構文解析結果を
  そのファイルに書き込む．オブジェクトの名前は書き込まれない(\code{dump} とは異なり)．
  もし \code{x} が関数なら関連する環境は取り除かれる．
  従ってスコープ情報は失われ得る．

  オブジェクトの逆構文解析は困難であり，いつも可能とは限らない．
  既定の \code{control} を用いると，\code{dput()} は可読な流儀で逆構文解析を
  試みるが，より複雑であったり普通ではないオブジェクトに対しては
  オリジナルと同一に構文解析されることは有りそうもない．
  最も完全な逆構文解析のためには \code{control = "all"} を使う；
  属性すら含まない最も単純な逆構文解析のためには
  \code{control = NULL} を使う．

  \code{dput} はもし期待されるよりも少ない文字がファイルに書き込まれると
  警告を出す．これはファイルシステムが一杯であるか破損していることを
  意味するかもしれない．

  内部表現の逆構文解析結果よりは保存されたソースを表示するためには
  \code{"useSource"} を \code{control} 中に含める．現在 \R は
  関数定義に対してだけソースを保存する．もしソースの表現について
  気にしない(例えばデータオブジェクトに対するように)のであれば
  速度の点で \code{source} を呼び出す時 \code{options(keep.source = FALSE})
  を設定する．
}
\value{
  \code{dput} に対しては最初の引数を不可視で返す．

  \code{dget} に対してはオブジェクトを作る．
}
\note{
  これは \R セッション間でオブジェクトを移動する良い方法では無い．
  \code{\link{dump}} の方が好ましいが，関数 \code{\link{save}} は
  \R データを持ち運ぶために使われるようにデザインされており，
  \code{dput} が正しく処理できない \R オブジェクトでも動作し，
  より速い．
  
  ソース属性が実際の関数定義と同期しないリスクを避けるため，
  関数のソース属性は決して属性として書かれない．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{deparse}}, \code{\link{dump}}, \code{\link{write}}.
}
\examples{
## 関数 mean のアスキー版をファイル "foo" に書き込む
dput(mean, "foo")
## そしてそれを 'bar' に復元
bar <- dget("foo")
## コメント付きの関数を作る
baz <- function(x) {
  # Subtract from one
  1-x
}
## そしてそれを表示
dput(baz)
## それから保存されたソースを表示
dput(baz, control = "useSource")

## 数値:
xx <- pi^(1:3)
dput(xx)
dput(xx, control = "digits17")
dput(xx, control = "hexNumeric")
dput(xx, "foo"); dget("foo") - xx # すべてのプラットフォームで少々丸め
dput(xx, "foo", control = "digits17")
dget("foo") - xx # ある種のプラットフォームで少々丸め
dput(xx, "foo", control = "hexNumeric"); dget("foo") - xx
unlink("foo")
}
\keyword{file}
\keyword{programming}
\keyword{connection}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/dput.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{dput}
%\alias{dput}
%\alias{dget}
%\title{Write an Object to a File or Recreate it}
%\description{
%  Writes an ASCII text representation of an \R object to a file
%  or connection, or uses one to recreate the object.
%}
%\usage{
%dput(x, file = "",
%     control = c("keepNA", "keepInteger", "showAttributes"))
%
%dget(file, keep.source = FALSE)
%}
%\arguments{
%  \item{x}{an object.}
%  \item{file}{either a character string naming a file or a
%    \link{connection}. \code{""} indicates output to the console.}
%  \item{control}{character vector indicating deparsing options.
%    See \code{\link{.deparseOpts}} for their description.}
%  \item{keep.source}{logical: should the source formatting be retained when
%    parsing functions, if possible?}
%}
%\details{
%  \code{dput} opens \code{file} and deparses the object \code{x} into
%  that file.  The object name is not written (unlike \code{dump}).
%  If \code{x} is a function the associated environment is stripped.
%  Hence scoping information can be lost.
%
%  Deparsing an object is difficult, and not always possible.  With the
%  default \code{control}, \code{dput()} attempts to deparse in a way
%  that is readable, but for more complex or unusual objects (see
%  \code{\link{dump}}, not likely
%  to be parsed as identical to the original.  Use \code{control = "all"}
%  for the most complete deparsing; use \code{control = NULL} for the
%  simplest deparsing, not even including attributes.
%
%  \code{dput} will warn if fewer characters were written to a file than
%  expected, which may indicate a full or corrupt file system.
%
%  To display saved source rather than deparsing the internal
%  representation include \code{"useSource"} in \code{control}.  \R
%  currently saves source only for function definitions.  If you do not
%  care about source representation (e.g., for a data object), for speed
%  set \code{options(keep.source = FALSE}) when calling \code{source}.
%}
%\value{
%  For \code{dput}, the first argument invisibly.
%
%  For \code{dget}, the object created.
%}
%\note{
%  This is \bold{not} a good way to transfer objects between \R sessions.
%  \code{\link{dump}} is better, but the function \code{\link{save}} is
%  designed to be used for transporting \R data, and will work with \R
%  objects that \code{dput} does not handle correctly as well as being
%  much faster.
%  
%  To avoid the risk of a source attribute out of sync with the actual
%  function definition, the source attribute of a function will never
%  be written as an attribute.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{deparse}}, \code{\link{dump}}, \code{\link{write}}.
%}
%\examples{
%## Write an ASCII version of function mean to the file "foo"
%dput(mean, "foo")
%## And read it back into 'bar'
%bar <- dget("foo")
%## Create a function with comments
%baz <- function(x) {
%  # Subtract from one
%  1-x
%}
%## and display it
%dput(baz)
%## and now display the saved source
%dput(baz, control = "useSource")
%
%## Numeric values:
%xx <- pi^(1:3)
%dput(xx)
%dput(xx, control = "digits17")
%dput(xx, control = "hexNumeric")
%dput(xx, "foo"); dget("foo") - xx # slight rounding on all platforms
%dput(xx, "foo", control = "digits17")
%dget("foo") - xx # slight rounding on some platforms
%dput(xx, "foo", control = "hexNumeric"); dget("foo") - xx
%unlink("foo")
%}
%\keyword{file}
%\keyword{programming}
%\keyword{connection}
%
\encoding{UTF8}
