% File src/library/base/man/eapply.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{eapply}
\title{Apply a Function Over Values in an Environment}
\usage{
eapply(env, FUN, \dots, all.names = FALSE, USE.NAMES = TRUE)
}
\alias{eapply}
\arguments{
  \item{env}{使われる環境．}
  \item{FUN}{適用される関数で，
    \code{\link{match.fun}} を使って見つけられる．
    \code{+}, \code{\%*\%}, のような関数に対しては関数名は
    逆引用化か引用化されなければならない．}
  \item{\dots}{\code{FUN} への追加引数．}
  \item{all.names}{すべての値に対して関数を適用するかどうかを指示する論理値．}
  \item{USE.NAMES}{結果のリストが名前を持つべきかどうかを指示する論理値．}
}
\description{
  \code{eapply} は \code{FUN} を \code{\link{environment}} からの
  名前付き値に適用し結果をリストとして返す．ユーザは
  すべての名前付きオブジェクトを使うことを要求できる(普通ドットで始まる名前は
  無視される)．出力はソートされず囲み環境は調べられない．

  これは \link{primitive} 関数である．
}
\value{
  名前付き(\code{USE.NAMES = FALSE} 出ない限り)リスト．成分の順序はハッシュされた
  環境に対しては任意であることを注意．
}
\seealso{
  \code{\link{environment}}, \code{\link{lapply}}.
}
\examples{
require(stats)

env <- new.env(hash = FALSE) # 従って順序は固定される
env$a <- 1:10
env$beta <- exp(-3:3)
env$logic <- c(TRUE, FALSE, FALSE, TRUE)
# そこに何があるのか?
utils::ls.str(env)

# 各リスト要素に対して平均を計算
       eapply(env, mean)
unlist(eapply(env, mean, USE.NAMES = FALSE))

# 各要素に対する中央値とクォンタイル("..." による引き渡しを利用):
eapply(env, quantile, probs = 1:3/4)
eapply(env, quantile)
}
\keyword{iteration}
\keyword{environment}
\keyword{list}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/eapply.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{eapply}
%\title{Apply a Function Over Values in an Environment}
%\usage{
%eapply(env, FUN, \dots, all.names = FALSE, USE.NAMES = TRUE)
%}
%\alias{eapply}
%\arguments{
%  \item{env}{environment to be used.}
%  \item{FUN}{the function to be applied, found \emph{via}
%    \code{\link{match.fun}}.
%    In the case of functions like \code{+}, \code{\%*\%}, etc., the
%    function name must be backquoted or quoted.}
%  \item{\dots}{optional arguments to \code{FUN}.}
%  \item{all.names}{a logical indicating whether to apply the function to
%    all values.}
%  \item{USE.NAMES}{logical indicating whether the resulting list should
%    have \code{\link{names}}.}
%}
%\description{
%  \code{eapply} applies \code{FUN} to the named values from an
%  \code{\link{environment}} and returns the results as a list.  The user
%  can request that all named objects are used (normally names that begin
%  with a dot are not).  The output is not sorted and no enclosing
%  environments are searched.
%
%  This is a \link{primitive} function.
%}
%\value{
%  A named (unless \code{USE.NAMES = FALSE}) list.  Note that the order of
%  the components is arbitrary for hashed environments.
%}
%\seealso{
%  \code{\link{environment}}, \code{\link{lapply}}.
%}
%\examples{
%require(stats)
%
%env <- new.env(hash = FALSE) # so the order is fixed
%env$a <- 1:10
%env$beta <- exp(-3:3)
%env$logic <- c(TRUE, FALSE, FALSE, TRUE)
%# what have we there?
%utils::ls.str(env)
%
%# compute the mean for each list element
%       eapply(env, mean)
%unlist(eapply(env, mean, USE.NAMES = FALSE))
%
%# median and quartiles for each element (making use of "..." passing):
%eapply(env, quantile, probs = 1:3/4)
%eapply(env, quantile)
%}
%\keyword{iteration}
%\keyword{environment}
%\keyword{list}
%
\encoding{UTF8}
