% File src/library/base/man/expression.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{expression}
\alias{expression}
\alias{is.expression}
\alias{as.expression}
\alias{as.expression.default}
\title{Unevaluated Expressions}
\description{
  モード \code{"expression"} のオブジェクトを作る，検査する．
}
\usage{
expression(\dots)

is.expression(x)
as.expression(x, \dots)
}
\arguments{
  \item{\dots}{\code{expression}: \R オブジェクトで，典型的には呼び出し，シンボル
    もしくは定数．\cr
    \code{as.expression}: メソッドに渡される引数．}
  \item{x}{任意の \R オブジェクト．}
}
\details{
  ここでは\sQuote{表現式}は数学的表現というその口語的な意味では使われていない．
  これらは \R の呼び出し(\code{\link{call}} を見よ)で，\R 表現式ベクトルは例えば
  \code{\link{parse}} が返すような呼び出し，シンボル等のリストである．

  モード \code{"expression"} のオブジェクトはリストなので，
  \code{[}, \code{[[} 又は \code{$} で部分操作が出来る．後者の二つは個別の
  呼び出しを取り出す．これらの演算子の置き換え形式は要素を置き換えたり消去
  することに使える．

  \code{expression} と \code{is.expression} はプリミティブな関数である．
  \code{expression} は\sQuote{特殊}である：それはその引数を評価しない．
}
\value{
  \code{expression} は型 \code{"expression"} のベクトルを返し，
  その引数(未評価)を含む．

  \code{is.expression} はもし \code{expr} が表現式オブジェクト
  ならば \code{TRUE} を，さもなければ \code{FALSE} を返す．

  \code{as.expression} はその引数を表現式オブジェクトに強制変換しようと
  試みる．これは総称的であり，唯一の既定メソッドはここで説明されている．
  (既定メソッドは\cr
  \code{as.vector(type = "expression")} を呼び出し，
  従って \code{\link{as.vector}} に対するメソッドを選択適用するかもしれない．
  \code{NULL}，呼び出し，シンボル(\code{\link{as.symbol}} を見よ)そして
  対リストは長さ1の表現式ベクトルの要素として返される．
  原子的なベクトルは要素ごとに表現式ベクトル中に配置される
  (一切の名前無しで)：リストの型は(すべての属性を保ったまま)表現式ベクトル
  に変更される．他の型は現在サポートされていない．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{call}},
  \code{\link{eval}},
  \code{\link{function}}.
  更に数学表現のプロットには
  \code{\link{text}} と
  \code{\link{legend}}．
}
\examples{
length(ex1 <- expression(1 + 0:9)) # 1
ex1
eval(ex1) # 1:10

length(ex3 <- expression(u, v, 1+ 0:9)) # 3
mode(ex3 [3])   # 表現式
mode(ex3[[3]])  # 呼び出し
rm(ex3)
}
\keyword{programming}
\keyword{dplot}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/expression.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2010 R Core Team
%% Distributed under GPL 2 or later
%
%\name{expression}
%\alias{expression}
%\alias{is.expression}
%\alias{as.expression}
%\alias{as.expression.default}
%\title{Unevaluated Expressions}
%\description{
%  Creates or tests for objects of mode \code{"expression"}.
%}
%\usage{
%expression(\dots)
%
%is.expression(x)
%as.expression(x, \dots)
%}
%\arguments{
%  \item{\dots}{\code{expression}: \R objects, typically calls, symbols
%    or constants.\cr
%    \code{as.expression}: arguments to be passed to methods.}
%  \item{x}{an arbitrary \R object.}
%}
%\details{
%  \sQuote{Expression} here is not being used in its colloquial sense,
%  that of mathematical expressions.  Those are calls (see
%  \code{\link{call}}) in \R, and an \R expression vector is a list of
%  calls, symbols etc, for example as returned by \code{\link{parse}}.
%
%  As an object of mode \code{"expression"} is a list, it can be
%  subsetted by \code{[}, \code{[[} or \code{$}, the latter two extracting
%  individual calls etc.  The replacement forms of these operators can be
%  used to replace or delete elements.
%
%  \code{expression} and \code{is.expression} are \link{primitive} functions.
%  \code{expression} is \sQuote{special}: it does not evaluate its arguments.
%}
%\value{
%  \code{expression} returns a vector of type \code{"expression"}
%  containing its arguments (unevaluated).
%
%  \code{is.expression} returns \code{TRUE} if \code{expr} is an
%  expression object and \code{FALSE} otherwise.
%
%  \code{as.expression} attempts to coerce its argument into an
%  expression object.  It is generic, and only the default method is
%  described here.  (The default method calls
%  \code{as.vector(type = "expression")} and so may dispatch methods for
%  \code{\link{as.vector}}.)  \code{NULL}, calls, symbols (see
%  \code{\link{as.symbol}}) and pairlists are returned as the element of
%  a length-one expression vector.  Atomic vectors are placed
%  element-by-element into an expression vector (without using any
%  names): lists are changed type to an expression vector (keeping all
%  attributes).  Other types are not currently supported.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{call}},
%  \code{\link{eval}},
%  \code{\link{function}}.
%  Further,
%  \code{\link{text}} and
%  \code{\link{legend}}
%  for plotting mathematical expressions.
%}
%\examples{
%length(ex1 <- expression(1 + 0:9)) # 1
%ex1
%eval(ex1) # 1:10
%
%length(ex3 <- expression(u, v, 1+ 0:9)) # 3
%mode(ex3 [3])   # expression
%mode(ex3[[3]])  # call
%rm(ex3)
%}
%\keyword{programming}
%\keyword{dplot}
%
\encoding{UTF8}
