% File src/library/base/man/force.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{force}
\alias{force}
\title{Force Evaluation of an Argument}
\description{
  関数引数の評価を強制する．
}
\usage{
force(x)
}
\arguments{
  \item{x}{囲み関数の形式的引数．}
}
\details{
  \code{force} は形式的引数の評価を強制する．これはもし引数が辞書式スコープ
  規則により囲み環境の中で補足され，後でループや apply 関数の中で
  明示的な付値や暗黙の付値によって変更される場合に役に立つ可能性がある．
}
\note{
  これは意味論的な甘味料である：単にシンボルを評価すれば
  同じことになる(例を見よ)．

  \code{force} は他の予約の評価を強制しない．
  (呼び出しの実引数が囲み環境の形式引数にマッチされた時に
  作られる予約を強制することで動作する，遅延評価を実装する機構である．)
}
\examples{
f <- function(y) function() y
lf <- vector("list", 5)
for (i in seq_along(lf)) lf[[i]] <- f(i)
lf[[1]]()  # 5 を返す

g <- function(y) { force(y); function() y }
lg <- vector("list", 5)
for (i in seq_along(lg)) lg[[i]] <- g(i)
lg[[1]]()  # 1 を返す

## これは以下と同一
g <- function(y) { y; function() y }
}
\keyword{data}
\keyword{programming}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/force.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{force}
%\alias{force}
%\title{Force Evaluation of an Argument}
%\description{
%  Forces the evaluation of a function argument.
%}
%\usage{
%force(x)
%}
%\arguments{
%  \item{x}{a formal argument of the enclosing function.}
%}
%\details{
%  \code{force} forces the evaluation of a formal argument.  This can
%  be useful if the argument will be captured in a closure by the lexical
%  scoping rules and will later be altered by an explicit assignment or
%  an implicit assignment in a loop or an apply function.
%}
%\note{
%  This is semantic sugar: just evaluating the symbol will do the
%  same thing (see the examples).
%
%  \code{force} does not force the evaluation of other
%  \link{promises}.  (It works by forcing the promise that
%  is created when the actual arguments of a call are matched to the
%  formal arguments of a closure, the mechanism which implements
%  \emph{lazy evaluation}.)
%}
%\examples{
%f <- function(y) function() y
%lf <- vector("list", 5)
%for (i in seq_along(lf)) lf[[i]] <- f(i)
%lf[[1]]()  # returns 5
%
%g <- function(y) { force(y); function() y }
%lg <- vector("list", 5)
%for (i in seq_along(lg)) lg[[i]] <- g(i)
%lg[[1]]()  # returns 1
%
%## This is identical to
%g <- function(y) { y; function() y }
%}
%\keyword{data}
%\keyword{programming}
%
\encoding{UTF8}
