% File src/library/base/man/formatc.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{formatC}
\title{Formatting Using C-style Formats}
\alias{formatC}
\alias{prettyNum}
\alias{.format.zeros}
\description{
  数値を個別にそして柔軟に整形する．\code{formatC()} は
  \code{C} 風の書式指定を持つ．

  \code{prettyNum()} は数値を\dQuote{見栄え良くする}(可能性として整形を行い)
  のに使われる．そしてまた \code{\link{format.default}} 中でも使われる．

  \code{.format.zeros()} は \code{prettyNum()} の補助関数で
  整形された数のベクトル \code{x} 中のゼロを再整形する．
}
\usage{
formatC(x, digits = NULL, width = NULL,
        format = NULL, flag = "", mode = NULL,
        big.mark = "", big.interval = 3L,
        small.mark = "", small.interval = 5L,
        decimal.mark = getOption("OutDec"),
        preserve.width = "individual", zero.print = NULL,
        drop0trailing = FALSE)

prettyNum(x, big.mark = "",   big.interval = 3L,
          small.mark  = "", small.interval = 5L,
          decimal.mark = getOption("OutDec"), input.d.mark = decimal.mark,
          preserve.width = c("common", "individual", "none"),
          zero.print = NULL, drop0trailing = FALSE, is.cmplx = NA,
          \dots)

.format.zeros(x, zero.print, nx = suppressWarnings(as.numeric(x)))
}
\arguments{
  \item{x}{原子的な数値又は文字列オブジェクトで，\code{prettyNum()} に
    対してだけはもしかすると複素数で，典型的には実数ベクトル．
    任意のクラスは警告付きで捨てられる．}

  \item{digits}{要求される小数点以降の桁数
    (\code{format = "f"}) 又は\emph{有効}桁数
    (\code{format = "g"}, \code{= "e"} 又は \code{= "fg"})．

    既定値: 整数には 2，実数には 4．もし 0 より小さければ
    C の既定値である 6 桁が使われる．もし50 以上であれば，
    \code{format = "f"} でない限り 50 が警告と共に使われるが典型的には
    324 が限界である．(15--21 桁以上は正確とは限らず，使われる OS と
    コンパイラーに依存する．この限界は単に基礎にある C の実行時の
    セグメンテーション違反に対する用心である．)
  }

  \item{width}{全欄幅；もし \code{digits} も \code{width} も共に未指定なら，
    \code{width} の既定値は 1，さもなければ \code{digits + 1}．\code{width = 0} は
    \code{width = digits} を使い，\code{width < 0} はこの欄での左ジャスティフィケーション
    数を意味する(\code{flag = "-"} と同値)．
    もし必要なら結果は \code{width} 以上の文字を持つ．文字列データに対してはこれは
    文字列単位と解釈される(バイト単位でもなくディスプレイ幅でもない)．
  }

  \item{format}{\code{"d"} (整数に対し)， \code{"f"},
    \code{"e"}, \code{"E"}, \code{"g"}, \code{"G"}, \code{"fg"} (実数に
    対し), 又は \code{"s"} (文字列に対し)に等しい．既定値は整数に対し \code{"d"} で
    実数に対しては \code{"g"}．

    \code{"f"} は通常の
    \code{xxx.xxx} 書式中の数を与える；\code{"e"} と \code{"E"} は \code{n.ddde+nn} 又は
    \code{n.dddE+nn} (科学的表記) を与える；\code{"g"} と \code{"G"} は
    そうすることでスペースが節約できる時だけ \code{x[i]} に科学的表記を用いる．

    \code{"fg"} は \code{"f"} のような固定書式を使うが，\code{digits} は
    \emph{有効}桁数の最小値である．これは非常に長い結果の文字列をもたらす可能性がある，
    下の例を見よ．
    \code{\link{signif}} とは異なり \code{digits} よりも多い有効桁数で
    大きな数をプリントする．この書式では \code{flag} が \code{"#"} を含まない限り
    末尾のゼロは捨て去られる．}

  \item{flag}{\code{formatC} に対して, Kernighan and Ritchie (1988, page 243)
    に於けるような書式の修正を与える文字列．
    \code{"0"} は先頭をゼロで埋め，\code{"-"} は左揃えを行い，
    他に \code{"+"}, \code{" "} そして \code{"#"} がある．これらが任意の順序で
    複数あっても良い．
  }

  \item{mode}{\code{"double"} (又は \code{"real"}), \code{"integer"} 又は
    \code{"character"}．
    既定値: \code{x} の保管モードから決定される．}

  \item{big.mark}{文字；もし空でなければ小数点の前(従って \code{big})の
    すべての \code{big.interval} 桁毎にマークとして使われる．}
  \item{big.interval}{上の \code{big.mark} を見よ；既定値は 3．}
  \item{small.mark}{文字；空でなければ小数点の後(従って \code{small})の
    すべての \code{small.interval} 桁毎にマークとして使われる．}
  \item{small.interval}{上の \code{small.mark} を見よ；既定値は 5．}
  \item{decimal.mark}{数値的な小数点を指定するのに使われる文字．}
  \item{input.d.mark}{もし \code{x} が \code{\link{character}} ならば，
    \code{x} 中で小数点として使われ続けていることが知られている文字．}
  \item{preserve.width}{マーク(\code{big.mark} や \code{small.mark})が
    加えられたケースで可能な限り文字幅を保つかどうかを指示する文字列．
    既定値の \code{"common"} は \code{\link{format}} 風の挙動である一方，
    \code{"individual"} は \code{formatC()} 中の既定値．値は簡略化出来る．}
  \item{zero.print}{論理値，文字列又は \code{NULL} で
    \emph{ゼロ}を特別に整形するか，またどのように整形するかを指示する．
    \sQuote{疎な}オブジェクトを見栄え良くプリントするのに役に立つ．}
  \item{drop0trailing}{論理値で，末尾のゼロ，つまり
    小数点マークの後の \code{"0"}，を取り除くべきかどうかを指示する；
    また指数表記中の \code{"e+00"} を除く．}
  \item{is.cmplx}{オプションの論理値で，\code{x} が \code{"\link{character}"}
    の時それが複素数ベクトル由来かどうかを指示する．
    既定(\code{NA})では，\code{x} は複素数らしくなる．}
  \item{\dots}{\code{format} に渡される引数．}

  \item{nx}{\code{x} と同じ長さの数値ベクトルで，典型的には
    文字列ベクトル \code{x} が予め整形されている数．}
}
\value{
  \code{x} と同じサイズと属性の文字列オブジェクト
  (任意のクラスを捨て去った後)で現在のロケールでエンコードされている．

  \code{\link{format}} とは異なり，各数値は個別に整形される．
  \code{x} の各要素に渡りループし C 関数
  \code{sprintf(\dots)} が数値入力に対し呼び出される
  (C 関数 \code{str_signif} の内部で)．

  \code{formatC}: 文字列 \code{x} に対して単純に(左もしくは右に)
  空白で埋める．
}
\details{
  \code{format} の設定は \code{mode} 設定を上書きする．
  従って次は \code{123} を与える，

  \code{formatC(123.45, mode = "double", format = "d")}．

  科学的表記の翻訳はプラットフォーム依存である：
  ある種のシステムは \code{n.ddde+nn} の代わりに \code{n.ddde+nnn} や
  \code{n.dddenn} を使う．

  \code{formatC} は必ずしも小数点で数を整列しないので
  次は \code{c("6.1", " 13")} を与える，

  \code{formatC(c(6.11, 13.1), digits = 2, format = "fg")}．
  もし幾つかの数を共通に整形したければ \code{\link{format}} を使う．

  \code{prettyNum} は \code{x} を見栄え良く整形するためのユーティリティーである．
  ここで \code{x} は複素数(又は \code{\link{format}(<complex>)} でも良い．もし
  \code{x} が文字列でなければ，\code{format(x[i], ...)} が各要素に適用され，
  そしてそれからもし他の引数が既定通りであればそのままにして置かれる．
  \code{x} がピリオドを小数点に持つ \code{format(<number>)} のようなものの
  結果ではない文字列ベクトルの時は，\code{prettyNum(x)} に対して
  \code{input.d.mark} 引数を使う．

  \code{big.mark} と \code{small.mark} を挿入するために \code{\link{gsub}} が
  使われるので，特殊文字はエスケープ化する必要がある．
  特に単一のバックスラッシュを挿入するには \code{"\\\\\\\\"} を使う．

  \R の数値ベクトルとして使われる C の倍精度実数は符号付きゼロを持つ．
  \code{formatC} はこれを \code{-0}, \code{-0.000} \dots のように
  出力するかもしれない．

  もし \code{big.mark} と \code{decimal.mark} が同じならば警告が出る：
  これは出力を読むものに混乱をもたらすであろう．
}
\note{
  \R 3.0.2 以前ではこれは \code{x} のクラスを返り値にコピーしたため，
  不正なオブジェクトを簡単に作りかねなかった．

  \code{formatC()} 中の \code{decimal.mark} の既定値は \R 3.2.0 で
  変更された：パッケージ中の \code{\link{print}} メソッドの内部で以前のバージョンの
  と共に使うためには \code{decimal.mark = getOption("OutDec")} を
  明示的に使う．
}
\author{
  \code{formatC} は最初 Bill Dunlap により S-PLUS のために書かれ，後で
  Martin Maechler によりより改良された．

  これは最初に Friedrich Leisch により \R に導入され，以来
  R Core team により改良された．

  %% The utilities \code{prettyNum()} and \code{.format.zeros()} are by
  %% Martin Maechler
}
\references{
  Kernighan, B. W. and Ritchie, D. M. (1988)
  \emph{The C Programming Language.}  Second edition.  Prentice Hall.
}
\seealso{
  \code{\link{format}}.

  より一般的な C 風整形には \code{\link{sprintf}}．
}
\examples{
xx  <- pi * 10^(-5:4)
cbind(format(xx, digits = 4), formatC(xx))
cbind(formatC(xx, width = 9, flag = "-"))
cbind(formatC(xx, digits = 5, width = 8, format = "f", flag = "0"))
cbind(format(xx, digits = 4), formatC(xx, digits = 4, format = "fg"))

formatC(    c("a", "Abc", "no way"), width = -7)  # <=> flag = "-"
formatC(c((-1:1)/0,c(1,100)*pi), width = 8, digits = 1)

## 結果の幾つかは多倍長算術の実装に依存する，これはプラットフォーム固有である
xx <- c(1e-12,-3.98765e-10,1.45645e-69,1e-70,pi*1e37,3.44e4)
##       1        2             3        4      5       6
formatC(xx)
formatC(xx, format = "fg")       # 特別な "固定" 書式．
formatC(xx[1:4], format = "f", digits = 75) #>> 更に長い文字列

formatC(c(3.24, 2.3e-6), format = "f", digits = 11, drop0trailing = TRUE)

r <- c("76491283764.97430", "29.12345678901", "-7.1234", "-100.1","1123")
## アメリカ：
prettyNum(r, big.mark = ",")
## ヨーロッパの幾つかの国：
prettyNum(r, big.mark = "'", decimal.mark = ",")

(dd <- sapply(1:10, function(i) paste((9:0)[1:i], collapse = "")))
prettyNum(dd, big.mark = "'")

## 'small.mark' の例
pN <- stats::pnorm(1:7, lower.tail = FALSE)
cbind(format (pN, small.mark = " ", digits = 15))
cbind(formatC(pN, small.mark = " ", digits = 17, format = "f"))

cbind(ff <- format(1.2345 + 10^(0:5), width = 11, big.mark = "'"))
## すべてが同じ幅(指定最小値より一つ多い)

## 共通の幅へ個別に整形：
fc <- formatC(1.234 + 10^(0:8), format = "fg", width = 11, big.mark = "'")
cbind(fc)
## 2の巾乗，正確に保管され，個別に整形：
pow.2 <- formatC(2^-(1:32), digits = 24, width = 1, format = "fg")
## 見栄え良くプリント(最後の行は 5^32 を正確に表現)：
noquote(cbind(pow.2))

## 複素数：
r <- 10.0000001; rv <- (r/10)^(1:10)
(zv <- (rv + 1i*rv))
op <- options(digits = 7) ## (system default)
(pnv <- prettyNum(zv))
stopifnot(pnv == "1+1i", pnv == format(zv),
          pnv == prettyNum(zv, drop0trailing = TRUE))
## より多くの桁数は様子が変わる：
options(digits = 8)
head(fv <- format(zv), 3)
prettyNum(fv)
prettyNum(fv, drop0trailing = TRUE) # 少し見栄えが良い
options(op)
}
\keyword{character}
\keyword{print}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/formatc.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{formatC}
%\title{Formatting Using C-style Formats}
%\alias{formatC}
%\alias{prettyNum}
%\alias{.format.zeros}
%\description{
%  Formatting numbers individually and flexibly, \code{formatC()} using
%  \code{C} style format specifications.
%
%  \code{prettyNum()} is used for \dQuote{prettifying} (possibly
%  formatted) numbers, also in \code{\link{format.default}}.
%
%  \code{.format.zeros()}, an auxiliary function of \code{prettyNum()}
%  re-formats the zeros in a vector \code{x} of formatted numbers.
%}
%\usage{
%formatC(x, digits = NULL, width = NULL,
%        format = NULL, flag = "", mode = NULL,
%        big.mark = "", big.interval = 3L,
%        small.mark = "", small.interval = 5L,
%        decimal.mark = getOption("OutDec"),
%        preserve.width = "individual", zero.print = NULL,
%        drop0trailing = FALSE)
%
%prettyNum(x, big.mark = "",   big.interval = 3L,
%          small.mark  = "", small.interval = 5L,
%          decimal.mark = getOption("OutDec"), input.d.mark = decimal.mark,
%          preserve.width = c("common", "individual", "none"),
%          zero.print = NULL, drop0trailing = FALSE, is.cmplx = NA,
%          \dots)
%
%.format.zeros(x, zero.print, nx = suppressWarnings(as.numeric(x)))
%}
%\arguments{
%  \item{x}{an atomic numerical or character object, possibly
%    \code{\link{complex}} only for \code{prettyNum()}, typically a
%    vector of real numbers.  Any class is discarded, with a warning.}
%
%  \item{digits}{the desired number of digits after the decimal
%    point (\code{format = "f"}) or \emph{significant} digits
%    (\code{format = "g"}, \code{= "e"} or \code{= "fg"}).
%
%    Default: 2 for integer, 4 for real numbers.  If less than 0,
%    the C default of 6 digits is used.  If specified as more than 50, 50
%    will be used with a warning unless \code{format = "f"} where it is
%    limited to typically 324. (Not more than 15--21 digits need be
%    accurate, depending on the OS and compiler used.  This limit is
%    just a precaution against segfaults in the underlying C runtime.)
%  }
%
%  \item{width}{the total field width; if both \code{digits} and
%    \code{width} are unspecified, \code{width} defaults to 1,
%    otherwise to \code{digits + 1}.  \code{width = 0} will use
%    \code{width = digits}, \code{width < 0} means left
%    justify the number in this field (equivalent to \code{flag = "-"}).
%    If necessary, the result will have more characters than
%    \code{width}.  For character data this is interpreted in characters
%    (not bytes nor display width).
%  }
%
%  \item{format}{equal to \code{"d"}  (for integers), \code{"f"},
%    \code{"e"}, \code{"E"}, \code{"g"}, \code{"G"}, \code{"fg"} (for
%    reals), or \code{"s"} (for strings).  Default is \code{"d"} for
%    integers, \code{"g"} for reals.
%
%    \code{"f"} gives numbers in the usual
%    \code{xxx.xxx} format;  \code{"e"} and \code{"E"} give \code{n.ddde+nn} or
%    \code{n.dddE+nn} (scientific format); \code{"g"} and \code{"G"} put
%    \code{x[i]} into scientific format only if it saves space to do so.
%
%    \code{"fg"} uses fixed format as \code{"f"}, but \code{digits} as
%    the minimum number of \emph{significant} digits.  This can lead
%    to quite long result strings, see examples below.  Note that unlike
%    \code{\link{signif}} this prints large numbers with
%    more significant digits than \code{digits}.  Trailing zeros are
%    \emph{dropped} in this format, unless \code{flag} contains
%    \code{"#"}.}
%
%  \item{flag}{For \code{formatC}, a character string giving a
%    format modifier as in Kernighan and Ritchie (1988, page 243).
%    \code{"0"}  pads leading zeros; \code{"-"} does left adjustment,
%    others are \code{"+"}, \code{" "}, and \code{"#"}.  There can be
%    more than one of these, in any order.
%  }
%
%  \item{mode}{\code{"double"} (or \code{"real"}), \code{"integer"} or
%    \code{"character"}.
%    Default: Determined from the storage mode of \code{x}.}
%
%  \item{big.mark}{character; if not empty used as mark between every
%    \code{big.interval} decimals \emph{before} (hence \code{big}) the
%    decimal point.}
%  \item{big.interval}{see \code{big.mark} above; defaults to 3.}
%  \item{small.mark}{character; if not empty used as mark between every
%    \code{small.interval} decimals \emph{after} (hence \code{small}) the
%    decimal point.}
%  \item{small.interval}{see \code{small.mark} above; defaults to 5.}
%  \item{decimal.mark}{the character to be used to indicate the numeric
%    decimal point.}
%  \item{input.d.mark}{if \code{x} is \code{\link{character}}, the
%    character known to have been used as the numeric decimal point in
%    \code{x}.}
%  \item{preserve.width}{string specifying if the string widths should
%    be preserved where possible in those cases where marks
%    (\code{big.mark} or \code{small.mark}) are added.  \code{"common"},
%    the default, corresponds to \code{\link{format}}-like behavior
%    whereas \code{"individual"} is the default in
%    \code{formatC()}. Value can be abbreviated.}
%  \item{zero.print}{logical, character string or \code{NULL} specifying
%    if and how \emph{zeros} should be formatted specially.  Useful for
%    pretty printing \sQuote{sparse} objects.}
%  \item{drop0trailing}{logical, indicating if trailing zeros,
%    i.e., \code{"0"} \emph{after} the decimal mark, should be removed;
%    also drops \code{"e+00"} in exponential formats.}
%  \item{is.cmplx}{optional logical, to be used when \code{x} is
%    \code{"\link{character}"} to indicate if it stems from
%    \code{\link{complex}} vector or not.  By default (\code{NA}),
%    \code{x} is checked to \sQuote{look like} complex.}
%  \item{\dots}{arguments passed to \code{format}.}
%
%  \item{nx}{numeric vector of the same length as \code{x}, typically the
%    numbers of which the character vector \code{x} is the pre-format.}
%}
%\value{
%  A character object of same size and attributes as \code{x} (after
%  discarding any class), in the current locale's encoding.
%
%  Unlike \code{\link{format}}, each number is formatted individually.
%  Looping over each element of \code{x}, the C function
%  \code{sprintf(\dots)} is called for numeric inputs (inside the C
%  function \code{str_signif}).
%
%  \code{formatC}: for character \code{x}, do simple (left or right)
%  padding with white space.
%}
%\details{
%  If you set \code{format} it overrides the setting of \code{mode}, so
%  \code{formatC(123.45, mode = "double", format = "d")} gives \code{123}.
%
%  The rendering of scientific format is platform-dependent: some systems
%  use \code{n.ddde+nnn} or \code{n.dddenn} rather than \code{n.ddde+nn}.
%
%  \code{formatC} does not necessarily align the numbers on the decimal
%  point, so \code{formatC(c(6.11, 13.1), digits = 2, format = "fg")} gives
%  \code{c("6.1", " 13")}.  If you want common formatting for several
%  numbers, use \code{\link{format}}.
%
%  \code{prettyNum} is the utility function for prettifying \code{x}.
%  \code{x} can be complex (or \code{\link{format}(<complex>)}, here.  If
%  \code{x} is not a character, \code{format(x[i], ...)} is applied to
%  each element, and then it is left unchanged if all the other arguments
%  are at their defaults.  Use the \code{input.d.mark} argument for
%  \code{prettyNum(x)} when \code{x} is a \code{character} vector not
%  resulting from something like \code{format(<number>)} with a period as
%  decimal mark.
%
%  Because \code{\link{gsub}} is used to insert the \code{big.mark}
%  and \code{small.mark}, special characters need escaping.  In particular,
%  to insert a single backslash, use \code{"\\\\\\\\"}.
%
%  The C doubles used for \R numerical vectors have signed zeros, which
%  \code{formatC} may output as \code{-0}, \code{-0.000} \dots.
%
%  There is a warning if \code{big.mark} and \code{decimal.mark} are the
%  same: that would be confusing to those reading the output.
%}
%\note{
%  Prior to \R 3.0.2 this copied the class of \code{x} to the return
%  value and could easily create invalid objects.
%
%  The default for \code{decimal.mark} in \code{formatC()} was changed in
%  \R 3.2.0: for use within \code{\link{print}} methods in packages which might
%  be used with earlier versions: use \code{decimal.mark = getOption("OutDec")}
%  explicitly.
%}
%\author{
%  \code{formatC} was originally written by Bill Dunlap for S-PLUS, later
%  much improved by Martin Maechler.
%
%  It was first adapted for \R by Friedrich Leisch and since much
%  improved by the R Core team.
%
%  %% The utilities \code{prettyNum()} and \code{.format.zeros()} are by
%  %% Martin Maechler
%}
%\references{
%  Kernighan, B. W. and Ritchie, D. M. (1988)
%  \emph{The C Programming Language.}  Second edition.  Prentice Hall.
%}
%\seealso{
%  \code{\link{format}}.
%
%  \code{\link{sprintf}} for more general C-like formatting.
%}
%\examples{
%xx  <- pi * 10^(-5:4)
%cbind(format(xx, digits = 4), formatC(xx))
%cbind(formatC(xx, width = 9, flag = "-"))
%cbind(formatC(xx, digits = 5, width = 8, format = "f", flag = "0"))
%cbind(format(xx, digits = 4), formatC(xx, digits = 4, format = "fg"))
%
%formatC(    c("a", "Abc", "no way"), width = -7)  # <=> flag = "-"
%formatC(c((-1:1)/0,c(1,100)*pi), width = 8, digits = 1)
%
%## note that some of the results here depend on the implementation
%## of long-double arithmetic, which is platform-specific.
%xx <- c(1e-12,-3.98765e-10,1.45645e-69,1e-70,pi*1e37,3.44e4)
%##       1        2             3        4      5       6
%formatC(xx)
%formatC(xx, format = "fg")       # special "fixed" format.
%formatC(xx[1:4], format = "f", digits = 75) #>> even longer strings
%
%formatC(c(3.24, 2.3e-6), format = "f", digits = 11, drop0trailing = TRUE)
%
%r <- c("76491283764.97430", "29.12345678901", "-7.1234", "-100.1","1123")
%## American:
%prettyNum(r, big.mark = ",")
%## Some Europeans:
%prettyNum(r, big.mark = "'", decimal.mark = ",")
%
%(dd <- sapply(1:10, function(i) paste((9:0)[1:i], collapse = "")))
%prettyNum(dd, big.mark = "'")
%
%## examples of 'small.mark'
%pN <- stats::pnorm(1:7, lower.tail = FALSE)
%cbind(format (pN, small.mark = " ", digits = 15))
%cbind(formatC(pN, small.mark = " ", digits = 17, format = "f"))
%
%cbind(ff <- format(1.2345 + 10^(0:5), width = 11, big.mark = "'"))
%## all with same width (one more than the specified minimum)
%
%## individual formatting to common width:
%fc <- formatC(1.234 + 10^(0:8), format = "fg", width = 11, big.mark = "'")
%cbind(fc)
%## Powers of two, stored exactly, formatted individually:
%pow.2 <- formatC(2^-(1:32), digits = 24, width = 1, format = "fg")
%## nicely printed (the last line showing 5^32 exactly):
%noquote(cbind(pow.2))
%
%## complex numbers:
%r <- 10.0000001; rv <- (r/10)^(1:10)
%(zv <- (rv + 1i*rv))
%op <- options(digits = 7) ## (system default)
%(pnv <- prettyNum(zv))
%stopifnot(pnv == "1+1i", pnv == format(zv),
%          pnv == prettyNum(zv, drop0trailing = TRUE))
%## more digits change the picture:
%options(digits = 8)
%head(fv <- format(zv), 3)
%prettyNum(fv)
%prettyNum(fv, drop0trailing = TRUE) # a bit nicer
%options(op)
%}
%\keyword{character}
%\keyword{print}
%
\encoding{UTF8}
