% File src/library/base/man/gettext.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{gettext}
\alias{gettext}
\alias{ngettext}
\alias{bindtextdomain}
\title{Translate Text Messages}
\description{
  もしこの \R の構築で自然言語のサポートが有効化されていれば
  文字列ベクトルを翻訳する，又はどこで翻訳が見つかるかを設定する．
}
\usage{
gettext(\dots, domain = NULL)

ngettext(n, msg1, msg2, domain = NULL)

bindtextdomain(domain, dirname = NULL)
}
\arguments{
  \item{\dots}{一つもしくはそれ以上の文字列ベクトル．}
  \item{domain}{翻訳のための\sQuote{ドメイン}．}
  \item{n}{非負整数．}
  \item{msg1}{\code{n = 1} に対して使われる英語メセージ．}
  \item{msg2}{\code{n = 0, 2, 3, \dots} に対して使われる英語メッセージ．}
  \item{dirname}{ドメインに対する翻訳メッセージを見つけるディレクトリ．}
}
\details{
  もし \code{domain} が \code{NULL} か \code{""} で，\code{gettext} 
  がパッケージ \pkg{pkg} の名前空間中の関数から呼び出されていれば，
  ドメインは \code{"R-pkg"} に設定される．さもなければ既定のドメインは無い．

  もし適当なドメインが見つかれば，各文字列が翻訳のために提供され，
  もし見つかればその翻訳によって現在の言語に置き換えられる．
  値(論理値) \code{NA} は任意の翻訳を抑制する．

  便宜上パッケージ \pkg{pkg} 中の \R の警告/エラーメッセージのドメインは
  \code{"R-pkg"} であり，C レベルのメッセージのそれは \code{"pkg"} である．

  \code{gettext} に対しては翻訳を探す時，先頭と末尾の空白は無視される．

  \code{ngettext} はメッセージが一つの整数で変化する必要がある箇所で
  使われる．そうしたメッセージの翻訳は異なった言語に対しては非常に固有な規則の
  下にある：GNU Gettext Manual を見よ．文字列はしばしば \code{\link{sprintf}}
  中で使われる単一の \code{\%d} の例を含むであろう．
  もし英語が使われれば，\code{msg1} はもし \code{n == 1} ならば，
  その他のすべてのケースでは \code{msg2} が使われる．

  \code{bindtextdomain} は同名の C 関数に対するラッパである：
  使用中のシステムはそれに対する \command{man} ページを持つかもしれない．
  \code{dirname} が \code{NULL} でなければ，それはメッセージのカタログを
  どこで探すかを指示する：
  \code{domain = NULL} ならばそれは現在の位置を返す．
}
\value{
  \code{gettext} に対しては文字列ベクトルで，\code{\dots} 中の文字列毎に
  一つの要素を持つ．もし翻訳が不可能か，如何なるドメインも見つからないか，
  そのドメイン中に翻訳がみつからなければ，元々の文字列が返される．

  \code{ngettext} に対しては文字列．

  \code{bindtextdomain} に対しては現在の基本ディレクトリを与える文字列，
  又はそれを設定するのが失敗すれば \code{NULL}．
}
\seealso{
  \code{\link{stop}} と \code{\link{warning}} はメッセージの翻訳に
  \code{gettext} を使う．

  \R のソースファイルから翻訳可能な文字列を取り出すには \code{\link{xgettext}}．
}
\examples{
bindtextdomain("R")  # NLS が有効な時，そしてその時に限り NULL でない

for(n in 0:3)
    print(sprintf(ngettext(n, "\%d variable has missing values",
                              "\%d variables have missing values"),
                  n))

\dontrun{
## 翻訳に対して，これらの文字列は R-pkg.pot 中に次のように登場すべきである
msgid        "\%d variable has missing values"
msgid_plural "\%d variables have missing values"
msgstr[0] ""
msgstr[1] ""
}

miss <- c("one", "or", "another")
cat(ngettext(length(miss), "variable", "variables"),
    paste(sQuote(miss), collapse = ", "),
    ngettext(length(miss), "contains", "contain"), "missing values\n")

## 翻訳者にお勧めの使用法
cat(sprintf(ngettext(length(miss),
                     "variable \%s contains missing values\n",
                     "variables \%s contain missing values\n"),
            paste(sQuote(miss), collapse = ", ")))
}
\keyword{ utilities }
\keyword{ character }
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/gettext.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{gettext}
%\alias{gettext}
%\alias{ngettext}
%\alias{bindtextdomain}
%\title{Translate Text Messages}
%\description{
%  If Native Language Support was enabled in this build of \R, attempt to
%  translate character vectors or set where the translations are to be found.
%}
%\usage{
%gettext(\dots, domain = NULL)
%
%ngettext(n, msg1, msg2, domain = NULL)
%
%bindtextdomain(domain, dirname = NULL)
%}
%\arguments{
%  \item{\dots}{One or more character vectors.}
%  \item{domain}{The \sQuote{domain} for the translation.}
%  \item{n}{a non-negative integer.}
%  \item{msg1}{the message to be used in English for \code{n = 1}.}
%  \item{msg2}{the message to be used in English for \code{n = 0, 2, 3, \dots}.}
%  \item{dirname}{The directory in which to find translated message
%    catalogs for the domain.}
%}
%\details{
%  If \code{domain} is \code{NULL} or \code{""}, and \code{gettext} is
%  called from a function in the namespace of package \pkg{pkg} the
%  domain is set to \code{"R-pkg"}.  Otherwise there is no default
%  domain.
%
%  If a suitable domain is found, each character string is offered for
%  translation, and replaced by its translation into the current language
%  if one is found.  The value (logical) \code{NA} suppresses any
%  translation.
%
%  Conventionally the domain for \R warning/error messages in package
%  \pkg{pkg} is \code{"R-pkg"}, and that for C-level messages is \code{"pkg"}.
%
%  For \code{gettext}, leading and trailing whitespace is ignored when
%  looking for the translation.
%
%  \code{ngettext} is used where the message needs to vary by a single
%  integer.  Translating such messages is subject to very specific rules
%  for different languages: see the GNU Gettext Manual.  The string
%  will often contain a single instance of \code{\%d} to be used in
%  \code{\link{sprintf}}.  If English is used, \code{msg1} is returned if
%  \code{n == 1} and \code{msg2} in all other cases.
%
%  \code{bindtextdomain} is a wrapper for the C function of the same
%  name: your system may have a \command{man} page for it.  With a
%  non-\code{NULL} \code{dirname} it specifies where to look for message
%  catalogues: with \code{domain = NULL} it returns the current location.
%}
%\value{
%  For \code{gettext}, a character vector, one element per string in
%  \code{\dots}.  If translation is not enabled or no domain is found or
%  no translation is found in that domain, the original strings are
%  returned.
%
%  For \code{ngettext}, a character string.
%
%  For \code{bindtextdomain}, a character string giving the current base
%  directory, or \code{NULL} if setting it failed.
%}
%\seealso{
%  \code{\link{stop}} and \code{\link{warning}} make use of \code{gettext} to
%  translate messages.
%
%  \code{\link{xgettext}} for extracting translatable strings from \R
%  source files.
%}
%\examples{
%bindtextdomain("R")  # non-null if and only if NLS is enabled
%
%for(n in 0:3)
%    print(sprintf(ngettext(n, "\%d variable has missing values",
%                              "\%d variables have missing values"),
%                  n))
%
%\dontrun{
%## for translation, those strings should appear in R-pkg.pot as
%msgid        "\%d variable has missing values"
%msgid_plural "\%d variables have missing values"
%msgstr[0] ""
%msgstr[1] ""
%}
%
%miss <- c("one", "or", "another")
%cat(ngettext(length(miss), "variable", "variables"),
%    paste(sQuote(miss), collapse = ", "),
%    ngettext(length(miss), "contains", "contain"), "missing values\n")
%
%## better for translators would be to use
%cat(sprintf(ngettext(length(miss),
%                     "variable \%s contains missing values\n",
%                     "variables \%s contain missing values\n"),
%            paste(sQuote(miss), collapse = ", ")))
%}
%\keyword{ utilities }
%\keyword{ character }
%
\encoding{UTF8}
