% File src/library/base/man/names.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{names}
\alias{names}
\alias{names.default}
\alias{names<-}
\alias{names<-.default}
\title{The Names of an Object}
\description{
  オブジェクトの名前を得る，又は設定する関数．
}
\usage{
names(x)
names(x) <- value
}
\arguments{
  \item{x}{\R オブジェクト．}
  \item{value}{最大 \code{x} と同じ長さの文字列ベクトル．又は \code{NULL}．}
}

\value{
  \code{names} に対しては \code{NULL} か \code{x} と同じ長さの文字列ベクトル．
  (\code{NULL} はオブジェクトが名前を持たないか，名前を持てないような
  型のオブジェクトの時与えられる．)  環境に対しては長さは環境中のオブジェクトの
  数であるが，名前の順序は任意である．

  \code{names<-} に対しては更新されたオブジェクト．
  (\code{names(x) <- value} の値は付値のそれ，\code{value}，であり，
  左辺側からの返り値ではないことを注意する．)
}

\details{
  \code{names} は総称的なアクセス関数であり，\code{names<-} は 
  総称的な置き換え関数である．既定のメソッドはベクトル(リストを含む)や対リスト
  の \code{"names"} 属性を取得したり設定したりする．

  環境 \code{env} に対しては \code{names(env)} は
  \code{names(as.list(env, all.names = TRUE))} であり，対応するリストの名前を返す．
  これはまた
  \code{\link{ls}(env, all.names = TRUE, sorted = FALSE)} でも得られる．もし
  環境がハッシュテーブルとして使われていると \code{names(env)} は
  その\dQuote{キー}である．

  もし \code{value} が \code{x} より短いと，それは文字
  \code{NA} で \code{x} の長さまで拡大される．

  一般的な規則を使い名前属性の一部分だけを更新することが出来る：
  下の例を見よ．これはそこでの表現式が
  \code{z <- "names<-"(z, "[<-"(names(z), 3, "c2"))} のように評価されることから
  動作する．

  名前 \code{""} は特殊である：これはベクトル(原子的か総称的)の要素に
  伴う名前がないことを指示するのに使われる．
  \code{""} による添字操作はどれともマッチしない(名前を持たない要素にすら)．

  名前は文字 \code{NA} でも良いが，そうした名前は決してマッチされることはなく
  混乱を招きやすい．

  双方はプリミティブ関数である．
}
\note{
  ベクトルに対しては，名前は可能な値に制限がある属性の一つである．
  対リストに対しては，名前はタグであり文字列ベクトルから/へ変換可能である．

  1次元配列に対しては名前属性は実際には \code{\link{dimnames}[[1]]} である．

  形式的クラスを持つ，つまり \dQuote{S4}， オブジェクトは典型的に
  \code{\link{slotNames}()} を持つ(そして \code{names()} は無い)．
}
\seealso{
  \code{\link{slotNames}}, \code{\link{dimnames}}.
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\examples{
# island データセットの名前属性をプリントする
names(islands)

# 名前属性を取り除く
names(islands) <- NULL
islands
rm(islands) # 作られたコピーを抹消

z <- list(a = 1, b = "c", c = 1:3)
names(z)
# 三番目の要素の名前だけを変更する．
names(z)[3] <- "c2"
z

z <- 1:3
names(z)
## 一つの名前だけを付値
names(z)[2] <- "b"
z

\dontshow{## 上で述べられた同値性を"示す"：
  for(e in c(baseenv(), globalenv()))
  stopifnot(identical(names(e), ls(e, all.names=TRUE, sorted=FALSE)),
            identical(names(e), names(as.list(e, all.names=TRUE))))
}
}
\keyword{attribute}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/names.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{names}
%\alias{names}
%\alias{names.default}
%\alias{names<-}
%\alias{names<-.default}
%\title{The Names of an Object}
%\description{
%  Functions to get or set the names of an object.
%}
%\usage{
%names(x)
%names(x) <- value
%}
%\arguments{
%  \item{x}{an \R object.}
%  \item{value}{a character vector of up to the same length as \code{x}, or
%    \code{NULL}.}
%}
%
%\value{
%  For \code{names}, \code{NULL} or a character vector of the same length
%  as \code{x}.  (\code{NULL} is given if the object has no names,
%  including for objects of types which cannot have names.)  For an
%  environment, the length is the number of objects in the environment
%  but the order of the names is arbitrary.
%
%  For \code{names<-}, the updated object.  (Note that the value of
%  \code{names(x) <- value} is that of the assignment, \code{value}, not
%  the return value from the left-hand side.)
%}
%
%\details{
%  \code{names} is a generic accessor function, and \code{names<-} is a
%  generic replacement function.  The default methods get and set
%  the \code{"names"} attribute of a vector (including a list) or
%  pairlist.
%
%  For an \code{\link{environment}} \code{env}, \code{names(env)} gives
%  the names of the corresponding list, i.e.,
%  \code{names(as.list(env, all.names = TRUE))} which are also given by
%  \code{\link{ls}(env, all.names = TRUE, sorted = FALSE)}.  If the
%  environment is used as a hash table, \code{names(env)} are its
%  \dQuote{keys}.
%
%  If \code{value} is shorter than \code{x}, it is extended by character
%  \code{NA}s to the length of \code{x}.
%
%  It is possible to update just part of the names attribute via the
%  general rules: see the examples.  This works because the expression
%  there is evaluated as \code{z <- "names<-"(z, "[<-"(names(z), 3, "c2"))}.
%
%  The name \code{""} is special: it is used to indicate that there is no
%  name associated with an element of a (atomic or generic) vector.
%  Subscripting by \code{""} will match nothing (not even elements which
%  have no name).
%
%  A name can be character \code{NA}, but such a name will never be
%  matched and is likely to lead to confusion.
%
%  Both are \link{primitive} functions.
%}
%\note{
%  For vectors, the names are one of the \link{attributes} with
%  restrictions on the possible values.  For pairlists, the names are the
%  tags and converted to and from a character vector.
%
%  For a one-dimensional array the \code{names} attribute really is
%  \code{\link{dimnames}[[1]]}.
%
%  Formally classed aka \dQuote{S4} objects typically have
%  \code{\link{slotNames}()} (and no \code{names()}).
%}
%\seealso{
%  \code{\link{slotNames}}, \code{\link{dimnames}}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\examples{
%# print the names attribute of the islands data set
%names(islands)
%
%# remove the names attribute
%names(islands) <- NULL
%islands
%rm(islands) # remove the copy made
%
%z <- list(a = 1, b = "c", c = 1:3)
%names(z)
%# change just the name of the third element.
%names(z)[3] <- "c2"
%z
%
%z <- 1:3
%names(z)
%## assign just one name
%names(z)[2] <- "b"
%z
%
%\dontshow{## "show" the equivalence claimed above:
%  for(e in c(baseenv(), globalenv()))
%  stopifnot(identical(names(e), ls(e, all.names=TRUE, sorted=FALSE)),
%            identical(names(e), names(as.list(e, all.names=TRUE))))
%}
%}
%\keyword{attribute}
%
\encoding{UTF8}
