% File src/library/base/man/ns-hooks.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{ns-hooks}
\alias{.onLoad}
\alias{.onUnload}
\alias{.onAttach}
\alias{.onDetach}
\alias{.Last.lib}
\title{Hooks for Namespace Events}
\description{
  パッケージはロード，付加，除去，又はアンロードの際に呼び出される
  関数を提供できる．
}

\usage{
.onLoad(libname, pkgname)
.onAttach(libname, pkgname)
.onUnload(libpath)
.onDetach(libpath)
.Last.lib(libpath)
}
\arguments{
  \item{libname}{名前空間を定義しているパッケージが見つかったライブラリの
  ディレクトリを与える文字列．}
  \item{pkgname}{パッケージの名前を与える文字列．}
  \item{libpath}{パッケージへの完全なパスを与える文字列．}
}
\details{
  ロード後，名前空間が封印され移出を実行する前に，\code{\link{loadNamespace}} は
  \code{.onLoad} という名前のフック関数を探しそれを
  (二つの名前無し引数と共に)呼び出す．

  パッケージが付加(\code{\link{library}} か
  \code{\link{attachNamespace}} を使い)されると．フック関数
  \code{.onAttach} が探され，もし見つかるとパッケージ環境が
  封印される前に(二つの名前のない引数と共に)呼び出される．

  もし関数 \code{.onDetach} (\R 3.0.0 以来)が名前空間中にあるか
  \code{.Last.lib} がパッケージから移出されていると，
  パッケージが \code{\link{detach}} される際に，
  それが(一つの引数と共に)呼び出される．
  それは \code{.onAttach} が失敗していても呼び出されるかもしれず，
  従って用心深く書かれる必要がある．
  (それは \code{\link{tryCatch}} 中で呼び出されるので，
  エラーはパッケージが除去されることをストップはしない．)

  もし名前空間が(\code{\link{unloadNamespace}} を使って)アンロードされると，
  フック関数 \code{.onUnload} が最終的なアンロードの前に(一つの引数で)
  実行される．

  \code{.onLoad} と \code{.onUnload} 中のコードは検索パス上に基本
  パッケージ以外のパッケージがあることを仮定すべきではないことを注意しよう．
  現在のパッケージ中のオブジェクトは可視である(これが禁止されていない限り)
  が，他のパッケージからのオブジェクトは移入されるか二重コロン演算子を
  使うべきである．
  
  \code{.onLoad}, \code{.onUnload}, \code{.onAttach} そして
  \code{.onDetach} は名前空間中の内部オブジェクトとして探され，
  移出されてはならない(一方で \code{.Last.lib} はすべきである)．

 パッケージはユーザがそうするようにアレンジしない限り
 (例えば \code{\link{.Last}} 経由で)，\R セッションの最後で
 除去もアンロードもされないことを注意しよう．

  名前空間の機能に対して必要な全てはロード/アンロード時に
  \code{.onLoad} と \code{.onUnload} フックで処理されるべきである．
  例えば，DLL は(\file{NAMESPACE} ファイル中で \code{useDynLib}
  ダイレクティブでなされるのでない限り) \code{.onLoad} 中で
  ロードと初期化を行うことが出来，そして \code{.onUnload} 中で
  アンロード出来る．\code{.onAttach} はパッケージがユーザに
  見えるようになった時だけ必要になるアクションにだけ使う
  (例えば起動メッセージ)か，もしくはパッケージ環境が作られた後に
  実行される必要がある．
}

\section{良い作法}{
  名前空間のロードは \code{.onAttach} で与えられる開始メッセージを持ち，
  それが可能な限り静かであるべきでである．
  これらのメッセージ(そして \code{.onLoad} からの本質的なもの)は
  \code{\link{packageStartupMessage}} を使うべきで，そうすることで
  それらが邪魔になるところでは無言に出来る．

  これらのフック中では \code{library} や \code{require} 呼び出しは
  あってはならない．あるパッケージが他のパッケージをロードする方法は
  ファイル \file{DESCRIPTION} の \samp{Depends} 欄を使うことである：
  これは従属性が文章化されパッケージが正しい順序でロードされることを保証する．
  名前空間のロードは検索パスを変更すべきではない．
  パッケージを付加するのではなく，名前空間の他のパッケージへの
  従属性は他のパッケージの名前空間から(選択的に)移入することで
  達成されるべきである．

  パッケージの基本情報を表示するための \code{library} の \code{help}
  引数を使用することは計算されたパッケージ情報オブジェクトに
  関する \code{format} を使い，そしてこれを
  \code{packageStartupMessage} に渡すべきである．

  開始コードには \code{\link{installed.packages}} の呼び出しは
  あってはならない：それは非常に遅い可能性があり，
  パッケージのインストールが並列で行われるならば \R の
  2.14.2 以前のバージョンでは失敗する可能性がある．
  別の方法についてはそのヘルプページを見よ．

  コンパイルされたコード(例えば \code{\link{library.dynam}} を使って)は
  \file{NAMESPACE} ファイル中の \code{.onLoad} 又は \code{useDynLib}
  ディレクティブ中でロードされるべきである．
  同様に，コンパイルされたコードは \code{.Last.lib} や \code{.onDetach}
  中でアンロード(例えば \code{\link{library.dynam.unload}} を使って)
  すべきではなく，\code{.onUnload} 中でだけ行うべきである．
}
\seealso{
  \code{\link{setHook}} は同じイベントに複数のフックを如何にして
  設定できるか．そして全てのフックを含むイベントの系列の
  リストを示す．

  セッションの最後に実行されるフックについては \code{\link{reg.finalizer}}．

  名前空間についてのより多くのことは \code{\link{loadNamespace}}．
}
\keyword{utilities}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/ns-hooks.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{ns-hooks}
%\alias{.onLoad}
%\alias{.onUnload}
%\alias{.onAttach}
%\alias{.onDetach}
%\alias{.Last.lib}
%\title{Hooks for Namespace Events}
%\description{
%  Packages can supply functions to be called when
%  loaded, attached, detached or unloaded.
%}
%
%\usage{
%.onLoad(libname, pkgname)
%.onAttach(libname, pkgname)
%.onUnload(libpath)
%.onDetach(libpath)
%.Last.lib(libpath)
%}
%\arguments{
%  \item{libname}{a character string giving the library directory where
%    the package defining the namespace was found.}
%  \item{pkgname}{a character string giving the name of the package.}
%  \item{libpath}{a character string giving the complete path to the package.}
%}
%\details{
%  After loading, \code{\link{loadNamespace}} looks for a hook function
%  named \code{.onLoad} and calls it (with two unnamed arguments) before
%  sealing the namespace and processing exports.
%
%  When the package is attached (via \code{\link{library}} or
%  \code{\link{attachNamespace}}), the hook function \code{.onAttach} is
%  looked for and if found is called (with two unnamed arguments) before
%  the package environment is sealed.
%
%  If a function \code{.onDetach} (as from \R 3.0.0) is in the namespace
%  or \code{.Last.lib} is exported from the package, it will be called
%  (with a single argument) when the package is \code{\link{detach}}ed.
%  Beware that it might be called if \code{.onAttach} has failed, so it should be
%  written defensively.  (It is called within \code{\link{tryCatch}}, so
%  errors will not stop the package being detached.)
%
%  If a namespace is unloaded (via \code{\link{unloadNamespace}}), a hook
%  function \code{.onUnload} is run (with a single argument) before final
%  unloading.
%
%  Note that the code in \code{.onLoad} and \code{.onUnload} should not
%  assume any package except the base package is on the search path.
%  Objects in the current package will be visible (unless this is
%  circumvented), but objects from other packages should be imported or
%  the double colon operator should be used.
%
%  \code{.onLoad}, \code{.onUnload}, \code{.onAttach} and
%  \code{.onDetach} are looked for as internal objects in the namespace
%  and should not be exported (whereas \code{.Last.lib} should be).
%
%  Note that packages are not detached nor namespaces unloaded at the end
%  of an \R session unless the user arranges to do so (e.g., \emph{via}
%  \code{\link{.Last}}).
%
%  Anything needed for the functioning of the namespace should be
%  handled at load/unload times by the \code{.onLoad} and
%  \code{.onUnload} hooks.  For example, DLLs can be loaded (unless done
%  by a \code{useDynLib} directive in the \file{NAMESPACE} file) and
%  initialized in \code{.onLoad} and unloaded in \code{.onUnload}.  Use
%  \code{.onAttach} only for actions that are needed only when the
%  package becomes visible to the user (for example a start-up message)
%  or need to be run after the package environment has been created.
%}
%
%\section{Good practice}{
%  Loading a namespace should where possible be silent, with startup
%  messages given by \code{.onAttach}.  These messages (and any essential
%  ones from \code{.onLoad}) should use \code{\link{packageStartupMessage}}
%  so they can be silenced where they would be a distraction.
%
%  There should be no calls to \code{library} nor \code{require} in these
%  hooks.  The way for a package to load other packages is via the
%  \samp{Depends} field in the \file{DESCRIPTION} file: this ensures
%  that the dependence is documented and packages are loaded in the
%  correct order.  Loading a namespace should not change the search path,
%  so rather than attach a package, dependence of a namespace on another
%  package should be achieved by (selectively) importing from the other
%  package's namespace.
%
%  Uses of \code{library} with argument \code{help} to display basic
%  information about the package should use \code{format} on the
%  computed package information object and pass this to
%  \code{packageStartupMessage}.
%
%  There should be no calls to \code{\link{installed.packages}} in startup
%  code: it is potentially very slow and may fail in versions of \R
%  before 2.14.2 if package installation is going on in parallel.  See
%  its help page for alternatives.
%
%  Compiled code should be loaded (e.g., \emph{via}
%  \code{\link{library.dynam}}) in \code{.onLoad} or a \code{useDynLib}
%  directive in the \file{NAMESPACE} file, and not in \code{.onAttach}.
%  Similarly, compiled code should not be unloaded (e.g., \emph{via}
%  \code{\link{library.dynam.unload}}) in \code{.Last.lib} nor
%  \code{.onDetach}, only in \code{.onUnload}.
%}
%\seealso{
%  \code{\link{setHook}} shows how users can set hooks on the same events, and
%  lists the sequence of events involving all of the hooks.
%
%  \code{\link{reg.finalizer}} for hooks to be run at the end of a session.
%
%  \code{\link{loadNamespace}} for more about namespaces.
%}
%\keyword{utilities}
%
\encoding{UTF8}
