% File src/library/base/man/rep.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{rep}
\alias{rep}
\alias{rep.factor}
\alias{rep.int}
\alias{rep.POSIXct}
\alias{rep.POSIXlt}
\alias{rep.Date}
\alias{rep_len}

\title{Replicate Elements of Vectors and Lists}
\description{
  \code{rep} は \code{x} 中の値を複製する．これは総称的な関数であり，
  (内部的)既定メソッドがここで解説される．

  \code{rep.int} と \code{rep_len} は二つの通常ケース用の
  速くて簡単なバージョンである．
}
\usage{
rep(x, \dots)

rep.int(x, times)

rep_len(x, length.out)
}
\arguments{
  \item{x}{ベクトル(リストを含む任意のモードの)または因子
    (\code{rep} のみ)または \code{POSIXct}，\code{POSIXlt}，\code{Date}
    オブジェクト；又はそうしたオブジェクトを含む S4 オブジェクト．}
  \item{\dots}{他のメソッドに・から渡される追加の引数．
    内部的な既定メソッドには次のものが含まれる：
    \describe{
      \item{\code{times}}{長さが \code{length(x)} なら
        各要素を繰り返す(非負の)回数，
        もしくは長さが 1 ならベクトル全体を繰り返す回数を与える整数ベクトル．
        負または \code{NA} 値はエラーになる．}
      \item{\code{length.out}}{非負整数．出力ベクトルの希望の長さ．
        他の入力は整数ベクトルに変換され最初の要素が使われる．
        もし \code{NA} か不正なら無視される．}
      \item{\code{each}}{非負整数．\code{x} の各要素は
	\code{each} 回繰り返される．他の入力は整数ベクトルに変換され
	最初の一つが使われる．
	もし \code{NA} か不正なら \code{1} とされる．}
    }
  }
  \item{times}{\code{\dots} を見よ．}
  \item{length.out}{非負整数：出力ベクトルの希望の長さ．}
}

\details{
  既定動作はあたかも呼び出しが
\preformatted{  rep(x, times = 1, length.out = NA, each = 1)
} であるかのように行われる．普通追加引数の単に一つが指定されるが，
  もし \code{each} が他の二つのどちらかと共に指定されると，
  その複製は最初に実行され，それから
  \code{times} か \code{length.out} が意味するものが実行される．

  もし \code{times} が一つの整数であれば結果は
  入力全体をこの回数繰り返す．もし \code{times} が
  \code{x} と同じ長さのベクトル(\code{each} による複製の後に)ならば
  結果は \code{x[1]} を \code{times[1]} 回繰り返し，
  \code{x[2]} を \code{times[2]} 回繰り返し，等としたものから成る．

  \code{length.out} を \code{times} の代わりに使うことができ，
  その場合 \code{x} はこの長さのベクトルを作るのに必要な回数繰り返される．
  もし両方が与えられると \code{length.out} が優先され \code{times} は
  無視される．

  \code{times} の整数でない値はゼロに向かって切り下げられる．
  もし \code{times} が計算された量なら小さな余裕を加えるか
  \code{\link{round}} を使うのが用心深い．\code{each} に
  対しても同様である．

  もし \code{x} が長さゼロを持ち，そして \code{length.out} が提供され正
  ならば，値は抽出規則を使って埋められる，つまり
  原子的なベクトルに対しては適当なクラスの \code{NA} 
  (バイト型ベクトルには \code{0}) そしてリストには \code{NULL}．
}
\value{
  \code{x} と同じタイプのオブジェクト．

  \code{rep.int} と \code{rep_len} は属性を返さない
  (もし因子を返すときはクラスを除く)．

  \code{rep} の既定メソッドはもし \code{x} が名前を持てば結果に名前
  (ほとんど常に複製を含む)を与えるが，他の属性は保存しない．
}
\note{
  関数 \code{rep.int} は部分的に S との互換性のため，そして部分的に
  速度(特に名前を取り除ける場合)のために別の関数として提供された
  簡単なケースである．\code{rep} の速度はそれ以来改善されたが，
  それでも \code{rep.int} は依然として \code{x} が名前を持つ時よりも
  少なくとも2倍速い．

  名前 \code{rep.int} は \code{rep} の総称化にはるかに先立つ．

  関数 \code{rep} はプリミティブであるが，引数名の(部分)マッチングは
  通常の関数に対するように実行される．

  歴史的な理由から \code{rep} (だけは) \code{NULL} にも使える：
  結果は \code{length.out} が正の時ですら常に \code{NULL} である．

  決してドキュメント化されていないが，これらの関数は常に
  表現式ベクトルにも使える．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{seq}}, \code{\link{sequence}}, \code{\link{replicate}}.
}
\examples{
rep(1:4, 2)
rep(1:4, each = 2)       # 同じではない．
rep(1:4, c(2,2,2,2))     # 二番目と同じ．
rep(1:4, c(2,1,2,1))
rep(1:4, each = 2, len = 4)    # 最初の 4 だけ．
rep(1:4, each = 2, len = 10)   # 8 つの整数と二つのリサイクルされた 1．
rep(1:4, each = 2, times = 3)  # 長さ 24，3 つの完全な複製

rep(1, 40*(1-.8)) # 殆どのプラットフォームで長さ 7
rep(1, 40*(1-.8)+1e-7) # より良い

## リストを複製する
fred <- list(happy = 1:10, name = "squash")
rep(fred, 5)

# 日付・時刻オブジェクト
x <- .leap.seconds[1:3]
rep(x, 2)
rep(as.POSIXlt(x), rep(2, 3))

## 名前付き因子
x <- factor(LETTERS[1:4]); names(x) <- letters[1:4]
x
rep(x, 2)
rep(x, each = 2)
rep.int(x, 2)  # 名前無し
rep_len(x, 10)
}
\keyword{manip}
\keyword{chron}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/rep.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{rep}
%\alias{rep}
%\alias{rep.factor}
%\alias{rep.int}
%\alias{rep.POSIXct}
%\alias{rep.POSIXlt}
%\alias{rep.Date}
%\alias{rep_len}
%
%\title{Replicate Elements of Vectors and Lists}
%\description{
%  \code{rep} replicates the values in \code{x}.  It is a generic
%  function, and the (internal) default method is described here.
%
%  \code{rep.int} and \code{rep_len} are faster simplified versions for
%  two common cases.  They are not generic.
%}
%\usage{
%rep(x, \dots)
%
%rep.int(x, times)
%
%rep_len(x, length.out)
%}
%\arguments{
%  \item{x}{a vector (of any mode including a list) or a factor or (for
%    \code{rep} only) a \code{POSIXct} or \code{POSIXlt} or \code{Date}
%    object; or an S4 object containing such an object.}
%  \item{\dots}{further arguments to be passed to or from other methods.
%    For the internal default method these can include:
%    \describe{
%      \item{\code{times}}{A integer vector giving the (non-negative) number of
%        times to repeat each element if of length \code{length(x)}, or to
%        repeat the whole vector if of length 1.  Negative or \code{NA}
%	values are an error.}
%      \item{\code{length.out}}{non-negative integer.  The desired length of the
%        output vector.  Other inputs will be coerced to an integer
%	vector and the first element taken.  Ignored if \code{NA} or invalid.}
%      \item{\code{each}}{non-negative integer.  Each element of \code{x}
%	is repeated \code{each} times.  Other inputs will be coerced to
%	an integer vector and the first element taken.  Treated as
%	\code{1} if \code{NA} or invalid.}
%    }
%  }
%  \item{times}{see \code{\dots}.}
%  \item{length.out}{non-negative integer: the desired length of the
%    output vector.}
%}
%
%\details{
%  The default behaviour is as if the call was
%\preformatted{  rep(x, times = 1, length.out = NA, each = 1)
%}.  Normally just one of the additional
%  arguments is specified, but if \code{each} is specified with either
%  of the other two, its replication is performed first, and then that
%  implied by \code{times} or \code{length.out}.
%
%  If \code{times} consists of a single integer, the result consists of
%  the whole input repeated this many times.  If \code{times} is a
%  vector of the same length as \code{x} (after replication by
%  \code{each}), the result consists of \code{x[1]} repeated
%  \code{times[1]} times, \code{x[2]} repeated \code{times[2]} times and
%  so on.
%
%  \code{length.out} may be given in place of \code{times},
%  in which case \code{x} is repeated as many times as is
%  necessary to create a vector of this length.  If both are given,
%  \code{length.out} takes priority and \code{times} is ignored.
%
%  Non-integer values of \code{times} will be truncated towards zero.
%  If \code{times} is a computed quantity it is prudent to add a small
%  fuzz or use \code{\link{round}}.  And analogously for \code{each}.
%
%  If \code{x} has length zero and \code{length.out} is supplied and is
%  positive, the values are filled in using the extraction rules, that is
%  by an \code{NA} of the appropriate class for an atomic vector
%  (\code{0} for raw vectors) and \code{NULL} for a list.
%}
%\value{
%  An object of the same type as \code{x}.
%
%  \code{rep.int} and \code{rep_len} return no attributes (except the
%  class if returning a factor).
%
%  The default method of \code{rep} gives the result names (which will
%  almost always contain duplicates) if \code{x} had names, but retains
%  no other attributes.
%}
%\note{
%  Function \code{rep.int} is a simple case which was provided as a
%  separate function partly for S compatibility and partly for speed
%  (especially when names can be dropped).  The performance of \code{rep}
%  has been improved since, but \code{rep.int} is still at least twice as
%  fast when \code{x} has names.
%
%  The name \code{rep.int} long precedes making \code{rep} generic.
%
%  Function \code{rep} is a primitive, but (partial) matching of argument
%  names is performed as for normal functions.
%
%  For historical reasons \code{rep} (only) works on \code{NULL}: the
%  result is always \code{NULL} even when \code{length.out} is positive.
%
%  Although it has never been documented, these functions have always
%  worked on \link{expression} vectors.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{seq}}, \code{\link{sequence}}, \code{\link{replicate}}.
%}
%\examples{
%rep(1:4, 2)
%rep(1:4, each = 2)       # not the same.
%rep(1:4, c(2,2,2,2))     # same as second.
%rep(1:4, c(2,1,2,1))
%rep(1:4, each = 2, len = 4)    # first 4 only.
%rep(1:4, each = 2, len = 10)   # 8 integers plus two recycled 1's.
%rep(1:4, each = 2, times = 3)  # length 24, 3 complete replications
%
%rep(1, 40*(1-.8)) # length 7 on most platforms
%rep(1, 40*(1-.8)+1e-7) # better
%
%## replicate a list
%fred <- list(happy = 1:10, name = "squash")
%rep(fred, 5)
%
%# date-time objects
%x <- .leap.seconds[1:3]
%rep(x, 2)
%rep(as.POSIXlt(x), rep(2, 3))
%
%## named factor
%x <- factor(LETTERS[1:4]); names(x) <- letters[1:4]
%x
%rep(x, 2)
%rep(x, each = 2)
%rep.int(x, 2)  # no names
%rep_len(x, 10)
%}
%\keyword{manip}
%\keyword{chron}
%
\encoding{UTF8}
