% File src/library/base/man/sQuote.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{sQuote}
\alias{sQuote}
\alias{dQuote}
\title{Quote Text}
\description{
  適当な一重または二重の左右の引用符を結合してテキストを
  一重または二重引用化する．
}
\usage{
sQuote(x)
dQuote(x)
}
\arguments{
  \item{x}{\R オブジェクト，文字列に変換される．}
}
\details{
  この関数の目的は \R の出力，例えば警告やエラー，中
  で使われるテキストの引用化に対する
  マークアップの簡単な方法を提供することである．

  適切な引用符の選択はロケールと利用できる文字セットに依存する．
  かっての Unix/X11 フォントはそれらが開き・閉じ一重引用符としても
  使えるようにグレーブアクセント(ASCII コード 0x60) とアポストロフィ (0x27)
  を表示した．現代のフォントの使用，又は非 Unix システム上では，
  これらの文字は最早マッチするグリフを与えない．Unicode は
  左右の一重引用符文字(U+2018 と U+2019)を提供する；
  もし Unicode マークアップが利用できないと仮定するならば，
  アポストロフィを方向のない一重引用符として使うのは良い手段と思われる．

  同様に Unicode は左右の二重引用符文字(U+201C と U+201D)を持つ；
  もしアスキーのタイプライタ特性を用いることが出来るならば，
  アスキーの引用符(0x22)を左右双方の二重引用符として使うべきである．

  幾つかの他のロケール，特に Windows で，はまた向き付きの引用符をもつ．
  TeX は向き付きの一重引用符としてグレーブとアポストロフィを，二重
  のグレーブとアポストロフィ引用符を向き付きの二重引用符として使う．

  どのような表現が使われるかは \code{useFancyQuotes} の
  \code{\link{options}} の設定に依存する．もしこれが \code{FALSE} ならば
  方向無しのアスキー引用スタイルが使われる．
  もしこれが \code{TRUE} (既定)ならば Unicode の向き付き引用化
  が利用できれば使われる
  (現在 Unix 風システム上では UTF-8 ロケール，そして \code{C} を除く全ての
  Windows ロケール)：もし \code{"UTF-8"} と設定すると UTF-8 マークアップが
  使われる(現在のロケールが何であろうと)．もし \code{"TeX"} と設定すると
  TeX スタイルのマークアップが使われる．
  最後に，もしこれを長さ4の文字列ベクトルに設定すると，
  最初の二つの項目が開始と終了の一重引用符として使われ，
  二番目の二つは開始と終了の二重引用符として使われる：
  これはギルメットの使用のような非英語の引用化慣習を移植するために使うことが出来る．

  装飾的な引用化が使われると，全てのフォントが必要なグリフを含むわけでは無い
  ので，それらは正しく表現されないかもしれないことを留意すべきである．
#ifdef windows
  これは Windows の\sQuote{コマンドプロンプト}ウィンドウで
  特に面倒になり，これは既定ではいわゆる OEM コードページで
  実行されるように設定され，これは殆どのロケールで Windows とは異なる
  エンコーディングを使う．更に，もしコードページが変更(\code{chcp.exe} を使う，
  例えば西ヨーロッパ言語中では 1252)されると，既定のラスターフォントは
  向き付きの引用化をサポートしない．

  これの応急処置として，\code{options("useFancyQuotes")} に対する既定は
  Windows では \code{Rgui} コンソールを除いて \code{FALSE} である．
  そこでは装飾的な引用化は既定の Courier New font そしてよりエレガントに
  Lucida Console と既定の西アジアフォントを使って動作するが，
  Courier と FixedSys では向き付きの二重引用符は無い．
#endif
}
\value{
  現在のロケールのエンコーディングでの \code{x} と同じ長さの
  (強制変換後の)文字列ベクトル．
}
\seealso{
  \R コードの引用化には \link{Quotes}．

  OS 命令を引用化するには \code{\link{shQuote}}．
}
\references{
  Markus Kuhn, \dQuote{ASCII and Unicode quotation marks}.
  \url{https://www.cl.cam.ac.uk/~mgk25/ucs/quotes.html}
}
% these char strings have to be readable in any locale,
% so cannot use \uxxxx (fails in Japanese).
\examples{
op <- options("useFancyQuotes")
paste("argument", sQuote("x"), "must be non-zero")
options(useFancyQuotes = FALSE)
cat("\ndistinguish plain", sQuote("single"), "and",
    dQuote("double"), "quotes\n")
options(useFancyQuotes = TRUE)
cat("\ndistinguish fancy", sQuote("single"), "and",
    dQuote("double"), "quotes\n")
options(useFancyQuotes = "TeX")
cat("\ndistinguish TeX", sQuote("single"), "and",
    dQuote("double"), "quotes\n")
if(l10n_info()$`Latin-1`) {
    options(useFancyQuotes = c("\xab", "\xbb", "\xbf", "?"))
    cat("\n", sQuote("guillemet"), "and",
        dQuote("Spanish question"), "styles\n")
} else if(l10n_info()$`UTF-8`) {
    options(useFancyQuotes = c("\xc2\xab", "\xc2\xbb", "\xc2\xbf", "?"))
    cat("\n", sQuote("guillemet"), "and",
        dQuote("Spanish question"), "styles\n")
}
options(op)
}
\keyword{character}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/sQuote.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{sQuote}
%\alias{sQuote}
%\alias{dQuote}
%\title{Quote Text}
%\description{
%  Single or double quote text by combining with appropriate single or
%  double left and right quotation marks.
%}
%\usage{
%sQuote(x)
%dQuote(x)
%}
%\arguments{
%  \item{x}{an \R object, to be coerced to a character vector.}
%}
%\details{
%  The purpose of the functions is to provide a simple means of markup
%  for quoting text to be used in the R output, e.g., in warnings or
%  error messages.
%
%  The choice of the appropriate quotation marks depends on both the
%  locale and the available character sets.  Older Unix/X11 fonts
%  displayed the grave accent (ASCII code 0x60) and the apostrophe (0x27)
%  in a way that they could also be used as matching open and close
%  single quotation marks.  Using modern fonts, or non-Unix systems,
%  these characters no longer produce matching glyphs.  Unicode provides
%  left and right single quotation mark characters (U+2018 and U+2019);
%  if Unicode markup cannot be assumed to be available, it seems good
%  practice to use the apostrophe as a non-directional single quotation
%  mark.
%
%  Similarly, Unicode has left and right double quotation mark characters
%  (U+201C and U+201D); if only ASCII's typewriter characteristics can be
%  employed, than the ASCII quotation mark (0x22) should be used as both
%  the left and right double quotation mark.
%
%  Some other locales also have the directional quotation marks, notably
%  on Windows.  TeX uses grave and apostrophe for the directional single
%  quotation marks, and doubled grave and doubled apostrophe for the
%  directional double quotation marks.
%
%  What rendering is used depend on the \code{\link{options}} setting for
%  \code{useFancyQuotes}.  If this is \code{FALSE} then the undirectional
%  ASCII quotation style is used.  If this is \code{TRUE} (the default),
%  Unicode directional quotes are used are used where available
%  (currently, UTF-8 locales on Unix-alikes and all Windows locales
%  except \code{C}): if set to \code{"UTF-8"} UTF-8 markup is used
%  (whatever the current locale). If set to \code{"TeX"}, TeX-style
%  markup is used.  Finally, if this is set to a character vector of
%  length four, the first two entries are used for beginning and ending
%  single quotes and the second two for beginning and ending double
%  quotes: this can be used to implement non-English quoting conventions
%  such as the use of guillemets.
%
%  Where fancy quotes are used, you should be aware that they may not be
%  rendered correctly as not all fonts include the requisite glyphs: for
%  example some have directional single quotes but not directional double
%  quotes.
%#ifdef windows
%  This is particularly troublesome in Windows \sQuote{Command Prompt}
%  windows, which by default are set up to run in the so-called OEM
%  codepage, which in most locales uses a different encoding from
%  Windows.  Further, if the codepage is changed (with \code{chcp.exe},
%  e.g.\sspace{}to 1252 in a Western European language), the default raster fonts
%  do not support the directional quotes.
%
%  To work around this, the default for \code{options("useFancyQuotes")}
%  is \code{FALSE} on Windows except for the \code{Rgui} console.  There
%  fancy quotes work with the default Courier New font and more elegantly with
%  Lucida Console and default East Asian fonts, but directional double
%  quotes are missing in raster fonts such as Courier and FixedSys.
%#endif
%}
%\value{
%  A character vector of the same length as \code{x} (after any coercion)
%  in the current locale's encoding.
%}
%\seealso{
%  \link{Quotes} for quoting \R code.
%
%  \code{\link{shQuote}} for quoting OS commands.
%}
%\references{
%  Markus Kuhn, \dQuote{ASCII and Unicode quotation marks}.
%  \url{https://www.cl.cam.ac.uk/~mgk25/ucs/quotes.html}
%}
%% these char strings have to be readable in any locale,
%% so cannot use \uxxxx (fails in Japanese).
%\examples{
%op <- options("useFancyQuotes")
%paste("argument", sQuote("x"), "must be non-zero")
%options(useFancyQuotes = FALSE)
%cat("\ndistinguish plain", sQuote("single"), "and",
%    dQuote("double"), "quotes\n")
%options(useFancyQuotes = TRUE)
%cat("\ndistinguish fancy", sQuote("single"), "and",
%    dQuote("double"), "quotes\n")
%options(useFancyQuotes = "TeX")
%cat("\ndistinguish TeX", sQuote("single"), "and",
%    dQuote("double"), "quotes\n")
%if(l10n_info()$`Latin-1`) {
%    options(useFancyQuotes = c("\xab", "\xbb", "\xbf", "?"))
%    cat("\n", sQuote("guillemet"), "and",
%        dQuote("Spanish question"), "styles\n")
%} else if(l10n_info()$`UTF-8`) {
%    options(useFancyQuotes = c("\xc2\xab", "\xc2\xbb", "\xc2\xbf", "?"))
%    cat("\n", sQuote("guillemet"), "and",
%        dQuote("Spanish question"), "styles\n")
%}
%options(op)
%}
%\keyword{character}
%
\encoding{UTF8}
