% File src/library/base/man/stop.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{stop}
\title{Stop Function Execution}
\usage{
stop(\dots, call. = TRUE, domain = NULL)
geterrmessage()
}
\alias{stop}
\alias{geterrmessage}
\arguments{
  \item{\dots}{ゼロもしくはそれ以上の文字列に変換可能なオブジェク
    (それらは分離記号なしに一緒に連結される)又は一つの条件オブジェクト．}
  \item{call.}{論理値，呼び出しがエラーメッセージの一部になるべきかどうかを
    指示する．}
  \item{domain}{\code{\link{gettext}} を見よ．もし \code{NA} なら
    メッセージは翻訳されない．}
}
\description{
  \code{stop} は現在の表現式の実行を停止しエラー動作を実行する．

  \code{geterrmessage} は最後のエラーメッセージを与える．
}
\details{
  エラー動作は実行コード中で確立されたエラーハンドラーと
  \code{options(error=)} で設定された現在の既定のエラーハンドラー
  で制御される．エラーは最初 \code{\link{signalCondition}()} を
  使用したかのように発令される．ハンドラーが無いかもしくは
  全てのハンドラーが復帰すればエラーメッセージがプリントされ
  (もし \code{options("show.error.messages")} が真なら)そして
  既定のハンドラーが使用される．対話的な使用時の既定の挙動
  (\code{NULL} エラーハンドラー)はトップレベルのプロンプトか
  トップレベルのブラウザに戻り，非対話的な使用時には
  (実効的に) \code{\link{q}("no", status = 1, runLast = FALSE}) の
  呼び出しを使う．既定のハンドラーはエラーメッセージをバッファに保存する；
  それは \code{geterrmessage()} で呼び出すことが出来る．それはまた呼び出しスタックの
  記録を保存し \code{\link{traceback}()} を使って呼び出すことが出来る．

  エラーは \code{getOption("warning.length")} 文字に切り詰められ，
  既定値は 1000 である．

  もし条件オブジェクトが与えられるとそれはただ一つの引数でなければならず，
  それ以上の引数は警告と共に無視される．
}
\note{
  \code{\dots} が \code{\link{gettextf}()} からの結果を含む時には，
  それは既に翻訳されているので \code{domain = NA} を使う．
}
\value{
  \code{geterrmessage} は \code{"\\n"} で終わる文字列として，
  最後のエラーメッセージを与える．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  エラーを捉え再試行するには \code{\link{warning}}, \code{\link{try}} そして
  エラーハンドラーを設定するには \code{\link{options}}．
  正当性の検査 には \code{\link{stopifnot}}．\code{tryCatch}
  と \code{withCallingHandlers} は表現式を実行中に
  カスタム化されたハンドラーを確立するために使える．

  メッセージの自動翻訳のための機構については \code{\link{gettext}}．
}
\examples{
iter <- 12
try(if(iter > 10) stop("too many iterations"))

tst1 <- function(...) stop("dummy error")
try(tst1(1:10, long, calling, expression))

tst2 <- function(...) stop("dummy error", call. = FALSE)
try(tst2(1:10, longcalling, expression, but.not.seen.in.Error))
}
\keyword{environment}
\keyword{programming}
\keyword{error}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/stop.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{stop}
%\title{Stop Function Execution}
%\usage{
%stop(\dots, call. = TRUE, domain = NULL)
%geterrmessage()
%}
%\alias{stop}
%\alias{geterrmessage}
%\arguments{
%  \item{\dots}{zero or more objects which can be coerced to character
%    (and which are pasted together with no separator) or a single
%    condition object.}
%  \item{call.}{logical, indicating if the call should become part of the
%    error message.}
%  \item{domain}{see \code{\link{gettext}}.  If \code{NA}, messages will
%    not be translated.}
%}
%\description{
%  \code{stop} stops execution of the current expression and executes
%  an error action.
%
%  \code{geterrmessage} gives the last error message.
%}
%\details{
%  The error action is controlled by error handlers established within
%  the executing code and by the current default error handler set by
%  \code{options(error=)}.  The error is first signaled as if using
%  \code{\link{signalCondition}()}.  If there are no handlers or if all handlers
%  return, then the error message is printed (if
%  \code{options("show.error.messages")} is true) and the default error
%  handler is used.  The default behaviour (the \code{NULL}
%  error-handler) in interactive use is to return to the top level
%  prompt or the top level browser, and in non-interactive use to
%  (effectively) call \code{\link{q}("no", status = 1, runLast = FALSE}).
%  The default handler stores the error message in a buffer; it can be
%  retrieved by \code{geterrmessage()}.  It also stores a trace of
%  the call stack that can be retrieved by \code{\link{traceback}()}.
%
%  Errors will be truncated to \code{getOption("warning.length")}
%  characters, default 1000.
%
%  If a condition object is supplied it should be the only argument, and
%  further arguments will be ignored, with a warning.
%}
%\note{
%  Use \code{domain = NA} whenever \code{\dots} contain a
%  result from \code{\link{gettextf}()} as that is translated already.
%}
%\value{
%  \code{geterrmessage} gives the last error message, as a character string
%  ending in \code{"\\n"}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{warning}}, \code{\link{try}} to catch errors and retry,
%  and \code{\link{options}} for setting error handlers.
%  \code{\link{stopifnot}} for validity testing.  \code{tryCatch}
%  and \code{withCallingHandlers} can be used to establish custom handlers
%  while executing an expression.
%
%  \code{\link{gettext}} for the mechanisms for the automated translation
%  of messages.
%}
%\examples{
%iter <- 12
%try(if(iter > 10) stop("too many iterations"))
%
%tst1 <- function(...) stop("dummy error")
%try(tst1(1:10, long, calling, expression))
%
%tst2 <- function(...) stop("dummy error", call. = FALSE)
%try(tst2(1:10, longcalling, expression, but.not.seen.in.Error))
%}
%\keyword{environment}
%\keyword{programming}
%\keyword{error}
%
\encoding{UTF8}
