% File src/library/base/man/system.file.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{system.file}
\title{Find Names of R System Files}
\usage{
system.file(\dots, package = "base", lib.loc = NULL,
            mustWork = FALSE)
}
\alias{system.file}
\arguments{
  \item{\dots}{文字列ベクトル．あるパッケージ中の
    副ディレクトリとファイルを指定する．既定の無しではパッケージのルート
    を返す．ワイルドカードはサポートされていない．}
  \item{package}{一つのパッケージの名前を持つ文字列．
    複数の名前が与えられるとエラーになる．}
  \item{lib.loc}{\R ライブラリのパス名を持つ文字列ベクトル．
    既定値の \code{NULL} の意味については\sQuote{詳細}を見よ．}
  \item{mustWork}{論理値．もし \code{TRUE} なら，もしマッチするファイルがなければ
    エラーになる．}
}
\description{
  パッケージの中等にあるファイルの完全なファイル名を見つける．
}
\details{
  これは指定されたファイルの存在を
  \code{\link{file.exists}} を使ってチェックする．
  従ってファイルパスはそれらの存在を確立するのに十分な許可がある時だけ
  返される．

  \code{...} 中の名前のない引数は普通文字列であるが，文字列ベクトル
  ならばそれらは同じ長さにまでリサイクルされる．

  これはパッケージを見つけるのに \code{\link{find.package}} を使うので，
  既定の \code{lib.loc = NULL} では最初に付加されたパッケージ，それから
  \code{\link{.libPaths}()} 中にリストされた各ライブラリ中を探す．
  名前空間がロードされているがパッケージは付加されていなければ，
  これは \code{\link{.libPaths}()} だけを探す．
}
\value{
  \code{\dots} にマッチしたファイルパスを含む正の長さの文字列ベクトル．
  もしくは(\code{mustWork = TRUE} で無い限り)何もマッチしなければ
  空の文字列 \code{""}

  もしパッケージのルートにマッチすれば末尾の分離子は無い．

  引数の無い \code{system.file()} は
  \pkg{base} パッケージのルートを与える．
}
\seealso{
  \R をインストールしたルートディレクトリについては \code{\link{R.home}}，
  \code{\link{list.files}}．

  ワイルドカードを使ってパスを見つける \code{\link{Sys.glob}}．
}
\examples{
system.file()                  # 'base' パッケージのルート
system.file(package = "stats") # 'stats' パッケージのルート
system.file("INDEX")
system.file("help", "AnIndex", package = "splines")
}
\keyword{file}
\keyword{utilities}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/system.file.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{system.file}
%\title{Find Names of R System Files}
%\usage{
%system.file(\dots, package = "base", lib.loc = NULL,
%            mustWork = FALSE)
%}
%\alias{system.file}
%\arguments{
%  \item{\dots}{character vectors, specifying subdirectory and file(s)
%    within some package.  The default, none, returns the
%    root of the package.  Wildcards are not supported.}
%  \item{package}{a character string with the name of a single package.
%    An error occurs if more than one package name is given.}
%  \item{lib.loc}{a character vector with path names of \R libraries.
%    See \sQuote{Details} for the meaning of the default value of \code{NULL}.}
%  \item{mustWork}{logical.  If \code{TRUE}, an error is given if there
%    are no matching files.}
%}
%\description{
%  Finds the full file names of files in packages etc.
%}
%\details{
%  This checks the existence of the specified files with
%  \code{\link{file.exists}}.  So file paths are only returned if there
%  are sufficient permissions to establish their existence.
%
%  The unnamed arguments in \code{...} are usually character strings, but
%  if character vectors they are recycled to the same length.
%
%  This uses \code{\link{find.package}} to find the package, and hence
%  with the default \code{lib.loc = NULL} looks first for attached
%  packages then in each library listed in \code{\link{.libPaths}()}.
%  Note that if a namespace is loaded but the package is not attached,
%  this will look only on \code{\link{.libPaths}()}.
%}
%\value{
%  A character vector of positive length, containing the file paths
%  that matched \code{\dots}, or the empty string, \code{""}, if none
%  matched (unless \code{mustWork = TRUE}).
%
%  If matching the root of a package, there is no trailing separator.
%
%  \code{system.file()} with no arguments gives the root of the
%  \pkg{base} package.
%}
%\seealso{
%  \code{\link{R.home}} for the root directory of the \R
%  installation, \code{\link{list.files}}.
%
%  \code{\link{Sys.glob}} to find paths via wildcards.
%}
%\examples{
%system.file()                  # The root of the 'base' package
%system.file(package = "stats") # The root of package 'stats'
%system.file("INDEX")
%system.file("help", "AnIndex", package = "splines")
%}
%\keyword{file}
%\keyword{utilities}
%\encoding{UTF8}

\encoding{UTF8}

