% File src/library/base/man/t.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{t}
\alias{t}
\alias{t.default}
\alias{t.data.frame}
\title{Matrix Transpose}
\description{
  行列やデータフレーム \code{x} を与えた時
  \code{t} は \code{x} の転置を与える．
}
\usage{
t(x)
}
\arguments{
  \item{x}{典型的に行列やデータフレーム．}
}
\details{
  これはそれに対してメソッドを書くことが出来る総称的関数である．
  ここでの説明は既定と \code{"data.frame"} メソッドに適用される．

  データフレームは最初行列に変換される：\code{\link{as.matrix}} を見よ．
  \code{x} がベクトルなら，それは列として扱われる．つまり結果は
  1 行の行列になる．
}
\value{
  \code{dim} と \code{dimnames} が \code{x} のそれらから
  適当に構成された行列で，名前を除く他の属性がコピーされている．
}
\note{
  複素数行列 \eqn{A} の\emph{共役}転置は
  \eqn{A^H} や \eqn{A^*} と表され \code{\link{Conj}(t(A))} として
  計算される．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  配列の次元を置換するためには \code{\link{aperm}}．
}
\examples{
a <- matrix(1:30, 5, 6)
ta <- t(a) ##-- つまり全ての i,j で  a[i, j] == ta[j, i]：
for(j in seq(ncol(a)))
  if(! all(a[, j] == ta[j, ])) stop("wrong transpose")
}
\keyword{array}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/t.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{t}
%\alias{t}
%\alias{t.default}
%\alias{t.data.frame}
%\title{Matrix Transpose}
%\description{
%  Given a matrix or \code{\link{data.frame}} \code{x},
%  \code{t} returns the transpose of \code{x}.
%}
%\usage{
%t(x)
%}
%\arguments{
%  \item{x}{a matrix or data frame, typically.}
%}
%\details{
%  This is a generic function for which methods can be written.  The
%  description here applies to the default and \code{"data.frame"} methods.
%
%  A data frame is first coerced to a matrix: see \code{\link{as.matrix}}.
%  When \code{x} is a vector, it is treated as a column, i.e., the
%  result is a 1-row matrix.
%}
%\value{
%  A matrix, with \code{dim} and \code{dimnames} constructed
%  appropriately from those of \code{x}, and other attributes except
%  names copied across.
%}
%\note{
%  The \emph{conjugate} transpose of a complex matrix \eqn{A}, denoted
%  \eqn{A^H} or \eqn{A^*}, is computed as \code{\link{Conj}(t(A))}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{aperm}} for permuting the dimensions of arrays.
%}
%\examples{
%a <- matrix(1:30, 5, 6)
%ta <- t(a) ##-- i.e.,  a[i, j] == ta[j, i] for all i,j :
%for(j in seq(ncol(a)))
%  if(! all(a[, j] == ta[j, ])) stop("wrong transpose")
%}
%\keyword{array}
%\encoding{UTF8}

\encoding{UTF8}

