% File src/library/base/man/taskCallbackManager.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2011 R Core Team
% Distributed under GPL 2 or later

\name{taskCallbackManager}
\alias{taskCallbackManager}
\title{Create an R-level Task Callback Manager}
\description{
  これは各トップレベルの作業の終了時に起動されるコールバックやアクションを
  管理するための完全に S 言語による機構を提供する．
  本質的に，基礎にあるネイティブなタスクコールバック機構を持つ一つの R 関数を
  このマネージャから登録し，そしてこの関数がマネージャの管理下にある
  他の R コールバックの起動を処理する．
  マネージャはユーザレベルのコールバックのリストを管理する
  共有変数にアクセスする関数の集まりからなる．
}
\usage{
taskCallbackManager(handlers = list(), registered = FALSE,
                    verbose = FALSE)
}
\arguments{
  \item{handlers}{これは各要素がリストであるコールバックのリストで良い．
    要素リストは要素，
    コールバック関数である名前付きの \code{"f"} と
    コールバックが起動されるときにそれに提供される5番目の引数
    である名前付きの \code{"data"}，を持つ．
    典型的にはこの引数は指定されず，マネージャが作られた後
    \code{add} を使ってコールバックを登録する．}
  \item{registered}{\code{evaluate} 関数が既に内部的タスクコールバック機構を使って
    登録されているかどうかを指示する論理値．
    これは普通 \code{FALSE} で，コールバックが \code{add} 関数を使って
    最初に加えられた時 \code{evaluate} 関数は自動的に登録される．
    この引数を \code{TRUE} とし \code{\link{addTaskCallback}} を
    手動で呼び出すことで関数が登録された時に制御できる．
  }
  \item{verbose}{論理値で，もし \code{TRUE} ならば，
    この選択適用マネージャが実行するある行動についての情報を
    コンソールにプリントするようにする．
    これはコールバックとハンドラー自体のデバッグに有用である．
  }
}
\value{
  6 個の関数を含むリスト：
   \item{add}{このマネージャにコールバックを登録する．
     オプションの5番目の引数，コールバックがリスト中に保管されるオプションの
     名前，そして必要なら C レベルの選択適用機構で \code{evaluate} を
     登録するかを制御する \code{register} 引数を持つ関数を与える．}
  \item{remove}{マネージャのコールバックの集まりから名前もしくは
    位置/添字を使い一つの要素を取り除く．}
  \item{evaluate}{\sQuote{実}コールバック関数で，C レベルの選択適用機構で
    登録され，このマネージャが管理する R レベルのコールバックの各々を起動する．}
  \item{suspend}{マネージャの一時停止状態を設定する関数．
    もし一時停止にされると，どのコールバックも作業終了時に起動されない．
    \code{status} 引数に論理値を指定することで状態を設定できる．
  }
  \item{register}{内部的な C レベルの選択適用機構をもつ \code{evaluate}
    関数を登録する関数．これは \code{add} 関数で自動的に行われるが，
    手動で呼び出すことも出来る．}
  \item{callbacks}{このマネージャで保守されているコールバックのリストを返す．}
}
\seealso{
  \code{\link{addTaskCallback}},
  \code{\link{removeTaskCallback}},
  \code{\link{getTaskCallbackNames}},\cr
  \url{http://developer.r-project.org/TaskHandlers.pdf}
}
\examples{
# マネージャを作る
h <- taskCallbackManager()

# コールバックを加える
h$add(function(expr, value, ok, visible) {
                       cat("In handler\n")
                       return(TRUE)
                     }, name = "simpleHandler")

# 内部コールバックを見る
getTaskCallbackNames()

# R レベルのコールバックを見る
names(h$callbacks())

getTaskCallbackNames()
removeTaskCallback("R-taskCallbackManager")
}
\keyword{environment}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/base/man/taskCallbackManager.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2011 R Core Team
%% Distributed under GPL 2 or later
%
%\name{taskCallbackManager}
%\alias{taskCallbackManager}
%\title{Create an R-level Task Callback Manager}
%\description{
%  This provides an entirely S-language mechanism
%  for managing callbacks or actions  that are invoked at
%  the conclusion of each top-level task.  Essentially,
%  we register a single R function from this manager
%  with the underlying, native
%  task-callback mechanism and this function handles invoking the other
%  R callbacks under the control of the manager.
%  The manager consists of a collection of functions that access shared
%  variables to manage the list of user-level callbacks.
%}
%\usage{
%taskCallbackManager(handlers = list(), registered = FALSE,
%                    verbose = FALSE)
%}
%\arguments{
%  \item{handlers}{this can be a list of callbacks in which each element
%    is a list with  an element  named \code{"f"}
%    which is a callback function, and an optional
%    element named \code{"data"} which is the 5-th argument to be
%    supplied  to the callback when it is invoked.
%    Typically this argument is not specified, and one uses \code{add} to
%    register callbacks after the manager is created.}
%  \item{registered}{a logical value indicating whether
%    the \code{evaluate} function has already been registered
%    with the internal task callback mechanism.
%    This is usually \code{FALSE} and
%    the first time a callback is added
%    via the \code{add} function, the
%    \code{evaluate} function is automatically registered.
%    One can control when the function is registered
%    by specifying \code{TRUE} for this argument
%    and calling \code{\link{addTaskCallback}} manually.
%  }
%  \item{verbose}{a logical value, which if \code{TRUE},
%    causes information to be printed to the console
%    about certain activities this dispatch manager performs.
%    This is useful for debugging callbacks and the handler
%    itself.
%  }
%}
%\value{
%  A list containing 6 functions:
%  \item{add}{register a callback with this manager, giving the
%    function, an optional 5-th argument, an optional name
%    by which the callback is stored in the list,
%    and a \code{register} argument which controls whether
%    the \code{evaluate} function is registered with the internal
%    C-level dispatch mechanism if necessary.}
%  \item{remove}{remove an element from the manager's collection
%    of callbacks, either by name or position/index.}
%  \item{evaluate}{the \sQuote{real} callback function that is registered
%    with the C-level dispatch mechanism and which invokes each of the
%    R-level callbacks within this manager's control.}
%  \item{suspend}{a function to set the suspend state
%    of the manager.  If it is suspended, none of the callbacks will be
%    invoked when a task is completed.  One sets the state by specifying
%    a logical value for the \code{status} argument.
%  }
%  \item{register}{a function to register the \code{evaluate}
%    function with the internal C-level dispatch mechanism.  This is
%    done automatically by the \code{add} function, but can be called
%    manually.}
%  \item{callbacks}{returns the list of callbacks being maintained by this
%   manager.}
%}
%\seealso{
%  \code{\link{addTaskCallback}},
%  \code{\link{removeTaskCallback}},
%  \code{\link{getTaskCallbackNames}}\\
%  \url{http://developer.r-project.org/TaskHandlers.pdf}
%}
%\examples{
%# create the manager
%h <- taskCallbackManager()
%
%# add a callback
%h$add(function(expr, value, ok, visible) {
%                       cat("In handler\n")
%                       return(TRUE)
%                     }, name = "simpleHandler")
%
%# look at the internal callbacks.
%getTaskCallbackNames()
%
%# look at the R-level callbacks
%names(h$callbacks())
%
%getTaskCallbackNames()
%removeTaskCallback("R-taskCallbackManager")
%}
%\keyword{environment}
%\encoding{UTF8}

\encoding{UTF8}

