% File src/library/graphics/man/cdplot.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{cdplot}
\alias{cdplot}
\alias{cdplot.default}
\alias{cdplot.formula}
\title{Conditional Density Plots}
\description{
  カテゴリカルな変数 \code{y} の条件付き分布が数値変数 \code{x} により
  どのように変換するかを記述する条件付き密度を計算しプロットする．
}
\usage{
cdplot(x, \dots)

\method{cdplot}{default}(x, y,
  plot = TRUE, tol.ylab = 0.05, ylevels = NULL,
  bw = "nrd0", n = 512, from = NULL, to = NULL,
  col = NULL, border = 1, main = "", xlab = NULL, ylab = NULL,
  yaxlabels = NULL, xlim = NULL, ylim = c(0, 1), \dots)

\method{cdplot}{formula}(formula, data = list(),
  plot = TRUE, tol.ylab = 0.05, ylevels = NULL,
  bw = "nrd0", n = 512, from = NULL, to = NULL,
  col = NULL, border = 1, main = "", xlab = NULL, ylab = NULL,
  yaxlabels = NULL, xlim = NULL, ylim = c(0, 1), \dots,
  subset = NULL)
}
\arguments{
  \item{x}{オブジェクト，既定のメソッドは単一の数値変数
    (又はそれに強制変換できるオブジェクト)を期待する．}
  \item{y}{従属変数と解釈される \code{"factor"}．}
  \item{formula}{\code{y ~ x} のタイプの \code{"formula"} で，
    一つの従属変数 \code{"factor"} aと単一の数値説明変数を持つ．}
  \item{data}{オプションのデータフレーム．}
  \item{plot}{論理値．計算された条件付き密度をプロットするか?}
  \item{tol.ylab}{y 軸の注釈のための適当な許容度パラメータ．
    もし二つのラベル間の距離がこの閾値以下になるとそれらは等距離でプロットされる．}
  \item{ylevels}{従属変数の水準をどの順序でプロットするかを指示する文字列
    もしくは数値ベクトル．}
  \item{bw, n, from, to, \dots}{\code{\link{density}} に渡される引数．}
  \item{col}{\code{levels(y)} と同じ長さの塗りつぶし色のベクトル．
    既定では \code{\link{gray.colors}} を呼び出す．}
  \item{border}{陰影付きの多角形の輪郭色．}
  \item{main, xlab, ylab}{注釈に対する文字列．}
  \item{yaxlabels}{y  軸の注釈のための文字列ベクトルで，
    既定では \code{levels(y)}．}
  \item{xlim, ylim}{意味のある既定値を持つ x と y 変数の範囲．}
  \item{subset}{プロットに使われる観測値の部分集合を指定するオプションのベクトル．}
}
\details{
  \code{cdplot} は \code{y} の水準を与えて \code{y} の周辺密度で
  重みが付けられた \code{x} の条件付き密度を計算する．
  密度は \code{y} の水準に関して累積的に導かれる．

  この可視化テクニックは spinogram (\code{\link{spineplot}} を見よ)に
  似ており，\eqn{P(y | x)} を \eqn{x} に対してプロットする．
  条件付き確率は(spinogram のように)離散化では導かれず，代わりに
  \code{\link{density}} による平滑化を用いる．

  条件付き密度の推定値は \eqn{x} の高密度領域でより信頼できることを注意しよう．
  逆に \eqn{x} 観測値が僅かな領域では信頼性が劣る．
}
\value{
  (\code{y} の水準に関して
  累積された)条件付き密度関数が不可視で返される．
}
\seealso{
  \code{\link{spineplot}}, \code{\link{density}}
}
\references{
  Hofmann, H., Theus, M. (2005), \emph{Interactive graphics for visualizing
  conditional distributions}, Unpublished Manuscript.
}
\author{
  Achim Zeileis \email{Achim.Zeileis@R-project.org}
}
\examples{
## NASA のスペースシャトルの o リングの不良品
fail <- factor(c(2, 2, 2, 2, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1,
                 1, 2, 1, 1, 1, 1, 1),
               levels = 1:2, labels = c("no", "yes"))
temperature <- c(53, 57, 58, 63, 66, 67, 67, 67, 68, 69, 70, 70,
                 70, 70, 72, 73, 75, 75, 76, 76, 78, 79, 81)

## CD プロット
cdplot(fail ~ temperature)
cdplot(fail ~ temperature, bw = 2)
cdplot(fail ~ temperature, bw = "SJ")

## spinogram と比較する
(spineplot(fail ~ temperature, breaks = 3))

## 失敗をハイライト
cdplot(fail ~ temperature, ylevels = 2:1)

## 条件付き密度を用いた散布図
cdens <- cdplot(fail ~ temperature, plot = FALSE)
plot(I(as.numeric(fail) - 1) ~ jitter(temperature, factor = 2),
     xlab = "Temperature", ylab = "Conditional failure probability")
lines(53:81, 1 - cdens[[1]](53:81), col = 2)
}
\keyword{hplot}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/cdplot.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{cdplot}
%\alias{cdplot}
%\alias{cdplot.default}
%\alias{cdplot.formula}
%\title{Conditional Density Plots}
%\description{
%  Computes and plots conditional densities describing how the
%  conditional distribution of a categorical variable \code{y} changes over a
%  numerical variable \code{x}.
%}
%\usage{
%cdplot(x, \dots)
%
%\method{cdplot}{default}(x, y,
%  plot = TRUE, tol.ylab = 0.05, ylevels = NULL,
%  bw = "nrd0", n = 512, from = NULL, to = NULL,
%  col = NULL, border = 1, main = "", xlab = NULL, ylab = NULL,
%  yaxlabels = NULL, xlim = NULL, ylim = c(0, 1), \dots)
%
%\method{cdplot}{formula}(formula, data = list(),
%  plot = TRUE, tol.ylab = 0.05, ylevels = NULL,
%  bw = "nrd0", n = 512, from = NULL, to = NULL,
%  col = NULL, border = 1, main = "", xlab = NULL, ylab = NULL,
%  yaxlabels = NULL, xlim = NULL, ylim = c(0, 1), \dots,
%  subset = NULL)
%}
%\arguments{
%  \item{x}{an object, the default method expects a single numerical
%    variable (or an object coercible to this).}
%  \item{y}{a \code{"factor"} interpreted to be the dependent variable}
%  \item{formula}{a \code{"formula"} of type \code{y ~ x} with a single dependent
%    \code{"factor"} and a single numerical explanatory variable.}
%  \item{data}{an optional data frame.}
%  \item{plot}{logical. Should the computed conditional densities be plotted?}
%  \item{tol.ylab}{convenience tolerance parameter for y-axis annotation.
%    If the distance between two labels drops under this threshold, they are
%    plotted equidistantly.}
%  \item{ylevels}{a character or numeric vector specifying in which order
%    the levels of the dependent variable should be plotted.}
%  \item{bw, n, from, to, \dots}{arguments passed to \code{\link{density}}}
%  \item{col}{a vector of fill colors of the same length as \code{levels(y)}.
%    The default is to call \code{\link{gray.colors}}.}
%  \item{border}{border color of shaded polygons.}
%  \item{main, xlab, ylab}{character strings for annotation}
%  \item{yaxlabels}{character vector for annotation of y axis, defaults to
%    \code{levels(y)}.}
%  \item{xlim, ylim}{the range of x and y values with sensible defaults.}
%  \item{subset}{an optional vector specifying a subset of observations
%    to be used for plotting.}
%}
%\details{
%  \code{cdplot} computes the conditional densities of \code{x} given
%  the levels of \code{y} weighted by the marginal distribution of \code{y}.
%  The densities are derived cumulatively over the levels of \code{y}.
%
%  This visualization technique is similar to spinograms (see \code{\link{spineplot}})
%  and plots \eqn{P(y | x)} against \eqn{x}. The conditional probabilities
%  are not derived by discretization (as in the spinogram), but using a smoothing
%  approach via \code{\link{density}}.
%
%  Note, that the estimates of the conditional densities are more reliable for
%  high-density regions of \eqn{x}. Conversely, the are less reliable in regions
%  with only few \eqn{x} observations.
%}
%\value{
%  The conditional density functions (cumulative over the levels of \code{y})
%  are returned invisibly.
%}
%\seealso{
%  \code{\link{spineplot}}, \code{\link{density}}
%}
%\references{
%  Hofmann, H., Theus, M. (2005), \emph{Interactive graphics for visualizing
%  conditional distributions}, Unpublished Manuscript.
%}
%\author{
%  Achim Zeileis \email{Achim.Zeileis@R-project.org}
%}
%\examples{
%## NASA space shuttle o-ring failures
%fail <- factor(c(2, 2, 2, 2, 1, 1, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1,
%                 1, 2, 1, 1, 1, 1, 1),
%               levels = 1:2, labels = c("no", "yes"))
%temperature <- c(53, 57, 58, 63, 66, 67, 67, 67, 68, 69, 70, 70,
%                 70, 70, 72, 73, 75, 75, 76, 76, 78, 79, 81)
%
%## CD plot
%cdplot(fail ~ temperature)
%cdplot(fail ~ temperature, bw = 2)
%cdplot(fail ~ temperature, bw = "SJ")
%
%## compare with spinogram
%(spineplot(fail ~ temperature, breaks = 3))
%
%## highlighting for failures
%cdplot(fail ~ temperature, ylevels = 2:1)
%
%## scatter plot with conditional density
%cdens <- cdplot(fail ~ temperature, plot = FALSE)
%plot(I(as.numeric(fail) - 1) ~ jitter(temperature, factor = 2),
%     xlab = "Temperature", ylab = "Conditional failure probability")
%lines(53:81, 1 - cdens[[1]](53:81), col = 2)
%}
%\keyword{hplot}
%


\encoding{UTF8}
