% File src/library/graphics/man/convertXY.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2008-2014 R Core Team
% Distributed under GPL 2 or later

\name{convertXY}
\alias{grconvertX}
\alias{grconvertY}
\title{Convert between Graphics Coordinate Systems}
\description{
  グラフィックス座標間で変換する．
}
\usage{
grconvertX(x, from = "user", to = "user")
grconvertY(y, from = "user", to = "user")
}
\arguments{
  \item{x, y}{座標の数値ベクトル．}
  \item{from, to}{その間で変換する座標システムを与える文字列．}
}
\details{
  座標システムは
  \describe{
    \item{\code{"user"}}{ユーザ座標．}
    \item{\code{"inches"}}{インチ．}
    \item{\code{"device"}}{デバイスの座標システム．}
    \item{\code{"ndc"}}{正規化されたデバイス座標．}
    \item{\code{"nfc"}}{正規化された図座標．}
    \item{\code{"npc"}}{正規化されたプロット座標．}
    \item{\code{"nic"}}{正規化された内部領域座標．
      (\sQuote{内部領域}は外部マージンの内部．)}
  }
  (これらの名前は部分的にマッチされる．)  \sQuote{正規化}された
  座標システムに対しては左下が値 0 で右上が値 1 を持つ．

  デバイス座標はデバイスがその内部で動作するものである：
  これらはそれが意味を持つ箇所では普通ピクセル単位，
  さもなければ big point (1/72 インチ)である
  (例えば \code{\link{pdf}} と \code{\link{postscript}})．.
}
\value{
  入力と同じ長さの数値ベクトル．
}

\examples{
op <- par(omd=c(0.1, 0.9, 0.1, 0.9), mfrow = c(1, 2))
plot(1:4)
for(tp in c("in", "dev", "ndc", "nfc", "npc", "nic"))
    print(grconvertX(c(1.0, 4.0), "user", tp))
par(op)
}
\keyword{ dplot }
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/convertXY.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2008-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{convertXY}
%\alias{grconvertX}
%\alias{grconvertY}
%\title{Convert between Graphics Coordinate Systems}
%\description{
%  Convert between graphics coordinate systems.
%}
%\usage{
%grconvertX(x, from = "user", to = "user")
%grconvertY(y, from = "user", to = "user")
%}
%\arguments{
%  \item{x, y}{numeric vector of coordinates.}
%  \item{from, to}{character strings giving the coordinate systems to
%    convert between.}
%}
%\details{
%  The coordinate systems are
%  \describe{
%    \item{\code{"user"}}{user coordinates.}
%    \item{\code{"inches"}}{inches.}
%    \item{\code{"device"}}{the device coordinate system.}
%    \item{\code{"ndc"}}{normalized device coordinates.}
%    \item{\code{"nfc"}}{normalized figure coordinates.}
%    \item{\code{"npc"}}{normalized plot coordinates.}
%    \item{\code{"nic"}}{normalized inner region coordinates.  (The
%      \sQuote{inner region} is that inside the outer margins.)}
%  }
%  (These names can be partially matched.)  For the \sQuote{normalized}
%  coordinate systems the lower left has value 0 and the top right
%  value 1.
%
%  Device coordinates are those in which the device works: they are
%  usually in pixels where that makes sense and in big points (1/72 inch)
%  otherwise (e.g., \code{\link{pdf}} and \code{\link{postscript}}).
%}
%\value{
%  A numeric vector of the same length as the input.
%}
%
%\examples{
%op <- par(omd=c(0.1, 0.9, 0.1, 0.9), mfrow = c(1, 2))
%plot(1:4)
%for(tp in c("in", "dev", "ndc", "nfc", "npc", "nic"))
%    print(grconvertX(c(1.0, 4.0), "user", tp))
%par(op)
%}
%\keyword{ dplot }
%
\encoding{UTF8}
