% File src/library/graphics/man/fourfoldplot.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{fourfoldplot}
\alias{fourfoldplot}
\title{Fourfold Plots}
\description{
  2 x 2 x \eqn{k} 分割表の4重プロットを
  現在のディスプレイ上に描く．
  これは一つ又は複数の母集団(層)中の二分割変数間の
  関連の視認を許す．
}
\usage{
fourfoldplot(x, color = c("#99CCFF", "#6699CC"),
             conf.level = 0.95,
             std = c("margins", "ind.max", "all.max"),
             margin = c(1, 2), space = 0.2, main = NULL,
             mfrow = NULL, mfcol = NULL)
}
\arguments{
  \item{x}{配列形式の 2 x 2 x \eqn{k} 分割表，又は
    \eqn{k} が 1 ならば 2 x 2 行列．}
  \item{color}{各 2 x 2 表の小さい対角線と大きな対角線に
    対して使われる色を指定する長さ 2 のベクトル．}
  \item{conf.level}{オッズ比に関する信頼リングに使われる信頼水準．
    1 以下の一つの非負数でなければならない；
    もし 0 に取ると信頼リングは抑制される．}
  \item{std}{テーブルをどのように正規化するかを指示する文字列．
    \code{"margins"}, \code{"ind.max"} 又は \code{"all.max"} の
    一つでなければならず，頭文字に短縮できる．
    もし \code{"margins"} ならば，各 2 x 2 テーブルは \code{margin} で
    指定されたマージンを等しくする一方オッズ比を保存する．
    もし \code{"ind.max"} か \code{"all.max"} ならば，テーブルは
    個々にか同時に最大セル頻度が 1 になるように標準化される．}
  \item{margin}{等しくされるマージンの数値ベクトル．
    \code{1}, \code{2} 又は \code{c(1, 2)} (既定値)のどれかでなければならず，
    各 2 x 2 テーブル中の行，列，そして行と列双方の標準化に対応する．
    \code{std} が \code{"margins"} に等しい時だけ使われる．}
  \item{space}{行と列のラベルに使われるスペース量
    (四半円の最大半径に対する割合)．}
  \item{main}{四重ディスプレイのタイトルである文字列．}
  \item{mfrow}{\code{c(nr, nc)} の形式の数値ベクトルで，
    2 x 2 テーブルの表示が行で埋められた \code{nr} x \code{nc}
    レイアウトに並べられることを指示する．}
  \item{mfcol}{\code{c(nr, nc)} の形式の数値ベクトルで，
    2 x 2 テーブルの表示が列で埋められた \code{nr} x \code{nc}
    レイアウトに並べられることを指示する．}
}
\details{
  4重ディスプレイは 2 x 2 x \eqn{k} テーブルの表示用にデザインされている．

  適当な標準化の後に，各 2 x 2 テーブルのセル頻度 \eqn{f_{ij}}{f[i,j]}
  はその半径が \eqn{\sqrt{f_{ij}}}{sqrt(f[i,j])} に比例する半径の
  四分円に表示されるので，その面積はセル頻度に比例する．
  二項行・列変数の間の関連(1 と異なるオッズ比)は
  ある方向の対角的に向き合ったセルの傾向が他の方向のそれらと
  異なる傾向により指示される．
  この方向を示すのに色が使われる．
  オッズ比に対する信頼リングは関連無しという帰無仮説に対する
  視覚的な検定法を与える；
  隣り合った象限に対するリングは
  観測数が帰無仮説と両立する時，そしてその時だけ重なりあう．

  典型的には数 \eqn{k} は層化された変数のレベル数に対応し，
  関連が層を跨って一様かどうかを見るのことに関心がある．
  四重ディスプレイは関連を視覚化する．
  個別のオッズに対する信頼リングは多重比較用に調整されていないことを
  注意する．
}
\references{
  Friendly, M. (1994).
  A fourfold display for 2 by 2 by \eqn{k} tables.
  Technical Report 217, York University, Psychology Department.
  \url{http://www.math.yorku.ca/SCS/Papers/4fold/4fold.ps.gz}
}
\seealso{
  \code{\link{mosaicplot}}
}
\examples{
## Friendly (1995) 中に於けるような Berkeley 入試データを使う
x <- aperm(UCBAdmissions, c(2, 1, 3))
dimnames(x)[[2]] <- c("Yes", "No")
names(dimnames(x)) <- c("Sex", "Admit?", "Department")
stats::ftable(x)

## 学部で累積されたデータの4重ディスプレイ
## 頻度は合格者と性別に対する周辺和に等しくなるように標準化されている
## Friendly (1994) の図1．
fourfoldplot(margin.table(x, c(1, 2)))

## x データの4重ディスプレイ．各テーブル中の頻度は合格者と性別に
## 対する周辺和が等しくなるように標準化されている
## Friendly (1994) の図2．
fourfoldplot(x)

## x データの4重ディスプレイ．各テーブル中の頻度は合格者
## (しかし性別に対してではない)に対する周辺和が等しく
## なるように標準化されている
## Friendly (1994) の図3．
fourfoldplot(x, margin = 2)
}
\keyword{hplot}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/fourfoldplot.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{fourfoldplot}
%\alias{fourfoldplot}
%\title{Fourfold Plots}
%\description{
%  Creates a fourfold display of a 2 by 2 by \eqn{k} contingency table on
%  the current graphics device, allowing for the visual inspection of the
%  association between two dichotomous variables in one or several
%  populations (strata).
%}
%\usage{
%fourfoldplot(x, color = c("#99CCFF", "#6699CC"),
%             conf.level = 0.95,
%             std = c("margins", "ind.max", "all.max"),
%             margin = c(1, 2), space = 0.2, main = NULL,
%             mfrow = NULL, mfcol = NULL)
%}
%\arguments{
%  \item{x}{a 2 by 2 by \eqn{k} contingency table in array form, or as a
%    2 by 2 matrix if \eqn{k} is 1.}
%  \item{color}{a vector of length 2 specifying the colors to use for the
%    smaller and larger diagonals of each 2 by 2 table.}
%  \item{conf.level}{confidence level used for the confidence rings on
%    the odds ratios.  Must be a single nonnegative number less than 1;
%    if set to 0, confidence rings are suppressed.}
%  \item{std}{a character string specifying how to standardize the table.
%    Must match one of \code{"margins"}, \code{"ind.max"}, or
%    \code{"all.max"}, and can be abbreviated to the initial letter.
%    If set to \code{"margins"}, each 2 by 2 table is standardized to
%    equate the margins specified by \code{margin} while preserving the
%    odds ratio.  If \code{"ind.max"} or \code{"all.max"}, the tables are
%    either individually or simultaneously standardized to a maximal cell
%    frequency of 1.}
%  \item{margin}{a numeric vector with the margins to equate.  Must be
%    one of \code{1}, \code{2}, or \code{c(1, 2)} (the default), which
%    corresponds to standardizing the row, column, or both margins in
%    each 2 by 2 table.
%    Only used if \code{std} equals \code{"margins"}.}
%  \item{space}{the amount of space (as a fraction of the maximal radius
%    of the quarter circles) used for the row and column labels.}
%  \item{main}{character string for the fourfold title.}
%  \item{mfrow}{a numeric vector of the form \code{c(nr, nc)}, indicating
%    that the displays for the 2 by 2 tables should be arranged in an
%    \code{nr} by \code{nc} layout, filled by rows.}
%  \item{mfcol}{a numeric vector of the form \code{c(nr, nc)}, indicating
%    that the displays for the 2 by 2 tables should be arranged in an
%    \code{nr} by \code{nc} layout, filled by columns.}
%}
%\details{
%  The fourfold display is designed for the display of 2 by 2 by \eqn{k}
%  tables.
%
%  Following suitable standardization, the cell frequencies
%  \eqn{f_{ij}}{f[i,j]} of each 2 by 2 table are shown as a quarter
%  circle whose radius is proportional to
%  \eqn{\sqrt{f_{ij}}}{sqrt(f[i,j])} so that its area is proportional to
%  the cell frequency.  An association (odds ratio different from 1)
%  between the binary row and column variables is indicated by the
%  tendency of diagonally opposite cells in one direction to differ in
%  size from those in the other direction; color is used to show this
%  direction.  Confidence rings for the odds ratio allow a visual test of
%  the null of no association; the rings for adjacent quadrants overlap
%  if and only if the observed counts are consistent with the null hypothesis.
%
%  Typically, the number \eqn{k} corresponds to the number of levels of a
%  stratifying variable, and it is of interest to see whether the
%  association is homogeneous across strata.  The fourfold display
%  visualizes the pattern of association.  Note that the confidence rings
%  for the individual odds ratios are not adjusted for multiple testing.
%}
%\references{
%  Friendly, M. (1994).
%  A fourfold display for 2 by 2 by \eqn{k} tables.
%  Technical Report 217, York University, Psychology Department.
%  \url{http://www.math.yorku.ca/SCS/Papers/4fold/4fold.ps.gz}
%}
%\seealso{
%  \code{\link{mosaicplot}}
%}
%\examples{
%## Use the Berkeley admission data as in Friendly (1995).
%x <- aperm(UCBAdmissions, c(2, 1, 3))
%dimnames(x)[[2]] <- c("Yes", "No")
%names(dimnames(x)) <- c("Sex", "Admit?", "Department")
%stats::ftable(x)
%
%## Fourfold display of data aggregated over departments, with
%## frequencies standardized to equate the margins for admission
%## and sex.
%## Figure 1 in Friendly (1994).
%fourfoldplot(margin.table(x, c(1, 2)))
%
%## Fourfold display of x, with frequencies in each table
%## standardized to equate the margins for admission and sex.
%## Figure 2 in Friendly (1994).
%fourfoldplot(x)
%
%## Fourfold display of x, with frequencies in each table
%## standardized to equate the margins for admission. but not
%## for sex.
%## Figure 3 in Friendly (1994).
%fourfoldplot(x, margin = 2)
%}
%\keyword{hplot}
%
\encoding{UTF8}
