% File src/library/graphics/man/rug.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2008 R Core Team
% Distributed under GPL 2 or later

\name{rug}
\title{Add a Rug to a Plot}
\alias{rug}
\usage{
rug(x, ticksize = 0.03, side = 1, lwd = 0.5, col = par("fg"),
    quiet = getOption("warn") < 0, \dots)
}
\arguments{
 \item{x}{数値ベクトル．}
 \item{ticksize}{
   \sQuote{ラグ}を構成するチックの長さ．
   性の長さは内向きのチックを与える．}
 \item{side}{プロットのボックスのどの側面にラグをプロットするか．
   plotted. 普通 1 (下側)又は 3 (上側)．}
 \item{lwd}{チックの線幅．幾つかのデバイスは
   最大 \code{1} で既定の長さを丸める．}
 \item{col}{チックがプロットされる色．}
 \item{quiet}{クリップされた値に関して警告するかどうかを指示する論理値．}
 \item{\dots}{
   ラグの位置を指定するための \code{line} や \code{pos} のような
   \code{\link{axis}} に渡される追加の引数．}
}
\description{
  プロットにデータの\emph{ラグ}表現(1次元プロット)を加える．
}
\details{
  \code{rug} の実装方法からプロット領域内に落ちる \code{x} の
  値だけが使われる．もし有限な値がどれか除外されると警告が出るが，
  有限でない値は黙って無視される．
}
\references{
  Chambers, J. M. and Hastie, T. J. (1992)
  \emph{Statistical Models in S.}
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{x} 中のタイに対して使いたいかもしれない \code{\link{jitter}}．}
\examples{
require(stats)  # 'density' とその既定メソッドのため
with(faithful, {
    plot(density(eruptions, bw = 0.15))
    rug(eruptions)
    rug(jitter(eruptions, amount = 0.01), side = 3, col = "light blue")
})
}
\keyword{aplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/rug.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2008 R Core Team
%% Distributed under GPL 2 or later
%
%\name{rug}
%\title{Add a Rug to a Plot}
%\alias{rug}
%\usage{
%rug(x, ticksize = 0.03, side = 1, lwd = 0.5, col = par("fg"),
%    quiet = getOption("warn") < 0, \dots)
%}
%\arguments{
% \item{x}{A numeric vector}
% \item{ticksize}{The length of the ticks making up the \sQuote{rug}.
%   Positive lengths give inwards ticks.}
% \item{side}{On which side of the plot box the rug will be
%   plotted. Normally 1 (bottom) or 3 (top).}
% \item{lwd}{The line width of the ticks.  Some devices will round the
%   default width up to \code{1}.}
% \item{col}{The colour the ticks are plotted in.}
% \item{quiet}{logical indicating if there should be a warning about
%   clipped values.}
% \item{\dots}{further arguments, passed to \code{\link{axis}}, such
%   as \code{line} or \code{pos} for specifying the location of the rug.}
%}
%\description{
%  Adds a \emph{rug} representation (1-d plot) of the data to the plot.
%}
%\details{
%  Because of the way \code{rug} is implemented, only values of \code{x}
%  that fall within the plot region are included.  There will be a
%  warning if any finite values are omitted, but non-finite values are
%  omitted silently.
%}
%\references{
%  Chambers, J. M. and Hastie, T. J. (1992)
%  \emph{Statistical Models in S.}
%  Wadsworth & Brooks/Cole.
%}
%\seealso{\code{\link{jitter}} which you may want for ties in \code{x}.}
%\examples{
%require(stats)  # both 'density' and its default method
%with(faithful, {
%    plot(density(eruptions, bw = 0.15))
%    rug(eruptions)
%    rug(jitter(eruptions, amount = 0.01), side = 3, col = "light blue")
%})
%}
%\keyword{aplot}
%
%\encoding{UTF8}
%