% File src/library/graphics/man/segments.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2009 R Core Team
% Distributed under GPL 2 or later

\name{segments}
\alias{segments}
\title{Add Line Segments to a Plot}
\description{
  点の対の間に線分を描く．
}
\usage{
segments(x0, y0, x1 = x0, y1 = y0,
         col = par("fg"), lty = par("lty"), lwd = par("lwd"),
         \dots)
}
\arguments{
  \item{x0, y0}{\bold{そこから}線を描く点の座標．}
  \item{x1, y1}{\bold{そこまで}線を描く点の座標．少なくとも一つが必要．}
  \item{col, lty, lwd}{
    \code{\link{par}} に於けるようなグラフィカルパラメータで，
    ベクトルでも良い．\code{col} 中の \code{NA} 値は線分を描かない．}
  \item{\dots}{
    \code{xpd} のような (\code{\link{par}} からの)
    グラフィカルパラメータと線特性
    \code{lend}, \code{ljoin} そして \code{lmitre}．}
}
\details{
  各 \code{i} に対して線分が点
  \code{(x0[i], y0[i])} と点
  \code{(x1[i], y1[i])} の間に描かれる．
  座標ベクトルは最長の長さまでリサイクルされる．

  グラフィカルパラメータ \code{col}, \code{lty} そして \code{lwd}
  は長さが1以上のベクトルでよく，必要ならリサイクルされる．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{arrows}}，
  少し簡単であるが柔軟性に欠ける線の描画には \code{\link{lines}}，
  そして通常の多角形には \code{\link{polygon}}．
}
\examples{
x <- stats::runif(12); y <- stats::rnorm(12)
i <- order(x, y); x <- x[i]; y <- y[i]
plot(x, y, main = "arrows(.) and segments(.)")
## 点から点へ矢印を描く
s <- seq(length(x)-1)  # データより一つ短い
arrows(x[s], y[s], x[s+1], y[s+1], col= 1:3)
s <- s[-length(s)]
segments(x[s], y[s], x[s+2], y[s+2], col= 'pink')
}
\keyword{aplot}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/segments.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2009 R Core Team
%% Distributed under GPL 2 or later
%
%\name{segments}
%\alias{segments}
%\title{Add Line Segments to a Plot}
%\description{
%  Draw line segments between pairs of points.
%}
%\usage{
%segments(x0, y0, x1 = x0, y1 = y0,
%         col = par("fg"), lty = par("lty"), lwd = par("lwd"),
%         \dots)
%}
%\arguments{
%  \item{x0, y0}{coordinates of points \bold{from} which to draw.}
%  \item{x1, y1}{coordinates of points \bold{to} which to draw.  At least
%    one must be supplied.}
%  \item{col, lty, lwd}{\link{graphical parameters} as in
%    \code{\link{par}}, possibly vectors.  \code{NA} values in \code{col}
%    cause the segment to be omitted.}
%  \item{\dots}{further \link{graphical parameters} (from \code{\link{par}}),
%    such as \code{xpd} and the line characteristics \code{lend}, \code{ljoin}
%    and \code{lmitre}.}
%}
%\details{
%  For each \code{i}, a line segment is drawn between the point
%  \code{(x0[i], y0[i])} and the point \code{(x1[i], y1[i])}.  The
%  coordinate vectors will be recycled to the length of the longest.
%
%  The \link{graphical parameters} \code{col}, \code{lty} and \code{lwd} can be
%  vectors of length greater than one and will be recycled if necessary.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{arrows}},
%  \code{\link{polygon}} for slightly easier and less flexible line
%  drawing, and
%  \code{\link{lines}} for the usual polygons.
%}
%\examples{
%x <- stats::runif(12); y <- stats::rnorm(12)
%i <- order(x, y); x <- x[i]; y <- y[i]
%plot(x, y, main = "arrows(.) and segments(.)")
%## draw arrows from point to point :
%s <- seq(length(x)-1)  # one shorter than data
%arrows(x[s], y[s], x[s+1], y[s+1], col= 1:3)
%s <- s[-length(s)]
%segments(x[s], y[s], x[s+2], y[s+2], col= 'pink')
%}
%\keyword{aplot}
%
%\encoding{UTF8}
%