% File src/library/graphics/man/symbols.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2012 R Core Team
% Distributed under GPL 2 or later

\name{symbols}
\alias{symbols}
\concept{circle}
\concept{star}
\concept{square}
\concept{rectangle}
\concept{thermometer}
\concept{boxplot}
\title{Draw Symbols (Circles, Squares, Stars, Thermometers, Boxplots)}
\description{
  この関数はプロット上にシンボルを描く．
  6種類のシンボル
  \emph{円}, \emph{正方形}, \emph{矩形}, \emph{星印},
  \emph{温度計}, そして \emph{箱型図} のどれか一つを
  指定された x と y の座標に描くことが出来る．
  相対的なサイズ等の特別な様相は追加パラメータでカスタマイズ出来る．
}
\usage{
symbols(x, y = NULL, circles, squares, rectangles, stars,
        thermometers, boxplots, inches = TRUE, add = FALSE,
        fg = par("col"), bg = NA,
        xlab = NULL, ylab = NULL, main = NULL,
        xlim = NULL, ylim = NULL, \dots)
}
\arguments{
  \item{x, y}{シンボルの中心に対する x と y 座標．
    それらは
    \code{\link{xy.coords}} が受け入れる任意の仕方で指定できる．}
  \item{circles}{円の半径を与えるベクトル．}
  \item{squares}{正方形の辺長を与えるベクトル．}
  \item{rectangles}{二列の行列．
    最初の列は矩形の幅を与え，二番目の列は矩形の高さを与える．}
  \item{stars}{3もしくはそれ以上の列を持つ行列で星印
    の中心からの放射線の長さを与える．
    \code{NA} 値はゼロで置き換えられる．}
  \item{thermometers}{
    3 もしくは 4 列の行列．
    最初の二つの列は温度計の幅と高さを与える．
    もし三つの列があれば，三番目は比率とされる：
    温度計はそれらの底部からそれらの高さのこの比率の分まで
    (色 \code{fg} を使い)塗りつぶされる．
    四つの列があれば三番目と四番目の列は比率とされ，
    温度計はそれらの高さのこれらの比率の間で塗りつぶされる．
    箱の \code{fg} で塗りつぶされない部分は
    \code{bg} で与えられる背景色(既定では透明)で塗りつぶされる．}
  \item{boxplots}{
    5つの列を持つ行列．最初の二つの列は箱の幅と高さ，
    次の二つの列は上下のヒゲの長さ，
    そして5番目の列は中央値線が描かれる
    箱の内部での比率である([0,1] 内にないと警告が出る)．}
  \item{inches}{\code{TRUE}, \code{FALSE} 又は正数．
    \sQuote{詳細}を見よ．}
  \item{add}{もし \code{add} が \code{TRUE} なら，シンボルは既存の
    プロットに加えられる．さもなければ新しいプロットが作られる．}
  \item{fg}{シンボルを描くべき色．}
  \item{bg}{もし指定されると，シンボルは色で塗りつぶされる．
    ベクトル \code{bg} はシンボルの数までリサイクルされる．
    既定値ではシンボルは塗りつぶされない．}
  \item{xlab}{
    もし \code{add} が真でなければプロットの x ラベル．
    既定では \code{x} に対して使われた逆構文解析表現．}
  \item{ylab}{プロットの y ラベル．
    もし \code{add = TRUE} ならば使われない．}
  \item{main}{プロットの主タイトル．
    もし \code{add = TRUE} ならば使われない．}
  \item{xlim}{プロットに対する x の限界を与える長さ 2 の数値ベクトル．
    もし \code{add = TRUE} ならば使われない．}
  \item{ylim}{プロットに対する y の限界を与える長さ 2 の数値ベクトル．
    もし \code{add = TRUE} ならば使われない．}
  \item{\dots}{
    プロットのアスペクト比 \code{asp} (\code{\link{plot.window}} を見よ)
    のような，グラフィックスパラメータをこの関数に渡すことが出来る．}
}
\details{
  座標又はサイズが欠損した観測値はプロットされない．
  これの例外は\emph{星印}である．
  この場合，\code{NA} である放射線の長さはゼロにリセットされる．

  引数 \code{inches} はシンボルのサイズを制御する．
  もし \code{TRUE} (既定値)ならば，任意のシンボルの最大次元が
  1インチになるようにシンボルはスケール化される．
  もし正の値を与えるとシンボルは最大次元がインチでこのサイズに
  なるようにスケール化される
  (従って \code{TRUE} と \code{1} は同値である)．
  もし \code{inches} が \code{FALSE} ならば，
  単位は適切な軸のそれらに取られる．
  (円，正方形そして星印に対しては x 軸の単位が使われる．
  箱型図に対しては，ヒゲの長さは幅に沿った次元，
  \code{inches} でスケール化されれば高さに沿って沿った次元と見做される．
  そしてさもなければ y 軸の単位で解釈される．)

  % The next is enforced in GCircle.
  半径ゼロの円は半径が1ピクセル(これはデバイス依存)としてプロットされる．
  非常に小さい半径がゼロでない円は見えるかもしれないし見えないかもしれない．
  そして半径ゼロの円よりも小さいかもしれない．
  ある種の Windows のバージョンがそれより小さい円を省略するため，
  \code{windows} デバイス上では円は少なくとも1ピクセルとして
  プロットされる．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  W. S. Cleveland (1985)
  \emph{The Elements of Graphing Data.}
  Monterey, California: Wadsworth.

  Murrell, P. (2005) \emph{R Graphics}. Chapman & Hall/CRC Press.
}
\seealso{
  \emph{星印}をもう少し柔軟に描くためには \code{\link{stars}}．

  もし\sQuote{バブルプロット}を
  \code{symbols(*, circles=*)} で描くことを考えているのなら，
  代わりに \code{\link{sunflowerplot}} を使うことを
  \emph{真剣に}考えたほうが良い．
}
\examples{
require(stats); require(grDevices)
x <- 1:10
y <- sort(10*runif(10))
z <- runif(10)
z3 <- cbind(z, 2*runif(10), runif(10))
symbols(x, y, thermometers = cbind(.5, 1, z), inches = .5, fg = 1:10)
symbols(x, y, thermometers = z3, inches = FALSE)
text(x, y, apply(format(round(z3, digits = 2)), 1, paste, collapse = ","),
     adj = c(-.2,0), cex = .75, col = "purple", xpd = NA)

## example(trees) がより意味のあるプロットを表示することを注意!
N <- nrow(trees)
with(trees, {
## 幹周りはインチ単位の直径
symbols(Height, Volume, circles = Girth/24, inches = FALSE,
        main = "Trees' Girth") # 自動的な xlab と ylab
## 色も：
op <- palette(rainbow(N, end = 0.9))
symbols(Height, Volume, circles = Girth/16, inches = FALSE, bg = 1:N,
        fg = "gray30", main = "symbols(*, circles = Girth/16, bg = 1:N)")
palette(op)
})
}
\keyword{aplot}
\keyword{hplot}
\keyword{multivariate}

\encoding{UTF8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/graphics/man/symbols.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2012 R Core Team
%% Distributed under GPL 2 or later
%
%\name{symbols}
%\alias{symbols}
%\concept{circle}
%\concept{star}
%\concept{square}
%\concept{rectangle}
%\concept{thermometer}
%\concept{boxplot}
%\title{Draw Symbols (Circles, Squares, Stars, Thermometers, Boxplots)}
%\description{
%  This function draws symbols on a plot.  One of six symbols;
%  \emph{circles}, \emph{squares}, \emph{rectangles}, \emph{stars},
%  \emph{thermometers}, and \emph{boxplots}, can be plotted at a
%  specified set of x and y coordinates.  Specific aspects of the
%  symbols, such as relative size, can be customized by additional
%  parameters.
%}
%\usage{
%symbols(x, y = NULL, circles, squares, rectangles, stars,
%        thermometers, boxplots, inches = TRUE, add = FALSE,
%        fg = par("col"), bg = NA,
%        xlab = NULL, ylab = NULL, main = NULL,
%        xlim = NULL, ylim = NULL, \dots)
%}
%\arguments{
%  \item{x, y}{the x and y co-ordinates for the centres of the symbols.
%    They can be specified in any way which is accepted by
%    \code{\link{xy.coords}}.}
%  \item{circles}{a vector giving the radii of the circles.}
%  \item{squares}{a vector giving the length of the sides of the squares.}
%  \item{rectangles}{a matrix with two columns.  The first column gives
%    widths and the second the heights of rectangles.}
%  \item{stars}{a matrix with three or more columns giving the lengths
%    of the rays from the center of the stars.  \code{NA} values
%    are replaced by zeroes.}
%  \item{thermometers}{a matrix with three or four columns.  The first
%    two columns give the width and height of the thermometer symbols. If
%    there are three columns, the third is taken as a proportion: the
%    thermometers are filled (using colour \code{fg}) from their base to
%    this proportion of their height.  If there are four columns, the
%    third and fourth columns are taken as proportions and the
%    thermometers are filled between these two proportions of their
%    heights.  The part of the box not filled in \code{fg} will be filled
%    in the background colour (default transparent) given by \code{bg}.}
%  \item{boxplots}{a matrix with five columns.  The first two columns
%    give the width and height of the boxes, the next two columns
%    give the lengths of the lower and upper whiskers and the fifth
%    the proportion (with a warning if not in [0,1]) of the way up
%    the box that the median line is drawn.}
%  \item{inches}{\code{TRUE}, \code{FALSE} or a positive number.
%    See \sQuote{Details}.}
%  \item{add}{if \code{add} is \code{TRUE}, the symbols are added to
%    an existing plot, otherwise a new plot is created.}
%  \item{fg}{colour(s) the symbols are to be drawn in.}
%  \item{bg}{if specified, the symbols are filled with colour(s), the
%    vector \code{bg} being recycled to the number of symbols.
%    The default is to leave the symbols unfilled.}
%  \item{xlab}{the x label of the plot if \code{add} is not true.
%    Defaults to the \code{\link{deparse}}d expression used for \code{x}.}
%  \item{ylab}{the y label of the plot.  Unused if \code{add = TRUE}.}
%  \item{main}{a main title for the plot.  Unused if \code{add = TRUE}.}
%  \item{xlim}{numeric vector of length 2 giving the x limits for the
%    plot.  Unused if \code{add = TRUE}.}
%  \item{ylim}{numeric vector of length 2 giving the y limits for the
%    plot.  Unused if \code{add = TRUE}.}
%  \item{\dots}{graphics parameters can also be passed to this function,
%    as can the plot aspect ratio \code{asp} (see \code{\link{plot.window}}).}
%}
%\details{
%  Observations which have missing coordinates or missing size
%  parameters are not plotted.  The exception to this is \emph{stars}.
%  In that case, the length of any ray which is \code{NA} is reset
%  to zero.
%
%  Argument \code{inches} controls the sizes of the symbols.  If
%  \code{TRUE} (the default), the symbols are scaled so that the
%  largest dimension of any symbol is one inch.  If a positive number is
%  given the symbols are scaled to make largest dimension this size in
%  inches (so \code{TRUE} and \code{1} are equivalent).  If \code{inches}
%  is \code{FALSE}, the units are taken to be those of the appropriate
%  axes.  (For circles, squares and stars the units of the x axis are
%  used.  For boxplots, the lengths of the whiskers are regarded as
%  dimensions alongside width and height when scaling by \code{inches},
%  and are otherwise interpreted in the units of the y axis.)
%
%  % The next is enforced in GCircle.
%  Circles of radius zero are plotted at radius one pixel (which is
%  device-dependent).  Circles of a very small non-zero radius may or may
%  not be visible, and may be smaller than circles of radius zero.  On
%  \code{windows} devices circles are plotted at radius at least one
%  pixel as some Windows versions omit smaller circles.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  W. S. Cleveland (1985)
%  \emph{The Elements of Graphing Data.}
%  Monterey, California: Wadsworth.
%
%  Murrell, P. (2005) \emph{R Graphics}. Chapman & Hall/CRC Press.
%}
%\seealso{
%  \code{\link{stars}} for drawing \emph{stars} with a bit more
%  flexibility.
%
%  If you are thinking about doing \sQuote{bubble plots} by
%  \code{symbols(*, circles=*)}, you should \emph{really} consider using
%  \code{\link{sunflowerplot}} instead.
%}
%\examples{
%require(stats); require(grDevices)
%x <- 1:10
%y <- sort(10*runif(10))
%z <- runif(10)
%z3 <- cbind(z, 2*runif(10), runif(10))
%symbols(x, y, thermometers = cbind(.5, 1, z), inches = .5, fg = 1:10)
%symbols(x, y, thermometers = z3, inches = FALSE)
%text(x, y, apply(format(round(z3, digits = 2)), 1, paste, collapse = ","),
%     adj = c(-.2,0), cex = .75, col = "purple", xpd = NA)
%
%## Note that  example(trees)  shows more sensible plots!
%N <- nrow(trees)
%with(trees, {
%## Girth is diameter in inches
%symbols(Height, Volume, circles = Girth/24, inches = FALSE,
%        main = "Trees' Girth") # xlab and ylab automatically
%## Colours too:
%op <- palette(rainbow(N, end = 0.9))
%symbols(Height, Volume, circles = Girth/16, inches = FALSE, bg = 1:N,
%        fg = "gray30", main = "symbols(*, circles = Girth/16, bg = 1:N)")
%palette(op)
%})
%}
%\keyword{aplot}
%\keyword{hplot}
%\keyword{multivariate}
%
%\encoding{UTF8}
%