% File src/library/parallel/man/makePSOCKcluster.Rd
% Part of the R package, https://www.R-project.org
% Copyright 2003-2014 R Core Team
% Distributed under GPL 2 or later

\name{makeCluster}
\alias{makeCluster}
\alias{makePSOCKcluster}
\alias{makeForkCluster}
\alias{stopCluster}
\alias{setDefaultCluster}
\alias{R_PARALLEL_PORT}

\title{
  Create a Parallel Socket Cluster
}
\description{
  並列に動作する \R のコピーのセットを作り，
  ソケットを通じて通信する．
}
\usage{
makeCluster(spec, type, ...)
makePSOCKcluster(names, ...)
makeForkCluster(nnodes = getOption("mc.cores", 2L), ...)

stopCluster(cl = NULL)

setDefaultCluster(cl = NULL)
}
\arguments{
  \item{spec}{クラスタのタイプに適当な指定．}
  \item{names}{\R のワーカーのコピーをその上で実行するホスト名の
    文字列ベクトルか，正整数
    (その場合その数のコピーが
    \samp{ローカルホスト} の上で実行される)．}
  \item{nnodes}{フォークされるノードの数．}
  \item{type}{サポートされるタイプの一つ：\sQuote{詳細}を見よ．}
  \item{\dots}{ワーカーを生み出す関数に渡されるオプション，\sQuote{詳細}を見よ．}
  \item{cl}{クラス \code{"cluster"} のオブジェクト．}
}
\details{
  \code{makeCluster} はサポートされるタイプの一つのクラスターを作る．
  creates a cluster of one of the supported types.
  既定のタイプ \code{"PSOCK"} は \code{makePSOCKcluster} を呼び出す．
  タイプ \code{"FORK"} は \code{makeForkCluster} を呼びだす．
  他のタイプはパッケージ \CRANpkg{snow} に渡される．

  \code{makePSOCKcluster} は
  パッケージ \CRANpkg{snow} 中の
  \code{makeSOCKcluster} の拡張版である．
  これは \command{Rscript} を指定されたホストの上で
  ソケットから評価すべき表現式を聴き取り，
  結果を(シリアル化されたオブジェクトとして)返す
  ワーカープロセスを設定する．

  \code{makeForkCluster} は
  Windows では単なる名残である．Unix 風プラットフォームでは
  これはフォークによりワーカープロセスを作る．

  ワーカーは最もしばしば同じホスト上で
  マスターとして稼働する．
  その時はオプションを設定する必要はない．

  幾つかのオプションがサポートされている(主に \code{makePSOCKcluster} 用)：
  \describe{
    \item{\code{master}}{ワーカーに知られているようなマスターのホスト名．
      これはマスターに知られているものと同じではないかもしれず，
      プライベートなサブネットではこれを
      数値 IP アドレスとして指定する必要があるかもしれない．
      例えば OS X はあるマシーンを恐らくそれだけに知られている名前の
      \samp{somename.local} として検出する．}
    \item{\code{port}}{ソケットコネクションのポート番号で，
      既定値は環境変数
      \env{R_PARALLEL_PORT} から取り，それから無作為に範囲
      \code{11000:11999} から選ぶ．}
    \item{\code{timeout}}{そのポートに対する時間切れの秒数．
      既定値は 30 日(そして POSIX 標準は最大31日までのサポートだけを
      要求する)．}
    \item{\code{outfile}}{
      ワーカーからの
      \code{\link{stdout}} と \code{\link{stderr}} コネクション出力を
      どこにダイレクトするか．
      \code{""} はリダイレクションをしないことを指示する
      (それはワーカーがローカルマシン上にある時だけ役に立つ)．
      既定では \file{/dev/null} へ(Windows では \file{nul:})．
      他の可能性はワーカーのホストのファイルパスである．
      ファイルは追加モードで開かれ，全てのワーカーのログが
      同じファイルに書かれる．}
    \item{\code{homogeneous}}{論理値．全てのホストは同一の設定で
      稼働し，従って
      \command{Rscript} はそれぞれ同じパスを使って始動されるか?
      さもなければ \command{Rscript} はワーカーの既定パス上に
      なければならない．}
    \item{\code{rscript}}{ワーカー上の \command{Rscript} へのパスで，
      \code{homogeneous} が真の時だけ使われる．
      既定ではマスター上のフルパス．}
    \item{\code{rscript_args}}{
      \option{--no-environ} のような
      \command{Rscript} への追加引数の文字列ベクトル．}
    \item{\code{renice}}{ワーカープロセスに対して設定される\sQuote{優先度}，
      例えば低優先度なら \code{15}．
      OS 依存：詳細は \code{\link{psnice}} を見よ．}
    \item{\code{rshcmd}}{他のホスト上のプロセスを指導するために
      実行される命令．既定値は \command{ssh}．}
    \item{\code{user}}{別のホストと通信する際に使われるユーザ名．}
    \item{\code{manual}}{論理値．もし真ならワーカーは手動で
      実行されなければならない．}
    \item{\code{methods}}{論理値．もし真(既定)ならばワーカーは
      パッケージ \pkg{methods} をロードする：
      それをロードしないとクラスターの起動 CPU 時間を
      約 30\% 節約する．}
    \item{\code{useXDR}}{論理値．もし真なら(既定値)シリアル化は
      XDR を使う：大量のデータが移動され全てのノードが
      リトルエンディアンならば，これを偽に設定すると
      通信はかなり速くなる．}
  }

  関数 \code{makeForkCluster} はソケットクラスターを
  フォークで作る(従って Windows では利用できない)．
  それはオプション \code{port}, \code{timeout} そして \code{outfile}
  をサポートし，常に \code{useXDR = FALSE} を使う．

  ワーカーを
  呼び出し \code{\link{stopCluster}} でシャットダウンするのは
  良い作法である：しかしながらワーカーは
  それらが命令を聴くソケットが利用不可能になるとそれ自体で
  終了し，もしマスターの \R セッションが完了(またはそれが死亡)すれば
  そうなるべきである．

  関数 \code{setDefaultCluster} は現在のセッションに対して一つの
  クラスターを既定として登録する．
  \code{setDefaultCluster(NULL)} の使用はそのクラスター
  を停止するので，登録クラスターを取り除く．
}

\value{
  クラス \code{c("SOCKcluster", "cluster")} のオブジェクト．
}

\author{
  Luke Tierney と R Core．

  パッケージ \CRANpkg{snow} に由来する．
}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/parallel/man/makePSOCKcluster.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 2003-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{makeCluster}
%\alias{makeCluster}
%\alias{makePSOCKcluster}
%\alias{makeForkCluster}
%\alias{stopCluster}
%\alias{setDefaultCluster}
%\alias{R_PARALLEL_PORT}
%
%\title{
%  Create a Parallel Socket Cluster
%}
%\description{
%  Creates a set of copies of \R running in parallel and communicating
%  over sockets.
%}
%\usage{
%makeCluster(spec, type, ...)
%makePSOCKcluster(names, ...)
%makeForkCluster(nnodes = getOption("mc.cores", 2L), ...)
%
%stopCluster(cl = NULL)
%
%setDefaultCluster(cl = NULL)
%}
%\arguments{
%  \item{spec}{A specification appropriate to the type of cluster.}
%  \item{names}{Either a character vector of host names on which to run
%    the worker copies of \R, or a positive integer (in which case
%    that number of copies is run on \samp{localhost}).}
%  \item{nnodes}{The number of nodes to be forked.}
%  \item{type}{One of the supported types: see \sQuote{Details}.}
%  \item{\dots}{Options to be passed to the function spawning the workers.
%    See \sQuote{Details}.}
%  \item{cl}{an object of class \code{"cluster"}.}
%}
%\details{
%  \code{makeCluster} creates a cluster of one of the supported types.
%  The default type, \code{"PSOCK"}, calls \code{makePSOCKcluster}.  Type
%  \code{"FORK"} calls \code{makeForkCluster}.  Other types are passed to
%  package \CRANpkg{snow}.
%
%  \code{makePSOCKcluster} is an enhanced version of
%  \code{makeSOCKcluster} in package \CRANpkg{snow}.  It runs
%  \command{Rscript} on the specified host(s) to set up a worker process
%  which listens on a socket for expressions to evaluate, and returns the
%  results (as serialized objects).
%
%  \code{makeForkCluster} is merely a stub on Windows.  On Unix-alike
%  platforms it creates the worker process by forking.
%
%  The workers are most often running on the same host as the master,
%  when no options need be set.
%
%  Several options are supported (mainly for \code{makePSOCKcluster}):
%  \describe{
%    \item{\code{master}}{The host name of the master, as known to the
%      workers.  This may not be the same as it is known to the master,
%      and on private subnets it may be necessary to specify this as a
%      numeric IP address.  For example, OS X is likely to detect a
%      machine as \samp{somename.local}, a name known only to itself.}
%    \item{\code{port}}{The port number for the socket connection,
%      default taken from the environment variable \env{R_PARALLEL_PORT},
%      then a randomly chosen port in the range \code{11000:11999}.}
%    \item{\code{timeout}}{The timeout in seconds for that port.  Default
%      30 days (and the POSIX standard only requires values up to 31 days
%      to be supported).}
%    \item{\code{outfile}}{Where to direct the \code{\link{stdout}} and
%      \code{\link{stderr}} connection output from the workers.
%      \code{""} indicates no redirection (which may only be useful for
%      workers on the local machine).
%      Defaults to \file{/dev/null} (\file{nul:} on Windows).  The other
%      possibility is a file path on the worker's host.
%      Files will be opened in append mode, as all workers log to the
%      same file.}
%    \item{\code{homogeneous}}{Logical.  Are all the hosts running
%      identical setups, so \command{Rscript} can be launched using
%      the same path on each?  Otherwise \command{Rscript} has to be in
%      the default path on the workers.}
%    \item{\code{rscript}}{The path to \command{Rscript} on the workers,
%      used if \code{homogeneous} is true. Defaults to the full path on
%      the master.}
%    \item{\code{rscript_args}}{Character vector of additional
%      arguments for \command{Rscript} such as \option{--no-environ}.}
%    \item{\code{renice}}{A numerical \sQuote{niceness} to set for the
%      worker processes, e.g.\sspace{}\code{15} for a low priority.
%      OS-dependent: see \code{\link{psnice}} for details.}
%    \item{\code{rshcmd}}{The command to be run on the master to launch a
%      process on another host.  Defaults to \command{ssh}.}
%    \item{\code{user}}{The user name to be used when communicating with
%      another host.}
%    \item{\code{manual}}{Logical.  If true the workers will need to be
%      run manually.}
%    \item{\code{methods}}{Logical.  If true (default) the workers will
%      load the \pkg{methods} package: not loading it saves ca 30\% of the
%      startup CPU time of the cluster.}
%    \item{\code{useXDR}}{Logical. If true (default) serialization will
%      use XDR: where large amounts of data are to be transferred and
%      all the nodes are little-endian, communication may be
%      substantially faster if this is set to false.}
%  }
%
%  Function \code{makeForkCluster} creates a socket cluster by forking
%  (and hence is not available on Windows).  It supports options
%  \code{port}, \code{timeout} and \code{outfile}, and always uses
%  \code{useXDR = FALSE}.
%
%  It is good practice to shut down the workers by calling
%  \code{\link{stopCluster}}: however the workers will terminate
%  themselves once the socket on which they are listening for commands
%  becomes unavailable, which it should if the master \R session is
%  completed (or its process dies).
%
%  Function \code{setDefaultCluster} registers a cluster as the default one
%  for the current session.  Using \code{setDefaultCluster(NULL)} removes
%  the registered cluster, as does stopping that cluster.
%}
%
%\value{
%  An object of class \code{c("SOCKcluster", "cluster")}.
%}
%
%\author{
%  Luke Tierney and R Core.
%
%  Derived from the \CRANpkg{snow} package.
%}
%
%\encoding{UTF-8}
%\encoding{UTF8}

