% File src/library/stats/man/AIC.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{AIC}

\alias{AIC}
\alias{BIC}
\title{Akaike's An Information Criterion}
\description{
  対数尤度値が得られる一つもしくは複数の当てはめモデルオブジェクト
  に対して
  赤池の \sQuote{情報量規準} を
  公式 \eqn{-2 \mbox{log-likelihood} + k n_{par}}{-2*log-likelihood + k*npar},
  で計算する総称的関数．
  ここで \eqn{n_{par}}{npar} は当てはめモデル中のパラメータ数を表し，
  \eqn{k = 2} は通常の AIC 用で，
  \eqn{k = \log(n)}{k = log(n)}
  (\eqn{n} は観測値の数)は
  いわゆる BIC 又は SBC (Schwarz のベイズ規準)用である．
}
\usage{
AIC(object, \dots, k = 2)

BIC(object, \dots)
}
\arguments{
  \item{object}{
    対応する対数尤度を取り出す
    \code{logLik} メソッドが存在する当てはめモデルオブジェクト，
    又は
    クラス \code{logLik} を継承するオブジェクト．}
  \item{\dots}{オプションの他の当てはめモデルオブジェクト．}
  \item{k}{数値，使用されるパラメータ毎の\emph{ペナルティー}：
    既定値 \code{k = 2} は古典的な AIC である．}
}
\details{
  同じデータに最大尤度で当てはめられたモデルを比較する際，
  AIC か BIC が小さいほど当てはめは良い．
  
  AIC 理論は対数尤度が最大化されていることを要求する：
  AIC が最尤法で当てはめられたのではないモデルに対して計算できたとしても，
  それらの AIC 値は比較されるべきではない．

  \sQuote{同じデータに当てはめられた}のではないモデルの例は
  応答が変換されている場合
  (accelerated-life モデルは対数時間に当てはめられる)と
  データの要約に分割表が使われている場合がある．
  
  これらは総称的関数である
  (パッケージ \pkg{stats4} 中で S4 総称的関数が定義されている)：
  しかしながらメソッドはこれらの関数に対してではなく対数尤度関数
  \code{\link{logLik}} に対して定義されるべきである：
  それらの既定メソッドの動作は
  全ての提供されたオブジェクトに \code{logLik} を呼び出して
  結果を集めることである．
  幾つかの通例のケースでは
  MLE での値を返さない：そのヘルプ頁を見よ．

  対数尤度，従って
  AIC/BIC は加算定数を除いてだけ定義される．
  慣習的に異なった定数が異なった目的に対して
  使われてきており，従って
  \code{\link{extractAIC}} と \code{AIC} は
  異なった値を与えるかもしれない
  (クラス \code{"lm"} のモデルに対してはそうなる，
  \code{\link{extractAIC}} のヘルプを見よ)．
  異なったクラスの当てはめを比較する場合は特別な用心が必要になる
  (例えばポアッソンとガンマ GLM の比較は一方が離散応答を持ち他方は
  連続値応答を持つので無意味である)．

  \code{BIC} は
  \code{AIC(object, \dots, k = log(nobs(object)))}
  で定義される．
  これには観測値の数が分かっている必要がある：
  既定のメソッドは先ず
  \code{\link{logLik}} メソッドの返り値の \code{"nobs"} 属性を探し，
  それから \code{\link{nobs}} 総称的関数を試み，
  どちらも不成功なら BIC を \code{NA} として返す．
}
\value{
  もしたった一つのオブジェクトが与えられると，
  対応する AIC (又は \code{k} に依存して BIC，又は \dots)．

  もし複数のオブジェクトが与えられると，
  行がオブジェクトに対応し，列がモデル中のパラメータ数と
  AIC 又は BIC であるデータフレーム．
}
\references{
  Sakamoto, Y., Ishiguro, M., and Kitagawa G. (1986).
  \emph{Akaike Information Criterion Statistics}.
  D. Reidel Publishing Company.
}
\author{
  オリジナルは \enc{José}{Jose} Pinheiro と Douglas Bates による．
  より最近の改訂は R-core．
}
\seealso{
  \code{\link{extractAIC}}, \code{\link{logLik}}, \code{\link{nobs}}.
}
\examples{
lm1 <- lm(Fertility ~ . , data = swiss)
AIC(lm1)
stopifnot(all.equal(AIC(lm1),
                    AIC(logLik(lm1))))
BIC(lm1)

lm2 <- update(lm1, . ~ . -Examination)
AIC(lm1, lm2)
BIC(lm1, lm2)
}
\keyword{models}

\encoding{UTF-8}
