% File src/library/stats/man/Chisquare.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{Chisquare}
\alias{Chisquare}
\alias{dchisq}
\alias{pchisq}
\alias{qchisq}
\alias{rchisq}
\title{The (non-central) Chi-Squared Distribution}
\description{
  自由度 \code{df} とオプションの非中心化パラメータ \code{ncp} の
  カイ二乗(\eqn{\chi^2}{chi^2})分布
  に対する密度，分布関数，クォンタイル関数と乱数生成．
}
\usage{
dchisq(x, df, ncp = 0, log = FALSE)
pchisq(q, df, ncp = 0, lower.tail = TRUE, log.p = FALSE)
qchisq(p, df, ncp = 0, lower.tail = TRUE, log.p = FALSE)
rchisq(n, df, ncp = 0)
}
\arguments{
  \item{x, q}{クォンタイルのベクトル．}
  \item{p}{確率のベクトル．}
  \item{n}{観測値数．もし \code{length(n) > 1} なら長さが
    必要な個数とされる．}
  \item{df}{自由度(非負だが整数でなくて良い)．}
  \item{ncp}{非中心化パラメータ(非負)．}
  \item{log, log.p}{論理値；もし TRUE なら確率 p は log(p) とされる．}
  \item{lower.tail}{論理値；もし TRUE (既定値)なら
    確率は \eqn{P[X \le x]} で，さもなければ \eqn{P[X > x]}．}
}
\value{
  \code{dchisq} は密度，\code{pchisq} は分布関数，
  \code{qchisq} はクォンタイル関数，そして
  \code{rchisq} は乱数を生成する．

  不正な引数は値 \code{NaN} を返し，警告が出る．

  \code{rchisq} に対しては結果の長さは \code{n} で決まり，．
  そして他の関数に対しては数値引数の最大長である．

  \code{n} 以外の数値引数は結果の長さまでリサイクルされる．
  論理値引数は最初の要素だけが使われる．
}
\details{
  自由度 \code{df}\eqn{= n \ge 0} のカイ二乗分布は
  \eqn{x > 0} に対して密度
  \deqn{f_n(x) = \frac{1}{{2}^{n/2} \Gamma (n/2)} {x}^{n/2-1} {e}^{-x/2}}{f_n(x) = 1 / (2^(n/2) \Gamma(n/2))  x^(n/2-1) e^(-x/2)}
  を持つ．平均と分散は \eqn{n} と \eqn{2n} である．

  非中心化カイ二乗分布
  自由度 \code{df}\eqn{= n} で非中心化パラメータ
  \code{ncp} \eqn{= \lambda} の
  非中心化カイ二乗分布は \eqn{x \ge 0} に対して密度
  \deqn{
    f(x) = e^{-\lambda / 2}
      \sum_{r=0}^\infty \frac{(\lambda/2)^r}{r!}\, f_{n + 2r}(x)}{f(x) = exp(-\lambda/2) SUM_{r=0}^\infty ((\lambda/2)^r / r!) dchisq(x, df + 2r)
  }
  を持つ．整数の \eqn{n} に対してはこれは分散 1 の
  \eqn{n} 個の互いに独立な正規変数の二乗和の分布で，
  \eqn{\lambda} は正規分布の平均の二乗和である；更に
  \cr
  \eqn{E(X) = n + \lambda}, \eqn{Var(X) = 2(n + 2*\lambda)}, そして
  \eqn{E((X - E(X))^3) = 8(n + 3*\lambda)}.

  自由度 \code{df}\eqn{= n} は非整数になり得ることを注意しよう．
  そして又 \eqn{n = 0} もあり得，これは非中心パラメータ
  \eqn{\lambda > 0} に関連する，
  Johnson \emph{et al} (1995, chapter 29) を見よ．
  そのケース(非中心，ゼロ自由度)では，分布は
  \eqn{x = 0} でのポイントマス(サイズ \code{pchisq(0, df=0, ncp=ncp)})と
  連続部分との混合である．そして
  \code{dchisq()} はこの混合分布に関する密度ではなく，むしろ
  \eqn{df \to 0}{df -> 0} に対する密度の極限である．

  約 1e5 以上の \code{ncp} 値は
  \code{pchisq} と \code{qchisq} に対して多くの警告と共に
  不正確な結果を与えるかもしれない．
}
\source{
  中心化ケースはガンマ分布を使い計算される．

  非中心化 \code{dchisq} と \code{rchisq} は
  中心化カイ二乗のポアッソン混合として計算される
  (Johnson \emph{et al}, 1995, p.436)．

  非中心化 \code{pchisq} は
  \code{ncp < 80} に対しては
  中心化カイ二乗のポアッソン混合として，そして
  計算される
  それ以上の \code{ncp} に対しては以下の C 翻訳を使う

  Ding, C. G. (1992)
  Algorithm AS275: Computing the non-central chi-squared
  distribution function. \emph{Appl.Statist.}, \bold{41} 478--482.

  これは下側裾部分だけを計算する
  (従って上側裾部分はキャンセル化の影響を受け，
  これが問題になりそうな時は警告が与えられる．)

  非中心化 \code{qchisq} は \code{pchisq} の逆関数に
  基づく．
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Johnson, N. L., Kotz, S. and Balakrishnan, N. (1995)
  \emph{Continuous Univariate Distributions}, chapters 18 (volume 1)
  and 29 (volume 2). Wiley, New York.
}
\note{
  \code{ncp = 0} を与えると非中心化分布に対するアルゴリズムを使う．
  それは
  \code{ncp} が省略された時に使われるのとは同じアルゴリズムではない．
  これは
  \code{ncp} が非常にゼロに近い極限ケースで一貫性のある挙動を
  与えるためである．

  ゼロでない \code{ncp} に対するコードは原則
  適度な \code{ncp} の値で使われることを意図している：
  それは大きな値に対しては特に裾部分で十分正確ではない．
}
\seealso{
  他の標準的分布については \link{Distributions}．

  自由度 \eqn{n} の中心化カイ二乗分布は
  \code{shape} \eqn{\alpha = n/2}{a = n/2} で
  \code{scale} \eqn{\sigma = 2}{s = 2} のガンマ分布と同じである．
  ガンマ分布については \code{\link{dgamma}}．
}
\examples{
require(graphics)

dchisq(1, df = 1:3)
pchisq(1, df =  3)
pchisq(1, df =  3, ncp = 0:4)  # 上を含む

x <- 1:10
## Chi-squared(df = 2) は特殊な指数分布である
all.equal(dchisq(x, df = 2), dexp(x, 1/2))
all.equal(pchisq(x, df = 2), pexp(x, 1/2))

## 非中心化 -- df = 0 で ncp > 0:  Z0 は 0 にポイントマスを持つ!
Z0 <- rchisq(100, df = 0, ncp = 2.)
graphics::stem(Z0)

\donttest{## 視覚的なテスト
## 様々な自由度での 1000 個の点の P-P プロット
L <- 1.2; n <- 1000; pp <- ppoints(n)
op <- par(mfrow = c(3,3), mar = c(3,3,1,1)+.1, mgp = c(1.5,.6,0),
          oma = c(0,0,3,0))
for(df in 2^(4*rnorm(9))) {
  plot(pp, sort(pchisq(rr <- rchisq(n, df = df, ncp = L), df = df, ncp = L)),
       ylab = "pchisq(rchisq(.),.)", pch = ".")
  mtext(paste("df = ", formatC(df, digits = 4)), line =  -2, adj = 0.05)
  abline(0, 1, col = 2)
}
mtext(expression("P-P plots : Noncentral  "*
                 chi^2 *"(n=1000, df=X, ncp= 1.2)"),
      cex = 1.5, font = 2, outer = TRUE)
par(op)}

## "解析的" なテスト
lam <- seq(0, 100, by = .25)
p00 <- pchisq(0,      df = 0, ncp = lam)
p.0 <- pchisq(1e-300, df = 0, ncp = lam)
stopifnot(all.equal(p00, exp(-lam/2)),
          all.equal(p.0, exp(-lam/2)))
}
\keyword{distribution}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/Chisquare.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Chisquare}
%\alias{Chisquare}
%\alias{dchisq}
%\alias{pchisq}
%\alias{qchisq}
%\alias{rchisq}
%\title{The (non-central) Chi-Squared Distribution}
%\description{
%  Density, distribution function, quantile function and random
%  generation for the chi-squared (\eqn{\chi^2}{chi^2}) distribution with
%  \code{df} degrees of freedom and optional non-centrality parameter
%  \code{ncp}.
%}
%\usage{
%dchisq(x, df, ncp = 0, log = FALSE)
%pchisq(q, df, ncp = 0, lower.tail = TRUE, log.p = FALSE)
%qchisq(p, df, ncp = 0, lower.tail = TRUE, log.p = FALSE)
%rchisq(n, df, ncp = 0)
%}
%\arguments{
%  \item{x, q}{vector of quantiles.}
%  \item{p}{vector of probabilities.}
%  \item{n}{number of observations. If \code{length(n) > 1}, the length
%    is taken to be the number required.}
%  \item{df}{degrees of freedom (non-negative, but can be non-integer).}
%  \item{ncp}{non-centrality parameter (non-negative).}
%  \item{log, log.p}{logical; if TRUE, probabilities p are given as log(p).}
%  \item{lower.tail}{logical; if TRUE (default), probabilities are
%    \eqn{P[X \le x]}, otherwise, \eqn{P[X > x]}.}
%}
%\value{
%  \code{dchisq} gives the density, \code{pchisq} gives the distribution
%  function, \code{qchisq} gives the quantile function, and \code{rchisq}
%  generates random deviates.
%
%  Invalid arguments will result in return value \code{NaN}, with a warning.
%
%  The length of the result is determined by \code{n} for
%  \code{rchisq}, and is the maximum of the lengths of the
%  numerical arguments for the other functions.
%
%  The numerical arguments other than \code{n} are recycled to the
%  length of the result.  Only the first elements of the logical
%  arguments are used.
%}
%\details{
%  The chi-squared distribution with \code{df}\eqn{= n \ge 0}
%  degrees of freedom has density
%  \deqn{f_n(x) = \frac{1}{{2}^{n/2} \Gamma (n/2)} {x}^{n/2-1} {e}^{-x/2}}{f_n(x) = 1 / (2^(n/2) \Gamma(n/2))  x^(n/2-1) e^(-x/2)}
%  for \eqn{x > 0}.  The mean and variance are \eqn{n} and \eqn{2n}.
%
%  The non-central chi-squared distribution with \code{df}\eqn{= n}
%  degrees of freedom and non-centrality parameter \code{ncp}
%  \eqn{= \lambda} has density
%  \deqn{
%    f(x) = e^{-\lambda / 2}
%      \sum_{r=0}^\infty \frac{(\lambda/2)^r}{r!}\, f_{n + 2r}(x)}{f(x) = exp(-\lambda/2) SUM_{r=0}^\infty ((\lambda/2)^r / r!) dchisq(x, df + 2r)
%  }
%  for \eqn{x \ge 0}.  For integer \eqn{n}, this is the distribution of
%  the sum of squares of \eqn{n} normals each with variance one,
%  \eqn{\lambda} being the sum of squares of the normal means; further,
%  \cr
%  \eqn{E(X) = n + \lambda}, \eqn{Var(X) = 2(n + 2*\lambda)}, and
%  \eqn{E((X - E(X))^3) = 8(n + 3*\lambda)}.
%
%  Note that the degrees of freedom \code{df}\eqn{= n}, can be
%  non-integer, and also \eqn{n = 0} which is relevant for
%  non-centrality \eqn{\lambda > 0},
%  see Johnson \emph{et al} (1995, chapter 29).
%  In that (noncentral, zero df) case, the distribution is a mixture of a
%  point mass at \eqn{x = 0} (of size \code{pchisq(0, df=0, ncp=ncp)} and
%  a continuous part, and \code{dchisq()} is \emph{not} a density with
%  respect to that mixture measure but rather the limit of the density
%  for \eqn{df \to 0}{df -> 0}.
%
%  Note that \code{ncp} values larger than about 1e5 may give inaccurate
%  results with many warnings for \code{pchisq} and \code{qchisq}.
%}
%\source{
%  The central cases are computed via the gamma distribution.
%
%  The non-central \code{dchisq} and \code{rchisq} are computed as a
%  Poisson mixture central of chi-squares (Johnson \emph{et al}, 1995, p.436).
%
%  The non-central \code{pchisq} is for \code{ncp < 80} computed from
%  the Poisson mixture of central chi-squares and for larger \code{ncp}
%  \emph{via} a C translation of
%
%  Ding, C. G. (1992)
%  Algorithm AS275: Computing the non-central chi-squared
%  distribution function. \emph{Appl.Statist.}, \bold{41} 478--482.
%
%  which computes the lower tail only (so the upper tail suffers from
%  cancellation and a warning will be given when this is likely to be
%  significant).
%
%  The non-central \code{qchisq} is based on inversion of \code{pchisq}.
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Johnson, N. L., Kotz, S. and Balakrishnan, N. (1995)
%  \emph{Continuous Univariate Distributions}, chapters 18 (volume 1)
%  and 29 (volume 2). Wiley, New York.
%}
%\note{
%  Supplying \code{ncp = 0} uses the algorithm for the non-central
%  distribution, which is not the same algorithm used if \code{ncp} is
%  omitted.  This is to give consistent behaviour in extreme cases with
%  values of \code{ncp} very near zero.
%
%  The code for non-zero \code{ncp} is principally intended to be used
%  for moderate values of \code{ncp}: it will not be highly accurate,
%  especially in the tails, for large values.
%}
%\seealso{
%  \link{Distributions} for other standard distributions.
%
%  A central chi-squared distribution with \eqn{n} degrees of freedom
%  is the same as a Gamma distribution with \code{shape} \eqn{\alpha =
%    n/2}{a = n/2} and \code{scale} \eqn{\sigma = 2}{s = 2}.  Hence, see
%  \code{\link{dgamma}} for the Gamma distribution.
%}
%\examples{
%require(graphics)
%
%dchisq(1, df = 1:3)
%pchisq(1, df =  3)
%pchisq(1, df =  3, ncp = 0:4)  # includes the above
%
%x <- 1:10
%## Chi-squared(df = 2) is a special exponential distribution
%all.equal(dchisq(x, df = 2), dexp(x, 1/2))
%all.equal(pchisq(x, df = 2), pexp(x, 1/2))
%
%## non-central RNG -- df = 0 with ncp > 0:  Z0 has point mass at 0!
%Z0 <- rchisq(100, df = 0, ncp = 2.)
%graphics::stem(Z0)
%
%\donttest{## visual testing
%## do P-P plots for 1000 points at various degrees of freedom
%L <- 1.2; n <- 1000; pp <- ppoints(n)
%op <- par(mfrow = c(3,3), mar = c(3,3,1,1)+.1, mgp = c(1.5,.6,0),
%          oma = c(0,0,3,0))
%for(df in 2^(4*rnorm(9))) {
%  plot(pp, sort(pchisq(rr <- rchisq(n, df = df, ncp = L), df = df, ncp = L)),
%       ylab = "pchisq(rchisq(.),.)", pch = ".")
%  mtext(paste("df = ", formatC(df, digits = 4)), line =  -2, adj = 0.05)
%  abline(0, 1, col = 2)
%}
%mtext(expression("P-P plots : Noncentral  "*
%                 chi^2 *"(n=1000, df=X, ncp= 1.2)"),
%      cex = 1.5, font = 2, outer = TRUE)
%par(op)}
%
%## "analytical" test
%lam <- seq(0, 100, by = .25)
%p00 <- pchisq(0,      df = 0, ncp = lam)
%p.0 <- pchisq(1e-300, df = 0, ncp = lam)
%stopifnot(all.equal(p00, exp(-lam/2)),
%          all.equal(p.0, exp(-lam/2)))
%}
%\keyword{distribution}
%
%\encoding{UTF-8}
%