% File src/library/stats/man/HoltWinters.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2010 R Core Team
% Distributed under GPL 2 or later

\name{HoltWinters}
\alias{HoltWinters}%@%\alias{Holt-Winters フィルタリング}
\alias{print.HoltWinters}
\alias{residuals.HoltWinters}
\title{Holt-Winters Filtering}
\description{
  与えられた時系列の Holt-Winters フィルタリングを計算する．
  未知のパラメータは二乗予測誤差を最少にすることで決定される．
}
\usage{
HoltWinters(x, alpha = NULL, beta = NULL, gamma = NULL,
            seasonal = c("additive", "multiplicative"),
            start.periods = 2, l.start = NULL, b.start = NULL,
            s.start = NULL,
            optim.start = c(alpha = 0.3, beta = 0.1, gamma = 0.1),
            optim.control = list())
}
\arguments{
  \item{x}{ クラス \code{ts} のオブジェクト．}
  \item{alpha}{Holt-Winters フィルターの \eqn{alpha} パラメータ．}
  \item{beta}{Holt-Winters フィルターの \eqn{beta} パラメータ．
    もし \code{FALSE} に設定すると関数は指数平滑化を行う．}
  \item{gamma}{季節成分に使われる \eqn{gamma} パラメータ．
    もし \code{FALSE} に設定すると非季節的モデルが当てはめられる．}
  \item{seasonal}{
    \code{"additive"} (既定)又は \code{"multiplicative"} 季節モデルを選択する
    文字列．最初の数文字が十分ある．
    (\code{gamma} がゼロでない時だけ効力がある)．}
  \item{start.periods}{開始値の自動検出で使われる開始周期．
    少なくとも 2 である必要．}
  \item{l.start}{ レベル (a[0]) の開始値．}
  \item{b.start}{トレンド (b[0]) の開始値．}
  \item{s.start}{季節成分 (\eqn{s_1[0] \ldots s_p[0]}{s_1[0] \dots s_p[0]}) に
    対する開始値のベクトル．}
  \item{optim.start}{
    最適化に対する開始値を含む名前付き成分 \code{alpha},
    \code{beta} そして \code{gamma} を含むベクトル．
    必要な値だけが指定されなければならない．
    1パラメータケースでは無視される．}
  \item{optim.control}{
    もしこれが使われる時 \code{optim} に渡される追加制御パラメータのリスト．
    1パラメータケースでは無視される．}
}
\details{
  加法的 Holt-Winters 予測関数(周期長 p の時系列に対する) は
  \deqn{\hat Y[t+h] = a[t] + h b[t] + s[t - p + 1 + (h - 1) \bmod p],}{
    Yhat[t+h] = a[t] + h * b[t] + s[t - p + 1 + (h - 1) mod p],}
   ここで \eqn{a[t]}, \eqn{b[t]} そして \eqn{s[t]} は次の様に与えられる
  \deqn{a[t] = \alpha (Y[t] - s[t-p])  + (1-\alpha) (a[t-1] + b[t-1])}{
  a[t] = \alpha (Y[t] - s[t-p])  + (1-\alpha) (a[t-1] + b[t-1])}
  \deqn{b[t] = \beta (a[t] -a[t-1]) + (1-\beta)  b[t-1]}{
  b[t] = \beta (a[t] - a[t-1]) + (1-\beta) b[t-1]}
  \deqn{s[t] = \gamma (Y[t] - a[t])   + (1-\gamma) s[t-p]}{
  s[t] = \gamma (Y[t] - a[t]) + (1-\gamma) s[t-p]}

  乗算的 Holt-Winters 予測関数(周期長 p の時系列に対する) は
  \deqn{\hat Y[t+h] = (a[t] + h b[t]) \times s[t - p + 1 + (h - 1) \bmod p].}{
    Yhat[t+h] = (a[t] + h * b[t]) * s[t - p + 1 + (h - 1) mod p],}
   ここで \eqn{a[t]}, \eqn{b[t]} そして \eqn{s[t]} は次の様に与えられる
  \deqn{a[t] = \alpha (Y[t] / s[t-p])  + (1-\alpha) (a[t-1] + b[t-1])}{
  a[t] = \alpha (Y[t] / s[t-p])  + (1-\alpha) (a[t-1] + b[t-1])}
  \deqn{b[t] = \beta (a[t] - a[t-1]) + (1-\beta) b[t-1]}{
  b[t] = \beta (a[t] - a[t-1]) + (1-\beta) b[t-1]}
  \deqn{s[t] = \gamma (Y[t] / a[t])   + (1-\gamma) s[t-p]}{
  s[t] = \gamma  (Y[t] / a[t])  + (1-\gamma) s[t-p]}
  \code{x} 中のデータは乗算モデルに対してはゼロでないことが必要であるが，
  それらが全て正の時に最も意味がある．

  関数は
  それらが \code{NULL} (既定値)ならば二乗一段階予測エラーを
  最小化することで見つけようとする．
  1パラメータケースでは \code{optimize} が，さもなければ
  \code{optim} が使われる．

  季節モデルに対しては
  \code{a}, \code{b} そして \code{s} に対する開始値は
  最初の \code{start.periods} 周期に移動平均を使い
  単純なトレンドと季節成分への分解(関数 \code{\link{decompose}} を見よ)
  を行うことで推測される
  (開始レベルとトレンドに対してはトレンド成分への単純な
  線形回帰が使われる)．
  レベル/トレンドモデル(季節成分なし)に対しては
  \code{a} と \code{b} に対する開始値はそれぞれ
  \code{x[2]} and \code{x[2] - x[1]} である．
  レベルだけのモデル(通常の指数平滑)に対しては
  \code{a} に対する開始値は
  \code{x[1] である}．
}
\value{
  クラス \code{"HoltWinters"} のオブジェクト，次の成分を持つリスト：
  \item{fitted}{多重時系列で行として
    フィルタリングされた時系列及び
    レベル，トレンド，そして季節成分を持つ．
    同時的に推定される(つまり系列の最後ではなく時刻 t で推定される)．}
  \item{x}{元の時系列．}
  \item{alpha}{フィルタリングに使われる alpha．}
  \item{beta}{フィルタリングに使われる beta．}
  \item{gamma}{フィルタリングに使われる gamma．}
  \item{coefficients}{
    名前付き成分 \code{a, b, s1, ..., sp} を持つベクトルで
    レベル，トレンドそして季節成分の推定値を含む．}
  \item{seasonal}{指定された \code{seasonal} パラメータ．}
  \item{SSE}{最適化で達成された最終的な二乗誤差和．}
  \item{call}{使われた呼び出し．}
}
\references{
  C. C. Holt (1957)
  Forecasting trends and seasonals by exponentially weighted
  moving averages,
  \emph{ONR Research Memorandum, Carnegie Institute of Technology} \bold{52}.

  P. R. Winters (1960)
  Forecasting sales by exponentially weighted moving averages,
  \emph{Management Science} \bold{6}, 324--342.
}
\author{
  David Meyer \email{David.Meyer@wu.ac.at}
}
\seealso{
  \code{\link{predict.HoltWinters}}, \code{\link{optim}}.
}

% Differences seen on 32-bit Linux at -O3
\examples{
\testonly{od <- options(digits = 5)}
require(graphics)

## 季節的な Holt-Winters
(m <- HoltWinters(co2))
plot(m)
plot(fitted(m))

(m <- HoltWinters(AirPassengers, seasonal = "mult"))
plot(m)

## 季節的でない Holt-Winters
x <- uspop + rnorm(uspop, sd = 5)
m <- HoltWinters(x, gamma = FALSE)
plot(m)

## 指数平滑
m2 <- HoltWinters(x, gamma = FALSE, beta = FALSE)
lines(fitted(m2)[,1], col = 3)
\testonly{options(od)}
}
\keyword{ts}

\encoding{UTF-8}
