% File src/library/stats/man/SignRank.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{SignRank}
\alias{SignRank}%@%\alias{Wilcoxon の符号付きランク統計量分布}
\alias{dsignrank}
\alias{psignrank}
\alias{qsignrank}
\alias{rsignrank}
\title{Distribution of the Wilcoxon Signed Rank Statistic}
\description{
  サイズ \code{n} のサンプルから得られた
  Wilcoxon の符号付きランク統計量
  の分布に対する密度，分布関数，クォンタイル関数と乱数生成．
}
\usage{
dsignrank(x, n, log = FALSE)
psignrank(q, n, lower.tail = TRUE, log.p = FALSE)
qsignrank(p, n, lower.tail = TRUE, log.p = FALSE)
rsignrank(nn, n)
}
\arguments{
  \item{x, q}{クォンタイルのベクトル．}
  \item{p}{確率のベクトル．}
  \item{nn}{観測値の数．もし \code{length(nn) > 1} ならその長さが
    必要な数とされる．}
  \item{n}{サンプル中の観測値の数．正整数又は
    そうした整数のベクトル．}
  \item{lambda}{(非負の)平均のベクトル．}
  \item{log, log.p}{論理値；もし TRUE なら確率 p は log(p) とされる．}
  \item{lower.tail}{論理値；もし TRUE (既定値)なら
    確率は \eqn{P[X \le x]} で，さもなければ \eqn{P[X > x]}．}
}
\value{
  \code{dsignrank} は(対数)密度，\code{psignrank} は分布関数，
  \code{qsignrank} はクォンタイル関数，そして
  \code{rsignrank} は乱数を生成する．

  不正な \code{lambda} は値 \code{NaN} を返し，警告が出る．

  \code{rsignrank} に対しては結果の長さは \code{nn} で決まり，
  そして他の関数に対しては数値引数の最大長である．

  \code{nn} 以外の数値引数は結果の長さまでリサイクルされる．
  論理値引数は最初の要素だけが使われる．
}
\details{
  この分布は次のように得られる．
  \code{x} を原点に対して対象な分布からのサイズ \code{n} の標本とする．
  すると Wilcoxon の符号付きランク統計量は
  \code{x[i]} が正である
  \code{x[i]} の絶対値のランクの和である．
  この統計量は
  \eqn{0} と \eqn{n(n+1)/2} の間の値を取り，そして
  その平均と分散はそれぞれ
  \eqn{n(n+1)/4} と \eqn{n(n+1)(2n+1)/24} となる．

  もし最初の引数のどちらかがベクトルならば，
  長い方のベクトルの長さまでリサイクル規則が使われ
  全ての二つの組み合わせに対する計算が行われる．
}
\author{Kurt Hornik; Ivo Ugrina による効率化．}
\seealso{
  データから統計量を計算，p 値を見つける等は \code{\link{wilcox.test}}．

  \emph{二標本} Wilcoxon ランク和統計量に対する
  \code{\link{dwilcox}} を含む標準分布については
  \link{Distributions}．
}
\examples{
require(graphics)

par(mfrow = c(2,2))
for(n in c(4:5,10,40)) {
  x <- seq(0, n*(n+1)/2, length = 501)
  plot(x, dsignrank(x, n = n), type = "l",
       main = paste0("dsignrank(x, n = ", n, ")"))
}
\dontshow{
p <- c(1, 1, 1, 2, 2:6, 8, 10, 11, 13, 15, 17, 20, 22, 24,
       27, 29, 31, 33, 35, 36, 38, 39, 39, 40)
stopifnot(round(dsignrank(0:56, n = 10)* 2^10) == c(p, rev(p), 0),
          qsignrank((1:16)/ 16, n = 4) == c(0:2, rep(3:7, each = 2), 8:10))
}
}
\keyword{distribution}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/SignRank.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{SignRank}
%\alias{SignRank}
%\alias{dsignrank}
%\alias{psignrank}
%\alias{qsignrank}
%\alias{rsignrank}
%\title{Distribution of the Wilcoxon Signed Rank Statistic}
%\description{
%  Density, distribution function, quantile function and random
%  generation for the distribution of the Wilcoxon Signed Rank statistic
%  obtained from a sample with size \code{n}.
%}
%\usage{
%dsignrank(x, n, log = FALSE)
%psignrank(q, n, lower.tail = TRUE, log.p = FALSE)
%qsignrank(p, n, lower.tail = TRUE, log.p = FALSE)
%rsignrank(nn, n)
%}
%\arguments{
%  \item{x, q}{vector of quantiles.}
%  \item{p}{vector of probabilities.}
%  \item{nn}{number of observations. If \code{length(nn) > 1}, the length
%    is taken to be the number required.}
%  \item{n}{number(s) of observations in the sample(s).  A positive
%    integer, or a vector of such integers.}
%  \item{log, log.p}{logical; if TRUE, probabilities p are given as log(p).}
%  \item{lower.tail}{logical; if TRUE (default), probabilities are
%    \eqn{P[X \le x]}, otherwise, \eqn{P[X > x]}.}
%}
%\value{
%  \code{dsignrank} gives the density,
%  \code{psignrank} gives the distribution function,
%  \code{qsignrank} gives the quantile function, and
%  \code{rsignrank} generates random deviates.
%
%  The length of the result is determined by \code{nn} for
%  \code{rsignrank}, and is the maximum of the lengths of the
%  numerical arguments for the other functions.  
%  
%  The numerical arguments other than \code{nn} are recycled to the
%  length of the result.  Only the first elements of the logical
%  arguments are used.
%}
%\details{
%  This distribution is obtained as follows.  Let \code{x} be a sample of
%  size \code{n} from a continuous distribution symmetric about the
%  origin.  Then the Wilcoxon signed rank statistic is the sum of the
%  ranks of the absolute values \code{x[i]} for which \code{x[i]} is
%  positive.  This statistic takes values between \eqn{0} and
%  \eqn{n(n+1)/2}, and its mean and variance are \eqn{n(n+1)/4} and
%  \eqn{n(n+1)(2n+1)/24}, respectively.
%
%  If either of the first two arguments is a vector, the recycling rule is
%  used to do the calculations for all combinations of the two up to
%  the length of the longer vector.
%}
%\author{Kurt Hornik; efficiency improvement by Ivo Ugrina.}
%\seealso{
%  \code{\link{wilcox.test}} to calculate the statistic from data, find p
%  values and so on.
%
%  \link{Distributions} for standard distributions, including
%  \code{\link{dwilcox}} for the distribution of \emph{two-sample}
%  Wilcoxon rank sum statistic.
%}
%\examples{
%require(graphics)
%
%par(mfrow = c(2,2))
%for(n in c(4:5,10,40)) {
%  x <- seq(0, n*(n+1)/2, length = 501)
%  plot(x, dsignrank(x, n = n), type = "l",
%       main = paste0("dsignrank(x, n = ", n, ")"))
%}
%\dontshow{
%p <- c(1, 1, 1, 2, 2:6, 8, 10, 11, 13, 15, 17, 20, 22, 24,
%       27, 29, 31, 33, 35, 36, 38, 39, 39, 40)
%stopifnot(round(dsignrank(0:56, n = 10)* 2^10) == c(p, rev(p), 0),
%          qsignrank((1:16)/ 16, n = 4) == c(0:2, rep(3:7, each = 2), 8:10))
%}
%}
%\keyword{distribution}
%
%\encoding{UTF-8}
%
