% File src/library/stats/man/aov.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2013 R Core Team
% Distributed under GPL 2 or later

\name{aov}
\alias{aov}
\alias{print.aov}
\alias{print.aovlist}
\alias{Error}
\title{Fit an Analysis of Variance Model}
\description{
  各層へ \code{lm} の呼び出しを行うことで分散分析を当てはめる．
}
\usage{
aov(formula, data = NULL, projections = FALSE, qr = TRUE,
    contrasts = NULL, \dots)
}
\arguments{
  \item{formula}{モデルを指定する公式．}
  \item{data}{公式厨で指定された変数をその中で見出すデータフレーム．
    もしなければ変数は通常の仕方で探される．}
  \item{projections}{論理フラグ：射影を返すべきか?}
  \item{qr}{論理フラグ：QR 分解をケアすべきか?}
  \item{contrasts}{公式中の因子のどれかに使われる対比のリスト．
    これらは任意の \code{Error} 項に対しては使われず，
    因子に対する対比を
    \code{Error} 項にだけ提供することは警告を与える．}
  \item{\dots}{
    \code{subset} や \code{na.action} のような
    \code{lm} に渡される引数．
    \code{weights} に関しては\sQuote{詳細}見よ．}
}
\details{
  これは線形モデルを釣り合い型もしくは非釣り合い型実験計画に
  当てはめるための \code{lm} のラッパを提供する．

  \code{lm} との主な違いは
  \code{print}, \code{summary} 等が当てはめを諸汁する仕方である：
  これは線形でモルではなく伝統的な分散分析の言葉で表現される．

  もし公式が単一の
  \code{Error} 項を含めば，これがエラー層として使われ，
  各エラー層内で適当なモデルが当てはめられる．

  公式は複数の応答を指定できる．

  重みは \code{weights} 引数で指定できるが，
  \code{Error} 項と共に使われるべきではなく，
  不完全にしかサポートされていない
  (例えば \code{\link{model.tables}} で)．
}
\note{
  \code{aov} は釣り合い型のデザイン用に設計されており，
  釣り合い形でなければ結果は解釈が難しい：
  応答中の欠損値は釣り合い性を失くしやすい．
  もし二つもしくはそれ以上のエラー層があれば，
  使われるメソッドは釣り合い性無しでは統計的に
  有効でなく，パッケージ \CRANpkg{nlme} 中の
  \code{\link[nlme]{lme}} を使うほうが良い．

  釣り合い性は
  \code{\link{replications}} 関数でチェックできる．

  \R での既定の\sQuote{対比}は直交対比ではなく，
  \code{aov} とその補助関数はそうした対比でより良く動作する：
  これらをどのように選ぶかについては例を見よ．
}
\value{
  クラス \code{c("aov", "lm")}，又は
  クラス \code{c("maov", "aov", "mlm", "lm")} の多重応答，
  又は クラス \code{c("aovlist", "\link{listof}")} の多重エラー層
  のオブジェクト．
  これらに対しては \code{\link{print}} と \code{\link{summary}} メソッドが
  利用できる．
}
\references{
  Chambers, J. M., Freeny, A and Heiberger, R. M. (1992)
  \emph{Analysis of variance; designed experiments.}
  Chapter 5 of \emph{Statistical Models in S}
  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
}
\author{
  デザインは
  Chambers \emph{et al} (1992) で説明されている同名の S 関数に啓発されている．
}
\seealso{
  \code{\link{lm}}, \code{\link{summary.aov}},
  \code{\link{replications}}, \code{\link{alias}},
  \code{\link{proj}}, \code{\link{model.tables}}, \code{\link{TukeyHSD}}
}
\examples{
## Venables and Ripley (2002) p.165 から

## 直交対比を設定する．
op <- options(contrasts = c("contr.helmert", "contr.poly"))
( npk.aov <- aov(yield ~ block + N*P*K, npk) )
\donttest{summary(npk.aov)}
coefficients(npk.aov)

## 項の並べ替えの効果を示すことが二つの当てはめを対照する
aov(yield ~ block + N * P + K, npk)
aov(terms(yield ~ block + N * P + K, keep.order = TRUE), npk)


## テスト用，統計的には特に意味はない
npk.aovE <- aov(yield ~  N*P*K + Error(block), npk)
npk.aovE
summary(npk.aovE)
options(op)  # 直前にリセット
}
\keyword{models}
\keyword{regression}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/aov.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2013 R Core Team
%% Distributed under GPL 2 or later
%
%\name{aov}
%\alias{aov}
%\alias{print.aov}
%\alias{print.aovlist}
%\alias{Error}
%\title{Fit an Analysis of Variance Model}
%\description{
%  Fit an analysis of variance model by a call to \code{lm} for each stratum.
%}
%\usage{
%aov(formula, data = NULL, projections = FALSE, qr = TRUE,
%    contrasts = NULL, \dots)
%}
%\arguments{
%  \item{formula}{A formula specifying the model.}
%  \item{data}{A data frame in which the variables specified in the
%    formula will be found. If missing, the variables are searched for in
%    the standard way.}
%  \item{projections}{Logical flag: should the projections be returned?}
%  \item{qr}{Logical flag: should the QR decomposition be returned?}
%  \item{contrasts}{A list of contrasts to be used for some of the factors
%    in the formula. These are not used for any \code{Error} term, and
%    supplying contrasts for factors only in the \code{Error} term will give
%    a warning.}
%  \item{\dots}{Arguments to be passed to \code{lm}, such as \code{subset}
%    or \code{na.action}.  See \sQuote{Details} about \code{weights}.}
%}
%\details{
%  This provides a wrapper to \code{lm} for fitting linear models to
%  balanced or unbalanced experimental designs.
%
%  The main difference from \code{lm} is in the way \code{print},
%  \code{summary} and so on handle the fit: this is expressed in the
%  traditional language of the analysis of variance rather than that of
%  linear models.
%
%  If the formula contains a single \code{Error} term, this is used to
%  specify error strata, and appropriate models are fitted within each
%  error stratum.
%
%  The formula can specify multiple responses.
%
%  Weights can be specified by a \code{weights} argument, but should not
%  be used with an \code{Error} term, and are incompletely supported
%  (e.g., not by \code{\link{model.tables}}).
%}
%\note{
%  \code{aov} is designed for balanced designs, and the results can be
%  hard to interpret without balance: beware that missing values in the
%  response(s) will likely lose the balance.  If there are two or more
%  error strata, the methods used are statistically inefficient without
%  balance, and it may be better to use \code{\link[nlme]{lme}} in
%  package \CRANpkg{nlme}.
%
%  Balance can be checked with the \code{\link{replications}} function.
%
%  The default \sQuote{contrasts} in \R are not orthogonal contrasts, and
%  \code{aov} and its helper functions will work better with such
%  contrasts: see the examples for how to select these.
%}
%\value{
%  An object of class \code{c("aov", "lm")} or for multiple responses
%  of class \code{c("maov", "aov", "mlm", "lm")} or for multiple error
%  strata of class \code{c("aovlist", "\link{listof}")}.  There are
%  \code{\link{print}} and \code{\link{summary}} methods available for these.
%}
%\references{
%  Chambers, J. M., Freeny, A and Heiberger, R. M. (1992)
%  \emph{Analysis of variance; designed experiments.}
%  Chapter 5 of \emph{Statistical Models in S}
%  eds J. M. Chambers and T. J. Hastie, Wadsworth & Brooks/Cole.
%}
%\author{
%  The design was inspired by the S function of the same name described
%  in Chambers \emph{et al} (1992).
%}
%\seealso{
%  \code{\link{lm}}, \code{\link{summary.aov}},
%  \code{\link{replications}}, \code{\link{alias}},
%  \code{\link{proj}}, \code{\link{model.tables}}, \code{\link{TukeyHSD}}
%}
%\examples{
%## From Venables and Ripley (2002) p.165.
%
%## Set orthogonal contrasts.
%op <- options(contrasts = c("contr.helmert", "contr.poly"))
%( npk.aov <- aov(yield ~ block + N*P*K, npk) )
%\donttest{summary(npk.aov)}
%coefficients(npk.aov)
%
%## to show the effects of re-ordering terms contrast the two fits
%aov(yield ~ block + N * P + K, npk)
%aov(terms(yield ~ block + N * P + K, keep.order = TRUE), npk)
%
%
%## as a test, not particularly sensible statistically
%npk.aovE <- aov(yield ~  N*P*K + Error(block), npk)
%npk.aovE
%summary(npk.aovE)
%options(op)  # reset to previous
%}
%\keyword{models}
%\keyword{regression}
%
%\encoding{UTF-8}
%