% File src/library/stats/man/arima.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{arima}
\alias{arima}%@%\alias{ARIMAモデルの当てはめ}
\concept{ARMA}
\title{ARIMA Modelling of Time Series}
\description{
  一変量時系列に ARIMA モデルを当てはめる．
}
\usage{
arima(x, order = c(0L, 0L, 0L),
      seasonal = list(order = c(0L, 0L, 0L), period = NA),
      xreg = NULL, include.mean = TRUE,
      transform.pars = TRUE,
      fixed = NULL, init = NULL,
      method = c("CSS-ML", "ML", "CSS"), n.cond,
      SSinit = c("Gardner1980", "Rossignol2011"),
      optim.method = "BFGS",
      optim.control = list(), kappa = 1e6)
}
\arguments{
  \item{x}{一変量時系列．}

  \item{order}{ARIMA モデルの非季節部分の指定：
    三つの整数成分 \eqn{(p, d, q)} は AR 次数，階差の階数，
    そして MA 次数．}

  \item{seasonal}{
    ARIMA モデルの季節部分と周期
    (既定値 \code{frequency(x)})の指定．
    これは成分 \code{order} と \code{period} のりストでなければならないが，
    長さ 3 の数値ベクトルを指定すれば
    \code{order} と同様の適当なリストに変換される．}

  \item{xreg}{オプション，外生変数のベクトルで，
    \code{x} と同じ数の行を持たなければならない．}

  \item{include.mean}{
    ARMA モデルは 平均/切片 項を含むべきか?
    非階差系列では既定は \code{TRUE} で，階差を取られた
    ARIMA モデルでは無視される．}

  \item{transform.pars}{論理値；もし真なら
    AR パラメータは定常領域に留まることを保証するように変換される．
    \code{method = "CSS"} に対しては使われない．
    \code{method = "ML"} に対しては
    \code{transform.pars = FALSE} と設定することが有利なケースががある，
    \code{fixed} も見よ．}

  \item{fixed}{パラメータの総数と同じ長さのオプションの数値ベクトル．
    もし提供されると 
    \code{fixed} 中の \code{NA} 項目は変化する．
    もし任意の AR パラメータが固定されると \code{transform.pars = TRUE}
    は上書きされる(警告と共に)．
    MA パラメータを固定する際は \code{transform.pars = FALSE} を
    設定するほうが賢明かもしれない，特に逆転不能に近い場合．
  }

  \item{init}{パラメータの初期値のオプションの数値ベクトル．
    欠損値は回帰系数を除いてゼロで埋められる．
    \code{fixed} 中で既に指定された値は無視される．}

  \item{method}{当てはめ手法：最尤法又は
    条件付き二乗和の最小化．
    (欠損値が無い限り)既定では初期値を見つけるには
    条件付き二乗和を使い，それから最尤法を使う．
    短縮できる．}

  \item{n.cond}{条件付き二乗和で当てはめる時だけ使われる：
    無視される初期観測値の数．
    もし AR 項の最大ラグ以下ならば無視される．}

  \item{SSinit}{尤度の状態空間初期化を計算するアルゴリズムを
    指定する．
    詳細は \code{\link{KalmanLike}} を見よ．短縮化出来る．}

  \item{optim.method}{
    \code{\link{optim}} へ \code{method} 引数として渡される値．}

  \item{optim.control}{
    \code{\link{optim}} に対する制御パラメータのリスト．}

  \item{kappa}{階差モデル中の過去の観測値に対する
    (イノベーション分散の倍数としての)事前分散．
    これを減らさないこと．}
}
\details{
  ARMA モデルの異なった定義は
  AR そして/または MA 係数に対して異なった符号を持つ．
  ここで使われる定義は

  \deqn{X_t= a_1X_{t-1}+ \cdots+ a_pX_{t-p} + e_t + b_1e_{t-1}+\cdots+ b_qe_{t-q}
  }{X[t] = a[1]X[t-1] + \dots + a[p]X[t-p] + e[t] + b[1]e[t-1] + \dots + b[q]e[t-q]}

  であり，従って MA 係数は
  S-PLUS のそれと符号が異なる．
  更に，もし \code{include.mean} が真なら(ARMA モデルの既定値)，
  この公式は \eqn{X} の代わりに \eqn{X -m} に適用される．
  階差を持つ ARIMA モデルに対しては階差系列はゼロ平均の ARMA モデルになる．
  もし \code{xreg} 項が含められると線形回帰モデル
  (もし \code{include.mean} が真で階差が取られなければ)
  がエラー項を持つ ARMA モデルに
  当てはめられる．

  推定量の分散行列は対数尤度のヘッセ行列から計算できるので，
  特に可逆性の境界近くの当てはめに対しては大雑把なガイドに過ぎない．

  最適化は \code{\link{optim}} で行われる．これは
  \code{xreg} 中の列が大まかに平均ゼロで単位分散の時に
  最も上手く動作するが，適当なスケーリングを推定することが
  試みられる．
}
\section{当てはめ手法}{
  正確な尤度は
  ARIMA プロセスの状態空間表現を使って計算され，
  イノベーションとそれらの分散はカルマンフィルターで見つけられる．
  階差 ARMA プロセスは定常性を利用し
  Gardner \emph{et al} (1980) に基づく．
  階差プロセスに対しては非定常成分は
  拡散事前分布を与えられる
  (\code{kappa} で制御される)．
  拡散事前分布で依然制御されている
  (少なくとも \code{1e4} のカルマン利得を持つことで決定される)
  観測値は尤度の計算から除外される．
  (除外される観測値が正確に階差により捨てられるものである時，
  これは欠損値がない場合の
  \code{\link{arima0}} と比較できる結果を与える．)

  欠損値が許され
  \code{"ML"} メソッドでは正確に処理される．

  もし \code{transform.pars} が真なら，最適化は
  Jones (1980) が提案したものの変種である別のパラメータ化を使って
  なされ，モデルが定常であることを保証する．
  AR(p) モデルに対してはパラメータ化は部分自己相関も逆
  tanh を使う：同じ手順が
  (個別に) AR と 季節 AR 項に適用される．
  MA 上は最適化の間可逆という制約を受けないが，
  もし \code{transform.pars} が真なら最適化の後で可逆に変換される．

  条件付き二乗和は主に説明目的で提供されている．
  これは
  \code{n.cond} 以降の観測値からの当てはめイノベーションの
  二乗和を計算し(ここで \code{n.cond} は少なくとも
  AR 項の最大ラグである)．全ての前のイノベーションは
  ゼロとして扱われる．
  引数 \code{n.cond} は異なった当てはめ間の比較を可能にするために使うことが出来る．
  \sQuote{部分対数尤度}
  は最初の項で，推定された平均二乗の対数の半分である．
  欠損値はゆるされるが，多くのイノベーションが欠損する結果になる．

  被回帰項が指定された場合は，
  それらは係数のどれかが固定されていない限り当てはめへの直交事前分布
  である．
  被回帰項を大まかに平均ゼロで単位分散になるようにスケール化
  することが役に立つかもしれない．
}
\value{
  クラス \code{"Arima"} のリストで次の成分を持つ：

  \item{coef}{
    AR, MA そして回帰係数のベクトルで，
    \code{\link{coef}} メソッドで取り出せる．}

  \item{sigma2}{イノベーション分散の MLE．}

  \item{var.coef}{
    係数 \code{coef} の推定分散行列で，
    \code{\link{vcov}} メソッドで取り出せる．}

  \item{loglik}{
    (階差データの)最大化対数尤度，又はそれに使われた近似．}

  \item{arma}{指定の簡潔な書式で，
    AR, MA, 季節 AR と季節 MA の係数に，
    非季節的と季節的な階差の数．}

  \item{aic}{対数尤度に対する AIC 値．
    \code{method = "ML"} 当てはめだけに適正である．}

  \item{residuals}{当てはめられたイノベーション．}

  \item{call}{マッチした呼び出し．}

  \item{series}{系列 \code{x} の名前．}

  \item{code}{\code{\link{optim}} が返す収束値．}

  \item{n.cond}{当てはめで使われなかった初期観測値の数．}

  \item{nobs}{
    当てはめに\dQuote{使われた}観測値で，やはり
    \code{\link{nobs}()} を使い取り出せ，
    \code{\link{BIC}} で使われる．}

  \item{model}{当てはめで使われたカルマンフィルターを表現するリスト．
    \code{\link{KalmanLike}} を見よ．}
}
\references{
  Brockwell, P. J. and Davis, R. A. (1996) \emph{Introduction to Time
    Series and Forecasting.} Springer, New York. Sections 3.3 and 8.3.

  Durbin, J. and Koopman, S. J. (2001) \emph{Time Series Analysis by
    State Space Methods.}  Oxford University Press.

  Gardner, G, Harvey, A. C. and Phillips, G. D. A. (1980) Algorithm
  AS154. An algorithm for exact maximum likelihood estimation of
  autoregressive-moving average models by means of Kalman filtering.
  \emph{Applied Statistics} \bold{29}, 311--322.

  Harvey, A. C. (1993) \emph{Time Series Models},
  2nd Edition, Harvester Wheatsheaf, sections 3.3 and 4.4.

  Jones, R. H. (1980) Maximum likelihood fitting of ARMA models to time
  series with missing observations. \emph{Technometrics} \bold{22} 389--395.

  Ripley, B. D. (2002) Time series in \R 1.5.0.
  \emph{R News}, \bold{2/2}, 2--7.
  \url{https://www.r-project.org/doc/Rnews/Rnews_2002-2.pdf}
}

\note{
  結果はおそらく
  S-PLUS の \code{arima.mle} とは異なる．後者は
  条件付き尤度を計算しモデル中に平均を含まない．
  更に \code{arima.mle} で使われる慣習は
  MA 係数の符号を反転する．

  \code{arima} は
  ARMA モデルや欠損値無しの階差モデルに対する
  \code{\link{arima0}} に非常に似ているが，
  欠損値を持つ階差モデルを正確に扱う．
  これは少々 \code{arima0} より遅く，特に季節成分を持つ
  階差モデルでそうである．
}

\seealso{
  \code{\link{predict.Arima}}，
  ARIMA モデルからのシミュレーションは \code{\link{arima.sim}}，
  \code{\link{tsdiag}}, \code{\link{arima0}},
  \code{\link{ar}}
}

\examples{
arima(lh, order = c(1,0,0))
arima(lh, order = c(3,0,0))
arima(lh, order = c(1,0,1))

arima(lh, order = c(3,0,0), method = "CSS")

arima(USAccDeaths, order = c(0,1,1), seasonal = list(order = c(0,1,1)))
arima(USAccDeaths, order = c(0,1,1), seasonal = list(order = c(0,1,1)),
      method = "CSS") # 最初の 13 個の観測値を取り除く
# これぐらい少ない年数のモデルに対しては完全な ML が欲しい

arima(LakeHuron, order = c(2,0,0), xreg = time(LakeHuron) - 1920)

## presidents データは NA を含む
## example(acf) 中のグラフは次数 1 か 3 を示唆する
require(graphics)
(fit1 <- arima(presidents, c(1, 0, 0)))
nobs(fit1)
tsdiag(fit1)
(fit3 <- arima(presidents, c(3, 0, 0)))  # より小さい AIC
tsdiag(fit3)
BIC(fit1, fit3)
## 全てのモデルを比較；BIC() は最小のものを選ぶ
AIC(fit1, arima(presidents, c(2,0,0)),
          arima(presidents, c(2,0,1)), # <- AIC で(かろうじて)選択
    fit3, arima(presidents, c(3,0,1)))

## ARIMA 予測の例：
predict(fit3, 3)
}
\keyword{ts}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/arima.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{arima}
%\alias{arima}
%\concept{ARMA}
%\title{ARIMA Modelling of Time Series}
%\description{
%  Fit an ARIMA model to a univariate time series.
%}
%\usage{
%arima(x, order = c(0L, 0L, 0L),
%      seasonal = list(order = c(0L, 0L, 0L), period = NA),
%      xreg = NULL, include.mean = TRUE,
%      transform.pars = TRUE,
%      fixed = NULL, init = NULL,
%      method = c("CSS-ML", "ML", "CSS"), n.cond,
%      SSinit = c("Gardner1980", "Rossignol2011"),
%      optim.method = "BFGS",
%      optim.control = list(), kappa = 1e6)
%}
%\arguments{
%  \item{x}{a univariate time series}
%
%  \item{order}{A specification of the non-seasonal part of the ARIMA
%    model: the three integer components \eqn{(p, d, q)} are the AR order, the
%    degree of differencing, and the MA order.}
%
%  \item{seasonal}{A specification of the seasonal part of the ARIMA
%    model, plus the period (which defaults to \code{frequency(x)}).
%    This should be a list with components \code{order} and
%    \code{period}, but a specification of just a numeric vector of
%    length 3 will be turned into a suitable list with the specification
%    as the \code{order}.}
%
%  \item{xreg}{Optionally, a vector or matrix of external regressors,
%    which must have the same number of rows as \code{x}.}
%
%  \item{include.mean}{Should the ARMA model include a mean/intercept term?  The
%    default is \code{TRUE} for undifferenced series, and it is ignored
%    for ARIMA models with differencing.}
%
%  \item{transform.pars}{logical; if true, the AR parameters are
%    transformed to ensure that they remain in the region of
%    stationarity.  Not used for \code{method = "CSS"}.  For
%    \code{method = "ML"}, it has been advantageous to set
%    \code{transform.pars = FALSE} in some cases, see also \code{fixed}.}
%
%  \item{fixed}{optional numeric vector of the same length as the total
%    number of parameters.  If supplied, only \code{NA} entries in
%    \code{fixed} will be varied.  \code{transform.pars = TRUE}
%    will be overridden (with a warning) if any AR parameters are fixed.
%    It may be wise to set \code{transform.pars = FALSE} when fixing
%    MA parameters, especially near non-invertibility.
%  }
%
%  \item{init}{optional numeric vector of initial parameter
%    values.  Missing values will be filled in, by zeroes except for
%    regression coefficients.  Values already specified in \code{fixed}
%    will be ignored.}
%
%  \item{method}{fitting method: maximum likelihood or minimize
%    conditional sum-of-squares.  The default (unless there are missing
%    values) is to use conditional-sum-of-squares to find starting
%    values, then maximum likelihood.  Can be abbreviated.}
%
%  \item{n.cond}{only used if fitting by conditional-sum-of-squares: the
%    number of initial observations to ignore.  It will be ignored if
%    less than the maximum lag of an AR term.}
%
%  \item{SSinit}{a string specifying the algorithm to compute the
%    state-space initialization of the likelihood; see
%    \code{\link{KalmanLike}} for details.   Can be abbreviated.}
%
%  \item{optim.method}{The value passed as the \code{method} argument to
%    \code{\link{optim}}.}
%
%  \item{optim.control}{List of control parameters for \code{\link{optim}}.}
%
%  \item{kappa}{the prior variance (as a multiple of the innovations
%    variance) for the past observations in a differenced model.  Do not
%    reduce this.}
%}
%\details{
%  Different definitions of ARMA models have different signs for the
%  AR and/or MA coefficients.  The definition used here has
%
%  \deqn{X_t= a_1X_{t-1}+ \cdots+ a_pX_{t-p} + e_t + b_1e_{t-1}+\cdots+ b_qe_{t-q}
%  }{X[t] = a[1]X[t-1] + \dots + a[p]X[t-p] + e[t] + b[1]e[t-1] + \dots + b[q]e[t-q]}
%
%  and so the MA coefficients differ in sign from those of S-PLUS.
%  Further, if \code{include.mean} is true (the default for an ARMA
%  model), this formula applies to \eqn{X - m} rather than \eqn{X}.  For
%  ARIMA models with differencing, the differenced series follows a
%  zero-mean ARMA model. If am \code{xreg} term is included, a linear
%  regression (with a constant term if \code{include.mean} is true and
%  there is no differencing) is fitted with an ARMA model for the error
%  term.
%
%  The variance matrix of the estimates is found from the Hessian of
%  the log-likelihood, and so may only be a rough guide.
%
%  Optimization is done by \code{\link{optim}}.  It will work
%  best if the columns in \code{xreg} are roughly scaled to zero mean
%  and unit variance, but does attempt to estimate suitable scalings.
%}
%\section{Fitting methods}{
%  The exact likelihood is computed via a state-space representation of
%  the ARIMA process, and the innovations and their variance found by a
%  Kalman filter.  The initialization of the differenced ARMA process uses
%  stationarity and is based on Gardner \emph{et al} (1980).  For a
%  differenced process the non-stationary components are given a diffuse
%  prior (controlled by \code{kappa}).  Observations which are still
%  controlled by the diffuse prior (determined by having a Kalman gain of
%  at least \code{1e4}) are excluded from the likelihood calculations.
%  (This gives comparable results to \code{\link{arima0}} in the absence
%  of missing values, when the observations excluded are precisely those
%  dropped by the differencing.)
%
%  Missing values are allowed, and are handled exactly in method \code{"ML"}.
%
%  If \code{transform.pars} is true, the optimization is done using an
%  alternative parametrization which is a variation on that suggested by
%  Jones (1980) and ensures that the model is stationary.  For an AR(p)
%  model the parametrization is via the inverse tanh of the partial
%  autocorrelations: the same procedure is applied (separately) to the
%  AR and seasonal AR terms.  The MA terms are not constrained to be
%  invertible during optimization, but they will be converted to
%  invertible form after optimization if \code{transform.pars} is true.
%
%  Conditional sum-of-squares is provided mainly for expositional
%  purposes.  This computes the sum of squares of the fitted innovations
%  from observation \code{n.cond} on, (where \code{n.cond} is at least
%  the maximum lag of an AR term), treating all earlier innovations to
%  be zero.  Argument \code{n.cond} can be used to allow comparability
%  between different fits.  The \sQuote{part log-likelihood} is the first
%  term, half the log of the estimated mean square.  Missing values
%  are allowed, but will cause many of the innovations to be missing.
%
%  When regressors are specified, they are orthogonalized prior to
%  fitting unless any of the coefficients is fixed.  It can be helpful to
%  roughly scale the regressors to zero mean and unit variance.
%}
%\value{
%  A list of class \code{"Arima"} with components:
%
%  \item{coef}{a vector of AR, MA and regression coefficients, which can
%    be extracted by the \code{\link{coef}} method.}
%
%  \item{sigma2}{the MLE of the innovations variance.}
%
%  \item{var.coef}{the estimated variance matrix of the coefficients
%    \code{coef}, which can be extracted by the \code{\link{vcov}} method.}
%
%  \item{loglik}{the maximized log-likelihood (of the differenced data),
%    or the approximation to it used.}
%
%  \item{arma}{A compact form of the specification, as a vector giving
%    the number of AR, MA, seasonal AR and seasonal MA coefficients,
%    plus the period and the number of non-seasonal and seasonal
%    differences.}
%
%  \item{aic}{the AIC value corresponding to the log-likelihood. Only
%    valid for \code{method = "ML"} fits.}
%
%  \item{residuals}{the fitted innovations.}
%
%  \item{call}{the matched call.}
%
%  \item{series}{the name of the series \code{x}.}
%
%  \item{code}{the convergence value returned by \code{\link{optim}}.}
%
%  \item{n.cond}{the number of initial observations not used in the fitting.}
%
%  \item{nobs}{the number of \dQuote{used} observations for the fitting,
%    can also be extracted via \code{\link{nobs}()} and is used by
%    \code{\link{BIC}}.}
%
%  \item{model}{A list representing the Kalman Filter used in the
%    fitting.  See \code{\link{KalmanLike}}.}
%}
%\references{
%  Brockwell, P. J. and Davis, R. A. (1996) \emph{Introduction to Time
%    Series and Forecasting.} Springer, New York. Sections 3.3 and 8.3.
%
%  Durbin, J. and Koopman, S. J. (2001) \emph{Time Series Analysis by
%    State Space Methods.}  Oxford University Press.
%
%  Gardner, G, Harvey, A. C. and Phillips, G. D. A. (1980) Algorithm
%  AS154. An algorithm for exact maximum likelihood estimation of
%  autoregressive-moving average models by means of Kalman filtering.
%  \emph{Applied Statistics} \bold{29}, 311--322.
%
%  Harvey, A. C. (1993) \emph{Time Series Models},
%  2nd Edition, Harvester Wheatsheaf, sections 3.3 and 4.4.
%
%  Jones, R. H. (1980) Maximum likelihood fitting of ARMA models to time
%  series with missing observations. \emph{Technometrics} \bold{22} 389--395.
%
%  Ripley, B. D. (2002) Time series in \R 1.5.0.
%  \emph{R News}, \bold{2/2}, 2--7.
%  \url{https://www.r-project.org/doc/Rnews/Rnews_2002-2.pdf}
%}
%
%\note{
%  The results are likely to be different from S-PLUS's
%  \code{arima.mle}, which computes a conditional likelihood and does
%  not include a mean in the model.  Further, the convention used by
%  \code{arima.mle} reverses the signs of the MA coefficients.
%
%  \code{arima} is very similar to \code{\link{arima0}} for
%  ARMA models or for differenced models without missing values,
%  but handles differenced models with missing values exactly.
%  It is somewhat slower than \code{arima0}, particularly for seasonally
%  differenced models.
%}
%
%\seealso{
%  \code{\link{predict.Arima}}, \code{\link{arima.sim}} for simulating
%  from an ARIMA model, \code{\link{tsdiag}}, \code{\link{arima0}},
%  \code{\link{ar}}
%}
%
%\examples{
%arima(lh, order = c(1,0,0))
%arima(lh, order = c(3,0,0))
%arima(lh, order = c(1,0,1))
%
%arima(lh, order = c(3,0,0), method = "CSS")
%
%arima(USAccDeaths, order = c(0,1,1), seasonal = list(order = c(0,1,1)))
%arima(USAccDeaths, order = c(0,1,1), seasonal = list(order = c(0,1,1)),
%      method = "CSS") # drops first 13 observations.
%# for a model with as few years as this, we want full ML
%
%arima(LakeHuron, order = c(2,0,0), xreg = time(LakeHuron) - 1920)
%
%## presidents contains NAs
%## graphs in example(acf) suggest order 1 or 3
%require(graphics)
%(fit1 <- arima(presidents, c(1, 0, 0)))
%nobs(fit1)
%tsdiag(fit1)
%(fit3 <- arima(presidents, c(3, 0, 0)))  # smaller AIC
%tsdiag(fit3)
%BIC(fit1, fit3)
%## compare a whole set of models; BIC() would choose the smallest
%AIC(fit1, arima(presidents, c(2,0,0)),
%          arima(presidents, c(2,0,1)), # <- chosen (barely) by AIC
%    fit3, arima(presidents, c(3,0,1)))
%
%## An example of ARIMA forecasting:
%predict(fit3, 3)
%}
%\keyword{ts}
%
%\encoding{UTF-8}
%
