% File src/library/stats/man/arima0.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{arima0}
\alias{arima0}%@%\alias{ARIMAモデルの当てはめ}
\alias{print.arima0}
\alias{predict.arima0}
\concept{ARNA}
\title{ARIMA Modelling of Time Series -- Preliminary Version}
\description{
  ARIMA モデルを一変量時系列に当てはめ，そして当てはめモデルから
  予測する．
}
\usage{
arima0(x, order = c(0, 0, 0),
       seasonal = list(order = c(0, 0, 0), period = NA),
       xreg = NULL, include.mean = TRUE, delta = 0.01,
       transform.pars = TRUE, fixed = NULL, init = NULL,
       method = c("ML", "CSS"), n.cond, optim.control = list())

\method{predict}{arima0}(object, n.ahead = 1, newxreg, se.fit = TRUE, \dots)
}
\arguments{
  \item{x}{一変量時系列．}

  \item{order}{ARIMA モデルの非季節部分の指定：
    三つの整数成分 \eqn{(p, d, q)} は AR 次数，階差の階数，
    そして MA 次数．}

  \item{seasonal}{
    ARIMA モデルの季節部分と周期
    (既定値 \code{frequency(x)})の指定．
    これは成分 \code{order} と \code{period} のりストでなければならないが，
    長さ 3 の数値ベクトルを指定すれば
    \code{order} と同様の適当なリストに変換される．}

  \item{xreg}{オプション，外生変数のベクトルで，
    \code{x} と同じ数の行を持たなければならない．}

  \item{include.mean}{
    ARIMA モデルは平均項を含むべきか?
    階差を取られていない系列には期待値は \code{TRUE}，
    階差系列 には \code{FALSE} (ここで平均は当てはめにも予測にも
    影響しない)．}

  \item{delta}{
      どこで\sQuote{高速再帰}が使われるべきかを指示する値．
      \sQuote{詳細}節を見よ．}

  \item{transform.pars}{論理値．
    もし真なら AR パラメータはそれらが定常領域に留まることを
    保証するように変換される．
    \code{method = "CSS"} に対しては使われない．}

  \item{fixed}{パラメータの総数と同じ長さのオプションの数値ベクトル．
    もし提供されると 
    \code{fixed} 中の \code{NA} 項目は変化する．
    もし任意の AR パラメータが固定されると \code{transform.pars = TRUE}
    は上書きされる(警告と共に)．}

  \item{init}{オプションの初期パラメータ値の数値ベクトル．
    values.  欠損値は回帰系数を除いてはゼロで埋められる．
    \code{fixed} 中に既に指示されている値は無視される．}

  \item{method}{当てはめ手法：最尤法又は
    条件付き二乗和の最小化．短縮化できる．}

  \item{optim.method}{\code{\link{optim}} へ \code{method} 引数として渡される値．}

  \item{optim.control}{\code{\link{optim}} に対する制御パラメータのリスト．}

  \item{object}{\code{arima0} 当てはめの結果．}

  \item{newxreg}{
    予測に対して使われる \code{xreg} の新しい値．
    少なくとも \code{n.ahead} 行を持たなければならない．}

  \item{n.ahead}{予測が必要とされる先のステップ数．}

  \item{se.fit}{論理値：予測の標準エラーが返されるべきか?}

  \item{\dots}{他のメソッドに・から渡される引数．}
}
\details{
  ARMA モデルの異なった定義は
  AR そして/または MA 係数に対して異なった符号を持つ．
  ここで使われる定義は

  \deqn{X_t = a_1X_{t-1} + \cdots + a_pX_{t-p} + e_t + b_1e_{t-1} + \dots + b_qe_{t-q}}{X[t] = a[1]X[t-1] + \dots + a[p]X[t-p] + e[t] + b[1]e[t-1] + \dots + b[q]e[t-q]}

  であり，従って MA 係数は
  S-PLUS のそれと符号が異なる．
  更に，もし \code{include.mean} が真なら(ARMA モデルの既定値)，
  この公式は \eqn{X} の代わりに \eqn{X -m} に適用される．
  階差を持つ ARIMA モデルに対しては階差系列はゼロ平均の ARMA モデルになる．

  推定量の分散行列は対数尤度のヘッセ行列から計算できるので，
  特に可逆性の境界近くの当てはめに対しては大雑把なガイドに過ぎない．

  最適化は \code{\link{optim}} で行われる．これは
  \code{xreg} 中の列が大まかに平均ゼロで単位分散の時に
  最も上手く動作するが，適当なスケーリングを推定することが
  試みられる．

  有限履歴の予測が使われる．
  これは当てはめの MA 部分が可逆の時だけ統計的に有効であるので，
  MA モデルに対して警告を与える．
}
\section{当てはめ手法}{
  正確な尤度は
  ARIMA プロセスの状態空間表現を使って計算され，
  イノベーションとそれらの分散はカルマンフィルターで見つけられる．
  階差 ARMA プロセスは定常性を利用し
  Gardner \emph{et al} (1980) に基づく．
  これはもしイノベーション分散がその漸近的限界に十分近ければ
  \sQuote{高速回帰}に切り替える
  (実効的に無限の過去を仮定して)オプションがある．
  引数 \code{delta} は許容度を設定する：
  その既定値では近似は普通無視可能で相当速度が向上する．
  正確な計算は \code{delta} を負の値にすることで保証される．

  もし \code{transform.pars} が真なら，最適化は
  Jones (1980) が提案したものの変種である別のパラメータ化を使って
  なされ，モデルが定常であることを保証する．
  AR(p) モデルに対してはパラメータ化は部分自己相関も逆
  tanh を使う：同じ手順が
  (個別に) AR と 季節 AR 項に適用される．
  MA 上は最適化の間可逆という制約を受けないが，
  もし \code{transform.pars} が真なら最適化の後で可逆に変換される．
  MA 項に対する MLE には単位根を持つ
  MA 多項式が登場する：
  そうしたモデルは \code{transform.pars = FALSE} と良い初期値
  (しばしば \code{transform.pars = TRUE} を用いた当てはめから得られる)
  を用いて当てはめることが出来る．

  欠損値は許されるがもしあれば
  \code{delta} は無視され完全な再帰が使われる．
  欠損値は階差を取ることで拡散するので，そうした場合には
  この関数で使われる手順は完全には有効ではない．

  条件付き二乗和は主に説明目的で提供されている．
  これは
  \code{n.cond} 以降の観測値からの当てはめイノベーションの
  二乗和を計算し(ここで \code{n.cond} は少なくとも
  AR 項の最大ラグである)，全ての前のイノベーションは
  ゼロとして扱われる．
  引数 \code{n.cond} は異なった当てはめ間の比較を可能にするために使うことが出来る．
  \sQuote{部分対数尤度}
  は最初の項で，推定された平均二乗の対数の半分である．
  欠損値はゆるされるが，多くのイノベーションが欠損する結果になる．

  被回帰項が指定された場合は，
  それらは係数のどれかが固定されていない限り当てはめへの直交事前分布
  である．
  被回帰項を大まかに平均ゼロで単位分散になるようにスケール化
  することが役に立つかもしれない．
}
\value{
  \code{arima0} に対してはクラス \code{"arima0"} のリストで次の成分を持つ：

  \item{coef}{
    AR, MA そして回帰係数のベクトル．}

  \item{sigma2}{イノベーション分散の MLE．}

  \item{var.coef}{
    係数 \code{coef} の推定分散行列で，
    \code{\link{vcov}} メソッドで取り出せる．}
  \item{loglik}{
    (階差データの)最大化対数尤度，又はそれに使われた近似．}

  \item{arma}{指定の簡潔な書式で，
    AR, MA, 季節 AR と季節 MA の係数に，
    非季節的と季節的な階差の数．}

  \item{aic}{対数尤度に対する AIC 値．
    \code{method = "ML"} 当てはめだけに適正である．}

  \item{residuals}{当てはめられたイノベーション．}

  \item{call}{マッチした呼び出し．}

  \item{series}{系列 \code{x} の名前．}

  \item{convergence}{\code{\link{optim}} により返される値．}

  \item{n.cond}{当てはめで使われない初期観測値数．}

  \code{predict.arima0} に対しては予測の時系列，又は
  もし \code{se.fit = TRUE} なら
  予測値である \code{pred} と
  推定標準エラーである \code{se} を成分に持つリスト．
  両者は時系列である．
}
\references{
  Brockwell, P. J. and Davis, R. A. (1996) \emph{Introduction to Time
    Series and Forecasting.} Springer, New York. Sections 3.3 and 8.3.

  Gardner, G, Harvey, A. C. and Phillips, G. D. A. (1980) Algorithm
  AS154. An algorithm for exact maximum likelihood estimation of
  autoregressive-moving average models by means of Kalman filtering.
  \emph{Applied Statistics} \bold{29}, 311--322.

  Harvey, A. C. (1993) \emph{Time Series Models},
  2nd Edition, Harvester Wheatsheaf, sections 3.3 and  4.4.

  Harvey, A. C. and McKenzie, C. R. (1982) Algorithm AS182.
  An algorithm for finite sample prediction from ARIMA processes.
  \emph{Applied Statistics} \bold{31}, 180--187.

  Jones, R. H. (1980) Maximum likelihood fitting of ARMA models to time
  series with missing observations. \emph{Technometrics} \bold{22} 389--395.
}

\note{
  これは初期バージョンであり
  \code{\link{arima}} で置き換えられるであろう．

  予測の標準誤差は
  ARMA モデルと回帰係数の不確実さを除外する．

  結果はおそらく
  S-PLUS の \code{arima.mle} とは異なる．後者は
  条件付き尤度を計算しモデル中に平均を含まない．
  更に \code{arima.mle} で使われる慣習は
  MA 係数の符号を反転する．
}

\seealso{\code{\link{arima}}, \code{\link{ar}}, \code{\link{tsdiag}}}

\examples{
\dontrun{arima0(lh, order = c(1,0,0))}
arima0(lh, order = c(3,0,0))
arima0(lh, order = c(1,0,1))
predict(arima0(lh, order = c(3,0,0)), n.ahead = 12)

arima0(lh, order = c(3,0,0), method = "CSS")

# このように少ない年数のモデルには完全な ML が欲しい
(fit <- arima0(USAccDeaths, order = c(0,1,1),
               seasonal = list(order=c(0,1,1)), delta = -1))
predict(fit, n.ahead = 6)

arima0(LakeHuron, order = c(2,0,0), xreg = time(LakeHuron)-1920)
\dontrun{
## presidents データセットは NA を含む
## example(acf) 中のグラフは次数 1 か 3 を示唆する
(fit1 <- arima0(presidents, c(1, 0, 0), delta = -1))  # 警告を避ける
tsdiag(fit1)
(fit3 <- arima0(presidents, c(3, 0, 0), delta = -1))  # より小さな AIC
tsdiag(fit3)}
}
\keyword{ts}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/arima0.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{arima0}
%\alias{arima0}
%\alias{print.arima0}
%\alias{predict.arima0}
%\concept{ARNA}
%\title{ARIMA Modelling of Time Series -- Preliminary Version}
%\description{
%  Fit an ARIMA model to a univariate time series, and forecast from
%  the fitted model.
%}
%\usage{
%arima0(x, order = c(0, 0, 0),
%       seasonal = list(order = c(0, 0, 0), period = NA),
%       xreg = NULL, include.mean = TRUE, delta = 0.01,
%       transform.pars = TRUE, fixed = NULL, init = NULL,
%       method = c("ML", "CSS"), n.cond, optim.control = list())
%
%\method{predict}{arima0}(object, n.ahead = 1, newxreg, se.fit = TRUE, \dots)
%}
%\arguments{
%  \item{x}{a univariate time series}
%
%  \item{order}{A specification of the non-seasonal part of the ARIMA
%    model: the three components \eqn{(p, d, q)} are the AR order, the
%    degree of differencing, and the MA order.}
%
%  \item{seasonal}{A specification of the seasonal part of the ARIMA
%    model, plus the period (which defaults to \code{frequency(x)}).
%    This should be a list with components \code{order} and
%    \code{period}, but a specification of just a numeric vector of
%    length 3 will be turned into a suitable list with the specification
%    as the \code{order}.}
%
%  \item{xreg}{Optionally, a vector or matrix of external regressors,
%    which must have the same number of rows as \code{x}.}
%
%  \item{include.mean}{Should the ARIMA model include
%    a mean term? The default is \code{TRUE} for undifferenced series,
%    \code{FALSE} for differenced ones (where a mean would not affect
%    the fit nor predictions).}
%
%  \item{delta}{A value to indicate at which point \sQuote{fast
%      recursions} should be used.  See the \sQuote{Details} section.}
%
%  \item{transform.pars}{Logical.  If true, the AR parameters are
%    transformed to ensure that they remain in the region of
%    stationarity.  Not used for \code{method = "CSS"}.}
%
%  \item{fixed}{optional numeric vector of the same length as the total
%    number of parameters.  If supplied, only \code{NA} entries in
%    \code{fixed} will be varied.  \code{transform.pars = TRUE}
%    will be overridden (with a warning) if any ARMA parameters are
%    fixed.}
%
%  \item{init}{optional numeric vector of initial parameter
%    values.  Missing values will be filled in, by zeroes except for
%    regression coefficients.  Values already specified in \code{fixed}
%    will be ignored.}
%
%  \item{method}{Fitting method: maximum likelihood or minimize
%    conditional sum-of-squares.  Can be abbreviated.}
%
%  \item{n.cond}{Only used if fitting by conditional-sum-of-squares: the
%    number of initial observations to ignore.  It will be ignored if
%    less than the maximum lag of an AR term.}
%
%  \item{optim.control}{List of control parameters for \code{\link{optim}}.}
%
%  \item{object}{The result of an \code{arima0} fit.}
%
%  \item{newxreg}{New values of \code{xreg} to be used for
%    prediction. Must have at least \code{n.ahead} rows.}
%
%  \item{n.ahead}{The number of steps ahead for which prediction is required.}
%
%  \item{se.fit}{Logical: should standard errors of prediction be returned?}
%
%  \item{\dots}{arguments passed to or from other methods.}
%}
%\details{
%  Different definitions of ARMA models have different signs for the
%  AR and/or MA coefficients. The definition here has
%
%  \deqn{X_t = a_1X_{t-1} + \cdots + a_pX_{t-p} + e_t + b_1e_{t-1} + \dots + b_qe_{t-q}}{X[t] = a[1]X[t-1] + \dots + a[p]X[t-p] + e[t] + b[1]e[t-1] + \dots + b[q]e[t-q]}
%
%  and so the MA coefficients differ in sign from those of
%  S-PLUS.  Further, if \code{include.mean} is true, this formula
%  applies to \eqn{X-m} rather than \eqn{X}.  For ARIMA models with
%  differencing, the differenced series follows a zero-mean ARMA model.
%
%  The variance matrix of the estimates is found from the Hessian of
%  the log-likelihood, and so may only be a rough guide, especially for
%  fits close to the boundary of invertibility.
%
%  Optimization is done by \code{\link{optim}}. It will work
%  best if the columns in \code{xreg} are roughly scaled to zero mean
%  and unit variance, but does attempt to estimate suitable scalings.
%
%  Finite-history prediction is used. This is only statistically
%  efficient if the MA part of the fit is invertible, so
%  \code{predict.arima0} will give a warning for non-invertible MA
%  models.
%}
%\section{Fitting methods}{
%  The exact likelihood is computed via a state-space representation of
%  the ARMA process, and the innovations and their variance found by a
%  Kalman filter based on Gardner \emph{et al} (1980).  This has
%  the option to switch to \sQuote{fast recursions} (assume an
%  effectively infinite past) if the innovations variance is close
%  enough to its asymptotic bound. The argument \code{delta} sets the
%  tolerance: at its default value the approximation is normally
%  negligible and the speed-up considerable.  Exact computations can be
%  ensured by setting \code{delta} to a negative value.
%
%  If \code{transform.pars} is true, the optimization is done using an
%  alternative parametrization which is a variation on that suggested by
%  Jones (1980) and ensures that the model is stationary.  For an AR(p)
%  model the parametrization is via the inverse tanh of the partial
%  autocorrelations: the same procedure is applied (separately) to the
%  AR and seasonal AR terms.  The MA terms are also constrained to be
%  invertible during optimization by the same transformation if
%  \code{transform.pars} is true.  Note that the MLE for MA terms does
%  sometimes occur for MA polynomials with unit roots: such models can be
%  fitted by using \code{transform.pars = FALSE} and specifying a good
%  set of initial values (often obtainable from a fit with
%  \code{transform.pars = TRUE}).
%
%  Missing values are allowed, but any missing values
%  will force \code{delta} to be ignored and full recursions used.
%  Note that missing values will be propagated by differencing, so the
%  procedure used in this function is not fully efficient in that case.
%
%  Conditional sum-of-squares is provided mainly for expositional
%  purposes.  This computes the sum of squares of the fitted innovations
%  from observation
%  \code{n.cond} on, (where \code{n.cond} is at least the maximum lag of
%  an AR term), treating all earlier innovations to be zero.  Argument
%  \code{n.cond} can be used to allow comparability between different
%  fits.  The \sQuote{part log-likelihood} is the first term, half the
%  log of the estimated mean square.  Missing values are allowed, but
%  will cause many of the innovations to be missing.
%
%  When regressors are specified, they are orthogonalized prior to
%  fitting unless any of the coefficients is fixed.  It can be helpful to
%  roughly scale the regressors to zero mean and unit variance.
%}
%\value{
%  For \code{arima0}, a list of class \code{"arima0"} with components:
%
%  \item{coef}{a vector of AR, MA and regression coefficients,}
%
%  \item{sigma2}{the MLE of the innovations variance.}
%
%  \item{var.coef}{the estimated variance matrix of the coefficients
%    \code{coef}.}
%
%  \item{loglik}{the maximized log-likelihood (of the differenced data),
%    or the approximation to it used.}
%
%  \item{arma}{A compact form of the specification, as a vector giving
%    the number of AR, MA, seasonal AR and seasonal MA coefficients,
%    plus the period and the number of non-seasonal and seasonal
%    differences.}
%
%  \item{aic}{the AIC value corresponding to the log-likelihood. Only
%    valid for \code{method = "ML"} fits.}
%
%  \item{residuals}{the fitted innovations.}
%
%  \item{call}{the matched call.}
%
%  \item{series}{the name of the series \code{x}.}
%
%  \item{convergence}{the value returned by \code{\link{optim}}.}
%
%  \item{n.cond}{the number of initial observations not used in the fitting.}
%
%  For \code{predict.arima0}, a time series of predictions, or if
%  \code{se.fit = TRUE}, a list with components \code{pred}, the
%  predictions, and \code{se}, the estimated standard errors. Both
%  components are time series.
%}
%\references{
%  Brockwell, P. J. and Davis, R. A. (1996) \emph{Introduction to Time
%    Series and Forecasting.} Springer, New York. Sections 3.3 and 8.3.
%
%  Gardner, G, Harvey, A. C. and Phillips, G. D. A. (1980) Algorithm
%  AS154. An algorithm for exact maximum likelihood estimation of
%  autoregressive-moving average models by means of Kalman filtering.
%  \emph{Applied Statistics} \bold{29}, 311--322.
%
%  Harvey, A. C. (1993) \emph{Time Series Models},
%  2nd Edition, Harvester Wheatsheaf, sections 3.3 and  4.4.
%
%  Harvey, A. C. and McKenzie, C. R. (1982) Algorithm AS182.
%  An algorithm for finite sample prediction from ARIMA processes.
%  \emph{Applied Statistics} \bold{31}, 180--187.
%
%  Jones, R. H. (1980) Maximum likelihood fitting of ARMA models to time
%  series with missing observations. \emph{Technometrics} \bold{22} 389--395.
%}
%
%\note{
%  This is a preliminary version, and will be replaced by \code{\link{arima}}.
%
%  The standard errors of prediction exclude the uncertainty in the
%  estimation of the ARMA model and the regression coefficients.
%
%  The results are likely to be different from S-PLUS's
%  \code{arima.mle}, which computes a conditional likelihood and does
%  not include a mean in the model.  Further, the convention used by
%  \code{arima.mle} reverses the signs of the MA coefficients.
%}
%
%\seealso{\code{\link{arima}}, \code{\link{ar}}, \code{\link{tsdiag}}}
%
%\examples{
%\dontrun{arima0(lh, order = c(1,0,0))}
%arima0(lh, order = c(3,0,0))
%arima0(lh, order = c(1,0,1))
%predict(arima0(lh, order = c(3,0,0)), n.ahead = 12)
%
%arima0(lh, order = c(3,0,0), method = "CSS")
%
%# for a model with as few years as this, we want full ML
%(fit <- arima0(USAccDeaths, order = c(0,1,1),
%               seasonal = list(order=c(0,1,1)), delta = -1))
%predict(fit, n.ahead = 6)
%
%arima0(LakeHuron, order = c(2,0,0), xreg = time(LakeHuron)-1920)
%\dontrun{
%## presidents contains NAs
%## graphs in example(acf) suggest order 1 or 3
%(fit1 <- arima0(presidents, c(1, 0, 0), delta = -1))  # avoid warning
%tsdiag(fit1)
%(fit3 <- arima0(presidents, c(3, 0, 0), delta = -1))  # smaller AIC
%tsdiag(fit3)}
%}
%\keyword{ts}
%
%\encoding{UTF-8}
%
