% File src/library/stats/man/box.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{Box.test}
\alias{Box.test}%@%\alias{Box--Pierce検定}%@%\alias{Ljung--Box検定}
\concept{portmanteau}
\title{Box-Pierce and Ljung-Box Tests}
\description{
  与えられた時系列中の独立性帰無仮説を調べるための
  Box--Pierce または Ljung--Box 検定統計量を計算する．
  これらは時々\sQuote{鞄}検定と呼ばれる．
}
\usage{
Box.test(x, lag = 1, type = c("Box-Pierce", "Ljung-Box"), fitdf = 0)
}
\arguments{
  \item{x}{数値ベクトル又は一変量時系列．}
  \item{lag}{
    統計量は \code{lag} 自己相関係数に基づいている．}
  \item{type}{実行される検定：部分マッチングが使われる．}
  \item{fitdf}{
    もし \code{x} が残差系列の時差し引かれる自由度数．}
}
\details{
  これらの検定はしばしば
  \code{ARMA(p, q)} 当てはめからの残差に適用され，
  その場合参考文献は
  帰無分布へのより良い近似が，勿論 \code{lag > fitdf} であれば，
  \code{fitdf = p+q} と置くことで得られると示唆している．
}
\note{
  欠損値は処理されない．
}
\value{
  A list with class
  クラス \code{"htest"} のりストで次の成分を持つ：
  \item{statistic}{検定統計量の値．}
  \item{parameter}{
    検定統計量の近似カイ二乗分布の自由度
    (\code{fitdf} を考慮する．}
  \item{p.value}{検定の p 値．}
  \item{method}{どのタイプの検定が実行されるかを指示する文字列．}
  \item{data.name}{データの名前を与える文字列．}
}
\references{
  Box, G. E. P. and Pierce, D. A. (1970),
  Distribution of residual correlations in autoregressive-integrated
  moving average time series models.
  \emph{Journal of the American Statistical Association}, \bold{65},
  1509--1526.

  Ljung, G. M. and Box, G. E. P. (1978),
  On a measure of lack of fit in time series models.
  \emph{Biometrika} \bold{65}, 297--303.

  Harvey, A. C. (1993)
  \emph{Time Series Models}.
  2nd Edition, Harvester Wheatsheaf, NY, pp.\sspace{}44, 45.
}
\author{A. Trapletti}
\examples{
x <- rnorm (100)
Box.test (x, lag = 1)
Box.test (x, lag = 1, type = "Ljung")
}
\keyword{ts}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/box.test.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{Box.test}
%\alias{Box.test}
%\concept{portmanteau}
%\title{Box-Pierce and Ljung-Box Tests}
%\description{
%  Compute the Box--Pierce or Ljung--Box test statistic for examining the
%  null hypothesis of independence in a given time series.  These are
%  sometimes known as \sQuote{portmanteau} tests.
%}
%\usage{
%Box.test(x, lag = 1, type = c("Box-Pierce", "Ljung-Box"), fitdf = 0)
%}
%\arguments{
%  \item{x}{a numeric vector or univariate time series.}
%  \item{lag}{the statistic will be based on \code{lag} autocorrelation
%    coefficients.}
%  \item{type}{test to be performed: partial matching is used.}
%  \item{fitdf}{number of degrees of freedom to be subtracted if \code{x}
%    is a series of residuals.}
%}
%\details{
%  These tests are sometimes applied to the residuals from an
%  \code{ARMA(p, q)} fit, in which case the references suggest a better
%  approximation to the null-hypothesis distribution is obtained by
%  setting \code{fitdf = p+q}, provided of course that \code{lag > fitdf}.
%}
%\note{
%  Missing values are not handled.
%}
%\value{
%  A list with class \code{"htest"} containing the following components:
%  \item{statistic}{the value of the test statistic.}
%  \item{parameter}{the degrees of freedom of the approximate chi-squared
%    distribution of the test statistic (taking \code{fitdf} into account.}
%  \item{p.value}{the p-value of the test.}
%  \item{method}{a character string indicating which type of test was
%    performed.}
%  \item{data.name}{a character string giving the name of the data.}
%}
%\references{
%  Box, G. E. P. and Pierce, D. A. (1970),
%  Distribution of residual correlations in autoregressive-integrated
%  moving average time series models.
%  \emph{Journal of the American Statistical Association}, \bold{65},
%  1509--1526.
%
%  Ljung, G. M. and Box, G. E. P. (1978),
%  On a measure of lack of fit in time series models.
%  \emph{Biometrika} \bold{65}, 297--303.
%
%  Harvey, A. C. (1993)
%  \emph{Time Series Models}.
%  2nd Edition, Harvester Wheatsheaf, NY, pp.\sspace{}44, 45.
%}
%\author{A. Trapletti}
%\examples{
%x <- rnorm (100)
%Box.test (x, lag = 1)
%Box.test (x, lag = 1, type = "Ljung")
%}
%\keyword{ts}
%
%\encoding{UTF-8}
%
