% File src/library/stats/man/cancor.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{cancor}
\title{Canonical Correlations}
\alias{cancor}
\usage{
cancor(x, y, xcenter = TRUE, ycenter = TRUE)
}
\arguments{
  \item{x}{数値行列(\eqn{n \times p_1}{n * p1})で x 座標を含む．}
  \item{y}{数値行列(\eqn{n \times p_2}{n * p2}) で y 座標を含む．}
  \item{xcenter}{論理値または
    長さ \eqn{p_1}{p1} の数値ベクトルで，
    解析前に x 変数になされる任意のセンタリングを
    記述する．
    もし \code{TRUE} (既定)ならば列平均を引く．
    もし \code{FALSE} ならば列を補正しない．
    さもなければ，列から数値ベクトルが引かれる．}
  \item{ycenter}{
    \code{xcenter} に似るが y 値用である．}
}
\description{
  二つのデータ行列間の正順相関を検定する．
}
\details{
  正順相関分析は
  \code{x} 変数の線形結合により上手く説明できる
  \code{y} 変数の線型結合を求める．
  \sQuote{上手く説明出来る}とは相関で測られるために
  関係は対称である．
}
\value{
  次の成分を含むリスト：
  \item{cor}{相関．}
  \item{xcoef}{\code{x} 変数に対する推定係数．}
  \item{ycoef}{\code{y} 変数に対する推定係数．}
  \item{xcenter}{\code{x} 変数の補正に使われる値．}
  \item{ycenter}{\code{y} 変数の補正に使われる値．}
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Hotelling H. (1936).
  Relations between two sets of variables.
  \emph{Biometrika}, \bold{28}, 321--327.

  Seber, G. A. F. (1984).
  \emph{Multivariate Observations}.
  New York: Wiley, p.\sspace{}506f.
}
\seealso{
  \code{\link{qr}}, \code{\link{svd}}.
}
\examples{\donttest{## 結果の符号はランダム
pop <- LifeCycleSavings[, 2:3]
oec <- LifeCycleSavings[, -(2:3)]
cancor(pop, oec)

x <- matrix(rnorm(150), 50, 3)
y <- matrix(rnorm(250), 50, 5)
(cxy <- cancor(x, y))
all(abs(cor(x \%*\% cxy$xcoef,
            y \%*\% cxy$ycoef)[,1:3] - diag(cxy $ cor)) < 1e-15)
all(abs(cor(x \%*\% cxy$xcoef) - diag(3)) < 1e-15)
all(abs(cor(y \%*\% cxy$ycoef) - diag(5)) < 1e-15)
}}
\keyword{multivariate}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/cancor.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{cancor}
%\title{Canonical Correlations}
%\alias{cancor}
%\usage{
%cancor(x, y, xcenter = TRUE, ycenter = TRUE)
%}
%\arguments{
%  \item{x}{numeric matrix (\eqn{n \times p_1}{n * p1}), containing the
%    x coordinates.}
%  \item{y}{numeric matrix (\eqn{n \times p_2}{n * p2}), containing the
%    y coordinates.}
%  \item{xcenter}{logical or numeric vector of length \eqn{p_1}{p1},
%    describing any centering to be done on the x values before the
%    analysis.  If \code{TRUE} (default), subtract the column means.
%    If \code{FALSE}, do not adjust the columns.  Otherwise, a vector
%    of values to be subtracted from the columns.}
%  \item{ycenter}{analogous to \code{xcenter}, but for the y values.}
%}
%\description{
%  Compute the canonical correlations between two data matrices.
%}
%\details{
%  The canonical correlation analysis seeks linear combinations of the
%  \code{y} variables which are well explained by linear combinations
%  of the \code{x} variables. The relationship is symmetric as
%  \sQuote{well explained} is measured by correlations.
%}
%\value{
%  A list containing the following components:
%  \item{cor}{correlations.}
%  \item{xcoef}{estimated coefficients for the \code{x} variables.}
%  \item{ycoef}{estimated coefficients for the \code{y} variables.}
%  \item{xcenter}{the values used to adjust the \code{x} variables.}
%  \item{ycenter}{the values used to adjust the \code{x} variables.}
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Hotelling H. (1936).
%  Relations between two sets of variables.
%  \emph{Biometrika}, \bold{28}, 321--327.
%
%  Seber, G. A. F. (1984).
%  \emph{Multivariate Observations}.
%  New York: Wiley, p.\sspace{}506f.
%}
%\seealso{
%  \code{\link{qr}}, \code{\link{svd}}.
%}
%\examples{\donttest{## signs of results are random
%pop <- LifeCycleSavings[, 2:3]
%oec <- LifeCycleSavings[, -(2:3)]
%cancor(pop, oec)
%
%x <- matrix(rnorm(150), 50, 3)
%y <- matrix(rnorm(250), 50, 5)
%(cxy <- cancor(x, y))
%all(abs(cor(x \%*\% cxy$xcoef,
%            y \%*\% cxy$ycoef)[,1:3] - diag(cxy $ cor)) < 1e-15)
%all(abs(cor(x \%*\% cxy$xcoef) - diag(3)) < 1e-15)
%all(abs(cor(y \%*\% cxy$ycoef) - diag(5)) < 1e-15)
%}}
%\keyword{multivariate}
%
%\encoding{UTF-8}
%