% File src/library/stats/man/cmdscale.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2015 R Core Team
% Distributed under GPL 2 or later

\name{cmdscale}
\alias{cmdscale}
\concept{ordination}
\concept{MDS}
\title{Classical (Metric) Multidimensional Scaling}
\usage{
cmdscale(d, k = 2, eig = FALSE, add = FALSE, x.ret = FALSE,
         list. = eig || add || x.ret)
}
\description{
  データ行列の古典的な多次元尺度法(MDS)．
  また\emph{主座標解析} (Gower, 1966) としても知られている．
}
\arguments{
  \item{d}{
    \code{dist} が返すような距離構造，又は
    非類似度を含む完全な対称行列．}
  \item{k}{データがその中に置かれる空間の最大次元；
    \eqn{\{1, 2, \ldots, n-1\}}{{1, 2, \dots, n-1}} の中に
    なければならない．}
  \item{eig}{固有値を返すべきかどうかを指示する．}
  \item{add}{
    加法定数 \eqn{c*} を計算し，
    修正された非類似度がユークリッド距離になるように非対角成分に
    加えるかどうかを指示する論理値．}
  \item{x.ret}{
    二重に中心化された対称距離行列を返すべきかかどうか指示する．}
  \item{list.}{
    \code{\link{list}} が返されるべきかそれとも
    \eqn{n \times k}{n * k} 行列を返すべきかどうかを指示する
    論理値，\sQuote{値:} を見よ．}
}
\details{
  多次元尺度法は非類似度のセットを取り
  点間の距離が概略非類似度に等しい点のセットを返す．
  (これは生態学者が \sQuote{序列法} と呼ぶものの中心部分である．)

  \eqn{n} 個の点のユークリッド距離は
  最大 \eqn{n - 1} 次元空間中に正確に表現可能である．
  \code{cmdscale} は Mardia (1978) の解析に従い，そして
  最も良く当てはまった \eqn{k} 次元の表現を与える，
  ここで \eqn{k} は 引数 \code{k} 以下かもしれない．

  表現は位置，回転そして反転を除いてのみ決定される．
  返される配置は主成分軸中で返されるので，
  選ばれた反転は
  \R のプラットフォームで異なるかもしれない(\code{\link{prcomp}} を見よ)．

  \code{add = TRUE} の時は，最少加法定数 \eqn{c*} が非類似度
  \eqn{d_{ij} + c*}{d[i,j] + c*} がユークリッド距離になり，従って
  \code{n - 1} 次元空間に表現出来るように計算される．
  S (Becker \emph{et al}, 1988) はこの定数を
  Torgerson が提案した近似で計算するが，\R は
  Cailliez (1983) の解析的な解を使う，Cox and Cox (2001) も見よ．
  数値的なエラーから計算された固有値は全て非負であるとは
  限らず，理論的にも表現は
  \code{n - 1} 次元よりも小さくなるかもしれないことを注意する．
}
\value{
  もし \code{.list} が偽なら(既定値であるように)，
  \code{k} 列で行が非類似度を表現するように選ばれた点の座標を
  持つ行列．

  さもなければつぎの成分を含むリスト．
  \item{points}{
    最大 \code{k} 列の
    その行が非類似度を表現するように選ばれた点の座標を
    持つの行列で．}
  \item{eig}{
    もし \code{eig} が真ならば
    \eqn{n} スケーリング途中で計算された固有値．
    \strong{注意}：
    2.12.1 以前の \R のバージョンは
    \code{k} だけを返したがドキュメントには
    \eqn{n - 1} を返すと書かれていた．}
  \item{x}{
    もし \code{x.ret} が真ならば二重に中心化された距離行列．}
  \item{ac}{加法定数 \eqn{c*}，もし \code{add = FALSE} ならば \code{0}．}
  \item{GOF}{長さ 2 の数値ベクトル，例えば
    \eqn{(g_1,g_2)}{(g.1,g.2)} とする，ここで\cr
    \eqn{g_i = (\sum_{j=1}^k \lambda_j)/ (\sum_{j=1}^n T_i(\lambda_j))}{g.i = (sum{j=1..k} \lambda[j]) / (sum{j=1..n} T.i(\lambda[j]))} で
    \eqn{\lambda_j}{\lambda[j]} は
    (減少順にソートされた)固有値．
    \eqn{T_1(v) = \left| v \right|}{T.1(v) = abs(v)}，そして
    \eqn{T_2(v) = max( v, 0 )}{T.2(v) = max(v, 0)}．
  }
}
\references{
  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
  \emph{The New S Language}.
  Wadsworth & Brooks/Cole.

  Cailliez, F. (1983)
  The analytical solution of the additive constant problem.
  \emph{Psychometrika} \bold{48}, 343--349.

  Cox, T. F. and Cox, M. A. A. (2001)
  \emph{Multidimensional Scaling}.  Second edition.
  Chapman and Hall.

  Gower, J. C. (1966)
  Some distance properties of latent root and vector
  methods used in multivariate analysis.
  \emph{Biometrika} \bold{53}, 325--328.

  Krzanowski, W. J. and Marriott, F. H. C. (1994)
  \emph{Multivariate Analysis. Part I. Distributions, Ordination and
  Inference.}  London: Edward Arnold. (Especially pp.\sspace{}108--111.)

  Mardia, K.V. (1978)
  Some properties of classical multidimensional scaling.
  \emph{Communications on Statistics -- Theory and Methods}, \bold{A7},
  1233--41.

  Mardia, K. V., Kent, J. T. and Bibby, J. M. (1979).  
  \emph{Multivariate Analysis} の第14章, London: Academic Press.

  Seber, G. A. F. (1984).
  \emph{Multivariate Observations}.
  New York: Wiley.

  Torgerson, W. S. (1958).
  \emph{Theory and Methods of Scaling}.
  New York: Wiley.
}
\seealso{
  \code{\link{dist}}.

  パッケージ \CRANpkg{MASS} 中の
  \code{\link[MASS]{isoMDS}} と \code{\link[MASS]{sammon}} は
  多次元尺度法の別の手法を与える．
}
\examples{
require(graphics)

loc <- cmdscale(eurodist)
x <- loc[, 1]
y <- -loc[, 2] # 北が上に来るように反転
## ユークリッド距離が正確に表現されるように asp = 1 に注意
plot(x, y, type = "n", xlab = "", ylab = "", asp = 1, axes = FALSE,
     main = "cmdscale(eurodist)")
text(x, y, rownames(loc), cex = 0.6)
}
\keyword{multivariate}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/cmdscale.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2015 R Core Team
%% Distributed under GPL 2 or later
%
%\name{cmdscale}
%\alias{cmdscale}
%\concept{ordination}
%\concept{MDS}
%\title{Classical (Metric) Multidimensional Scaling}
%\usage{
%cmdscale(d, k = 2, eig = FALSE, add = FALSE, x.ret = FALSE,
%         list. = eig || add || x.ret)
%}
%\description{
%  Classical multidimensional scaling (MDS) of a data matrix.
%  Also known as \emph{principal coordinates analysis} (Gower, 1966).
%}
%\arguments{
%  \item{d}{a distance structure such as that returned by \code{dist}
%    or a full symmetric matrix containing the dissimilarities.}
%  \item{k}{the maximum dimension of the space which the data are to be
%    represented in; must be in \eqn{\{1, 2, \ldots, n-1\}}{{1, 2, \dots, n-1}}.}
%  \item{eig}{indicates whether eigenvalues should be returned.}
%  \item{add}{logical indicating if an additive constant \eqn{c*} should
%    be computed, and added to the non-diagonal dissimilarities such that
%    the modified dissimilarities are Euclidean.}
%  \item{x.ret}{indicates whether the doubly centred symmetric distance
%    matrix should be returned.}
%  \item{list.}{logical indicating if a \code{\link{list}} should be
%    returned or just the \eqn{n \times k}{n * k} matrix, see \sQuote{Value:}.}
%}
%\details{
%  Multidimensional scaling takes a set of dissimilarities and returns a
%  set of points such that the distances between the points are
%  approximately equal to the dissimilarities.  (It is a major part of
%  what ecologists call \sQuote{ordination}.)
%
%  A set of Euclidean distances on \eqn{n} points can be represented
%  exactly in at most \eqn{n - 1} dimensions.  \code{cmdscale} follows
%  the analysis of Mardia (1978), and returns the best-fitting
%  \eqn{k}-dimensional representation, where \eqn{k} may be less than the
%  argument \code{k}.
%
%  The representation is only determined up to location (\code{cmdscale}
%  takes the column means of the configuration to be at the origin),
%  rotations and reflections.  The configuration returned is given in
%  principal-component axes, so the reflection chosen may differ between
%  \R platforms (see \code{\link{prcomp}}).
%
%  When \code{add = TRUE}, a minimal additive constant \eqn{c*} is
%  computed such that the dissimilarities \eqn{d_{ij} + c*}{d[i,j] +
%  c*} are Euclidean and hence can be represented in \code{n - 1}
%  dimensions.  Whereas S (Becker \emph{et al}, 1988) computes this
%  constant using an approximation suggested by Torgerson, \R uses the
%  analytical solution of Cailliez (1983), see also Cox and Cox (2001).
%  Note that because of numerical errors the computed eigenvalues need
%  not all be non-negative, and even theoretically the representation
%  could be in fewer than \code{n - 1} dimensions.
%}
%\value{
%  If \code{.list} is false (as per default), a matrix with \code{k}
%  columns whose rows give the coordinates of the points chosen to
%  represent the dissimilarities.
%
%  Otherwise, a \code{\link{list}} containing the following components.
%  \item{points}{a matrix with up to \code{k} columns whose rows give the
%    coordinates of the points chosen to represent the dissimilarities.}
%  \item{eig}{the \eqn{n} eigenvalues computed during the scaling process if
%    \code{eig} is true.  \strong{NB}: versions of \R before 2.12.1
%    returned only \code{k} but were documented to return \eqn{n - 1}.}
%  \item{x}{the doubly centered distance matrix if \code{x.ret} is true.}
%  \item{ac}{the additive constant \eqn{c*}, \code{0} if \code{add = FALSE}.}
%  \item{GOF}{a numeric vector of length 2, equal to say
%    \eqn{(g_1,g_2)}{(g.1,g.2)}, where
%    \eqn{g_i = (\sum_{j=1}^k \lambda_j)/ (\sum_{j=1}^n T_i(\lambda_j))}{g.i = (sum{j=1..k} \lambda[j]) / (sum{j=1..n} T.i(\lambda[j]))},
%    where \eqn{\lambda_j}{\lambda[j]} are the eigenvalues (sorted in
%    decreasing order),
%    \eqn{T_1(v) = \left| v \right|}{T.1(v) = abs(v)}, and
%    \eqn{T_2(v) = max( v, 0 )}{T.2(v) = max(v, 0)}.
%  }
%}
%\references{
%  Becker, R. A., Chambers, J. M. and Wilks, A. R. (1988)
%  \emph{The New S Language}.
%  Wadsworth & Brooks/Cole.
%
%  Cailliez, F. (1983)
%  The analytical solution of the additive constant problem.
%  \emph{Psychometrika} \bold{48}, 343--349.
%
%  Cox, T. F. and Cox, M. A. A. (2001)
%  \emph{Multidimensional Scaling}.  Second edition.
%  Chapman and Hall.
%
%  Gower, J. C. (1966)
%  Some distance properties of latent root and vector
%  methods used in multivariate analysis.
%  \emph{Biometrika} \bold{53}, 325--328.
%
%  Krzanowski, W. J. and Marriott, F. H. C. (1994)
%  \emph{Multivariate Analysis. Part I. Distributions, Ordination and
%  Inference.}  London: Edward Arnold. (Especially pp.\sspace{}108--111.)
%
%  Mardia, K.V. (1978)
%  Some properties of classical multidimensional scaling.
%  \emph{Communications on Statistics -- Theory and Methods}, \bold{A7},
%  1233--41.
%
%  Mardia, K. V., Kent, J. T. and Bibby, J. M. (1979).  Chapter 14 of
%  \emph{Multivariate Analysis}, London: Academic Press.
%
%  Seber, G. A. F. (1984).
%  \emph{Multivariate Observations}.
%  New York: Wiley.
%
%  Torgerson, W. S. (1958).
%  \emph{Theory and Methods of Scaling}.
%  New York: Wiley.
%}
%\seealso{
%  \code{\link{dist}}.
%
%  \code{\link[MASS]{isoMDS}} and \code{\link[MASS]{sammon}}
%  in package \CRANpkg{MASS} provide alternative methods of
%  multidimensional scaling.
%}
%\examples{
%require(graphics)
%
%loc <- cmdscale(eurodist)
%x <- loc[, 1]
%y <- -loc[, 2] # reflect so North is at the top
%## note asp = 1, to ensure Euclidean distances are represented correctly
%plot(x, y, type = "n", xlab = "", ylab = "", asp = 1, axes = FALSE,
%     main = "cmdscale(eurodist)")
%text(x, y, rownames(loc), cex = 0.6)
%}
%\keyword{multivariate}
%
%\encoding{UTF-8}
%