% File src/library/stats/man/extractAIC.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

%-- This page by Martin Maechler,  improvements welcome!
\name{extractAIC}
\title{Extract AIC from a Fitted Model}
%
\alias{extractAIC}%@%\alias{当てはめモデルから AIC を取り出す}
\usage{
extractAIC(fit, scale, k = 2, \dots)
}
\arguments{
  \item{fit}{当てはめモデルで，普通
    \code{\link{lm}} のような当てはめ関数の結果．}
 \item{scale}{
   モデルのスケールパラメータを指定するオプションの数値，
   \code{\link{step}} 中の \code{scale} を見よ．
   現在 \code{"lm"} メソッド中だけで使われている，
   ここで \code{scale} はエラー分散の推定値を指定し，
   そして \code{scale = 0} はそれが最尤推定で推定されることを指示する．
 }
 \item{k}{AIC 公式中の
   \emph{同値自由度} (\eqn{\equiv}{=:} \code{edf})
   の\sQuote{重み}を指定する数値．}
 \item{\dots}{追加の引数(現在基本 \R では使われていない)．}
}
%-- Source in ../R/add.R
\description{
  当てはめられたパラメトリックモデルに対して
  (一般化)赤池情報量規準を計算する．
}
\details{
  これは総称的関数で，
  基本 \R 中で
  クラス \code{"aov"}, \code{"glm"} と \code{"lm"} に対するメソッドを持つ．
  更に
  \code{"negbin"} (パッケージ \CRANpkg{MASS}) と \code{"coxph"} そして
  \code{"survreg"} (パッケージ \CRANpkg{survival}) に対しても
  メソッドを持つ．

  使われる規準は
  \deqn{AIC = - 2\log L +  k \times \mbox{edf},}{AIC = - 2*log L +  k * edf}
  で，ここで \eqn{L} は尤度で \code{edf} は \code{fit} の同値自由度
  (つまり，普通のパラメトリックモデルでは自由パラメータの数)である．

  未知のスケールを持つ線形モデル(つまり \code{\link{lm}} と
  \code{\link{aov}})に対しては，
  \eqn{-2\log L}{-2 log L} は
  \emph{逸脱度}から計算され
  \code{\link{logLik}}，従って\code{\link{AIC}}
  に対しても異なる加法定数を用いる．
  もし \eqn{RSS} が(重み付きの)残差平方和を表せば
  \code{extractAIC} は
  \eqn{- 2\log L}{-2 log L} に対して既知のスケール \eqn{s} の
  場合は式 \eqn{RSS/s - n}
  (Mallows の \eqn{C_p}{Cp} に対応する)
  ，未知の場合は \eqn{n \log (RSS/n)}{n log (RSS/n)} を使う．
  \code{\link{AIC}} は未知のスケールのみを扱い，
  そして式
  \eqn{n \log (RSS/n) + n + n \log 2\pi - \sum \log w}{n*log(RSS/n) + n + n*log 2pi - sum(log w)}
  を使う，ここで \eqn{w} は重みである．
  更に \code{AIC} はスケール推定を
  \code{edf} 中のパラメータとしてカウントするが
  \code{extractAIC} はしない．

  \code{glm} 当てはめに対しては族の \code{aic()} 関数が
  AIC の計算に使われる：
  これが用いる仮定については \code{logLik} の下の
  注意を見よ．

  \code{k = 2} は伝統的な AIC で使われ，
  \code{k = log(n)} は代わりに BIC (Bayesian IC) が使う．

  この関数に対するメソッドは
  \code{\link{AIC}} (普通
  \code{\link{logLik}} に対するメソッドを用いる)に
  対するメソッドのそれらとは仮定が異なることを注意する．
  推定されたスケールを持つ \code{"lm"} モデルのケースに
  ついては既に述べた．そして
  逸脱度パラメータを\sQuote{自由}と見做すか否かで
  \code{"glm"} と \code{"negbin"} でも同じ問題が起きる．
  \code{extractAIC} は同じクラスのモデルの比較だけに使われる
  (そこでは AIC 値の差だけが考慮される)ので
  これは本質的ではない．
}
\note{
  この関数は
  \code{\link{add1}}, \code{\link{drop1}} そして
  \code{\link{step}} 更にそれが導入された
  パッケージ \CRANpkg{MASS} 中の類似の関数中で
  使われる．
}
\value{
  長さ 2 の数値ベクトルで，最初と二番目の要素は以下を与える

  \item{edf}{当てはめモデル \code{fit} に対する \sQuote{同値自由度}．}

  \item{AIC}{\code{fit} に対する(一般化)赤池情報量規準．}
}
%-- Source in ../R/add.R
\author{B. D. Ripley}
\references{
  Venables, W. N. and Ripley, B. D. (2002)
  \emph{Modern Applied Statistics with S.}
  New York: Springer (4th ed).
}
\seealso{
  \code{\link{AIC}}, \code{\link{deviance}}, \code{\link{add1}},
  \code{\link{step}}
}
\examples{\donttest{
utils::example(glm)
extractAIC(glm.D93)  #>>  5  15.129
}}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/extractAIC.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%%-- This page by Martin Maechler,  improvements welcome!
%\name{extractAIC}
%\title{Extract AIC from a Fitted Model}
%%
%\alias{extractAIC}
%\usage{
%extractAIC(fit, scale, k = 2, \dots)
%}
%\arguments{
%  \item{fit}{fitted model, usually the result of a fitter like
%    \code{\link{lm}}.}
% \item{scale}{optional numeric specifying the scale parameter of the
%   model, see \code{scale} in \code{\link{step}}.  Currently only used
%   in the \code{"lm"} method, where \code{scale} specifies the estimate
%   of the error variance, and \code{scale = 0} indicates that it is to
%   be estimated by maximum likelihood.
% }
% \item{k}{numeric specifying the \sQuote{weight} of the
%   \emph{equivalent degrees of freedom} (\eqn{\equiv}{=:} \code{edf})
%   part in the AIC formula.}
% \item{\dots}{further arguments (currently unused in base \R).}
%}
%%-- Source in ../R/add.R
%\description{
%  Computes the (generalized) Akaike \bold{A}n \bold{I}nformation
%  \bold{C}riterion for a fitted parametric model.
%}
%\details{
%  This is a generic function, with methods in base \R for classes
%  \code{"aov"}, \code{"glm"} and \code{"lm"} as well as for
%  \code{"negbin"} (package \CRANpkg{MASS}) and \code{"coxph"} and
%  \code{"survreg"} (package \CRANpkg{survival}).
%
%  The criterion used is
%  \deqn{AIC = - 2\log L +  k \times \mbox{edf},}{AIC = - 2*log L +  k * edf,}
%  where \eqn{L} is the likelihood and \code{edf} the equivalent degrees
%  of freedom (i.e., the number of free parameters for usual parametric
%  models) of \code{fit}.
%
%  For linear models with unknown scale (i.e., for \code{\link{lm}} and
%  \code{\link{aov}}), \eqn{-2\log L}{-2 log L} is computed from the
%  \emph{deviance} and uses a different additive constant to
%  \code{\link{logLik}} and hence \code{\link{AIC}}.  If \eqn{RSS}
%  denotes the (weighted) residual sum of squares then \code{extractAIC}
%  uses for \eqn{- 2\log L}{-2 log L} the formulae \eqn{RSS/s - n} (corresponding
%  to Mallows' \eqn{C_p}{Cp}) in the case of known scale \eqn{s} and
%  \eqn{n \log (RSS/n)}{n log (RSS/n)} for unknown scale.
%  \code{\link{AIC}} only handles unknown scale and uses the formula
%  \eqn{n \log (RSS/n) + n + n \log 2\pi - \sum \log w}{n*log(RSS/n) + n + n*log 2pi - sum(log w)}
%  where \eqn{w} are the weights.  Further \code{AIC} counts the scale
%  estimation as a parameter in the \code{edf} and \code{extractAIC} does not.
%
%  For \code{glm} fits the family's \code{aic()} function is used to
%  compute the AIC: see the note under \code{logLik} about the
%  assumptions this makes.
%
%  \code{k = 2} corresponds to the traditional AIC, using \code{k =
%    log(n)} provides the BIC (Bayesian IC) instead.
%
%  Note that the methods for this function may differ in their
%  assumptions from those of methods for \code{\link{AIC}} (usually
%  \emph{via} a method for \code{\link{logLik}}).  We have already
%  mentioned the case of \code{"lm"} models with estimated scale, and
%  there are similar issues in the \code{"glm"} and \code{"negbin"}
%  methods where the dispersion parameter may or may not be taken as
%  \sQuote{free}.  This is immaterial as \code{extractAIC} is only used
%  to compare models of the same class (where only differences in AIC
%  values are considered).
%}
%\note{
%  This function is used in \code{\link{add1}}, \code{\link{drop1}}
%  and \code{\link{step}} and the similar functions in package
%  \CRANpkg{MASS} from which it was adopted.
%}
%\value{
%  A numeric vector of length 2, with first and second elements giving
%
%  \item{edf}{the \sQuote{\bold{e}quivalent \bold{d}egrees of \bold{f}reedom}
%    for the fitted model \code{fit}.}
%
%  \item{AIC}{the (generalized) Akaike Information Criterion for \code{fit}.}
%}
%%-- Source in ../R/add.R
%\author{B. D. Ripley}
%\references{
%  Venables, W. N. and Ripley, B. D. (2002)
%  \emph{Modern Applied Statistics with S.}
%  New York: Springer (4th ed).
%}
%\seealso{
%  \code{\link{AIC}}, \code{\link{deviance}}, \code{\link{add1}},
%  \code{\link{step}}
%}
%\examples{\donttest{
%utils::example(glm)
%extractAIC(glm.D93)  #>>  5  15.129
%}}
%\keyword{models}
%
%\encoding{UTF-8}
%
