% File src/library/stats/man/factanal.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{factanal}
\alias{factanal}%@%\alias{最尤因子分析}

\title{Factor Analysis}
\description{
  共分散行列やデータ行列に対して最尤因子分析を
  実行する．
}
\usage{
factanal(x, factors, data = NULL, covmat = NULL, n.obs = NA,
         subset, na.action, start = NULL,
         scores = c("none", "regression", "Bartlett"),
         rotation = "varimax", control = NULL, \dots)
}
\arguments{
  \item{x}{公式，数値行列，又は数値行列に変換できるオブジェクト．}
  \item{factors}{当てはめられる因子数．}
  \item{data}{オプションのデータフレーム(又は類似物：
    \code{\link{model.frame}} を見よ)で，
    \code{x} が公式の時だけ使われる．既定では
    変数は \code{environment(formula)} から取られる．}
  \item{covmat}{共分散行列，又は
    \code{\link{cov.wt}} が返すような共分散のリスト．
    勿論相関行列は共分散行列である．}
  \item{n.obs}{観測値数で，
    \code{covmat} が共分散行列ならば使われる．}
  \item{subset}{
     もし \code{x} が行列か公式として使われるならば，
     使われるケースの指定．}
  \item{na.action}{
    もし \code{x} が公式として使われるならば，使われる \code{na.action}．}
  \item{start}{\code{NULL} 又は初期値の行列で，
    各列は一意性の初期集合を与える．}
  \item{scores}{もしあれば，作られるスコアのタイプ．
    既定は無く，
    \code{"regression"} は Thompson のスコア，
    \code{"Bartlett"} は
    Bartlett の重み付き最少二乗スコアを与える．
    部分マッチングによりこれらの名前は短縮化出来る．}
  \item{rotation}{文字列．\code{"none"} か因子を回転するのに使われる
    関数の名前：
    これは負荷行列の最初の引数と共に呼びだされ，
    回転された負荷 \code{loadings} を成分に持つリストか，
    又は単に回転された負荷を返すべきである．}
  \item{control}{制御値のリスト，
    \describe{
      \item{nstart}{\code{start = NULL} ならば試みられる初期値の数．既定値は 1．}
      \item{trace}{論理値．
        実行経過を出力すべきか? 既定値は \code{FALSE}．}
      \item{lower}{最適化の過程での一意性に対する下界．
	正でなければならない．既定値は 0.005．}
      \item{opt}{\code{\link{optim}} の \code{control} 引数に
	渡される制御変数のリスト．}
      \item{rotate}{回転関数に対する追加引数のリスト．}
    }
  }
  \item{\dots}{ \code{control} の成分を
    \code{factanal} への名前付き引数として提供できる．}
}
\details{
  因子分析モデルは
  \deqn{x = \Lambda f + e}
  で，\eqn{p}--\eqn{x} の要素ベクトル，\eqn{p \times k}{p x k}
  の \emph{負荷}行列 \eqn{\Lambda}，\eqn{k}--\emph{スコア}
  \eqn{f} の要素ベクトル，そして \eqn{p}--エラー \eqn{e}
  の要素ベクトル．
  \eqn{x} 以外の成分は全て観測されないが，
  主要な制約はスコアは無相関で単位行列で，
  エラーは分散 \eqn{\Psi}{Psi} で独立，
  \emph{一意性}，である．
  観測値を単位分散にスケール化するのも普通であり，
  この関数でもそうされる．

  このように因子文先は本質的に
  相関行列 \eqn{x} のモデル
  \deqn{\Sigma = \Lambda\Lambda^\prime + \Psi}{\Sigma = \Lambda \Lambda' + \Psi}
  である．\eqn{\Lambda} を直交行列 \eqn{G} を使い \eqn{G \Lambda}
  で置き換えてもモデルは不偏でありある種の未決定性が依然残る．
  そうした行列 \eqn{G} は
  \emph{回転} (この用語は非直交正規行列に対しても使われるものの)と呼ばれる．

  もし \code{covmat} が与えられるとそれが使われる．
  さもなければもしそれが行列ならば \code{x} が使われ，
  もしくは公式 \code{x} で，\code{data} からモデル行列を作るために 
  使われそれが共分散行列を構成するために使われる．
  (公式が応答を持つことは無意味であり，全ての変数は数値でなければならない．)
  一旦共分散行列が見つかるか \code{x} から計算されると，
  それは解析のために相関行列に変換される．この相関係数は
  返り値の成分 \code{correlation} として返される． 

  当てはめは一意性に対する多変量正規性を仮定して
  対数尤度を最大化することでなされる．
  (与えられた一致性に対する最大負荷は
  解析的に求められる：
  Lawley & Maxwell (1971, p.\sspace{}27).)
  \code{start} で与えられる全ての初期値が順に試みられ，
  そして得られた最良の当てはめが使われる．
  もし \code{start = NULL} ならば最初の当てはめは
  \enc{Jöreskog}{Joreskog} (1963) が示唆し
  Lawley & Maxwell (1971, p.\sspace{}31) で与えられている値から
  出発し，それから一意性の値が等しいように無作為に選ばれた
  \code{control$nstart - 1} 個の他の値が試みられる．

  一意性は技術的には
  \eqn{[0, 1]} 中に制限されるが，ゼロに近い値は問題があり，
  最適化は
  下界 \code{control$lower} でなされ，既定値は 0.005 である
  (Lawley & Maxwell, 1971, p.\sspace{}32)．

  スコアはもしデータ行列が与えられ使われた時だけ作られる．
  最初の手法は
  Thomson (1951) の回帰法であり，二番目は
  Bartlett (1937, 8) の重み付き最小二乗法である．
  両者は未観測のスコア
  \eqn{f} を推定する．Thomson の方法は
  (母集団中で)未知の \eqn{f} を \eqn{x} に回帰し
  \deqn{\hat f = \Lambda^\prime \Sigma^{-1} x}{hat f = \Lambda' \Sigma^-1 x}
  を求め，それから右辺にクォンタイルの標本推定値を代入する．
  Bartlett の方法は与えられた\eqn{\Lambda} に対し.
  \eqn{f} の選択に対する標準化誤差の平方和を最小化する．

  もし \code{x} が公式なら標準的な
  \code{NA} 処理がスコアに適用される
  (もし要求されれば)：\code{\link{napredict}} を見よ．

  \code{print} メソッドは結果のパターンに注意を引く
  因子分析の慣例に従う(\code{\link{loadings}} でドキュメント化されている)
  ので，既定の精度は三桁であり，小さな負荷は抑制される．
}
\value{
  クラス \code{"factanal"} のオブジェクトで次の成分を持つ
  \item{loadings}{負荷の行列で各因子に対して一つの列を持つ．
    因子は負荷の二乗和の減少順に並べられ，
    負荷の和が正になるように符号が与えられる．
    これはクラス \code{"loadings"} である：
    その \code{print} メソッドに対しては \code{\link{loadings}} を見よ．}
  \item{uniquenesses}{計算された一意性．}
  \item{correlation}{使われた相関行列．}
  \item{criteria}{最適化の結果：
    規準(負の対数尤度の線形関数)
    の値と使われた繰り返しに関する情報．}
  \item{factors}{引数 \code{factors}．}
  \item{dof}{因子分析モデルの自由度の数．}
  \item{method}{手法：常に \code{"mle"}．}
  \item{rotmat}{もし関連すれば回転行列．}
  \item{scores}{もし要求されればスコアの行列．
    \code{na.action} により除外された値の処理に適用される．}
  \item{n.obs}{利用できるならば観測値数，又は \code{NA}．}
  \item{call}{マッチした呼び出し．}
  \item{na.action}{もし関係すれば．}
  \item{STATISTIC, PVAL}{もし計算可能ならば有意度検定統計量と P 値．}
}

\note{
  因子分析に関しては非常に多くの変種があり
  異なったプログラムの出力を比較するのは困難である．
  更に最尤因子分析に於ける最適化は困難で，
  我々が比較した多くの例ではこの関数が生み出したものより劣る
  結果であった．
  特に，\sQuote{Heywood ケース} (一つ又はそれ以上の
  一意性ががゼロ) であるケースは
  多くのテキストや他のプログラムが信じさせようとしているよりも
  はるかに普通である．
}

\references{
  Bartlett, M. S. (1937) The statistical conception of mental factors.
  \emph{British Journal of Psychology}, \bold{28}, 97--104.

  Bartlett, M. S. (1938) Methods of estimating mental
  factors. \emph{Nature}, \bold{141}, 609--610.

  \enc{Jöreskog}{Joreskog}, K. G. (1963)
  \emph{Statistical Estimation in Factor Analysis.}  Almqvist and Wicksell.

  Lawley, D. N. and Maxwell, A. E. (1971) \emph{Factor Analysis as a
    Statistical Method.} Second edition. Butterworths.

  Thomson, G. H. (1951) \emph{The Factorial Analysis of Human Ability.}
  London University Press.
}

\seealso{
  \code{\link{loadings}}
  (これは \code{print} メソッドの幾つかの詳細を説明する),
  \code{\link{varimax}}, \code{\link{princomp}},
  \code{\link{ability.cov}}, \code{\link{Harman23.cor}},
  \code{\link{Harman74.cor}}.

  他の回転メソッドが
  \CRANpkg{GPArotation} と \CRANpkg{psych}
  を含む様々な貢献パッケージから利用できる．
}

\examples{
# 小さなデモ，v2 は単に雑音を入れた v1，
# そして v4 対 v3 と v6 対 v5 も同様
# 最後の四つのケースは雑音を加えるためにある
# そして正の多様体 (g 因子)
v1 <- c(1,1,1,1,1,1,1,1,1,1,3,3,3,3,3,4,5,6)
v2 <- c(1,2,1,1,1,1,2,1,2,1,3,4,3,3,3,4,6,5)
v3 <- c(3,3,3,3,3,1,1,1,1,1,1,1,1,1,1,5,4,6)
v4 <- c(3,3,4,3,3,1,1,2,1,1,1,1,2,1,1,5,6,4)
v5 <- c(1,1,1,1,1,3,3,3,3,3,1,1,1,1,1,6,4,5)
v6 <- c(1,1,1,2,1,3,3,3,4,3,1,1,1,2,1,6,5,4)
m1 <- cbind(v1,v2,v3,v4,v5,v6)
cor(m1)
factanal(m1, factors = 3) # varimax は既定
\donttest{factanal(m1, factors = 3, rotation = "promax")}
# 次は g 因子を PC1 として示す
\donttest{prcomp(m1) # 符号はプラットフォームに依存}

## 公式インタフェイス
factanal(~v1+v2+v3+v4+v5+v6, factors = 3,
         scores = "Bartlett")$scores

\donttest{## Bartholomew (1987, pp. 61-65) からの現実的な例
utils::example(ability.cov)
}}
\keyword{multivariate}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/factanal.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{factanal}
%\alias{factanal}
%
%\title{Factor Analysis}
%\description{
%  Perform maximum-likelihood factor analysis on a covariance matrix or
%  data matrix.
%}
%\usage{
%factanal(x, factors, data = NULL, covmat = NULL, n.obs = NA,
%         subset, na.action, start = NULL,
%         scores = c("none", "regression", "Bartlett"),
%         rotation = "varimax", control = NULL, \dots)
%}
%\arguments{
%  \item{x}{A formula or a numeric matrix or an object that can be
%    coerced to a numeric matrix.}
%  \item{factors}{The number of factors to be fitted.}
%  \item{data}{An optional data frame (or similar: see
%    \code{\link{model.frame}}), used only if \code{x} is a formula.  By
%    default the variables are taken from \code{environment(formula)}.}
%  \item{covmat}{A covariance matrix, or a covariance list as returned by
%    \code{\link{cov.wt}}.  Of course, correlation matrices are covariance
%    matrices.}
%  \item{n.obs}{The number of observations, used if \code{covmat} is a
%    covariance matrix.}
%  \item{subset}{A specification of the cases to be used, if \code{x} is
%    used as a matrix or formula.}
%  \item{na.action}{The \code{na.action} to be used if \code{x} is
%    used as a formula.}
%  \item{start}{\code{NULL} or a matrix of starting values, each column
%    giving an initial set of uniquenesses.}
%  \item{scores}{Type of scores to produce, if any.  The default is none,
%    \code{"regression"} gives Thompson's scores, \code{"Bartlett"} given
%    Bartlett's weighted least-squares scores. Partial matching allows
%    these names to be abbreviated.}
%  \item{rotation}{character. \code{"none"} or the name of a function
%    to be used to rotate the factors: it will be called with first
%    argument the loadings matrix, and should return a list with component
%    \code{loadings} giving the rotated loadings, or just the rotated loadings.}
%  \item{control}{A list of control values,
%    \describe{
%      \item{nstart}{The number of starting values to be tried if
%        \code{start = NULL}. Default 1.}
%      \item{trace}{logical. Output tracing information? Default \code{FALSE}.}
%      \item{lower}{The lower bound for uniquenesses during
%        optimization. Should be > 0. Default 0.005.}
%      \item{opt}{A list of control values to be passed to
%        \code{\link{optim}}'s \code{control} argument.}
%      \item{rotate}{a list of additional arguments for the rotation function.}
%    }
%  }
%  \item{\dots}{Components of \code{control} can also be supplied as
%    named arguments to \code{factanal}.}
%}
%\details{
%  The factor analysis model is
%  \deqn{x = \Lambda f + e}
%  for a \eqn{p}--element vector \eqn{x}, a \eqn{p \times k}{p x k}
%  matrix \eqn{\Lambda} of \emph{loadings}, a \eqn{k}--element vector
%  \eqn{f} of \emph{scores} and a \eqn{p}--element vector \eqn{e} of
%  errors.  None of the components other than \eqn{x} is observed, but
%  the major restriction is that the scores be uncorrelated and of unit
%  variance, and that the errors be independent with variances
%  \eqn{\Psi}{Psi}, the \emph{uniquenesses}.  It is also common to
%  scale the observed variables to unit variance, and done in this function.
%
%  Thus factor analysis is in essence a model for the correlation matrix
%  of \eqn{x},
%  \deqn{\Sigma = \Lambda\Lambda^\prime + \Psi}{\Sigma = \Lambda \Lambda' + \Psi}
%  There is still some indeterminacy in the model for it is unchanged
%  if \eqn{\Lambda} is replaced by \eqn{G \Lambda} for
%  any orthogonal matrix \eqn{G}.  Such matrices \eqn{G} are known as
%  \emph{rotations} (although the term is applied also to non-orthogonal
%  invertible matrices).
%
%  If \code{covmat} is supplied it is used.  Otherwise \code{x} is used
%  if it is a matrix, or a formula \code{x} is used with \code{data} to
%  construct a model matrix, and that is used to construct a covariance
%  matrix.  (It makes no sense for the formula to have a response, and
%  all the variables must be numeric.)  Once a covariance matrix is found
%  or calculated from \code{x}, it is converted to a correlation matrix
%  for analysis.  The correlation matrix is returned as component
%  \code{correlation} of the result.
%
%  The fit is done by optimizing the log likelihood assuming multivariate
%  normality over the uniquenesses.  (The maximizing loadings for given
%  uniquenesses can be found analytically: Lawley & Maxwell (1971,
%  p.\sspace{}27).)  All the starting values supplied in \code{start} are tried
%  in turn and the best fit obtained is used.  If \code{start = NULL}
%  then the first fit is started at the value suggested by
%  \enc{Jöreskog}{Joreskog} (1963) and given by Lawley & Maxwell
%  (1971, p.\sspace{}31), and then \code{control$nstart - 1} other values are
%  tried, randomly selected as equal values of the uniquenesses.
%
%  The uniquenesses are technically constrained to lie in \eqn{[0, 1]},
%  but near-zero values are problematical, and the optimization is
%  done with a lower bound of \code{control$lower}, default 0.005
%  (Lawley & Maxwell, 1971, p.\sspace{}32).
%
%  Scores can only be produced if a data matrix is supplied and used.
%  The first method is the regression method of Thomson (1951), the
%  second the weighted least squares method of Bartlett (1937, 8).
%  Both are estimates of the unobserved scores \eqn{f}.  Thomson's method
%  regresses (in the population) the unknown \eqn{f} on \eqn{x} to yield
%  \deqn{\hat f = \Lambda^\prime \Sigma^{-1} x}{hat f = \Lambda' \Sigma^-1 x}
%  and then substitutes the sample estimates of the quantities on the
%  right-hand side.  Bartlett's method minimizes the sum of squares of
%  standardized errors over the choice of \eqn{f}, given (the fitted)
%  \eqn{\Lambda}.
%
%  If \code{x} is a formula then the standard \code{NA}-handling is
%  applied to the scores (if requested): see \code{\link{napredict}}.
%
%  The \code{print} method (documented under \code{\link{loadings}})
%  follows the factor analysis convention of drawing attention to the
%  patterns of the results, so the default precision is three decimal
%  places, and small loadings are suppressed.
%}
%\value{
%  An object of class \code{"factanal"} with components
%  \item{loadings}{A matrix of loadings, one column for each factor.  The
%    factors are ordered in decreasing order of sums of squares of
%    loadings, and given the sign that will make the sum of the loadings
%    positive.  This is of class \code{"loadings"}: see
%    \code{\link{loadings}} for its \code{print} method.}
%  \item{uniquenesses}{The uniquenesses computed.}
%  \item{correlation}{The correlation matrix used.}
%  \item{criteria}{The results of the optimization: the value of the
%    criterion (a linear function of the negative log-likelihood) and information on the iterations used.}
%  \item{factors}{The argument \code{factors}.}
%  \item{dof}{The number of degrees of freedom of the factor analysis model.}
%  \item{method}{The method: always \code{"mle"}.}
%  \item{rotmat}{The rotation matrix if relevant.}
%  \item{scores}{If requested, a matrix of scores.  \code{napredict} is
%    applied to handle the treatment of values omitted by the \code{na.action}.}
%  \item{n.obs}{The number of observations if available, or \code{NA}.}
%  \item{call}{The matched call.}
%  \item{na.action}{If relevant.}
%  \item{STATISTIC, PVAL}{The significance-test statistic and P value, if
%    it can be computed.}
%}
%
%\note{
%  There are so many variations on factor analysis that it is hard to
%  compare output from different programs.  Further, the optimization in
%  maximum likelihood factor analysis is hard, and many other examples we
%  compared had less good fits than produced by this function.  In
%  particular, solutions which are \sQuote{Heywood cases} (with one or more
%  uniquenesses essentially zero) are much more common than most texts
%  and some other programs would lead one to believe.
%}
%
%\references{
%  Bartlett, M. S. (1937) The statistical conception of mental factors.
%  \emph{British Journal of Psychology}, \bold{28}, 97--104.
%
%  Bartlett, M. S. (1938) Methods of estimating mental
%  factors. \emph{Nature}, \bold{141}, 609--610.
%
%  \enc{Jöreskog}{Joreskog}, K. G. (1963)
%  \emph{Statistical Estimation in Factor Analysis.}  Almqvist and Wicksell.
%
%  Lawley, D. N. and Maxwell, A. E. (1971) \emph{Factor Analysis as a
%    Statistical Method.} Second edition. Butterworths.
%
%  Thomson, G. H. (1951) \emph{The Factorial Analysis of Human Ability.}
%  London University Press.
%}
%
%\seealso{
%  \code{\link{loadings}} (which explains some details of the
%  \code{print} method), \code{\link{varimax}}, \code{\link{princomp}},
%  \code{\link{ability.cov}}, \code{\link{Harman23.cor}},
%  \code{\link{Harman74.cor}}.
%
%  Other rotation methods are available in various contributed packages,
%  including \CRANpkg{GPArotation} and \CRANpkg{psych}.
%}
%
%\examples{
%# A little demonstration, v2 is just v1 with noise,
%# and same for v4 vs. v3 and v6 vs. v5
%# Last four cases are there to add noise
%# and introduce a positive manifold (g factor)
%v1 <- c(1,1,1,1,1,1,1,1,1,1,3,3,3,3,3,4,5,6)
%v2 <- c(1,2,1,1,1,1,2,1,2,1,3,4,3,3,3,4,6,5)
%v3 <- c(3,3,3,3,3,1,1,1,1,1,1,1,1,1,1,5,4,6)
%v4 <- c(3,3,4,3,3,1,1,2,1,1,1,1,2,1,1,5,6,4)
%v5 <- c(1,1,1,1,1,3,3,3,3,3,1,1,1,1,1,6,4,5)
%v6 <- c(1,1,1,2,1,3,3,3,4,3,1,1,1,2,1,6,5,4)
%m1 <- cbind(v1,v2,v3,v4,v5,v6)
%cor(m1)
%factanal(m1, factors = 3) # varimax is the default
%\donttest{factanal(m1, factors = 3, rotation = "promax")}
%# The following shows the g factor as PC1
%\donttest{prcomp(m1) # signs may depend on platform}
%
%## formula interface
%factanal(~v1+v2+v3+v4+v5+v6, factors = 3,
%         scores = "Bartlett")$scores
%
%\donttest{## a realistic example from Bartholomew (1987, pp. 61-65)
%utils::example(ability.cov)
%}}
%\keyword{multivariate}
%
%\encoding{UTF-8}
%
