% File src/library/stats/man/ls.diag.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{ls.diag}
\title{Compute Diagnostics for \code{lsfit} Regression Results}
\usage{
ls.diag(ls.out)
}
\alias{ls.diag}%@%\alias{lsfit による回帰結果の診断を計算}
\arguments{
  \item{ls.out}{典型的に \code{\link{lsfit}()} の計算結果．}
}
\description{
  回帰係数に対する標準偏差 t と p 値を含む基本統計量を計算する．
}
\value{
  次の数値成分を含むリスト．
  \item{std.dev}{誤差の標準偏差，\eqn{\sigma} の推定値．}
  \item{hat}{ハット行列 \eqn{H} の対角要素 \eqn{h_{ii}}．}
  \item{std.res}{標準化残差．}
  \item{stud.res}{スチューデント化残差．}
  \item{cooks}{Cook の距離．}
  \item{dfits}{DFITS 統計量．}
  \item{correlation}{相関行列．}
  \item{std.err}{回帰係数の標準誤差．}
  \item{cov.scaled}{係数のスケール化共分散行列．}
  \item{cov.unscaled}{係数のスケール化されていない共分散行列．}
}
\references{
  Belsley, D. A., Kuh, E. and Welsch, R. E. (1980)
  \emph{Regression Diagnostics.}
  New York: Wiley.
}
\seealso{
  ハット行列の対角成分には \code{\link{hat}}，
  \code{\link{ls.print}},
  \code{\link{lm.influence}}, \code{\link{summary.lm}},
  \code{\link{anova}}.
}
\examples{\donttest{
\dontshow{utils::example("lm", echo = FALSE)}
##-- lm(.) の例と同じデータを使う：
lsD9 <- lsfit(x = as.numeric(gl(2, 10, 20)), y = weight)
dlsD9 <- ls.diag(lsD9)
utils::str(dlsD9, give.attr = FALSE)
abs(1 - sum(dlsD9$hat) / 2) < 10*.Machine$double.eps # sum(h.ii) = p
plot(dlsD9$hat, dlsD9$stud.res, xlim = c(0, 0.11))
abline(h = 0, lty = 2, col = "lightgray")
}}
\keyword{regression}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/ls.diag.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{ls.diag}
%\title{Compute Diagnostics for \code{lsfit} Regression Results}
%\usage{
%ls.diag(ls.out)
%}
%\alias{ls.diag}
%\arguments{
%  \item{ls.out}{Typically the result of \code{\link{lsfit}()}}
%}
%\description{
%  Computes basic statistics, including standard errors, t- and p-values
%  for the regression coefficients.
%}
%\value{
%  A \code{list} with the following numeric components.
%  \item{std.dev}{The standard deviation of the errors, an estimate of
%    \eqn{\sigma}.}
%  \item{hat}{diagonal entries \eqn{h_{ii}} of the hat matrix \eqn{H}}
%  \item{std.res}{standardized residuals}
%  \item{stud.res}{studentized residuals}
%  \item{cooks}{Cook's distances}
%  \item{dfits}{DFITS statistics}
%  \item{correlation}{correlation matrix}
%  \item{std.err}{standard errors of the regression coefficients}
%  \item{cov.scaled}{Scaled covariance matrix of the coefficients}
%  \item{cov.unscaled}{Unscaled covariance matrix of the coefficients}
%}
%\references{
%  Belsley, D. A., Kuh, E. and Welsch, R. E. (1980)
%  \emph{Regression Diagnostics.}
%  New York: Wiley.
%}
%\seealso{
%  \code{\link{hat}} for the hat matrix diagonals,
%  \code{\link{ls.print}},
%  \code{\link{lm.influence}}, \code{\link{summary.lm}},
%  \code{\link{anova}}.
%}
%\examples{\donttest{
%\dontshow{utils::example("lm", echo = FALSE)}
%##-- Using the same data as the lm(.) example:
%lsD9 <- lsfit(x = as.numeric(gl(2, 10, 20)), y = weight)
%dlsD9 <- ls.diag(lsD9)
%utils::str(dlsD9, give.attr = FALSE)
%abs(1 - sum(dlsD9$hat) / 2) < 10*.Machine$double.eps # sum(h.ii) = p
%plot(dlsD9$hat, dlsD9$stud.res, xlim = c(0, 0.11))
%abline(h = 0, lty = 2, col = "lightgray")
%}}
%\keyword{regression}
%
%\encoding{UTF-8}
%
