% File src/library/stats/man/mantelhaen.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2008 R Core Team
% Distributed under GPL 2 or later

\name{mantelhaen.test}
\alias{mantelhaen.test}
%@%\alias{計数データに対する Cochran-Mantel-Haenszel カイ二乗検定}
\title{Cochran-Mantel-Haenszel Chi-Squared Test for Count Data}
\description{
  二つの質的データが各層で条件付き独立であるという
  帰無仮説の Cochran-Mantel-Haenszel カイ二乗検定を
  三元の交互作用が無いことを仮定し実行する．
}
\usage{
mantelhaen.test(x, y = NULL, z = NULL,
                alternative = c("two.sided", "less", "greater"),
                correct = TRUE, exact = FALSE, conf.level = 0.95)
}
\arguments{
  \item{x}{配列形式の3元分割表で各次元は少なくとも2で最後の次元が
    層に対応する，もしくは少なくとも2水準を持つ因子オブジェクト．}
  \item{y}{少なくとも2水準を持つ因子オブジェクト；
    もし \code{x} が配列なら無視される．}
  \item{z}{少なくとも2水準を持つ因子オブジェクで，
    \code{x} と \code{y} 中の対応する要素がどの層に属するかを
    特定する；
    もし \code{x} が配列ならば無視される．}
  \item{alternative}{対立仮説を指示し，
    \code{"two.sided"}, \code{"greater"} 又は \code{"less"} の
    どれかでなければならない．頭文字だけを指定すれば良い．
    2 x 2 x \eqn{K} ケースでだけ使われる．}
  \item{correct}{
    検定統計量を計算する時連続補正を適用するかどうかを
    指示する論理値．
    2 x 2 x \eqn{K} ケースでだけ使われる．}
  \item{exact}{
    Mantel-Haenszel 検定か(層マージンを与えた)正確な条件付き検定
    を計算するかを指示する論理値．
    2 x 2 x \eqn{K} ケースでだけ使われる．}
  \item{conf.level}{
    返される信頼区間に対する信頼水準．
    2 x 2 x \eqn{K} ケースでだけ使われる．}
}
\value{
  クラス \code{"htest"} のりストで次の成分を含む：
  \item{statistic}{正確な検定が実行されない時だけ存在する．
    古典的な 2 x y x \eqn{K} 表では(つまり基礎にある変数の
    二分割) Mantel-Haenszel カイ二乗統計量；
    さもなければ一般化 Cochran-Mantel-Haenszel 統計量．}
  \item{parameter}{近似カイ二乗分布の自由度
    (古典絵的なケースでは \eqn{1})．
    正確な検定が実行されない時だけ存在する．}
  \item{p.value}{検定の p 値．}
  \item{conf.int}{共通のオッズ比に対する信頼区間．
    正確な検定が実行されない時だけ存在する．}
  \item{estimate}{共通のオッズ比の推定値．
    もし正確検定が実行されると，
    条件付き最尤推定値が与えられる；さもなければ
    Mantel-Haenszel 推定値．
    正確な検定が実行されない時だけ存在する．}
  \item{null.value}{独立性の帰無仮説の下での共通オッズ比，\code{1}．
    正確な検定が実行されない時だけ存在する．}
  \item{alternative}{対立仮説を記述する文字列．
    正確な検定が実行されない時だけ存在する．}
  \item{method}{使われた手法と
    そして連続補正が使われたかどうかを
    を指示する文字列．}
  \item{data.name}{データの名前を与える文字列．}
}
\details{
  もし \code{x} が配列ならば，各次元は少なくとも2でなければならず，
  そして項目は非負整数でなければならない．
  \code{NA} は許されない．
  さもなければ \code{x}, \code{y} そして \code{z}
  は同じ長さでなければならない．
  \code{NA} を含む三つ組は取り除かれる．
  全ての変数は少なくとも異なる値を二つは取らなければならない．
}
\note{
  漸近分布は3元の相互作用が無い時だけ適正である．
  古典的な 2 x 2 x \eqn{K} ケースではこれは
  各層における条件付きオッズ比が等しいことに同値である．
  現在オッズ比の等質性に対する如何なる推測もされない．

  下の例も見よ．
}
\references{
  Alan Agresti (1990).
  \emph{Categorical data analysis}.
  New York: Wiley.
  Pages 230--235.

  Alan Agresti (2002).
  \emph{Categorical data analysis} (second edition).
  New York: Wiley.
}
\examples{
## Agresti (1990), pages 231--237, ペニシリンとうさぎ
## ベータ溶血性連鎖球菌の致死量の注射からうさぎを守る
## 直後と1.5時間遅れたペニシリン注射の効果の調査
Rabbits <-
array(c(0, 0, 6, 5,
        3, 0, 3, 6,
        6, 2, 0, 4,
        5, 6, 1, 0,
        2, 5, 0, 0),
      dim = c(2, 2, 5),
      dimnames = list(
          Delay = c("None", "1.5h"),
          Response = c("Cured", "Died"),
          Penicillin.Level = c("1/8", "1/4", "1/2", "1", "4")))
Rabbits
## 古典的な Mantel-Haenszel 検定
mantelhaen.test(Rabbits)
## => p = 0.047, 直後の注射のより高い治癒率の幾らかの証拠
## 正確な条件付き検定
mantelhaen.test(Rabbits, exact = TRUE)
## => p - 0.040
## 直後の注射に対するより高い治癒率という片側対立仮説の正確な条件付き検定
mantelhaen.test(Rabbits, exact = TRUE, alternative = "greater")
## => p = 0.020

## UC Berkeley 校の志願者の合否データ
mantelhaen.test(UCBAdmissions)
## 学部ごとに補正した際，合否と性別の関連には証拠はない
## しかしながら
apply(UCBAdmissions, 3, function(x) (x[1,1]*x[2,2])/(x[1,2]*x[2,1]))
## これは(条件付きの)等質的なオッズ比の仮定が満たされないことを示唆する
## 伝統的なアプローチは交互作用に対する Woolf 検定を使う：
woolf <- function(x) {
  x <- x + 1 / 2
  k <- dim(x)[3]
  or <- apply(x, 3, function(x) (x[1,1]*x[2,2])/(x[1,2]*x[2,1]))
  w <-  apply(x, 3, function(x) 1 / sum(1 / x))
  1 - pchisq(sum(w * (log(or) - weighted.mean(log(or), w)) ^ 2), k - 1)
}
woolf(UCBAdmissions)
## => p = 0.003, 相当な異質性があることを示す．
## (従って Mantel-Haenszel 検定は使えない．)

## Agresti (2002), p. 287f and p. 297.
## 仕事に対する満足度の例．
Satisfaction <-
    as.table(array(c(1, 2, 0, 0, 3, 3, 1, 2,
                     11, 17, 8, 4, 2, 3, 5, 2,
                     1, 0, 0, 0, 1, 3, 0, 1,
                     2, 5, 7, 9, 1, 1, 3, 6),
                   dim = c(4, 4, 2),
                   dimnames =
                   list(Income =
                        c("<5000", "5000-15000",
                          "15000-25000", ">25000"),
                        "Job Satisfaction" =
                        c("V_D", "L_S", "M_S", "V_S"),
                        Gender = c("Female", "Male"))))
## (満足カテゴリーは便宜上略記．)
ftable(. ~ Gender + Income, Satisfaction)
## Agresti (2002), p. 288 中の表 7.8．
mantelhaen.test(Satisfaction)
## Agresti (2002), p. 297 の表 7.12 を見よ．
}
\keyword{htest}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/mantelhaen.test.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2008 R Core Team
%% Distributed under GPL 2 or later
%
%\name{mantelhaen.test}
%\alias{mantelhaen.test}
%\title{Cochran-Mantel-Haenszel Chi-Squared Test for Count Data}
%\description{
%  Performs a Cochran-Mantel-Haenszel chi-squared test of the null that
%  two nominal variables are conditionally independent in each stratum,
%  assuming that there is no three-way interaction.
%}
%\usage{
%mantelhaen.test(x, y = NULL, z = NULL,
%                alternative = c("two.sided", "less", "greater"),
%                correct = TRUE, exact = FALSE, conf.level = 0.95)
%}
%\arguments{
%  \item{x}{either a 3-dimensional contingency table in array form where
%    each dimension is at least 2 and the last dimension corresponds to
%    the strata, or a factor object with at least 2 levels.}
%  \item{y}{a factor object with at least 2 levels; ignored if \code{x}
%    is an array.}
%  \item{z}{a factor object with at least 2 levels identifying to which
%    stratum the corresponding elements in \code{x} and \code{y} belong;
%    ignored if \code{x} is an array.}
%  \item{alternative}{indicates the alternative hypothesis and must be
%    one of \code{"two.sided"}, \code{"greater"} or \code{"less"}.
%    You can specify just the initial letter.
%    Only used in the 2 by 2 by \eqn{K} case.}
%  \item{correct}{a logical indicating whether to apply continuity
%    correction when computing the test statistic.
%    Only used in the 2 by 2 by \eqn{K} case.}
%  \item{exact}{a logical indicating whether the Mantel-Haenszel test or
%    the exact conditional test (given the strata margins) should be
%    computed.
%    Only used in the 2 by 2 by \eqn{K} case.}
%  \item{conf.level}{confidence level for the returned confidence
%    interval.
%    Only used in the 2 by 2 by \eqn{K} case.}
%}
%\value{
%  A list with class \code{"htest"} containing the following components:
%  \item{statistic}{Only present if no exact test is performed.  In the
%    classical case of a 2 by 2 by \eqn{K} table (i.e., of dichotomous
%    underlying variables), the Mantel-Haenszel chi-squared statistic;
%    otherwise, the generalized Cochran-Mantel-Haenszel statistic.}
%  \item{parameter}{the degrees of freedom of the approximate chi-squared
%    distribution of the test statistic (\eqn{1} in the classical case).
%    Only present if no exact test is performed.}
%  \item{p.value}{the p-value of the test.}
%  \item{conf.int}{a confidence interval for the common odds ratio.
%    Only present in the 2 by 2 by \eqn{K} case.}
%  \item{estimate}{an estimate of the common odds ratio.  If an exact
%    test is performed, the conditional Maximum Likelihood Estimate is
%    given; otherwise, the Mantel-Haenszel estimate.
%    Only present in the 2 by 2 by \eqn{K} case.}
%  \item{null.value}{the common odds ratio under the null of
%    independence, \code{1}.
%    Only present in the 2 by 2 by \eqn{K} case.}
%  \item{alternative}{a character string describing the alternative
%    hypothesis.
%    Only present in the 2 by 2 by \eqn{K} case.}
%  \item{method}{a character string indicating the method employed, and whether
%    or not continuity correction was used.}
%  \item{data.name}{a character string giving the names of the data.}
%}
%\details{
%  If \code{x} is an array, each dimension must be at least 2, and
%  the entries should be nonnegative integers.  \code{NA}'s are not
%  allowed.  Otherwise, \code{x}, \code{y} and \code{z} must have the
%  same length.  Triples containing \code{NA}'s are removed.  All
%  variables must take at least two different values.
%}
%\note{
%  The asymptotic distribution is only valid if there is no three-way
%  interaction.  In the classical 2 by 2 by \eqn{K} case, this is
%  equivalent to the conditional odds ratios in each stratum being
%  identical.  Currently, no inference on homogeneity of the odds ratios
%  is performed.
%
%  See also the example below.
%}
%\references{
%  Alan Agresti (1990).
%  \emph{Categorical data analysis}.
%  New York: Wiley.
%  Pages 230--235.
%
%  Alan Agresti (2002).
%  \emph{Categorical data analysis} (second edition).
%  New York: Wiley.
%}
%\examples{
%## Agresti (1990), pages 231--237, Penicillin and Rabbits
%## Investigation of the effectiveness of immediately injected or 1.5
%##  hours delayed penicillin in protecting rabbits against a lethal
%##  injection with beta-hemolytic streptococci.
%Rabbits <-
%array(c(0, 0, 6, 5,
%        3, 0, 3, 6,
%        6, 2, 0, 4,
%        5, 6, 1, 0,
%        2, 5, 0, 0),
%      dim = c(2, 2, 5),
%      dimnames = list(
%          Delay = c("None", "1.5h"),
%          Response = c("Cured", "Died"),
%          Penicillin.Level = c("1/8", "1/4", "1/2", "1", "4")))
%Rabbits
%## Classical Mantel-Haenszel test
%mantelhaen.test(Rabbits)
%## => p = 0.047, some evidence for higher cure rate of immediate
%##               injection
%## Exact conditional test
%mantelhaen.test(Rabbits, exact = TRUE)
%## => p - 0.040
%## Exact conditional test for one-sided alternative of a higher
%## cure rate for immediate injection
%mantelhaen.test(Rabbits, exact = TRUE, alternative = "greater")
%## => p = 0.020
%
%## UC Berkeley Student Admissions
%mantelhaen.test(UCBAdmissions)
%## No evidence for association between admission and gender
%## when adjusted for department.  However,
%apply(UCBAdmissions, 3, function(x) (x[1,1]*x[2,2])/(x[1,2]*x[2,1]))
%## This suggests that the assumption of homogeneous (conditional)
%## odds ratios may be violated.  The traditional approach would be
%## using the Woolf test for interaction:
%woolf <- function(x) {
%  x <- x + 1 / 2
%  k <- dim(x)[3]
%  or <- apply(x, 3, function(x) (x[1,1]*x[2,2])/(x[1,2]*x[2,1]))
%  w <-  apply(x, 3, function(x) 1 / sum(1 / x))
%  1 - pchisq(sum(w * (log(or) - weighted.mean(log(or), w)) ^ 2), k - 1)
%}
%woolf(UCBAdmissions)
%## => p = 0.003, indicating that there is significant heterogeneity.
%## (And hence the Mantel-Haenszel test cannot be used.)
%
%## Agresti (2002), p. 287f and p. 297.
%## Job Satisfaction example.
%Satisfaction <-
%    as.table(array(c(1, 2, 0, 0, 3, 3, 1, 2,
%                     11, 17, 8, 4, 2, 3, 5, 2,
%                     1, 0, 0, 0, 1, 3, 0, 1,
%                     2, 5, 7, 9, 1, 1, 3, 6),
%                   dim = c(4, 4, 2),
%                   dimnames =
%                   list(Income =
%                        c("<5000", "5000-15000",
%                          "15000-25000", ">25000"),
%                        "Job Satisfaction" =
%                        c("V_D", "L_S", "M_S", "V_S"),
%                        Gender = c("Female", "Male"))))
%## (Satisfaction categories abbreviated for convenience.)
%ftable(. ~ Gender + Income, Satisfaction)
%## Table 7.8 in Agresti (2002), p. 288.
%mantelhaen.test(Satisfaction)
%## See Table 7.12 in Agresti (2002), p. 297.
%}
%\keyword{htest}
%
%\encoding{UTF-8}
%
