% File src/library/stats/man/na.fail.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2007 R Core Team
% Distributed under GPL 2 or later

\name{na.fail}
\alias{na.fail}%@%\alias{欠損値を処理する関数}
\alias{na.fail.default}
\alias{na.omit}
\alias{na.omit.data.frame}
\alias{na.omit.default}
\alias{na.exclude}
\alias{na.exclude.data.frame}
\alias{na.exclude.default}
\alias{na.pass}
\title{Handle Missing Values in Objects}
\usage{
na.fail(object, \dots)
na.omit(object, \dots)
na.exclude(object, \dots)
na.pass(object, \dots)
}
\arguments{
  \item{object}{\R オブジェクト，典型的にはデータフレーム．}
  \item{\dots}{特別なメソッドが必要とするかもしれない追加引数．}
}
\description{
  これらの総称的関数は例えばデータが中の
  \code{\link{NA}} 値を処理するのに役立つ．
  \code{na.fail} はもしそれが欠損値を含まなければオブジェクトを返し，
  さもなければエラー信号を発生する．
  \code{na.omit} は不完全なケースを取り除いたオブジェクトを返す．
  \code{na.pass} はオブジェクトを未変更で返す．
}
\details{
  現在これらはベクトル，行列，そしてベクトルと行列(だけ)からなるデータフレーム
  を処理する．

  もし \code{na.omit} がケースを取り除けば，ケースの行番号は
  クラス \code{"omit"} である結果の \code{"na.action"} 属性を作る．

  \code{na.exclude} は \code{na.omit} と結果の
  \code{"na.action"} 属性に於いてだけ異なり，\code{"exclude"} である．
  これは
  \code{\link{naresid}} と \code{\link{napredict}} を利用する関数中の
  挙動が異なる：\code{na.exclude} が使われると残差と予測値は
  \code{na.exclude} で取り除かれたケースに
  \code{NA} を挿入して埋められる．
  
}
\references{
  Chambers, J. M. and Hastie, T. J. (1992)
  \emph{Statistical Models in S.}
  Wadsworth & Brooks/Cole.
}
\seealso{
  \code{\link{na.action}};
  NA 行動の設定には引数 \code{na.action} を持つ \code{\link{options}}；
  そしてこれらを使う関数に対しては \code{\link{lm}} と \code{\link{glm}}．
  時系列に対する代替物は \code{\link{na.contiguous}}．
}
\examples{
DF <- data.frame(x = c(1, 2, 3), y = c(0, 10, NA))
na.omit(DF)
m <- as.matrix(DF)
na.omit(m)
stopifnot(all(na.omit(1:3) == 1:3))  # NA を持たないオブジェクトには無影響
try(na.fail(DF))   #> Error: missing values in ...

options("na.action")
}
\keyword{NA}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/na.fail.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2007 R Core Team
%% Distributed under GPL 2 or later
%
%\name{na.fail}
%\alias{na.fail}
%\alias{na.fail.default}
%\alias{na.omit}
%\alias{na.omit.data.frame}
%\alias{na.omit.default}
%\alias{na.exclude}
%\alias{na.exclude.data.frame}
%\alias{na.exclude.default}
%\alias{na.pass}
%\title{Handle Missing Values in Objects}
%\usage{
%na.fail(object, \dots)
%na.omit(object, \dots)
%na.exclude(object, \dots)
%na.pass(object, \dots)
%}
%\arguments{
%  \item{object}{an \R object, typically a data frame}
%  \item{\dots}{further arguments special methods could require.}
%}
%\description{
%  These generic functions are useful for dealing with \code{\link{NA}}s
%  in e.g., data frames.
%  \code{na.fail} returns the object if it does not contain any
%  missing values, and signals an error otherwise.
%  \code{na.omit} returns the object with incomplete cases removed.
%  \code{na.pass} returns the object unchanged.
%}
%\details{
%  At present these will handle vectors, matrices and data frames
%  comprising vectors and matrices (only).
%
%  If \code{na.omit} removes cases, the row numbers of the cases form the
%  \code{"na.action"} attribute of the result, of class \code{"omit"}.
%
%  \code{na.exclude} differs from \code{na.omit} only in the class of the
%  \code{"na.action"} attribute of the result, which is
%  \code{"exclude"}.  This gives different behaviour in functions making
%  use of \code{\link{naresid}} and \code{\link{napredict}}: when
%  \code{na.exclude} is used the residuals and predictions are padded to
%  the correct length by inserting \code{NA}s for cases omitted by
%  \code{na.exclude}.
%}
%\references{
%  Chambers, J. M. and Hastie, T. J. (1992)
%  \emph{Statistical Models in S.}
%  Wadsworth & Brooks/Cole.
%}
%\seealso{
%  \code{\link{na.action}};
%  \code{\link{options}} with argument \code{na.action} for setting NA actions;
%  and \code{\link{lm}} and \code{\link{glm}} for functions using these.
%  \code{\link{na.contiguous}} as alternative for time series.
%}
%\examples{
%DF <- data.frame(x = c(1, 2, 3), y = c(0, 10, NA))
%na.omit(DF)
%m <- as.matrix(DF)
%na.omit(m)
%stopifnot(all(na.omit(1:3) == 1:3))  # does not affect objects with no NA's
%try(na.fail(DF))   #> Error: missing values in ...
%
%options("na.action")
%}
%\keyword{NA}
%
%\encoding{UTF-8}
%
