% File src/library/stats/man/oneway.test.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{oneway.test}
\alias{oneway.test}%@%\alias{一元配置の平均の同等性の検定}
\title{Test for Equal Means in a One-Way Layout}
\description{
  二つ以上の正規分布からの標本が同じ平均を持つかどうか検定する．
  分散は必ずしも等しくなくて良い．
}
\usage{
oneway.test(formula, data, subset, na.action, var.equal = FALSE)
}
\arguments{
  \item{formula}{
    形式 \code{lhs ~ rhs} の公式．ここで \code{lhs}
    は標本値を与え，\code{rhs} は対応するグループを与える．}
  \item{data}{オプションの行列かデータフレーム
    (又は類似物：\code{\link{model.frame}} を見よ)で
    公式 \code{formula} 中の変数を含む．既定では変数は
    \code{environment(formula)} から取られる．}
  \item{subset}{使われる観測値の部分集合を与えるオプションのベクトル．}
  \item{na.action}{
    データが \code{NA} 値を含む時何が起こるかを指示する関数．
    既定では\cr
    \code{getOption("na.action")}．}
  \item{var.equal}{
    標本の分散が等しいとして処理するかどうかを指示する論理値．
    もし \code{TRUE} なら，一元配置分散分析の平均の同等性の単純な
    F 検定が実行される．
    もし \code{FALSE} ならば，
    Welch (1951) の近似法が使われる．
    これは既知の二標本 Welch 検定を品位個数の標本に一般化したものである．}  
}
\value{
  クラス \code{"htest"} のリストで次の成分を含む：
  \item{statistic}{検定統計量の値．}
  \item{parameter}{検定統計量の正確か近似 F 分布の自由度．}
  \item{p.value}{検定の p 値．}
  \item{method}{実行された検定を指示する文字列．}
  \item{data.name}{データの名前を与える文字列．}
}
\details{
  もし公式の右辺が二つ以上の項を含めば，
  それらの交互作用はグルーピングを形作るとされる．
}
\references{
  B. L. Welch (1951),
  On the comparison of several mean values: an alternative approach.
  \emph{Biometrika}, \bold{38}, 330--336.
}
\seealso{
  二標本に対する特殊例としての標準 t 検定(\code{\link{t.test}})；
  一元配置の位置パラメータの同一性に対する
  ノンパラメトリック検定の Kruskal-Wallis 検定 \code{\link{kruskal.test}}．
}
\examples{
## 等しい分散を仮定しない
oneway.test(extra ~ group, data = sleep)
## 等しい分散を仮定する
oneway.test(extra ~ group, data = sleep, var.equal = TRUE)
## これは次と同じ結果を与える
anova(lm(extra ~ group, data = sleep))
}
\keyword{htest}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/oneway.test.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{oneway.test}
%\alias{oneway.test}
%\title{Test for Equal Means in a One-Way Layout}
%\description{
%  Test whether two or more samples from normal distributions have the
%  same means.  The variances are not necessarily assumed to be equal.
%}
%\usage{
%oneway.test(formula, data, subset, na.action, var.equal = FALSE)
%}
%\arguments{
%  \item{formula}{a formula of the form \code{lhs ~ rhs} where \code{lhs}
%    gives the sample values and \code{rhs} the corresponding groups.}
%  \item{data}{an optional matrix or data frame (or similar: see
%    \code{\link{model.frame}}) containing the variables in the
%    formula \code{formula}.  By default the variables are taken from
%    \code{environment(formula)}.}
%  \item{subset}{an optional vector specifying a subset of observations
%    to be used.}
%  \item{na.action}{a function which indicates what should happen when
%    the data contain \code{NA}s.  Defaults to
%    \code{getOption("na.action")}.}
%  \item{var.equal}{a logical variable indicating whether to treat the
%    variances in the samples as equal.  If \code{TRUE}, then a simple F
%    test for the equality of means in a one-way analysis of variance is
%    performed.  If \code{FALSE}, an approximate method of Welch (1951)
%    is used, which generalizes the commonly known 2-sample Welch test to
%    the case of arbitrarily many samples.}
%}
%\value{
%  A list with class \code{"htest"} containing the following components:
%  \item{statistic}{the value of the test statistic.}
%  \item{parameter}{the degrees of freedom of the exact or approximate F
%    distribution of the test statistic.}
%  \item{p.value}{the p-value of the test.}
%  \item{method}{a character string indicating the test performed.}
%  \item{data.name}{a character string giving the names of the data.}
%}
%\details{
%  If the right-hand side of the formula contains more than one term,
%  their interaction is taken to form the grouping.
%}
%\references{
%  B. L. Welch (1951),
%  On the comparison of several mean values: an alternative approach.
%  \emph{Biometrika}, \bold{38}, 330--336.
%}
%\seealso{
%  The standard t test (\code{\link{t.test}}) as the special case for two
%  samples;
%  the Kruskal-Wallis test \code{\link{kruskal.test}} for a nonparametric
%  test for equal location parameters in a one-way layout.
%}
%\examples{
%## Not assuming equal variances
%oneway.test(extra ~ group, data = sleep)
%## Assuming equal variances
%oneway.test(extra ~ group, data = sleep, var.equal = TRUE)
%## which gives the same result as
%anova(lm(extra ~ group, data = sleep))
%}
%\keyword{htest}
%
%\encoding{UTF-8}
%
