% File src/library/stats/man/plot.HoltWinters.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2009 R Core Team
% Distributed under GPL 2 or later

\name{plot.HoltWinters}
\alias{plot.HoltWinters}%@%\alias{ホルト・ウィンターオブエクトのプロット}
\title{Plot function for HoltWinters objects}
\description{
  当てはめ値を伴うオリジナルの時系列のプロットを作る．
  オプションで予測値(とそれらの信頼区間)もプロットできる．
}
\usage{
\method{plot}{HoltWinters}(x, predicted.values = NA, intervals = TRUE,
        separator = TRUE, col = 1, col.predicted = 2,
        col.intervals = 4, col.separator = 1, lty = 1,
        lty.predicted = 1, lty.intervals = 1, lty.separator = 3,
        ylab = "Observed / Fitted",
        main = "Holt-Winters filtering",
        ylim = NULL, \dots)
}
\arguments{
  \item{x}{クラス \code{"HoltWinters"} のオブジェクト．}
  \item{predicted.values}{
    \code{predict.HoltWinters}により返されるような予測値．}
  \item{intervals}{もし \code{TRUE} ならば
    予測値がプロットされる(既定)．}
  \item{separator}{もし \code{TRUE} ならば
    当てはめ地と予測値を分離する線がプロットされる(既定)．}
  \item{col, lty}{オリジナルのデータの色/線種 (既定：黒の実線)．}
  \item{col.predicted, lty.predicted}{
    当てはめ値と予測値の色/線種 (既定：赤の実線)．}
  \item{col.intervals, lty.intervals}{
    予測区間の色/線種 (既定：青の実線)．}
  \item{col.separator, lty.separator}{
    観測値/予測値の分離線の色/線種 (既定：黒のダッシュ)．}
  \item{ylab}{y 軸のラベル．}
  \item{main}{主タイトル．}
  \item{ylim}{y 軸の限界．もし \code{NULL} なら，
    範囲はプロットがオリジナル時系列，当てはめ値，そして
    予測値を含むように選ばれる．}
  \item{\dots}{他のグラフィックスパラメータ．}
}
\references{
  C. C. Holt (1957)
  Forecasting trends and seasonals by exponentially weighted
  moving averages,
  \emph{ONR Research Memorandum, Carnegie Institute of Technology} \bold{52}.

  P. R. Winters (1960)
  Forecasting sales by exponentially weighted moving averages,
  \emph{Management Science} \bold{6}, 324--342.
}
\author{
  David Meyer \email{David.Meyer@wu.ac.at}
}
\seealso{
  \code{\link{HoltWinters}}, \code{\link{predict.HoltWinters}}
}

\keyword{ts}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/plot.HoltWinters.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2009 R Core Team
%% Distributed under GPL 2 or later
%
%\name{plot.HoltWinters}
%\alias{plot.HoltWinters}
%\title{Plot function for HoltWinters objects}
%\description{
%  Produces a chart of the original time series along with the fitted
%  values. Optionally, predicted values (and their confidence bounds) can
%  also be plotted.
%}
%\usage{
%\method{plot}{HoltWinters}(x, predicted.values = NA, intervals = TRUE,
%        separator = TRUE, col = 1, col.predicted = 2,
%        col.intervals = 4, col.separator = 1, lty = 1,
%        lty.predicted = 1, lty.intervals = 1, lty.separator = 3,
%        ylab = "Observed / Fitted",
%        main = "Holt-Winters filtering",
%        ylim = NULL, \dots)
%}
%\arguments{
%  \item{x}{Object of class \code{"HoltWinters"}}
%  \item{predicted.values}{Predicted values as returned by \code{predict.HoltWinters}}
%  \item{intervals}{If \code{TRUE}, the prediction intervals are plotted (default).}
%  \item{separator}{If \code{TRUE}, a separating line between fitted and predicted values is plotted (default).}
%  \item{col, lty}{Color/line type of original data (default: black solid).}
%  \item{col.predicted, lty.predicted}{Color/line type of
%    fitted and predicted values (default: red solid).}
%  \item{col.intervals, lty.intervals}{Color/line type of prediction
%    intervals (default: blue solid).}
%  \item{col.separator, lty.separator}{Color/line type of
%    observed/predicted values separator (default: black dashed).}
%  \item{ylab}{Label of the y-axis.}
%  \item{main}{Main title.}
%  \item{ylim}{Limits of the y-axis. If \code{NULL}, the range is chosen
%    such that the plot contains the original series, the fitted values,
%    and the predicted values if any.}
%  \item{\dots}{Other graphics parameters.}
%}
%\references{
%  C. C. Holt (1957)
%  Forecasting trends and seasonals by exponentially weighted
%  moving averages,
%  \emph{ONR Research Memorandum, Carnegie Institute of Technology} \bold{52}.
%
%  P. R. Winters (1960)
%  Forecasting sales by exponentially weighted moving averages,
%  \emph{Management Science} \bold{6}, 324--342.
%}
%\author{
%  David Meyer \email{David.Meyer@wu.ac.at}
%}
%\seealso{
%  \code{\link{HoltWinters}}, \code{\link{predict.HoltWinters}}
%}
%
%\keyword{ts}
%
%\encoding{UTF-8}
%
