% File src/library/stats/man/predict.loess.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{predict.loess}
\alias{predict.loess}%@%\alias{Loess 平滑化からの予測}
\title{Predict Loess Curve or Surface}
\description{
 \code{loess} 当てはめからの予測，オプションで標準偏差が付く．
}
\usage{
\method{predict}{loess}(object, newdata = NULL, se = FALSE,
        na.action = na.pass, \dots)
}
\arguments{
  \item{object}{\code{loess} で当てはめられたオブジェクト．}
  \item{newdata}{
    それを使い予測する変数を探すオプションのデータフレーム，
    又は予測に必要な変数を正確に含む行列かベクトル．
    もしなければオリジナルのデータ点が使われる．}
  \item{se}{標準偏差を計算すべきか?}
  \item{na.action}{
    データフレーム \code{newdata} 中に欠損値があった場合
    何をすべきかを決める関数．既定は \code{NA} を予測．}
  \item{\dots}{メソッドに・から渡される引数．}
}
\details{
  標準偏差の計算は予測よりも遅い．

  当てはめが \code{surface = "interpolate"} (既定)を
  用いて行われた時は \code{predict.loess} は外挿をしない
  -- 従ってオリジナルのデータを囲む軸に平行な超矩形の外の
  点は欠損(\code{NA})予測値と標準偏差を持つ．
}
\value{
  もし \code{se = FALSE} ならば，
  \code{newdata} の各行(又はオリジナルデータ)に対する予測値を与える
  ベクトル．もし \code{se = TRUE} ならば，次の成分を含むリスト
  \item{fit}{予測値．}
  \item{se}{各予測値に対する推定標準誤差．}
  \item{residual.scale}{標準偏差の計算で使われた残差の推定スケール．}
  \item{df}{残差のスケールの推定で使われた実効的自由度の推定値で，
    t 分布に基づく信頼区間で使われることを意図している．}

  もし \code{newdata} が
  \code{\link{expand.grid}} への呼び出しの結果であれば，予測
  (と要求されれば標準偏差)は適当な次元の配列になる．

  \code{loess} は外挿をサポートしていないため無限の入力は
  \code{NA} になる．
}
\author{
  B. D. Ripley，  Cleveland, Grosse and Shyu のパッケージ \code{cloess}
  に基づく．
}
\note{
  変数は最初
  \code{newdata} で探され，次に通常の仕方で探される
  (当てはめに使われた公式の環境も含まれる)．
  見つかった変数が
  (もし提供されていたならば) \code{newdata} 中のそれらと長さが異なれば
  警告が出る．
}

\seealso{\code{\link{loess}}}

\examples{
cars.lo <- loess(dist ~ speed, cars)
predict(cars.lo, data.frame(speed = seq(5, 30, 1)), se = TRUE)
# 外挿を得るために
cars.lo2 <- loess(dist ~ speed, cars,
  control = loess.control(surface = "direct"))
predict(cars.lo2, data.frame(speed = seq(5, 30, 1)), se = TRUE)
}
\keyword{smooth}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/predict.loess.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{predict.loess}
%\alias{predict.loess}
%\title{Predict Loess Curve or Surface}
%\description{
% Predictions from a \code{loess} fit, optionally with standard errors.
%}
%\usage{
%\method{predict}{loess}(object, newdata = NULL, se = FALSE,
%        na.action = na.pass, \dots)
%}
%\arguments{
%  \item{object}{an object fitted by \code{loess}.}
%  \item{newdata}{an optional data frame in which to look for variables with
%    which to predict, or a matrix or vector containing exactly the variables
%    needs for prediction.  If missing, the original data points are used.}
%  \item{se}{should standard errors be computed?}
%  \item{na.action}{function determining what should be done with missing
%    values in data frame \code{newdata}.  The default is to predict \code{NA}.}
%  \item{\dots}{arguments passed to or from other methods.}
%}
%\details{
%  The standard errors calculation is slower than prediction.
%
%  When the fit was made using \code{surface = "interpolate"} (the
%  default), \code{predict.loess} will not extrapolate -- so points outside
%  an axis-aligned hypercube enclosing the original data will have
%  missing (\code{NA}) predictions and standard errors.
%}
%\value{
%  If \code{se = FALSE}, a vector giving the prediction for each row of
%  \code{newdata} (or the original data). If \code{se = TRUE}, a list
%  containing components
%  \item{fit}{the predicted values.}
%  \item{se}{an estimated standard error for each predicted value.}
%  \item{residual.scale}{the estimated scale of the residuals used in
%    computing the standard errors.}
%  \item{df}{an estimate of the effective degrees of freedom used in
%    estimating the residual scale, intended for use with t-based
%    confidence intervals. }
%  If \code{newdata} was the result of a call to
%  \code{\link{expand.grid}}, the predictions (and s.e.'s if requested)
%  will be an array of the appropriate dimensions.
%
%  Predictions from infinite inputs will be \code{NA} since \code{loess}
%  does not support extrapolation.
%}
%\author{
%  B. D. Ripley, based on the \code{cloess} package of Cleveland,
%  Grosse and Shyu.
%}
%\note{
%  Variables are first looked for in \code{newdata} and then searched for
%  in the usual way (which will include the environment of the formula
%  used in the fit).  A warning will be given if the
%  variables found are not of the same length as those in \code{newdata}
%  if it was supplied.
%}
%
%\seealso{\code{\link{loess}}}
%
%\examples{
%cars.lo <- loess(dist ~ speed, cars)
%predict(cars.lo, data.frame(speed = seq(5, 30, 1)), se = TRUE)
%# to get extrapolation
%cars.lo2 <- loess(dist ~ speed, cars,
%  control = loess.control(surface = "direct"))
%predict(cars.lo2, data.frame(speed = seq(5, 30, 1)), se = TRUE)
%}
%\keyword{smooth}
%
%\encoding{UTF-8}
%
