% File src/library/stats/man/reorder.factor.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2016 R Core Team
% Distributed under GPL 2 or later

\name{reorder.default}
\alias{reorder}%@%\alias{因子の水準を並べ替える}
\alias{reorder.default}
\title{Reorder Levels of a Factor}
\description{
  \code{reorder} は総称的関数である．
  既定メソッドはその第一引数としてカテゴリカル変数を取り，
  その水準を普通数値である第二引数の値に基づいて並べ替える．
}

\usage{
reorder(x, \dots)

\method{reorder}{default}(x, X, FUN = mean, \dots,
        order = is.ordered(x))

}
\arguments{
  \item{x}{原子的ベクトルで，普通因子
    (順序付きかもしれない)．
    ベクトルはその水準が並べ替えられるカテゴリカルな変数と
    して扱われる．
    もし \code{x} が因子でなければ，そのユニークな値が
    暗黙の水準として使われる．
  }
  \item{X}{
    \code{x} と同じ長さのベクトルで，
    \code{x} のユニークな各要素に対する値の部分集合が
    最終的な水準の順序を決める．
  }
  \item{FUN}{
    その最初の引数がベクトルでスカラを返す関数で，
    \code{x} の水準で決まる \code{X} の各部分集合に適用される．}
  \item{\dots}{オプション：\code{FUN} に提供されるその他の引数．}
  \item{order}{論理値，返り値は因子でなく順序付き因子かどうか．}
}
\value{
  因子又は順序付き因子
  (\code{order} の値に依る)で，
  \code{x} でグループ化された
  \code{X} に適用された \code{FUN} で決まる
  水準の順序を持つ．水準は
  \code{FUN} が返した値が増加順であるように順序が付く．
  空の水準は除かれる．

  加えて，\code{X} の部分集合に適用された \code{FUN} の値
  (\code{x} の水準のオリジナルの順序で)が
  \code{"scores"} 属性として返される．
}
\details{
  これは \code{\link{relevel}()} のように単に
  \code{\link{factor}(x, levels = levels(x)[....])} を呼び出す
  特殊なケースである．
}
\author{Deepayan Sarkar \email{deepayan.sarkar@r-project.org}}

\seealso{
  \code{\link{reorder.dendrogram}}, \code{\link{levels}},
  \code{\link{relevel}}.
}

\examples{
require(graphics)

bymedian <- with(InsectSprays, reorder(spray, count, median))
boxplot(count ~ bymedian, data = InsectSprays,
        xlab = "Type of spray", ylab = "Insect count",
        main = "InsectSprays data", varwidth = TRUE,
        col = "lightgray")
}
\keyword{utilities}


\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/reorder.factor.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2016 R Core Team
%% Distributed under GPL 2 or later
%
%\name{reorder.default}
%\alias{reorder}
%\alias{reorder.default}
%\title{Reorder Levels of a Factor}
%\description{
%  \code{reorder} is a generic function.  The \code{"default"} method
%  treats its first argument as a categorical variable, and reorders its
%  levels based on the values of a second variable, usually numeric.
%}
%
%\usage{
%reorder(x, \dots)
%
%\method{reorder}{default}(x, X, FUN = mean, \dots,
%        order = is.ordered(x))
%
%}
%\arguments{
%  \item{x}{an atomic vector, usually a \code{\link{factor}} (possibly
%    ordered).  The vector is treated as a categorical variable whose
%    levels will be reordered.  If \code{x} is not a factor, its unique
%    values will be used as the implicit levels.
%  }
%  \item{X}{ a vector of the same length as \code{x}, whose subset
%    of values for each unique level of \code{x} determines the
%    eventual order of that level.
%  }
%  \item{FUN}{a \code{\link{function}} whose first argument is a vector
%    and returns a scalar, to be applied to each subset of \code{X}
%    determined by the levels of \code{x}.}
%  \item{\dots}{ optional: extra arguments supplied to \code{FUN}}
%  \item{order}{ logical, whether return value will be an ordered factor
%    rather than a factor.
%  }
%}
%
%\value{
%  A factor or an ordered factor (depending on the value of
%  \code{order}), with the order of the levels determined by
%  \code{FUN} applied to \code{X} grouped by \code{x}.  The
%  levels are ordered such that the values returned by \code{FUN}
%  are in increasing order.  Empty levels will be dropped.
%
%  Additionally, the values of \code{FUN} applied to the subsets of
%  \code{X} (in the original order of the levels of \code{x}) is returned
%  as the \code{"scores"} attribute.
%}
%\details{
%  This, as \code{\link{relevel}()}, is a special case of simply calling
%  \code{\link{factor}(x, levels = levels(x)[....])}.
%}
%\author{Deepayan Sarkar \email{deepayan.sarkar@r-project.org}}
%
%\seealso{
%  \code{\link{reorder.dendrogram}}, \code{\link{levels}},
%  \code{\link{relevel}}.
%}
%
%\examples{
%require(graphics)
%
%bymedian <- with(InsectSprays, reorder(spray, count, median))
%boxplot(count ~ bymedian, data = InsectSprays,
%        xlab = "Type of spray", ylab = "Insect count",
%        main = "InsectSprays data", varwidth = TRUE,
%        col = "lightgray")
%}
%\keyword{utilities}
%
%
%\encoding{UTF-8}
%
