% File src/library/stats/man/update.formula.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{update.formula}
\alias{update.formula}%@%\alias{モデルの更新}
\title{Model Updating}
\usage{
\method{update}{formula}(old, new, \dots)
}
\arguments{
  \item{old}{更新されるべきモデル公式．}
  \item{new}{どのように更新するかを指示するテンプレートを与える公式．}
  \item{\dots}{他のメソッドに・から渡される追加引数．}
}
\description{
  \code{update.formula} はモデル公式を更新するのに使われる．
  これは典型的には項を付け加えたり取り去ったりするが，
  更新はもっと一般的であり得る．
}
\details{
  \code{old} と \code{new} のどちらか又は双方は
  \code{\link{as.formula}} により公式に強制変換出来る長さ1の
  文字列ベクトルのオブジェクトで良い．

  関数は先ず
  \code{old} 公式の\emph{左側}と
  \emph{右側}を特定する．
  それから
  \code{new} 公式を吟味し
  \code{old} 公式の \emph{lhs} に
  \code{new} の左側の任意の \sQuote{.} 中のものを
  代入し，そして
  \code{old} 公式の \emph{rhs} に
  \code{new} の右側の任意の \sQuote{.} 中のものを
  代入する．結果はそれから
  \code{\link{terms.formula}(simplify = TRUE)} で簡略化される．
}
\value{
  更新された公式が返される．
  結果の環境は \code{old} のそれである．
}
\seealso{
  \code{\link{terms}}, \code{\link{model.matrix}}.
}
\examples{
update(y ~ x,    ~ . + x2) #> y ~ x + x2
update(y ~ x, log(.) ~ . ) #> log(y) ~ x
update(. ~ u+v, res  ~ . ) #> res ~ u + v
}
\keyword{models}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/update.formula.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{update.formula}
%\alias{update.formula}
%\title{Model Updating}
%\usage{
%\method{update}{formula}(old, new, \dots)
%}
%\arguments{
%  \item{old}{a model formula to be updated.}
%  \item{new}{a formula giving a template which specifies how to update.}
%  \item{\dots}{further arguments passed to or from other methods.}
%}
%\description{
%  \code{update.formula} is used to update model formulae.
%  This typically involves adding or dropping terms,
%  but updates can be more general.
%}
%\details{
%  Either or both of \code{old} and \code{new} can be objects such as
%  length-one character vectors which can be coerced to a formula via
%  \code{\link{as.formula}}.
%
%  The function works by first identifying the \emph{left-hand side}
%  and \emph{right-hand side} of the \code{old} formula.
%  It then examines the \code{new} formula and substitutes
%  the \emph{lhs} of the \code{old} formula for any occurrence
%  of \sQuote{.} on the left of \code{new}, and substitutes
%  the \emph{rhs} of the \code{old} formula for any occurrence
%  of \sQuote{.} on the right of \code{new}.  The result is then
%  simplified \emph{via} \code{\link{terms.formula}(simplify = TRUE)}.
%}
%\value{
%  The updated formula is returned.  The environment of the result is
%  that of \code{old}.
%}
%\seealso{
%  \code{\link{terms}}, \code{\link{model.matrix}}.
%}
%\examples{
%update(y ~ x,    ~ . + x2) #> y ~ x + x2
%update(y ~ x, log(.) ~ . ) #> log(y) ~ x
%update(. ~ u+v, res  ~ . ) #> res ~ u + v
%}
%\keyword{models}
%
%\encoding{UTF-8}
%
