% File src/library/stats/man/xtabs.Rd
% Part of the R package, https://www.R-project.org
% Copyright 1995-2014 R Core Team
% Distributed under GPL 2 or later

\name{xtabs}
\alias{xtabs}%@%\alias{クロス分割表}
\alias{print.xtabs}
\title{Cross Tabulation}
\description{
  公式インタフェイスを使い，普通データフレーム中に
  含まれるクロス分類因子から分割表を作る
  (オプションで疎行列)．
}
\usage{
xtabs(formula = ~., data = parent.frame(), subset, sparse = FALSE,
      na.action, exclude = c(NA, NaN), drop.unused.levels = FALSE)
}
\arguments{
  \item{formula}{公式オブジェクトで，
    右辺に(\code{+} で分離された)クロス分類変数
    を持つ(又は公式に変換できるオブジェクト)．
    交互作用は許されない．
    左辺にはオプションでカウントのベクトル又は行列を与えることが出来る：
    後者の場合列は変数の水準と解釈される．
    これはもしデータが既に表化されている場合に有用である，
    下の例を見よ．}
  \item{data}{
    公式 \code{formula} 中の変数を含むオプションの行列かデータフレーム(又は類似物：
    \code{\link{model.frame}} を見よ)
    既定では変数は \code{environment(formula)} から取られる．}
  \item{subset}{使用される観測値の部分集合を指定するオプションのベクトル．}
  \item{sparse}{
    結果を疎な行列にするかどうかを指示する論理値，つまり
    \code{\link[Matrix:sparseMatrix-class]{sparseMatrix}}
    を継承するオブジェクト．%\linkS4class{sparseMatrix}.
    二因子に対してだけ使える
    (まだ高次の疎配列クラスは無いため)．
  }
  \item{na.action}{
    データが \code{NA} を含むときに何が起きるかを指示する関数．}
  \item{exclude}{
    分類因子の水準セットを作る際除外されるべき値のベクトル．}
  \item{drop.unused.levels}{
    分類因子から未使用の水準を捨て去るかどうかを指示する論理値．
    もしこれが \code{FALSE} で未使用の水準があれば，
    表はゼロの周辺和を持ち，
    引き続く独立性のカイ二乗検定は使えない．}
}
\details{
  \code{table} か \code{xtabs(*, sparse = FALSE)} で作られた
  分割表に対しては \code{summary} メソッドがあり，
  これは基本情報を与え独立性に対するカイ二乗検定を実行する
  (関数 \code{\link{chisq.test}} は現在2次元の表だけを扱う)．

  \code{formula} 中に左辺があれば，その項目は単に右辺に
  対応するセルに集計される；
  これはまた左辺がカウントを与えなくても動作する．
  
  因子である \code{formula} 中の変数に対しては，
  \code{exclude} は明示的に指定される必要がある；
  既定の除外は使われない．
}
\value{
  B既定では，\code{sparse = FALSE} の時，
  S3 クラス \code{c("xtabs", "table")} の配列表現の分割表で，
  マッチした呼び出しを保管する \code{"call"} 属性を持つ．

  \code{sparse = TRUE} の時は，疎な数値行列で，具体的には
  パッケージ \CRANpkg{Matrix} からの S4 クラス
  \code{\link[Matrix:dgTMatrix-class]{dgTMatrix}} のオブジェクト．
  
}
\seealso{
  伝統的なクロス分割には \code{\link{table}}，そして
  \code{xtabs} の逆操作である
  \code{\link{as.data.frame.table}} 
  (下の \code{DF} 例を見よ)．

  パッケージ \CRANpkg{Matrix} 中の疎行列に関する
  \code{\link[Matrix:sparseMatrix-class]{sparseMatrix}}．
}
\examples{
## 'esoph' は変数 'agegp', 'alcgp' そして 'tobgp' の全ての
## 水準に対してケースと制御の頻度を持つ
## 
xtabs(cbind(ncases, ncontrols) ~ ., data = esoph)
## 出力は実際は役に立たない ... フラットな表のほうが良い：
ftable(xtabs(cbind(ncases, ncontrols) ~ ., data = esoph))
## 特により少ない因子があれば ...
ftable(xtabs(cbind(ncases, ncontrols) ~ agegp, data = esoph))

## これは既に配列形式の分割表である
DF <- as.data.frame(UCBAdmissions)
## 新しい 'DF' は変数 'Freq' 中の因子とカウントのグリッドを持つデータフレーム
## in variable 'Freq'.
DF
## 周辺和を取るのに便利 ...
xtabs(Freq ~ Gender + Admit, DF)
## そして独立性の検定にも ...
summary(xtabs(Freq ~ ., DF))

## 縦糸の切断データに対する良い表示を作る．
warpbreaks$replicate <- rep(1:9, len = 54)
ftable(xtabs(breaks ~ wool + tension + replicate, data = warpbreaks))

### ---- 疎な例 ----

\donttest{if(require("Matrix")) {
 ## "nlme" の 'ergoStool' に類似：
 d.ergo <- data.frame(Type = paste0("T", rep(1:4, 9*4)),
                      Subj = gl(9, 4, 36*4))
 print(xtabs(~ Type + Subj, data = d.ergo)) # 各々4回の繰り返し
 set.seed(15) # ケースの一部分：
 print(xtabs(~ Type + Subj, data = d.ergo[sample(36, 10), ], sparse = TRUE))

 ## 仮説的な二水準設定：
 inner <- factor(sample(letters[1:25], 100, replace = TRUE))
 inout <- factor(sample(LETTERS[1:5], 25, replace = TRUE))
 fr <- data.frame(inner = inner, outer = inout[as.integer(inner)])
 print(xtabs(~ inner + outer, fr, sparse = TRUE))
}}% only if Matrix is available
}
\keyword{category}

\encoding{UTF-8}
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% File src/library/stats/man/xtabs.Rd
%% Part of the R package, https://www.R-project.org
%% Copyright 1995-2014 R Core Team
%% Distributed under GPL 2 or later
%
%\name{xtabs}
%\alias{xtabs}
%\alias{print.xtabs}
%\title{Cross Tabulation}
%\description{
%  Create a contingency table (optionally a sparse matrix) from
%  cross-classifying factors, usually contained in a data frame,
%  using a formula interface.
%}
%\usage{
%xtabs(formula = ~., data = parent.frame(), subset, sparse = FALSE,
%      na.action, exclude = c(NA, NaN), drop.unused.levels = FALSE)
%}
%\arguments{
%  \item{formula}{a \link{formula} object with the cross-classifying variables
%    (separated by \code{+}) on the right hand side (or an object which
%    can be coerced to a formula).  Interactions are not allowed.  On the
%    left hand side, one may optionally give a vector or a matrix of
%    counts; in the latter case, the columns are interpreted as
%    corresponding to the levels of a variable.  This is useful if the
%    data have already been tabulated, see the examples below.}
%  \item{data}{an optional matrix or data frame (or similar: see
%    \code{\link{model.frame}}) containing the variables in the
%    formula \code{formula}.  By default the variables are taken from
%    \code{environment(formula)}.}
%  \item{subset}{an optional vector specifying a subset of observations
%    to be used.}
%  \item{sparse}{logical specifying if the result should be a
%    \emph{sparse} matrix, i.e., inheriting from
%    \code{\link[Matrix:sparseMatrix-class]{sparseMatrix}}%\linkS4class{sparseMatrix}.
%    Only works for two factors (since there
%    are no higher-order sparse array classes yet).
%  }
%  \item{na.action}{a function which indicates what should happen when
%    the data contain \code{NA}s.}
%  \item{exclude}{a vector of values to be excluded when forming the
%    set of levels of the classifying factors.}
%  \item{drop.unused.levels}{a logical indicating whether to drop unused
%    levels in the classifying factors.  If this is \code{FALSE} and
%    there are unused levels, the table will contain zero marginals, and
%    a subsequent chi-squared test for independence of the factors will
%    not work.}
%}
%\details{
%  There is a \code{summary} method for contingency table objects created
%  by \code{table} or \code{xtabs(*, sparse = FALSE)}, which gives basic
%  information and performs a chi-squared test for independence of
%  factors (note that the function \code{\link{chisq.test}} currently
%  only handles 2-d tables).
%
%  If a left hand side is given in \code{formula}, its entries are simply
%  summed over the cells corresponding to the right hand side; this also
%  works if the lhs does not give counts.
%  
%  For variables in \code{formula} which are factors, \code{exclude}
%  must be specified explicitly; the default exclusions will not be used.  
%}
%\value{
%  By default, when \code{sparse = FALSE},
%  a contingency table in array representation of S3 class \code{c("xtabs",
%    "table")}, with a \code{"call"} attribute storing the matched call.
%
%  When \code{sparse = TRUE}, a sparse numeric matrix, specifically an
%  object of S4 class %\linkS4class{dgTMatrix}
%  \code{\link[Matrix:dgTMatrix-class]{dgTMatrix}} from package
%  \CRANpkg{Matrix}.
%}
%\seealso{
%  \code{\link{table}} for traditional cross-tabulation, and
%  \code{\link{as.data.frame.table}} which is the inverse operation of
%  \code{xtabs} (see the \code{DF} example below).
%
%  \code{\link[Matrix:sparseMatrix-class]{sparseMatrix}} on sparse
%  matrices in package \CRANpkg{Matrix}.
%}
%\examples{
%## 'esoph' has the frequencies of cases and controls for all levels of
%## the variables 'agegp', 'alcgp', and 'tobgp'.
%xtabs(cbind(ncases, ncontrols) ~ ., data = esoph)
%## Output is not really helpful ... flat tables are better:
%ftable(xtabs(cbind(ncases, ncontrols) ~ ., data = esoph))
%## In particular if we have fewer factors ...
%ftable(xtabs(cbind(ncases, ncontrols) ~ agegp, data = esoph))
%
%## This is already a contingency table in array form.
%DF <- as.data.frame(UCBAdmissions)
%## Now 'DF' is a data frame with a grid of the factors and the counts
%## in variable 'Freq'.
%DF
%## Nice for taking margins ...
%xtabs(Freq ~ Gender + Admit, DF)
%## And for testing independence ...
%summary(xtabs(Freq ~ ., DF))
%
%## Create a nice display for the warp break data.
%warpbreaks$replicate <- rep(1:9, len = 54)
%ftable(xtabs(breaks ~ wool + tension + replicate, data = warpbreaks))
%
%### ---- Sparse Examples ----
%
%\donttest{if(require("Matrix")) {
% ## similar to "nlme"s  'ergoStool' :
% d.ergo <- data.frame(Type = paste0("T", rep(1:4, 9*4)),
%                      Subj = gl(9, 4, 36*4))
% print(xtabs(~ Type + Subj, data = d.ergo)) # 4 replicates each
% set.seed(15) # a subset of cases:
% print(xtabs(~ Type + Subj, data = d.ergo[sample(36, 10), ], sparse = TRUE))
%
% ## Hypothetical two-level setup:
% inner <- factor(sample(letters[1:25], 100, replace = TRUE))
% inout <- factor(sample(LETTERS[1:5], 25, replace = TRUE))
% fr <- data.frame(inner = inner, outer = inout[as.integer(inner)])
% print(xtabs(~ inner + outer, fr, sparse = TRUE))
%}}% only if Matrix is available
%}
%\keyword{category}
%
%\encoding{UTF-8}
%
